/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db_streaminputs.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db_streaminputs.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db_streaminputs.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14DbStreamInputsE_t {};
} // unnamed namespace

template <> constexpr inline auto DbStreamInputs::qt_create_metaobjectdata<qt_meta_tag_ZN14DbStreamInputsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbStreamInputs",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "pluginsChanged",
        "",
        "useDefaultInputDeviceChanged",
        "inputDeviceChanged",
        "blocklistChanged",
        "showBlocklistedAppsChanged",
        "blocklistUsesMediaNameChanged",
        "showPluginsListChanged",
        "visiblePageChanged",
        "visiblePluginChanged",
        "listenToMicChanged",
        "listenToMicIncludesOutputEffectsChanged",
        "usedPresetsChanged",
        "mostUsedPresetsChanged",
        "pluginsListWidthChanged",
        "plugins",
        "isPluginsImmutable",
        "useDefaultInputDevice",
        "isUseDefaultInputDeviceImmutable",
        "defaultUseDefaultInputDeviceValue",
        "inputDevice",
        "isInputDeviceImmutable",
        "defaultInputDeviceValue",
        "blocklist",
        "isBlocklistImmutable",
        "showBlocklistedApps",
        "isShowBlocklistedAppsImmutable",
        "defaultShowBlocklistedAppsValue",
        "blocklistUsesMediaName",
        "isBlocklistUsesMediaNameImmutable",
        "defaultBlocklistUsesMediaNameValue",
        "showPluginsList",
        "isShowPluginsListImmutable",
        "defaultShowPluginsListValue",
        "visiblePage",
        "isVisiblePageImmutable",
        "defaultVisiblePageValue",
        "visiblePlugin",
        "isVisiblePluginImmutable",
        "defaultVisiblePluginValue",
        "listenToMic",
        "isListenToMicImmutable",
        "defaultListenToMicValue",
        "listenToMicIncludesOutputEffects",
        "isListenToMicIncludesOutputEffectsImmutable",
        "defaultListenToMicIncludesOutputEffectsValue",
        "usedPresets",
        "isUsedPresetsImmutable",
        "mostUsedPresets",
        "isMostUsedPresetsImmutable",
        "pluginsListWidth",
        "isPluginsListWidthImmutable",
        "defaultPluginsListWidthValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pluginsChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useDefaultInputDeviceChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputDeviceChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blocklistChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showBlocklistedAppsChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blocklistUsesMediaNameChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showPluginsListChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visiblePageChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visiblePluginChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'listenToMicChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'listenToMicIncludesOutputEffectsChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'usedPresetsChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mostUsedPresetsChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pluginsListWidthChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'plugins'
        QtMocHelpers::PropertyData<QStringList>(20, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isPluginsImmutable'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useDefaultInputDevice'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isUseDefaultInputDeviceImmutable'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultUseDefaultInputDeviceValue'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputDevice'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isInputDeviceImmutable'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputDeviceValue'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'blocklist'
        QtMocHelpers::PropertyData<QStringList>(28, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isBlocklistImmutable'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showBlocklistedApps'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isShowBlocklistedAppsImmutable'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowBlocklistedAppsValue'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'blocklistUsesMediaName'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isBlocklistUsesMediaNameImmutable'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBlocklistUsesMediaNameValue'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showPluginsList'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isShowPluginsListImmutable'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowPluginsListValue'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'visiblePage'
        QtMocHelpers::PropertyData<int>(39, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isVisiblePageImmutable'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVisiblePageValue'
        QtMocHelpers::PropertyData<int>(41, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'visiblePlugin'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isVisiblePluginImmutable'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVisiblePluginValue'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'listenToMic'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isListenToMicImmutable'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultListenToMicValue'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'listenToMicIncludesOutputEffects'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isListenToMicIncludesOutputEffectsImmutable'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultListenToMicIncludesOutputEffectsValue'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'usedPresets'
        QtMocHelpers::PropertyData<QStringList>(51, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isUsedPresetsImmutable'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mostUsedPresets'
        QtMocHelpers::PropertyData<QStringList>(53, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isMostUsedPresetsImmutable'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pluginsListWidth'
        QtMocHelpers::PropertyData<int>(55, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isPluginsListWidthImmutable'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPluginsListWidthValue'
        QtMocHelpers::PropertyData<int>(57, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DbStreamInputs, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbStreamInputs::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14DbStreamInputsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14DbStreamInputsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14DbStreamInputsE_t>.metaTypes,
    nullptr
} };

void DbStreamInputs::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbStreamInputs *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pluginsChanged(); break;
        case 1: _t->useDefaultInputDeviceChanged(); break;
        case 2: _t->inputDeviceChanged(); break;
        case 3: _t->blocklistChanged(); break;
        case 4: _t->showBlocklistedAppsChanged(); break;
        case 5: _t->blocklistUsesMediaNameChanged(); break;
        case 6: _t->showPluginsListChanged(); break;
        case 7: _t->visiblePageChanged(); break;
        case 8: _t->visiblePluginChanged(); break;
        case 9: _t->listenToMicChanged(); break;
        case 10: _t->listenToMicIncludesOutputEffectsChanged(); break;
        case 11: _t->usedPresetsChanged(); break;
        case 12: _t->mostUsedPresetsChanged(); break;
        case 13: _t->pluginsListWidthChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbStreamInputs::*)()>(_a, &DbStreamInputs::pluginsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStreamInputs::*)()>(_a, &DbStreamInputs::useDefaultInputDeviceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStreamInputs::*)()>(_a, &DbStreamInputs::inputDeviceChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStreamInputs::*)()>(_a, &DbStreamInputs::blocklistChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStreamInputs::*)()>(_a, &DbStreamInputs::showBlocklistedAppsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStreamInputs::*)()>(_a, &DbStreamInputs::blocklistUsesMediaNameChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStreamInputs::*)()>(_a, &DbStreamInputs::showPluginsListChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStreamInputs::*)()>(_a, &DbStreamInputs::visiblePageChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStreamInputs::*)()>(_a, &DbStreamInputs::visiblePluginChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStreamInputs::*)()>(_a, &DbStreamInputs::listenToMicChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStreamInputs::*)()>(_a, &DbStreamInputs::listenToMicIncludesOutputEffectsChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStreamInputs::*)()>(_a, &DbStreamInputs::usedPresetsChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStreamInputs::*)()>(_a, &DbStreamInputs::mostUsedPresetsChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStreamInputs::*)()>(_a, &DbStreamInputs::pluginsListWidthChanged, 13))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->plugins(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isPluginsImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->useDefaultInputDevice(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isUseDefaultInputDeviceImmutable(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->defaultUseDefaultInputDeviceValue(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->inputDevice(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isInputDeviceImmutable(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->defaultInputDeviceValue(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->blocklist(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isBlocklistImmutable(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->showBlocklistedApps(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isShowBlocklistedAppsImmutable(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->defaultShowBlocklistedAppsValue(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->blocklistUsesMediaName(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->isBlocklistUsesMediaNameImmutable(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->defaultBlocklistUsesMediaNameValue(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->showPluginsList(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->isShowPluginsListImmutable(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->defaultShowPluginsListValue(); break;
        case 19: *reinterpret_cast<int*>(_v) = _t->visiblePage(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->isVisiblePageImmutable(); break;
        case 21: *reinterpret_cast<int*>(_v) = _t->defaultVisiblePageValue(); break;
        case 22: *reinterpret_cast<QString*>(_v) = _t->visiblePlugin(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->isVisiblePluginImmutable(); break;
        case 24: *reinterpret_cast<QString*>(_v) = _t->defaultVisiblePluginValue(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->listenToMic(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->isListenToMicImmutable(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->defaultListenToMicValue(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->listenToMicIncludesOutputEffects(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->isListenToMicIncludesOutputEffectsImmutable(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->defaultListenToMicIncludesOutputEffectsValue(); break;
        case 31: *reinterpret_cast<QStringList*>(_v) = _t->usedPresets(); break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->isUsedPresetsImmutable(); break;
        case 33: *reinterpret_cast<QStringList*>(_v) = _t->mostUsedPresets(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isMostUsedPresetsImmutable(); break;
        case 35: *reinterpret_cast<int*>(_v) = _t->pluginsListWidth(); break;
        case 36: *reinterpret_cast<bool*>(_v) = _t->isPluginsListWidthImmutable(); break;
        case 37: *reinterpret_cast<int*>(_v) = _t->defaultPluginsListWidthValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPlugins(*reinterpret_cast<QStringList*>(_v)); break;
        case 2: _t->setUseDefaultInputDevice(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setInputDevice(*reinterpret_cast<QString*>(_v)); break;
        case 8: _t->setBlocklist(*reinterpret_cast<QStringList*>(_v)); break;
        case 10: _t->setShowBlocklistedApps(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setBlocklistUsesMediaName(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setShowPluginsList(*reinterpret_cast<bool*>(_v)); break;
        case 19: _t->setVisiblePage(*reinterpret_cast<int*>(_v)); break;
        case 22: _t->setVisiblePlugin(*reinterpret_cast<QString*>(_v)); break;
        case 25: _t->setListenToMic(*reinterpret_cast<bool*>(_v)); break;
        case 28: _t->setListenToMicIncludesOutputEffects(*reinterpret_cast<bool*>(_v)); break;
        case 31: _t->setUsedPresets(*reinterpret_cast<QStringList*>(_v)); break;
        case 33: _t->setMostUsedPresets(*reinterpret_cast<QStringList*>(_v)); break;
        case 35: _t->setPluginsListWidth(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbStreamInputs::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbStreamInputs::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14DbStreamInputsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbStreamInputs::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    return _id;
}

// SIGNAL 0
void DbStreamInputs::pluginsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbStreamInputs::useDefaultInputDeviceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbStreamInputs::inputDeviceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbStreamInputs::blocklistChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DbStreamInputs::showBlocklistedAppsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DbStreamInputs::blocklistUsesMediaNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DbStreamInputs::showPluginsListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DbStreamInputs::visiblePageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DbStreamInputs::visiblePluginChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DbStreamInputs::listenToMicChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DbStreamInputs::listenToMicIncludesOutputEffectsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DbStreamInputs::usedPresetsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void DbStreamInputs::mostUsedPresetsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void DbStreamInputs::pluginsListWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}
QT_WARNING_POP
