/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db_limiter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db_limiter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db_limiter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9DbLimiterE_t {};
} // unnamed namespace

template <> constexpr inline auto DbLimiter::qt_create_metaobjectdata<qt_meta_tag_ZN9DbLimiterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbLimiter",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "bypassChanged",
        "inputGainChanged",
        "outputGainChanged",
        "modeLabelsChanged",
        "modeChanged",
        "oversamplingLabelsChanged",
        "oversamplingChanged",
        "ditheringLabelsChanged",
        "ditheringChanged",
        "sidechainTypeLabelsChanged",
        "sidechainTypeChanged",
        "lookaheadChanged",
        "attackChanged",
        "releaseChanged",
        "thresholdChanged",
        "gainBoostChanged",
        "sidechainPreampChanged",
        "stereoLinkChanged",
        "alrChanged",
        "alrAttackChanged",
        "alrReleaseChanged",
        "alrKneeChanged",
        "alrKneeSmoothChanged",
        "sidechainInputDeviceChanged",
        "inputToSidechainChanged",
        "inputToLinkChanged",
        "sidechainToInputChanged",
        "sidechainToLinkChanged",
        "linkToSidechainChanged",
        "linkToInputChanged",
        "bypass",
        "isBypassImmutable",
        "defaultBypassValue",
        "inputGain",
        "isInputGainImmutable",
        "defaultInputGainValue",
        "outputGain",
        "isOutputGainImmutable",
        "defaultOutputGainValue",
        "modeLabels",
        "isModeLabelsImmutable",
        "defaultModeLabelsValue",
        "mode",
        "isModeImmutable",
        "defaultModeValue",
        "oversamplingLabels",
        "isOversamplingLabelsImmutable",
        "defaultOversamplingLabelsValue",
        "oversampling",
        "isOversamplingImmutable",
        "defaultOversamplingValue",
        "ditheringLabels",
        "isDitheringLabelsImmutable",
        "defaultDitheringLabelsValue",
        "dithering",
        "isDitheringImmutable",
        "defaultDitheringValue",
        "sidechainTypeLabels",
        "isSidechainTypeLabelsImmutable",
        "defaultSidechainTypeLabelsValue",
        "sidechainType",
        "isSidechainTypeImmutable",
        "defaultSidechainTypeValue",
        "lookahead",
        "isLookaheadImmutable",
        "defaultLookaheadValue",
        "attack",
        "isAttackImmutable",
        "defaultAttackValue",
        "release",
        "isReleaseImmutable",
        "defaultReleaseValue",
        "threshold",
        "isThresholdImmutable",
        "defaultThresholdValue",
        "gainBoost",
        "isGainBoostImmutable",
        "defaultGainBoostValue",
        "sidechainPreamp",
        "isSidechainPreampImmutable",
        "defaultSidechainPreampValue",
        "stereoLink",
        "isStereoLinkImmutable",
        "defaultStereoLinkValue",
        "alr",
        "isAlrImmutable",
        "defaultAlrValue",
        "alrAttack",
        "isAlrAttackImmutable",
        "defaultAlrAttackValue",
        "alrRelease",
        "isAlrReleaseImmutable",
        "defaultAlrReleaseValue",
        "alrKnee",
        "isAlrKneeImmutable",
        "defaultAlrKneeValue",
        "alrKneeSmooth",
        "isAlrKneeSmoothImmutable",
        "defaultAlrKneeSmoothValue",
        "sidechainInputDevice",
        "isSidechainInputDeviceImmutable",
        "defaultSidechainInputDeviceValue",
        "inputToSidechain",
        "isInputToSidechainImmutable",
        "defaultInputToSidechainValue",
        "inputToLink",
        "isInputToLinkImmutable",
        "defaultInputToLinkValue",
        "sidechainToInput",
        "isSidechainToInputImmutable",
        "defaultSidechainToInputValue",
        "sidechainToLink",
        "isSidechainToLinkImmutable",
        "defaultSidechainToLinkValue",
        "linkToSidechain",
        "isLinkToSidechainImmutable",
        "defaultLinkToSidechainValue",
        "linkToInput",
        "isLinkToInputImmutable",
        "defaultLinkToInputValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bypassChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputGainChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputGainChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeLabelsChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'oversamplingLabelsChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'oversamplingChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ditheringLabelsChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ditheringChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainTypeLabelsChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainTypeChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lookaheadChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'attackChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'releaseChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'thresholdChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gainBoostChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainPreampChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stereoLinkChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alrChanged'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alrAttackChanged'
        QtMocHelpers::SignalData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alrReleaseChanged'
        QtMocHelpers::SignalData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alrKneeChanged'
        QtMocHelpers::SignalData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alrKneeSmoothChanged'
        QtMocHelpers::SignalData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainInputDeviceChanged'
        QtMocHelpers::SignalData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputToSidechainChanged'
        QtMocHelpers::SignalData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputToLinkChanged'
        QtMocHelpers::SignalData<void()>(32, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainToInputChanged'
        QtMocHelpers::SignalData<void()>(33, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainToLinkChanged'
        QtMocHelpers::SignalData<void()>(34, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'linkToSidechainChanged'
        QtMocHelpers::SignalData<void()>(35, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'linkToInputChanged'
        QtMocHelpers::SignalData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bypass'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isBypassImmutable'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassValue'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputGain'
        QtMocHelpers::PropertyData<double>(40, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isInputGainImmutable'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputGainValue'
        QtMocHelpers::PropertyData<double>(42, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'outputGain'
        QtMocHelpers::PropertyData<double>(43, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isOutputGainImmutable'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOutputGainValue'
        QtMocHelpers::PropertyData<double>(45, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'modeLabels'
        QtMocHelpers::PropertyData<QStringList>(46, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isModeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultModeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(48, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mode'
        QtMocHelpers::PropertyData<int>(49, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isModeImmutable'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultModeValue'
        QtMocHelpers::PropertyData<int>(51, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'oversamplingLabels'
        QtMocHelpers::PropertyData<QStringList>(52, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isOversamplingLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOversamplingLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(54, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'oversampling'
        QtMocHelpers::PropertyData<int>(55, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isOversamplingImmutable'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOversamplingValue'
        QtMocHelpers::PropertyData<int>(57, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ditheringLabels'
        QtMocHelpers::PropertyData<QStringList>(58, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isDitheringLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDitheringLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(60, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dithering'
        QtMocHelpers::PropertyData<int>(61, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isDitheringImmutable'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDitheringValue'
        QtMocHelpers::PropertyData<int>(63, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainTypeLabels'
        QtMocHelpers::PropertyData<QStringList>(64, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isSidechainTypeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainTypeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(66, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainType'
        QtMocHelpers::PropertyData<int>(67, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isSidechainTypeImmutable'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainTypeValue'
        QtMocHelpers::PropertyData<int>(69, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lookahead'
        QtMocHelpers::PropertyData<double>(70, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isLookaheadImmutable'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLookaheadValue'
        QtMocHelpers::PropertyData<double>(72, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'attack'
        QtMocHelpers::PropertyData<double>(73, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isAttackImmutable'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAttackValue'
        QtMocHelpers::PropertyData<double>(75, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'release'
        QtMocHelpers::PropertyData<double>(76, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isReleaseImmutable'
        QtMocHelpers::PropertyData<bool>(77, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultReleaseValue'
        QtMocHelpers::PropertyData<double>(78, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'threshold'
        QtMocHelpers::PropertyData<double>(79, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(80, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultThresholdValue'
        QtMocHelpers::PropertyData<double>(81, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gainBoost'
        QtMocHelpers::PropertyData<bool>(82, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isGainBoostImmutable'
        QtMocHelpers::PropertyData<bool>(83, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGainBoostValue'
        QtMocHelpers::PropertyData<bool>(84, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainPreamp'
        QtMocHelpers::PropertyData<double>(85, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isSidechainPreampImmutable'
        QtMocHelpers::PropertyData<bool>(86, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainPreampValue'
        QtMocHelpers::PropertyData<double>(87, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stereoLink'
        QtMocHelpers::PropertyData<double>(88, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'isStereoLinkImmutable'
        QtMocHelpers::PropertyData<bool>(89, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultStereoLinkValue'
        QtMocHelpers::PropertyData<double>(90, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alr'
        QtMocHelpers::PropertyData<bool>(91, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'isAlrImmutable'
        QtMocHelpers::PropertyData<bool>(92, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAlrValue'
        QtMocHelpers::PropertyData<bool>(93, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alrAttack'
        QtMocHelpers::PropertyData<double>(94, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'isAlrAttackImmutable'
        QtMocHelpers::PropertyData<bool>(95, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAlrAttackValue'
        QtMocHelpers::PropertyData<double>(96, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alrRelease'
        QtMocHelpers::PropertyData<double>(97, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'isAlrReleaseImmutable'
        QtMocHelpers::PropertyData<bool>(98, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAlrReleaseValue'
        QtMocHelpers::PropertyData<double>(99, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alrKnee'
        QtMocHelpers::PropertyData<double>(100, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'isAlrKneeImmutable'
        QtMocHelpers::PropertyData<bool>(101, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAlrKneeValue'
        QtMocHelpers::PropertyData<double>(102, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alrKneeSmooth'
        QtMocHelpers::PropertyData<double>(103, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'isAlrKneeSmoothImmutable'
        QtMocHelpers::PropertyData<bool>(104, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAlrKneeSmoothValue'
        QtMocHelpers::PropertyData<double>(105, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainInputDevice'
        QtMocHelpers::PropertyData<QString>(106, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'isSidechainInputDeviceImmutable'
        QtMocHelpers::PropertyData<bool>(107, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainInputDeviceValue'
        QtMocHelpers::PropertyData<QString>(108, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputToSidechain'
        QtMocHelpers::PropertyData<double>(109, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'isInputToSidechainImmutable'
        QtMocHelpers::PropertyData<bool>(110, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputToSidechainValue'
        QtMocHelpers::PropertyData<double>(111, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputToLink'
        QtMocHelpers::PropertyData<double>(112, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 25),
        // property 'isInputToLinkImmutable'
        QtMocHelpers::PropertyData<bool>(113, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputToLinkValue'
        QtMocHelpers::PropertyData<double>(114, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainToInput'
        QtMocHelpers::PropertyData<double>(115, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 26),
        // property 'isSidechainToInputImmutable'
        QtMocHelpers::PropertyData<bool>(116, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainToInputValue'
        QtMocHelpers::PropertyData<double>(117, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainToLink'
        QtMocHelpers::PropertyData<double>(118, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 27),
        // property 'isSidechainToLinkImmutable'
        QtMocHelpers::PropertyData<bool>(119, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainToLinkValue'
        QtMocHelpers::PropertyData<double>(120, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'linkToSidechain'
        QtMocHelpers::PropertyData<double>(121, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 28),
        // property 'isLinkToSidechainImmutable'
        QtMocHelpers::PropertyData<bool>(122, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLinkToSidechainValue'
        QtMocHelpers::PropertyData<double>(123, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'linkToInput'
        QtMocHelpers::PropertyData<double>(124, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 29),
        // property 'isLinkToInputImmutable'
        QtMocHelpers::PropertyData<bool>(125, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLinkToInputValue'
        QtMocHelpers::PropertyData<double>(126, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DbLimiter, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbLimiter::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DbLimiterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DbLimiterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9DbLimiterE_t>.metaTypes,
    nullptr
} };

void DbLimiter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbLimiter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bypassChanged(); break;
        case 1: _t->inputGainChanged(); break;
        case 2: _t->outputGainChanged(); break;
        case 3: _t->modeLabelsChanged(); break;
        case 4: _t->modeChanged(); break;
        case 5: _t->oversamplingLabelsChanged(); break;
        case 6: _t->oversamplingChanged(); break;
        case 7: _t->ditheringLabelsChanged(); break;
        case 8: _t->ditheringChanged(); break;
        case 9: _t->sidechainTypeLabelsChanged(); break;
        case 10: _t->sidechainTypeChanged(); break;
        case 11: _t->lookaheadChanged(); break;
        case 12: _t->attackChanged(); break;
        case 13: _t->releaseChanged(); break;
        case 14: _t->thresholdChanged(); break;
        case 15: _t->gainBoostChanged(); break;
        case 16: _t->sidechainPreampChanged(); break;
        case 17: _t->stereoLinkChanged(); break;
        case 18: _t->alrChanged(); break;
        case 19: _t->alrAttackChanged(); break;
        case 20: _t->alrReleaseChanged(); break;
        case 21: _t->alrKneeChanged(); break;
        case 22: _t->alrKneeSmoothChanged(); break;
        case 23: _t->sidechainInputDeviceChanged(); break;
        case 24: _t->inputToSidechainChanged(); break;
        case 25: _t->inputToLinkChanged(); break;
        case 26: _t->sidechainToInputChanged(); break;
        case 27: _t->sidechainToLinkChanged(); break;
        case 28: _t->linkToSidechainChanged(); break;
        case 29: _t->linkToInputChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::bypassChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::inputGainChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::outputGainChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::modeLabelsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::modeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::oversamplingLabelsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::oversamplingChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::ditheringLabelsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::ditheringChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::sidechainTypeLabelsChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::sidechainTypeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::lookaheadChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::attackChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::releaseChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::thresholdChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::gainBoostChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::sidechainPreampChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::stereoLinkChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::alrChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::alrAttackChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::alrReleaseChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::alrKneeChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::alrKneeSmoothChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::sidechainInputDeviceChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::inputToSidechainChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::inputToLinkChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::sidechainToInputChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::sidechainToLinkChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::linkToSidechainChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLimiter::*)()>(_a, &DbLimiter::linkToInputChanged, 29))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bypass(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isBypassImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultBypassValue(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->inputGain(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isInputGainImmutable(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->defaultInputGainValue(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->outputGain(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isOutputGainImmutable(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->defaultOutputGainValue(); break;
        case 9: *reinterpret_cast<QStringList*>(_v) = _t->modeLabels(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isModeLabelsImmutable(); break;
        case 11: *reinterpret_cast<QStringList*>(_v) = _t->defaultModeLabelsValue(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->mode(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isModeImmutable(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->defaultModeValue(); break;
        case 15: *reinterpret_cast<QStringList*>(_v) = _t->oversamplingLabels(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isOversamplingLabelsImmutable(); break;
        case 17: *reinterpret_cast<QStringList*>(_v) = _t->defaultOversamplingLabelsValue(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->oversampling(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isOversamplingImmutable(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->defaultOversamplingValue(); break;
        case 21: *reinterpret_cast<QStringList*>(_v) = _t->ditheringLabels(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isDitheringLabelsImmutable(); break;
        case 23: *reinterpret_cast<QStringList*>(_v) = _t->defaultDitheringLabelsValue(); break;
        case 24: *reinterpret_cast<int*>(_v) = _t->dithering(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isDitheringImmutable(); break;
        case 26: *reinterpret_cast<int*>(_v) = _t->defaultDitheringValue(); break;
        case 27: *reinterpret_cast<QStringList*>(_v) = _t->sidechainTypeLabels(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isSidechainTypeLabelsImmutable(); break;
        case 29: *reinterpret_cast<QStringList*>(_v) = _t->defaultSidechainTypeLabelsValue(); break;
        case 30: *reinterpret_cast<int*>(_v) = _t->sidechainType(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isSidechainTypeImmutable(); break;
        case 32: *reinterpret_cast<int*>(_v) = _t->defaultSidechainTypeValue(); break;
        case 33: *reinterpret_cast<double*>(_v) = _t->lookahead(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isLookaheadImmutable(); break;
        case 35: *reinterpret_cast<double*>(_v) = _t->defaultLookaheadValue(); break;
        case 36: *reinterpret_cast<double*>(_v) = _t->attack(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isAttackImmutable(); break;
        case 38: *reinterpret_cast<double*>(_v) = _t->defaultAttackValue(); break;
        case 39: *reinterpret_cast<double*>(_v) = _t->release(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->isReleaseImmutable(); break;
        case 41: *reinterpret_cast<double*>(_v) = _t->defaultReleaseValue(); break;
        case 42: *reinterpret_cast<double*>(_v) = _t->threshold(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->isThresholdImmutable(); break;
        case 44: *reinterpret_cast<double*>(_v) = _t->defaultThresholdValue(); break;
        case 45: *reinterpret_cast<bool*>(_v) = _t->gainBoost(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->isGainBoostImmutable(); break;
        case 47: *reinterpret_cast<bool*>(_v) = _t->defaultGainBoostValue(); break;
        case 48: *reinterpret_cast<double*>(_v) = _t->sidechainPreamp(); break;
        case 49: *reinterpret_cast<bool*>(_v) = _t->isSidechainPreampImmutable(); break;
        case 50: *reinterpret_cast<double*>(_v) = _t->defaultSidechainPreampValue(); break;
        case 51: *reinterpret_cast<double*>(_v) = _t->stereoLink(); break;
        case 52: *reinterpret_cast<bool*>(_v) = _t->isStereoLinkImmutable(); break;
        case 53: *reinterpret_cast<double*>(_v) = _t->defaultStereoLinkValue(); break;
        case 54: *reinterpret_cast<bool*>(_v) = _t->alr(); break;
        case 55: *reinterpret_cast<bool*>(_v) = _t->isAlrImmutable(); break;
        case 56: *reinterpret_cast<bool*>(_v) = _t->defaultAlrValue(); break;
        case 57: *reinterpret_cast<double*>(_v) = _t->alrAttack(); break;
        case 58: *reinterpret_cast<bool*>(_v) = _t->isAlrAttackImmutable(); break;
        case 59: *reinterpret_cast<double*>(_v) = _t->defaultAlrAttackValue(); break;
        case 60: *reinterpret_cast<double*>(_v) = _t->alrRelease(); break;
        case 61: *reinterpret_cast<bool*>(_v) = _t->isAlrReleaseImmutable(); break;
        case 62: *reinterpret_cast<double*>(_v) = _t->defaultAlrReleaseValue(); break;
        case 63: *reinterpret_cast<double*>(_v) = _t->alrKnee(); break;
        case 64: *reinterpret_cast<bool*>(_v) = _t->isAlrKneeImmutable(); break;
        case 65: *reinterpret_cast<double*>(_v) = _t->defaultAlrKneeValue(); break;
        case 66: *reinterpret_cast<double*>(_v) = _t->alrKneeSmooth(); break;
        case 67: *reinterpret_cast<bool*>(_v) = _t->isAlrKneeSmoothImmutable(); break;
        case 68: *reinterpret_cast<double*>(_v) = _t->defaultAlrKneeSmoothValue(); break;
        case 69: *reinterpret_cast<QString*>(_v) = _t->sidechainInputDevice(); break;
        case 70: *reinterpret_cast<bool*>(_v) = _t->isSidechainInputDeviceImmutable(); break;
        case 71: *reinterpret_cast<QString*>(_v) = _t->defaultSidechainInputDeviceValue(); break;
        case 72: *reinterpret_cast<double*>(_v) = _t->inputToSidechain(); break;
        case 73: *reinterpret_cast<bool*>(_v) = _t->isInputToSidechainImmutable(); break;
        case 74: *reinterpret_cast<double*>(_v) = _t->defaultInputToSidechainValue(); break;
        case 75: *reinterpret_cast<double*>(_v) = _t->inputToLink(); break;
        case 76: *reinterpret_cast<bool*>(_v) = _t->isInputToLinkImmutable(); break;
        case 77: *reinterpret_cast<double*>(_v) = _t->defaultInputToLinkValue(); break;
        case 78: *reinterpret_cast<double*>(_v) = _t->sidechainToInput(); break;
        case 79: *reinterpret_cast<bool*>(_v) = _t->isSidechainToInputImmutable(); break;
        case 80: *reinterpret_cast<double*>(_v) = _t->defaultSidechainToInputValue(); break;
        case 81: *reinterpret_cast<double*>(_v) = _t->sidechainToLink(); break;
        case 82: *reinterpret_cast<bool*>(_v) = _t->isSidechainToLinkImmutable(); break;
        case 83: *reinterpret_cast<double*>(_v) = _t->defaultSidechainToLinkValue(); break;
        case 84: *reinterpret_cast<double*>(_v) = _t->linkToSidechain(); break;
        case 85: *reinterpret_cast<bool*>(_v) = _t->isLinkToSidechainImmutable(); break;
        case 86: *reinterpret_cast<double*>(_v) = _t->defaultLinkToSidechainValue(); break;
        case 87: *reinterpret_cast<double*>(_v) = _t->linkToInput(); break;
        case 88: *reinterpret_cast<bool*>(_v) = _t->isLinkToInputImmutable(); break;
        case 89: *reinterpret_cast<double*>(_v) = _t->defaultLinkToInputValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBypass(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setInputGain(*reinterpret_cast<double*>(_v)); break;
        case 6: _t->setOutputGain(*reinterpret_cast<double*>(_v)); break;
        case 9: _t->setModeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 12: _t->setMode(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setOversamplingLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 18: _t->setOversampling(*reinterpret_cast<int*>(_v)); break;
        case 21: _t->setDitheringLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 24: _t->setDithering(*reinterpret_cast<int*>(_v)); break;
        case 27: _t->setSidechainTypeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 30: _t->setSidechainType(*reinterpret_cast<int*>(_v)); break;
        case 33: _t->setLookahead(*reinterpret_cast<double*>(_v)); break;
        case 36: _t->setAttack(*reinterpret_cast<double*>(_v)); break;
        case 39: _t->setRelease(*reinterpret_cast<double*>(_v)); break;
        case 42: _t->setThreshold(*reinterpret_cast<double*>(_v)); break;
        case 45: _t->setGainBoost(*reinterpret_cast<bool*>(_v)); break;
        case 48: _t->setSidechainPreamp(*reinterpret_cast<double*>(_v)); break;
        case 51: _t->setStereoLink(*reinterpret_cast<double*>(_v)); break;
        case 54: _t->setAlr(*reinterpret_cast<bool*>(_v)); break;
        case 57: _t->setAlrAttack(*reinterpret_cast<double*>(_v)); break;
        case 60: _t->setAlrRelease(*reinterpret_cast<double*>(_v)); break;
        case 63: _t->setAlrKnee(*reinterpret_cast<double*>(_v)); break;
        case 66: _t->setAlrKneeSmooth(*reinterpret_cast<double*>(_v)); break;
        case 69: _t->setSidechainInputDevice(*reinterpret_cast<QString*>(_v)); break;
        case 72: _t->setInputToSidechain(*reinterpret_cast<double*>(_v)); break;
        case 75: _t->setInputToLink(*reinterpret_cast<double*>(_v)); break;
        case 78: _t->setSidechainToInput(*reinterpret_cast<double*>(_v)); break;
        case 81: _t->setSidechainToLink(*reinterpret_cast<double*>(_v)); break;
        case 84: _t->setLinkToSidechain(*reinterpret_cast<double*>(_v)); break;
        case 87: _t->setLinkToInput(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbLimiter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbLimiter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DbLimiterE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbLimiter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 30;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 90;
    }
    return _id;
}

// SIGNAL 0
void DbLimiter::bypassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbLimiter::inputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbLimiter::outputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbLimiter::modeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DbLimiter::modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DbLimiter::oversamplingLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DbLimiter::oversamplingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DbLimiter::ditheringLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DbLimiter::ditheringChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DbLimiter::sidechainTypeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DbLimiter::sidechainTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DbLimiter::lookaheadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void DbLimiter::attackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void DbLimiter::releaseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void DbLimiter::thresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void DbLimiter::gainBoostChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void DbLimiter::sidechainPreampChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void DbLimiter::stereoLinkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void DbLimiter::alrChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void DbLimiter::alrAttackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void DbLimiter::alrReleaseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void DbLimiter::alrKneeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void DbLimiter::alrKneeSmoothChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void DbLimiter::sidechainInputDeviceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void DbLimiter::inputToSidechainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void DbLimiter::inputToLinkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void DbLimiter::sidechainToInputChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void DbLimiter::sidechainToLinkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void DbLimiter::linkToSidechainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void DbLimiter::linkToInputChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}
QT_WARNING_POP
