// This file is generated by kconfig_compiler_kf6 from easyeffects_db_crystalizer.kcfg.
// All changes you do to this file will be lost.

#include "easyeffects_db_crystalizer.h"

DbCrystalizer::DbCrystalizer( const QString & masterGroup, const QString & instanceIndex )
  : KConfigBaseEE( QStringLiteral( "easyeffects/db/crystalizerrc" ) )
  , mParammasterGroup(masterGroup)
  , mParaminstanceIndex(instanceIndex)
{
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&DbCrystalizer::itemChanged);

  KConfigGroup cgmasterGroup(this->config(), QStringLiteral( "%1" ).arg( mParammasterGroup ));
  KConfigGroup cgCrystalizerinstanceIndex = cgmasterGroup.group(QStringLiteral( "Crystalizer#%1" ).arg( mParaminstanceIndex ));
  KConfigCompilerSignallingItem  *itemBypass;
  KConfigBaseEE::ItemBool  *innerItemBypass;
  innerItemBypass = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "bypass" ), mBypass, false );
  itemBypass = new KConfigCompilerSignallingItem(innerItemBypass, this, notifyFunction, signalBypassChanged);
  itemBypass->setWriteFlags(KConfigBase::Notify);
  itemBypass->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemBypass, QStringLiteral( "bypass" ) );
  KConfigCompilerSignallingItem  *itemInputGain;
  KConfigBaseEE::ItemDouble  *innerItemInputGain;
  innerItemInputGain = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "inputGain" ), mInputGain, 0 );
  itemInputGain = new KConfigCompilerSignallingItem(innerItemInputGain, this, notifyFunction, signalInputGainChanged);
  innerItemInputGain->setMinValue(-36);
  innerItemInputGain->setMaxValue(36);
  itemInputGain->setWriteFlags(KConfigBase::Notify);
  itemInputGain->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemInputGain, QStringLiteral( "inputGain" ) );
  KConfigCompilerSignallingItem  *itemOutputGain;
  KConfigBaseEE::ItemDouble  *innerItemOutputGain;
  innerItemOutputGain = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "outputGain" ), mOutputGain, 0 );
  itemOutputGain = new KConfigCompilerSignallingItem(innerItemOutputGain, this, notifyFunction, signalOutputGainChanged);
  innerItemOutputGain->setMinValue(-36);
  innerItemOutputGain->setMaxValue(36);
  itemOutputGain->setWriteFlags(KConfigBase::Notify);
  itemOutputGain->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemOutputGain, QStringLiteral( "outputGain" ) );
  KConfigCompilerSignallingItem  *itemAdaptiveIntensity;
  KConfigBaseEE::ItemBool  *innerItemAdaptiveIntensity;
  innerItemAdaptiveIntensity = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "adaptiveIntensity" ), mAdaptiveIntensity, true );
  itemAdaptiveIntensity = new KConfigCompilerSignallingItem(innerItemAdaptiveIntensity, this, notifyFunction, signalAdaptiveIntensityChanged);
  itemAdaptiveIntensity->setWriteFlags(KConfigBase::Notify);
  itemAdaptiveIntensity->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemAdaptiveIntensity, QStringLiteral( "adaptiveIntensity" ) );
  KConfigCompilerSignallingItem  *itemOversampling;
  KConfigBaseEE::ItemBool  *innerItemOversampling;
  innerItemOversampling = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "oversampling" ), mOversampling, true );
  itemOversampling = new KConfigCompilerSignallingItem(innerItemOversampling, this, notifyFunction, signalOversamplingChanged);
  itemOversampling->setWriteFlags(KConfigBase::Notify);
  itemOversampling->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemOversampling, QStringLiteral( "oversampling" ) );
  KConfigCompilerSignallingItem  *itemOversamplingQuality;
  KConfigBaseEE::ItemDouble  *innerItemOversamplingQuality;
  innerItemOversamplingQuality = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "oversamplingQuality" ), mOversamplingQuality, 5 );
  itemOversamplingQuality = new KConfigCompilerSignallingItem(innerItemOversamplingQuality, this, notifyFunction, signalOversamplingQualityChanged);
  innerItemOversamplingQuality->setMinValue(0);
  innerItemOversamplingQuality->setMaxValue(10);
  itemOversamplingQuality->setWriteFlags(KConfigBase::Notify);
  itemOversamplingQuality->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemOversamplingQuality, QStringLiteral( "oversamplingQuality" ) );
  KConfigCompilerSignallingItem  *itemUseFixedQuantum;
  KConfigBaseEE::ItemBool  *innerItemUseFixedQuantum;
  innerItemUseFixedQuantum = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "useFixedQuantum" ), mUseFixedQuantum, false );
  itemUseFixedQuantum = new KConfigCompilerSignallingItem(innerItemUseFixedQuantum, this, notifyFunction, signalUseFixedQuantumChanged);
  itemUseFixedQuantum->setWriteFlags(KConfigBase::Notify);
  itemUseFixedQuantum->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemUseFixedQuantum, QStringLiteral( "useFixedQuantum" ) );
  KConfigCompilerSignallingItem  *itemTransitionBand;
  KConfigBaseEE::ItemDouble  *innerItemTransitionBand;
  innerItemTransitionBand = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "transitionBand" ), mTransitionBand, 120 );
  itemTransitionBand = new KConfigCompilerSignallingItem(innerItemTransitionBand, this, notifyFunction, signalTransitionBandChanged);
  innerItemTransitionBand->setMinValue(10);
  innerItemTransitionBand->setMaxValue(1000);
  itemTransitionBand->setWriteFlags(KConfigBase::Notify);
  itemTransitionBand->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemTransitionBand, QStringLiteral( "transitionBand" ) );
  KConfigCompilerSignallingItem  *itemIntensityBand0;
  KConfigBaseEE::ItemDouble  *innerItemIntensityBand0;
  innerItemIntensityBand0 = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "intensityBand0" ), mIntensityBand0, 0 );
  itemIntensityBand0 = new KConfigCompilerSignallingItem(innerItemIntensityBand0, this, notifyFunction, signalIntensityBand0Changed);
  innerItemIntensityBand0->setMinValue(-40);
  innerItemIntensityBand0->setMaxValue(32);
  itemIntensityBand0->setWriteFlags(KConfigBase::Notify);
  itemIntensityBand0->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemIntensityBand0, QStringLiteral( "intensityBand0" ) );
  KConfigCompilerSignallingItem  *itemIntensityBand1;
  KConfigBaseEE::ItemDouble  *innerItemIntensityBand1;
  innerItemIntensityBand1 = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "intensityBand1" ), mIntensityBand1, 0 );
  itemIntensityBand1 = new KConfigCompilerSignallingItem(innerItemIntensityBand1, this, notifyFunction, signalIntensityBand1Changed);
  innerItemIntensityBand1->setMinValue(-40);
  innerItemIntensityBand1->setMaxValue(32);
  itemIntensityBand1->setWriteFlags(KConfigBase::Notify);
  itemIntensityBand1->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemIntensityBand1, QStringLiteral( "intensityBand1" ) );
  KConfigCompilerSignallingItem  *itemIntensityBand2;
  KConfigBaseEE::ItemDouble  *innerItemIntensityBand2;
  innerItemIntensityBand2 = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "intensityBand2" ), mIntensityBand2, -2 );
  itemIntensityBand2 = new KConfigCompilerSignallingItem(innerItemIntensityBand2, this, notifyFunction, signalIntensityBand2Changed);
  innerItemIntensityBand2->setMinValue(-40);
  innerItemIntensityBand2->setMaxValue(32);
  itemIntensityBand2->setWriteFlags(KConfigBase::Notify);
  itemIntensityBand2->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemIntensityBand2, QStringLiteral( "intensityBand2" ) );
  KConfigCompilerSignallingItem  *itemIntensityBand3;
  KConfigBaseEE::ItemDouble  *innerItemIntensityBand3;
  innerItemIntensityBand3 = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "intensityBand3" ), mIntensityBand3, 0 );
  itemIntensityBand3 = new KConfigCompilerSignallingItem(innerItemIntensityBand3, this, notifyFunction, signalIntensityBand3Changed);
  innerItemIntensityBand3->setMinValue(-40);
  innerItemIntensityBand3->setMaxValue(32);
  itemIntensityBand3->setWriteFlags(KConfigBase::Notify);
  itemIntensityBand3->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemIntensityBand3, QStringLiteral( "intensityBand3" ) );
  KConfigCompilerSignallingItem  *itemIntensityBand4;
  KConfigBaseEE::ItemDouble  *innerItemIntensityBand4;
  innerItemIntensityBand4 = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "intensityBand4" ), mIntensityBand4, 0 );
  itemIntensityBand4 = new KConfigCompilerSignallingItem(innerItemIntensityBand4, this, notifyFunction, signalIntensityBand4Changed);
  innerItemIntensityBand4->setMinValue(-40);
  innerItemIntensityBand4->setMaxValue(32);
  itemIntensityBand4->setWriteFlags(KConfigBase::Notify);
  itemIntensityBand4->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemIntensityBand4, QStringLiteral( "intensityBand4" ) );
  KConfigCompilerSignallingItem  *itemIntensityBand5;
  KConfigBaseEE::ItemDouble  *innerItemIntensityBand5;
  innerItemIntensityBand5 = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "intensityBand5" ), mIntensityBand5, 0 );
  itemIntensityBand5 = new KConfigCompilerSignallingItem(innerItemIntensityBand5, this, notifyFunction, signalIntensityBand5Changed);
  innerItemIntensityBand5->setMinValue(-40);
  innerItemIntensityBand5->setMaxValue(32);
  itemIntensityBand5->setWriteFlags(KConfigBase::Notify);
  itemIntensityBand5->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemIntensityBand5, QStringLiteral( "intensityBand5" ) );
  KConfigCompilerSignallingItem  *itemIntensityBand6;
  KConfigBaseEE::ItemDouble  *innerItemIntensityBand6;
  innerItemIntensityBand6 = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "intensityBand6" ), mIntensityBand6, 0 );
  itemIntensityBand6 = new KConfigCompilerSignallingItem(innerItemIntensityBand6, this, notifyFunction, signalIntensityBand6Changed);
  innerItemIntensityBand6->setMinValue(-40);
  innerItemIntensityBand6->setMaxValue(32);
  itemIntensityBand6->setWriteFlags(KConfigBase::Notify);
  itemIntensityBand6->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemIntensityBand6, QStringLiteral( "intensityBand6" ) );
  KConfigCompilerSignallingItem  *itemIntensityBand7;
  KConfigBaseEE::ItemDouble  *innerItemIntensityBand7;
  innerItemIntensityBand7 = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "intensityBand7" ), mIntensityBand7, 0 );
  itemIntensityBand7 = new KConfigCompilerSignallingItem(innerItemIntensityBand7, this, notifyFunction, signalIntensityBand7Changed);
  innerItemIntensityBand7->setMinValue(-40);
  innerItemIntensityBand7->setMaxValue(32);
  itemIntensityBand7->setWriteFlags(KConfigBase::Notify);
  itemIntensityBand7->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemIntensityBand7, QStringLiteral( "intensityBand7" ) );
  KConfigCompilerSignallingItem  *itemIntensityBand8;
  KConfigBaseEE::ItemDouble  *innerItemIntensityBand8;
  innerItemIntensityBand8 = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "intensityBand8" ), mIntensityBand8, 0 );
  itemIntensityBand8 = new KConfigCompilerSignallingItem(innerItemIntensityBand8, this, notifyFunction, signalIntensityBand8Changed);
  innerItemIntensityBand8->setMinValue(-40);
  innerItemIntensityBand8->setMaxValue(32);
  itemIntensityBand8->setWriteFlags(KConfigBase::Notify);
  itemIntensityBand8->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemIntensityBand8, QStringLiteral( "intensityBand8" ) );
  KConfigCompilerSignallingItem  *itemIntensityBand9;
  KConfigBaseEE::ItemDouble  *innerItemIntensityBand9;
  innerItemIntensityBand9 = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "intensityBand9" ), mIntensityBand9, 0 );
  itemIntensityBand9 = new KConfigCompilerSignallingItem(innerItemIntensityBand9, this, notifyFunction, signalIntensityBand9Changed);
  innerItemIntensityBand9->setMinValue(-40);
  innerItemIntensityBand9->setMaxValue(32);
  itemIntensityBand9->setWriteFlags(KConfigBase::Notify);
  itemIntensityBand9->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemIntensityBand9, QStringLiteral( "intensityBand9" ) );
  KConfigCompilerSignallingItem  *itemIntensityBand10;
  KConfigBaseEE::ItemDouble  *innerItemIntensityBand10;
  innerItemIntensityBand10 = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "intensityBand10" ), mIntensityBand10, 0 );
  itemIntensityBand10 = new KConfigCompilerSignallingItem(innerItemIntensityBand10, this, notifyFunction, signalIntensityBand10Changed);
  innerItemIntensityBand10->setMinValue(-40);
  innerItemIntensityBand10->setMaxValue(32);
  itemIntensityBand10->setWriteFlags(KConfigBase::Notify);
  itemIntensityBand10->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemIntensityBand10, QStringLiteral( "intensityBand10" ) );
  KConfigCompilerSignallingItem  *itemIntensityBand11;
  KConfigBaseEE::ItemDouble  *innerItemIntensityBand11;
  innerItemIntensityBand11 = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "intensityBand11" ), mIntensityBand11, 0 );
  itemIntensityBand11 = new KConfigCompilerSignallingItem(innerItemIntensityBand11, this, notifyFunction, signalIntensityBand11Changed);
  innerItemIntensityBand11->setMinValue(-40);
  innerItemIntensityBand11->setMaxValue(32);
  itemIntensityBand11->setWriteFlags(KConfigBase::Notify);
  itemIntensityBand11->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemIntensityBand11, QStringLiteral( "intensityBand11" ) );
  KConfigCompilerSignallingItem  *itemIntensityBand12;
  KConfigBaseEE::ItemDouble  *innerItemIntensityBand12;
  innerItemIntensityBand12 = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "intensityBand12" ), mIntensityBand12, 0 );
  itemIntensityBand12 = new KConfigCompilerSignallingItem(innerItemIntensityBand12, this, notifyFunction, signalIntensityBand12Changed);
  innerItemIntensityBand12->setMinValue(-40);
  innerItemIntensityBand12->setMaxValue(32);
  itemIntensityBand12->setWriteFlags(KConfigBase::Notify);
  itemIntensityBand12->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemIntensityBand12, QStringLiteral( "intensityBand12" ) );
  KConfigCompilerSignallingItem  *itemMuteBand0;
  KConfigBaseEE::ItemBool  *innerItemMuteBand0;
  innerItemMuteBand0 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "muteBand0" ), mMuteBand0, false );
  itemMuteBand0 = new KConfigCompilerSignallingItem(innerItemMuteBand0, this, notifyFunction, signalMuteBand0Changed);
  itemMuteBand0->setWriteFlags(KConfigBase::Notify);
  itemMuteBand0->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemMuteBand0, QStringLiteral( "muteBand0" ) );
  KConfigCompilerSignallingItem  *itemMuteBand1;
  KConfigBaseEE::ItemBool  *innerItemMuteBand1;
  innerItemMuteBand1 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "muteBand1" ), mMuteBand1, false );
  itemMuteBand1 = new KConfigCompilerSignallingItem(innerItemMuteBand1, this, notifyFunction, signalMuteBand1Changed);
  itemMuteBand1->setWriteFlags(KConfigBase::Notify);
  itemMuteBand1->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemMuteBand1, QStringLiteral( "muteBand1" ) );
  KConfigCompilerSignallingItem  *itemMuteBand2;
  KConfigBaseEE::ItemBool  *innerItemMuteBand2;
  innerItemMuteBand2 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "muteBand2" ), mMuteBand2, false );
  itemMuteBand2 = new KConfigCompilerSignallingItem(innerItemMuteBand2, this, notifyFunction, signalMuteBand2Changed);
  itemMuteBand2->setWriteFlags(KConfigBase::Notify);
  itemMuteBand2->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemMuteBand2, QStringLiteral( "muteBand2" ) );
  KConfigCompilerSignallingItem  *itemMuteBand3;
  KConfigBaseEE::ItemBool  *innerItemMuteBand3;
  innerItemMuteBand3 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "muteBand3" ), mMuteBand3, false );
  itemMuteBand3 = new KConfigCompilerSignallingItem(innerItemMuteBand3, this, notifyFunction, signalMuteBand3Changed);
  itemMuteBand3->setWriteFlags(KConfigBase::Notify);
  itemMuteBand3->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemMuteBand3, QStringLiteral( "muteBand3" ) );
  KConfigCompilerSignallingItem  *itemMuteBand4;
  KConfigBaseEE::ItemBool  *innerItemMuteBand4;
  innerItemMuteBand4 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "muteBand4" ), mMuteBand4, false );
  itemMuteBand4 = new KConfigCompilerSignallingItem(innerItemMuteBand4, this, notifyFunction, signalMuteBand4Changed);
  itemMuteBand4->setWriteFlags(KConfigBase::Notify);
  itemMuteBand4->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemMuteBand4, QStringLiteral( "muteBand4" ) );
  KConfigCompilerSignallingItem  *itemMuteBand5;
  KConfigBaseEE::ItemBool  *innerItemMuteBand5;
  innerItemMuteBand5 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "muteBand5" ), mMuteBand5, false );
  itemMuteBand5 = new KConfigCompilerSignallingItem(innerItemMuteBand5, this, notifyFunction, signalMuteBand5Changed);
  itemMuteBand5->setWriteFlags(KConfigBase::Notify);
  itemMuteBand5->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemMuteBand5, QStringLiteral( "muteBand5" ) );
  KConfigCompilerSignallingItem  *itemMuteBand6;
  KConfigBaseEE::ItemBool  *innerItemMuteBand6;
  innerItemMuteBand6 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "muteBand6" ), mMuteBand6, false );
  itemMuteBand6 = new KConfigCompilerSignallingItem(innerItemMuteBand6, this, notifyFunction, signalMuteBand6Changed);
  itemMuteBand6->setWriteFlags(KConfigBase::Notify);
  itemMuteBand6->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemMuteBand6, QStringLiteral( "muteBand6" ) );
  KConfigCompilerSignallingItem  *itemMuteBand7;
  KConfigBaseEE::ItemBool  *innerItemMuteBand7;
  innerItemMuteBand7 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "muteBand7" ), mMuteBand7, false );
  itemMuteBand7 = new KConfigCompilerSignallingItem(innerItemMuteBand7, this, notifyFunction, signalMuteBand7Changed);
  itemMuteBand7->setWriteFlags(KConfigBase::Notify);
  itemMuteBand7->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemMuteBand7, QStringLiteral( "muteBand7" ) );
  KConfigCompilerSignallingItem  *itemMuteBand8;
  KConfigBaseEE::ItemBool  *innerItemMuteBand8;
  innerItemMuteBand8 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "muteBand8" ), mMuteBand8, false );
  itemMuteBand8 = new KConfigCompilerSignallingItem(innerItemMuteBand8, this, notifyFunction, signalMuteBand8Changed);
  itemMuteBand8->setWriteFlags(KConfigBase::Notify);
  itemMuteBand8->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemMuteBand8, QStringLiteral( "muteBand8" ) );
  KConfigCompilerSignallingItem  *itemMuteBand9;
  KConfigBaseEE::ItemBool  *innerItemMuteBand9;
  innerItemMuteBand9 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "muteBand9" ), mMuteBand9, false );
  itemMuteBand9 = new KConfigCompilerSignallingItem(innerItemMuteBand9, this, notifyFunction, signalMuteBand9Changed);
  itemMuteBand9->setWriteFlags(KConfigBase::Notify);
  itemMuteBand9->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemMuteBand9, QStringLiteral( "muteBand9" ) );
  KConfigCompilerSignallingItem  *itemMuteBand10;
  KConfigBaseEE::ItemBool  *innerItemMuteBand10;
  innerItemMuteBand10 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "muteBand10" ), mMuteBand10, false );
  itemMuteBand10 = new KConfigCompilerSignallingItem(innerItemMuteBand10, this, notifyFunction, signalMuteBand10Changed);
  itemMuteBand10->setWriteFlags(KConfigBase::Notify);
  itemMuteBand10->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemMuteBand10, QStringLiteral( "muteBand10" ) );
  KConfigCompilerSignallingItem  *itemMuteBand11;
  KConfigBaseEE::ItemBool  *innerItemMuteBand11;
  innerItemMuteBand11 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "muteBand11" ), mMuteBand11, false );
  itemMuteBand11 = new KConfigCompilerSignallingItem(innerItemMuteBand11, this, notifyFunction, signalMuteBand11Changed);
  itemMuteBand11->setWriteFlags(KConfigBase::Notify);
  itemMuteBand11->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemMuteBand11, QStringLiteral( "muteBand11" ) );
  KConfigCompilerSignallingItem  *itemMuteBand12;
  KConfigBaseEE::ItemBool  *innerItemMuteBand12;
  innerItemMuteBand12 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "muteBand12" ), mMuteBand12, false );
  itemMuteBand12 = new KConfigCompilerSignallingItem(innerItemMuteBand12, this, notifyFunction, signalMuteBand12Changed);
  itemMuteBand12->setWriteFlags(KConfigBase::Notify);
  itemMuteBand12->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemMuteBand12, QStringLiteral( "muteBand12" ) );
  KConfigCompilerSignallingItem  *itemBypassBand0;
  KConfigBaseEE::ItemBool  *innerItemBypassBand0;
  innerItemBypassBand0 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "bypassBand0" ), mBypassBand0, false );
  itemBypassBand0 = new KConfigCompilerSignallingItem(innerItemBypassBand0, this, notifyFunction, signalBypassBand0Changed);
  itemBypassBand0->setWriteFlags(KConfigBase::Notify);
  itemBypassBand0->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemBypassBand0, QStringLiteral( "bypassBand0" ) );
  KConfigCompilerSignallingItem  *itemBypassBand1;
  KConfigBaseEE::ItemBool  *innerItemBypassBand1;
  innerItemBypassBand1 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "bypassBand1" ), mBypassBand1, false );
  itemBypassBand1 = new KConfigCompilerSignallingItem(innerItemBypassBand1, this, notifyFunction, signalBypassBand1Changed);
  itemBypassBand1->setWriteFlags(KConfigBase::Notify);
  itemBypassBand1->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemBypassBand1, QStringLiteral( "bypassBand1" ) );
  KConfigCompilerSignallingItem  *itemBypassBand2;
  KConfigBaseEE::ItemBool  *innerItemBypassBand2;
  innerItemBypassBand2 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "bypassBand2" ), mBypassBand2, false );
  itemBypassBand2 = new KConfigCompilerSignallingItem(innerItemBypassBand2, this, notifyFunction, signalBypassBand2Changed);
  itemBypassBand2->setWriteFlags(KConfigBase::Notify);
  itemBypassBand2->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemBypassBand2, QStringLiteral( "bypassBand2" ) );
  KConfigCompilerSignallingItem  *itemBypassBand3;
  KConfigBaseEE::ItemBool  *innerItemBypassBand3;
  innerItemBypassBand3 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "bypassBand3" ), mBypassBand3, false );
  itemBypassBand3 = new KConfigCompilerSignallingItem(innerItemBypassBand3, this, notifyFunction, signalBypassBand3Changed);
  itemBypassBand3->setWriteFlags(KConfigBase::Notify);
  itemBypassBand3->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemBypassBand3, QStringLiteral( "bypassBand3" ) );
  KConfigCompilerSignallingItem  *itemBypassBand4;
  KConfigBaseEE::ItemBool  *innerItemBypassBand4;
  innerItemBypassBand4 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "bypassBand4" ), mBypassBand4, false );
  itemBypassBand4 = new KConfigCompilerSignallingItem(innerItemBypassBand4, this, notifyFunction, signalBypassBand4Changed);
  itemBypassBand4->setWriteFlags(KConfigBase::Notify);
  itemBypassBand4->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemBypassBand4, QStringLiteral( "bypassBand4" ) );
  KConfigCompilerSignallingItem  *itemBypassBand5;
  KConfigBaseEE::ItemBool  *innerItemBypassBand5;
  innerItemBypassBand5 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "bypassBand5" ), mBypassBand5, false );
  itemBypassBand5 = new KConfigCompilerSignallingItem(innerItemBypassBand5, this, notifyFunction, signalBypassBand5Changed);
  itemBypassBand5->setWriteFlags(KConfigBase::Notify);
  itemBypassBand5->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemBypassBand5, QStringLiteral( "bypassBand5" ) );
  KConfigCompilerSignallingItem  *itemBypassBand6;
  KConfigBaseEE::ItemBool  *innerItemBypassBand6;
  innerItemBypassBand6 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "bypassBand6" ), mBypassBand6, false );
  itemBypassBand6 = new KConfigCompilerSignallingItem(innerItemBypassBand6, this, notifyFunction, signalBypassBand6Changed);
  itemBypassBand6->setWriteFlags(KConfigBase::Notify);
  itemBypassBand6->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemBypassBand6, QStringLiteral( "bypassBand6" ) );
  KConfigCompilerSignallingItem  *itemBypassBand7;
  KConfigBaseEE::ItemBool  *innerItemBypassBand7;
  innerItemBypassBand7 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "bypassBand7" ), mBypassBand7, false );
  itemBypassBand7 = new KConfigCompilerSignallingItem(innerItemBypassBand7, this, notifyFunction, signalBypassBand7Changed);
  itemBypassBand7->setWriteFlags(KConfigBase::Notify);
  itemBypassBand7->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemBypassBand7, QStringLiteral( "bypassBand7" ) );
  KConfigCompilerSignallingItem  *itemBypassBand8;
  KConfigBaseEE::ItemBool  *innerItemBypassBand8;
  innerItemBypassBand8 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "bypassBand8" ), mBypassBand8, false );
  itemBypassBand8 = new KConfigCompilerSignallingItem(innerItemBypassBand8, this, notifyFunction, signalBypassBand8Changed);
  itemBypassBand8->setWriteFlags(KConfigBase::Notify);
  itemBypassBand8->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemBypassBand8, QStringLiteral( "bypassBand8" ) );
  KConfigCompilerSignallingItem  *itemBypassBand9;
  KConfigBaseEE::ItemBool  *innerItemBypassBand9;
  innerItemBypassBand9 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "bypassBand9" ), mBypassBand9, false );
  itemBypassBand9 = new KConfigCompilerSignallingItem(innerItemBypassBand9, this, notifyFunction, signalBypassBand9Changed);
  itemBypassBand9->setWriteFlags(KConfigBase::Notify);
  itemBypassBand9->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemBypassBand9, QStringLiteral( "bypassBand9" ) );
  KConfigCompilerSignallingItem  *itemBypassBand10;
  KConfigBaseEE::ItemBool  *innerItemBypassBand10;
  innerItemBypassBand10 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "bypassBand10" ), mBypassBand10, false );
  itemBypassBand10 = new KConfigCompilerSignallingItem(innerItemBypassBand10, this, notifyFunction, signalBypassBand10Changed);
  itemBypassBand10->setWriteFlags(KConfigBase::Notify);
  itemBypassBand10->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemBypassBand10, QStringLiteral( "bypassBand10" ) );
  KConfigCompilerSignallingItem  *itemBypassBand11;
  KConfigBaseEE::ItemBool  *innerItemBypassBand11;
  innerItemBypassBand11 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "bypassBand11" ), mBypassBand11, false );
  itemBypassBand11 = new KConfigCompilerSignallingItem(innerItemBypassBand11, this, notifyFunction, signalBypassBand11Changed);
  itemBypassBand11->setWriteFlags(KConfigBase::Notify);
  itemBypassBand11->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemBypassBand11, QStringLiteral( "bypassBand11" ) );
  KConfigCompilerSignallingItem  *itemBypassBand12;
  KConfigBaseEE::ItemBool  *innerItemBypassBand12;
  innerItemBypassBand12 = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "bypassBand12" ), mBypassBand12, false );
  itemBypassBand12 = new KConfigCompilerSignallingItem(innerItemBypassBand12, this, notifyFunction, signalBypassBand12Changed);
  itemBypassBand12->setWriteFlags(KConfigBase::Notify);
  itemBypassBand12->setGroup(cgCrystalizerinstanceIndex);
  addItem( itemBypassBand12, QStringLiteral( "bypassBand12" ) );
}

bool DbCrystalizer::defaultBypassValue_helper() const
{

  return false;
}

double DbCrystalizer::defaultInputGainValue_helper() const
{

  return 0;
}

double DbCrystalizer::defaultOutputGainValue_helper() const
{

  return 0;
}

bool DbCrystalizer::defaultAdaptiveIntensityValue_helper() const
{

  return true;
}

bool DbCrystalizer::defaultOversamplingValue_helper() const
{

  return true;
}

double DbCrystalizer::defaultOversamplingQualityValue_helper() const
{

  return 5;
}

bool DbCrystalizer::defaultUseFixedQuantumValue_helper() const
{

  return false;
}

double DbCrystalizer::defaultTransitionBandValue_helper() const
{

  return 120;
}

double DbCrystalizer::defaultIntensityBand0Value_helper() const
{

  return 0;
}

double DbCrystalizer::defaultIntensityBand1Value_helper() const
{

  return 0;
}

double DbCrystalizer::defaultIntensityBand2Value_helper() const
{

  return -2;
}

double DbCrystalizer::defaultIntensityBand3Value_helper() const
{

  return 0;
}

double DbCrystalizer::defaultIntensityBand4Value_helper() const
{

  return 0;
}

double DbCrystalizer::defaultIntensityBand5Value_helper() const
{

  return 0;
}

double DbCrystalizer::defaultIntensityBand6Value_helper() const
{

  return 0;
}

double DbCrystalizer::defaultIntensityBand7Value_helper() const
{

  return 0;
}

double DbCrystalizer::defaultIntensityBand8Value_helper() const
{

  return 0;
}

double DbCrystalizer::defaultIntensityBand9Value_helper() const
{

  return 0;
}

double DbCrystalizer::defaultIntensityBand10Value_helper() const
{

  return 0;
}

double DbCrystalizer::defaultIntensityBand11Value_helper() const
{

  return 0;
}

double DbCrystalizer::defaultIntensityBand12Value_helper() const
{

  return 0;
}

bool DbCrystalizer::defaultMuteBand0Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultMuteBand1Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultMuteBand2Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultMuteBand3Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultMuteBand4Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultMuteBand5Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultMuteBand6Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultMuteBand7Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultMuteBand8Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultMuteBand9Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultMuteBand10Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultMuteBand11Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultMuteBand12Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultBypassBand0Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultBypassBand1Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultBypassBand2Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultBypassBand3Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultBypassBand4Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultBypassBand5Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultBypassBand6Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultBypassBand7Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultBypassBand8Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultBypassBand9Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultBypassBand10Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultBypassBand11Value_helper() const
{

  return false;
}

bool DbCrystalizer::defaultBypassBand12Value_helper() const
{

  return false;
}

DbCrystalizer::~DbCrystalizer()
{
}


void DbCrystalizer::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalBypassChanged:
    Q_EMIT bypassChanged();
    break;
  case signalInputGainChanged:
    Q_EMIT inputGainChanged();
    break;
  case signalOutputGainChanged:
    Q_EMIT outputGainChanged();
    break;
  case signalAdaptiveIntensityChanged:
    Q_EMIT adaptiveIntensityChanged();
    break;
  case signalOversamplingChanged:
    Q_EMIT oversamplingChanged();
    break;
  case signalOversamplingQualityChanged:
    Q_EMIT oversamplingQualityChanged();
    break;
  case signalUseFixedQuantumChanged:
    Q_EMIT useFixedQuantumChanged();
    break;
  case signalTransitionBandChanged:
    Q_EMIT transitionBandChanged();
    break;
  case signalIntensityBand0Changed:
    Q_EMIT intensityBand0Changed();
    break;
  case signalIntensityBand1Changed:
    Q_EMIT intensityBand1Changed();
    break;
  case signalIntensityBand2Changed:
    Q_EMIT intensityBand2Changed();
    break;
  case signalIntensityBand3Changed:
    Q_EMIT intensityBand3Changed();
    break;
  case signalIntensityBand4Changed:
    Q_EMIT intensityBand4Changed();
    break;
  case signalIntensityBand5Changed:
    Q_EMIT intensityBand5Changed();
    break;
  case signalIntensityBand6Changed:
    Q_EMIT intensityBand6Changed();
    break;
  case signalIntensityBand7Changed:
    Q_EMIT intensityBand7Changed();
    break;
  case signalIntensityBand8Changed:
    Q_EMIT intensityBand8Changed();
    break;
  case signalIntensityBand9Changed:
    Q_EMIT intensityBand9Changed();
    break;
  case signalIntensityBand10Changed:
    Q_EMIT intensityBand10Changed();
    break;
  case signalIntensityBand11Changed:
    Q_EMIT intensityBand11Changed();
    break;
  case signalIntensityBand12Changed:
    Q_EMIT intensityBand12Changed();
    break;
  case signalMuteBand0Changed:
    Q_EMIT muteBand0Changed();
    break;
  case signalMuteBand1Changed:
    Q_EMIT muteBand1Changed();
    break;
  case signalMuteBand2Changed:
    Q_EMIT muteBand2Changed();
    break;
  case signalMuteBand3Changed:
    Q_EMIT muteBand3Changed();
    break;
  case signalMuteBand4Changed:
    Q_EMIT muteBand4Changed();
    break;
  case signalMuteBand5Changed:
    Q_EMIT muteBand5Changed();
    break;
  case signalMuteBand6Changed:
    Q_EMIT muteBand6Changed();
    break;
  case signalMuteBand7Changed:
    Q_EMIT muteBand7Changed();
    break;
  case signalMuteBand8Changed:
    Q_EMIT muteBand8Changed();
    break;
  case signalMuteBand9Changed:
    Q_EMIT muteBand9Changed();
    break;
  case signalMuteBand10Changed:
    Q_EMIT muteBand10Changed();
    break;
  case signalMuteBand11Changed:
    Q_EMIT muteBand11Changed();
    break;
  case signalMuteBand12Changed:
    Q_EMIT muteBand12Changed();
    break;
  case signalBypassBand0Changed:
    Q_EMIT bypassBand0Changed();
    break;
  case signalBypassBand1Changed:
    Q_EMIT bypassBand1Changed();
    break;
  case signalBypassBand2Changed:
    Q_EMIT bypassBand2Changed();
    break;
  case signalBypassBand3Changed:
    Q_EMIT bypassBand3Changed();
    break;
  case signalBypassBand4Changed:
    Q_EMIT bypassBand4Changed();
    break;
  case signalBypassBand5Changed:
    Q_EMIT bypassBand5Changed();
    break;
  case signalBypassBand6Changed:
    Q_EMIT bypassBand6Changed();
    break;
  case signalBypassBand7Changed:
    Q_EMIT bypassBand7Changed();
    break;
  case signalBypassBand8Changed:
    Q_EMIT bypassBand8Changed();
    break;
  case signalBypassBand9Changed:
    Q_EMIT bypassBand9Changed();
    break;
  case signalBypassBand10Changed:
    Q_EMIT bypassBand10Changed();
    break;
  case signalBypassBand11Changed:
    Q_EMIT bypassBand11Changed();
    break;
  case signalBypassBand12Changed:
    Q_EMIT bypassBand12Changed();
    break;
  }
}
