/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6DbMainE_t {};
} // unnamed namespace

template <> constexpr inline auto DbMain::qt_create_metaobjectdata<qt_meta_tag_ZN6DbMainE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbMain",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "widthChanged",
        "",
        "heightChanged",
        "visibilityChanged",
        "enableServiceModeChanged",
        "showTrayIconChanged",
        "autostartOnLoginChanged",
        "noWindowAfterStartingChanged",
        "englishLanguageChanged",
        "reducePluginsListControlsChanged",
        "xdgGlobalShortcutsChanged",
        "xdgGlobalShortcutsBoundChanged",
        "databaseAutosaveIntervalChanged",
        "presetsAutoloadIntervalChanged",
        "maxMostUsedPresetsChanged",
        "autoHideInlineMessageTimeoutChanged",
        "inputAutoloadingUsesFallbackChanged",
        "outputAutoloadingUsesFallbackChanged",
        "inputAutoloadingFallbackPresetChanged",
        "outputAutoloadingFallbackPresetChanged",
        "visiblePageChanged",
        "visiblePresetSheetPageChanged",
        "visibleAutoloadingTabChanged",
        "visiblePipeWirePageChanged",
        "collapsePluginsListChanged",
        "forceBreezeThemeChanged",
        "ignorePresetBlocklistChanged",
        "lastLoadedInputPresetChanged",
        "lastLoadedOutputPresetChanged",
        "lastLoadedInputCommunityPackageChanged",
        "lastLoadedOutputCommunityPackageChanged",
        "bypassChanged",
        "processAllOutputsChanged",
        "processAllInputsChanged",
        "excludeMonitorStreamsChanged",
        "useCubicVolumesChanged",
        "ignoreSystemNotificationsChanged",
        "linkDelayEnableChanged",
        "linkDelayChanged",
        "inactivityTimerEnableChanged",
        "inactivityTimeoutChanged",
        "levelMetersLabelTimerChanged",
        "enableLevelMetersAnimationChanged",
        "levelMetersAnimationDurationChanged",
        "levelMetersFpsCapChanged",
        "copyFilterInputBuffersChanged",
        "activateMonitorChannelVolumesChanged",
        "showNativePluginUiChanged",
        "lv2uiUpdateFrequencyChanged",
        "width",
        "isWidthImmutable",
        "defaultWidthValue",
        "height",
        "isHeightImmutable",
        "defaultHeightValue",
        "visibility",
        "isVisibilityImmutable",
        "defaultVisibilityValue",
        "enableServiceMode",
        "isEnableServiceModeImmutable",
        "defaultEnableServiceModeValue",
        "showTrayIcon",
        "isShowTrayIconImmutable",
        "defaultShowTrayIconValue",
        "autostartOnLogin",
        "isAutostartOnLoginImmutable",
        "defaultAutostartOnLoginValue",
        "noWindowAfterStarting",
        "isNoWindowAfterStartingImmutable",
        "defaultNoWindowAfterStartingValue",
        "englishLanguage",
        "isEnglishLanguageImmutable",
        "defaultEnglishLanguageValue",
        "reducePluginsListControls",
        "isReducePluginsListControlsImmutable",
        "defaultReducePluginsListControlsValue",
        "xdgGlobalShortcuts",
        "isXdgGlobalShortcutsImmutable",
        "defaultXdgGlobalShortcutsValue",
        "xdgGlobalShortcutsBound",
        "isXdgGlobalShortcutsBoundImmutable",
        "defaultXdgGlobalShortcutsBoundValue",
        "databaseAutosaveInterval",
        "isDatabaseAutosaveIntervalImmutable",
        "defaultDatabaseAutosaveIntervalValue",
        "presetsAutoloadInterval",
        "isPresetsAutoloadIntervalImmutable",
        "defaultPresetsAutoloadIntervalValue",
        "maxMostUsedPresets",
        "isMaxMostUsedPresetsImmutable",
        "defaultMaxMostUsedPresetsValue",
        "autoHideInlineMessageTimeout",
        "isAutoHideInlineMessageTimeoutImmutable",
        "defaultAutoHideInlineMessageTimeoutValue",
        "inputAutoloadingUsesFallback",
        "isInputAutoloadingUsesFallbackImmutable",
        "defaultInputAutoloadingUsesFallbackValue",
        "outputAutoloadingUsesFallback",
        "isOutputAutoloadingUsesFallbackImmutable",
        "defaultOutputAutoloadingUsesFallbackValue",
        "inputAutoloadingFallbackPreset",
        "isInputAutoloadingFallbackPresetImmutable",
        "defaultInputAutoloadingFallbackPresetValue",
        "outputAutoloadingFallbackPreset",
        "isOutputAutoloadingFallbackPresetImmutable",
        "defaultOutputAutoloadingFallbackPresetValue",
        "visiblePage",
        "isVisiblePageImmutable",
        "defaultVisiblePageValue",
        "visiblePresetSheetPage",
        "isVisiblePresetSheetPageImmutable",
        "defaultVisiblePresetSheetPageValue",
        "visibleAutoloadingTab",
        "isVisibleAutoloadingTabImmutable",
        "defaultVisibleAutoloadingTabValue",
        "visiblePipeWirePage",
        "isVisiblePipeWirePageImmutable",
        "defaultVisiblePipeWirePageValue",
        "collapsePluginsList",
        "isCollapsePluginsListImmutable",
        "defaultCollapsePluginsListValue",
        "forceBreezeTheme",
        "isForceBreezeThemeImmutable",
        "defaultForceBreezeThemeValue",
        "ignorePresetBlocklist",
        "isIgnorePresetBlocklistImmutable",
        "defaultIgnorePresetBlocklistValue",
        "lastLoadedInputPreset",
        "isLastLoadedInputPresetImmutable",
        "defaultLastLoadedInputPresetValue",
        "lastLoadedOutputPreset",
        "isLastLoadedOutputPresetImmutable",
        "defaultLastLoadedOutputPresetValue",
        "lastLoadedInputCommunityPackage",
        "isLastLoadedInputCommunityPackageImmutable",
        "defaultLastLoadedInputCommunityPackageValue",
        "lastLoadedOutputCommunityPackage",
        "isLastLoadedOutputCommunityPackageImmutable",
        "defaultLastLoadedOutputCommunityPackageValue",
        "bypass",
        "isBypassImmutable",
        "defaultBypassValue",
        "processAllOutputs",
        "isProcessAllOutputsImmutable",
        "defaultProcessAllOutputsValue",
        "processAllInputs",
        "isProcessAllInputsImmutable",
        "defaultProcessAllInputsValue",
        "excludeMonitorStreams",
        "isExcludeMonitorStreamsImmutable",
        "defaultExcludeMonitorStreamsValue",
        "useCubicVolumes",
        "isUseCubicVolumesImmutable",
        "defaultUseCubicVolumesValue",
        "ignoreSystemNotifications",
        "isIgnoreSystemNotificationsImmutable",
        "defaultIgnoreSystemNotificationsValue",
        "linkDelayEnable",
        "isLinkDelayEnableImmutable",
        "defaultLinkDelayEnableValue",
        "linkDelay",
        "isLinkDelayImmutable",
        "defaultLinkDelayValue",
        "inactivityTimerEnable",
        "isInactivityTimerEnableImmutable",
        "defaultInactivityTimerEnableValue",
        "inactivityTimeout",
        "isInactivityTimeoutImmutable",
        "defaultInactivityTimeoutValue",
        "levelMetersLabelTimer",
        "isLevelMetersLabelTimerImmutable",
        "defaultLevelMetersLabelTimerValue",
        "enableLevelMetersAnimation",
        "isEnableLevelMetersAnimationImmutable",
        "defaultEnableLevelMetersAnimationValue",
        "levelMetersAnimationDuration",
        "isLevelMetersAnimationDurationImmutable",
        "defaultLevelMetersAnimationDurationValue",
        "levelMetersFpsCap",
        "isLevelMetersFpsCapImmutable",
        "defaultLevelMetersFpsCapValue",
        "copyFilterInputBuffers",
        "isCopyFilterInputBuffersImmutable",
        "defaultCopyFilterInputBuffersValue",
        "activateMonitorChannelVolumes",
        "isActivateMonitorChannelVolumesImmutable",
        "defaultActivateMonitorChannelVolumesValue",
        "showNativePluginUi",
        "isShowNativePluginUiImmutable",
        "defaultShowNativePluginUiValue",
        "lv2uiUpdateFrequency",
        "isLv2uiUpdateFrequencyImmutable",
        "defaultLv2uiUpdateFrequencyValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'widthChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'heightChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visibilityChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableServiceModeChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showTrayIconChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autostartOnLoginChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noWindowAfterStartingChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'englishLanguageChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reducePluginsListControlsChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'xdgGlobalShortcutsChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'xdgGlobalShortcutsBoundChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'databaseAutosaveIntervalChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'presetsAutoloadIntervalChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxMostUsedPresetsChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoHideInlineMessageTimeoutChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputAutoloadingUsesFallbackChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputAutoloadingUsesFallbackChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputAutoloadingFallbackPresetChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputAutoloadingFallbackPresetChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visiblePageChanged'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visiblePresetSheetPageChanged'
        QtMocHelpers::SignalData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visibleAutoloadingTabChanged'
        QtMocHelpers::SignalData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visiblePipeWirePageChanged'
        QtMocHelpers::SignalData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'collapsePluginsListChanged'
        QtMocHelpers::SignalData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'forceBreezeThemeChanged'
        QtMocHelpers::SignalData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ignorePresetBlocklistChanged'
        QtMocHelpers::SignalData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastLoadedInputPresetChanged'
        QtMocHelpers::SignalData<void()>(32, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastLoadedOutputPresetChanged'
        QtMocHelpers::SignalData<void()>(33, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastLoadedInputCommunityPackageChanged'
        QtMocHelpers::SignalData<void()>(34, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastLoadedOutputCommunityPackageChanged'
        QtMocHelpers::SignalData<void()>(35, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bypassChanged'
        QtMocHelpers::SignalData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'processAllOutputsChanged'
        QtMocHelpers::SignalData<void()>(37, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'processAllInputsChanged'
        QtMocHelpers::SignalData<void()>(38, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'excludeMonitorStreamsChanged'
        QtMocHelpers::SignalData<void()>(39, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useCubicVolumesChanged'
        QtMocHelpers::SignalData<void()>(40, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ignoreSystemNotificationsChanged'
        QtMocHelpers::SignalData<void()>(41, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'linkDelayEnableChanged'
        QtMocHelpers::SignalData<void()>(42, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'linkDelayChanged'
        QtMocHelpers::SignalData<void()>(43, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inactivityTimerEnableChanged'
        QtMocHelpers::SignalData<void()>(44, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inactivityTimeoutChanged'
        QtMocHelpers::SignalData<void()>(45, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'levelMetersLabelTimerChanged'
        QtMocHelpers::SignalData<void()>(46, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableLevelMetersAnimationChanged'
        QtMocHelpers::SignalData<void()>(47, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'levelMetersAnimationDurationChanged'
        QtMocHelpers::SignalData<void()>(48, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'levelMetersFpsCapChanged'
        QtMocHelpers::SignalData<void()>(49, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'copyFilterInputBuffersChanged'
        QtMocHelpers::SignalData<void()>(50, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activateMonitorChannelVolumesChanged'
        QtMocHelpers::SignalData<void()>(51, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showNativePluginUiChanged'
        QtMocHelpers::SignalData<void()>(52, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lv2uiUpdateFrequencyChanged'
        QtMocHelpers::SignalData<void()>(53, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'width'
        QtMocHelpers::PropertyData<int>(54, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isWidthImmutable'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWidthValue'
        QtMocHelpers::PropertyData<int>(56, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'height'
        QtMocHelpers::PropertyData<int>(57, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isHeightImmutable'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultHeightValue'
        QtMocHelpers::PropertyData<int>(59, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'visibility'
        QtMocHelpers::PropertyData<int>(60, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isVisibilityImmutable'
        QtMocHelpers::PropertyData<bool>(61, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVisibilityValue'
        QtMocHelpers::PropertyData<int>(62, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enableServiceMode'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isEnableServiceModeImmutable'
        QtMocHelpers::PropertyData<bool>(64, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnableServiceModeValue'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showTrayIcon'
        QtMocHelpers::PropertyData<bool>(66, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isShowTrayIconImmutable'
        QtMocHelpers::PropertyData<bool>(67, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowTrayIconValue'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autostartOnLogin'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isAutostartOnLoginImmutable'
        QtMocHelpers::PropertyData<bool>(70, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutostartOnLoginValue'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'noWindowAfterStarting'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isNoWindowAfterStartingImmutable'
        QtMocHelpers::PropertyData<bool>(73, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNoWindowAfterStartingValue'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'englishLanguage'
        QtMocHelpers::PropertyData<bool>(75, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isEnglishLanguageImmutable'
        QtMocHelpers::PropertyData<bool>(76, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnglishLanguageValue'
        QtMocHelpers::PropertyData<bool>(77, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'reducePluginsListControls'
        QtMocHelpers::PropertyData<bool>(78, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isReducePluginsListControlsImmutable'
        QtMocHelpers::PropertyData<bool>(79, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultReducePluginsListControlsValue'
        QtMocHelpers::PropertyData<bool>(80, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xdgGlobalShortcuts'
        QtMocHelpers::PropertyData<bool>(81, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isXdgGlobalShortcutsImmutable'
        QtMocHelpers::PropertyData<bool>(82, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultXdgGlobalShortcutsValue'
        QtMocHelpers::PropertyData<bool>(83, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'xdgGlobalShortcutsBound'
        QtMocHelpers::PropertyData<bool>(84, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isXdgGlobalShortcutsBoundImmutable'
        QtMocHelpers::PropertyData<bool>(85, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultXdgGlobalShortcutsBoundValue'
        QtMocHelpers::PropertyData<bool>(86, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'databaseAutosaveInterval'
        QtMocHelpers::PropertyData<int>(87, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isDatabaseAutosaveIntervalImmutable'
        QtMocHelpers::PropertyData<bool>(88, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDatabaseAutosaveIntervalValue'
        QtMocHelpers::PropertyData<int>(89, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'presetsAutoloadInterval'
        QtMocHelpers::PropertyData<int>(90, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isPresetsAutoloadIntervalImmutable'
        QtMocHelpers::PropertyData<bool>(91, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPresetsAutoloadIntervalValue'
        QtMocHelpers::PropertyData<int>(92, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maxMostUsedPresets'
        QtMocHelpers::PropertyData<int>(93, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isMaxMostUsedPresetsImmutable'
        QtMocHelpers::PropertyData<bool>(94, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMaxMostUsedPresetsValue'
        QtMocHelpers::PropertyData<int>(95, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoHideInlineMessageTimeout'
        QtMocHelpers::PropertyData<int>(96, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isAutoHideInlineMessageTimeoutImmutable'
        QtMocHelpers::PropertyData<bool>(97, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutoHideInlineMessageTimeoutValue'
        QtMocHelpers::PropertyData<int>(98, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputAutoloadingUsesFallback'
        QtMocHelpers::PropertyData<bool>(99, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isInputAutoloadingUsesFallbackImmutable'
        QtMocHelpers::PropertyData<bool>(100, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputAutoloadingUsesFallbackValue'
        QtMocHelpers::PropertyData<bool>(101, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'outputAutoloadingUsesFallback'
        QtMocHelpers::PropertyData<bool>(102, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isOutputAutoloadingUsesFallbackImmutable'
        QtMocHelpers::PropertyData<bool>(103, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOutputAutoloadingUsesFallbackValue'
        QtMocHelpers::PropertyData<bool>(104, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputAutoloadingFallbackPreset'
        QtMocHelpers::PropertyData<QString>(105, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'isInputAutoloadingFallbackPresetImmutable'
        QtMocHelpers::PropertyData<bool>(106, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputAutoloadingFallbackPresetValue'
        QtMocHelpers::PropertyData<QString>(107, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'outputAutoloadingFallbackPreset'
        QtMocHelpers::PropertyData<QString>(108, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'isOutputAutoloadingFallbackPresetImmutable'
        QtMocHelpers::PropertyData<bool>(109, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOutputAutoloadingFallbackPresetValue'
        QtMocHelpers::PropertyData<QString>(110, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'visiblePage'
        QtMocHelpers::PropertyData<int>(111, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'isVisiblePageImmutable'
        QtMocHelpers::PropertyData<bool>(112, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVisiblePageValue'
        QtMocHelpers::PropertyData<int>(113, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'visiblePresetSheetPage'
        QtMocHelpers::PropertyData<int>(114, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'isVisiblePresetSheetPageImmutable'
        QtMocHelpers::PropertyData<bool>(115, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVisiblePresetSheetPageValue'
        QtMocHelpers::PropertyData<int>(116, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'visibleAutoloadingTab'
        QtMocHelpers::PropertyData<int>(117, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'isVisibleAutoloadingTabImmutable'
        QtMocHelpers::PropertyData<bool>(118, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVisibleAutoloadingTabValue'
        QtMocHelpers::PropertyData<int>(119, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'visiblePipeWirePage'
        QtMocHelpers::PropertyData<int>(120, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'isVisiblePipeWirePageImmutable'
        QtMocHelpers::PropertyData<bool>(121, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVisiblePipeWirePageValue'
        QtMocHelpers::PropertyData<int>(122, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'collapsePluginsList'
        QtMocHelpers::PropertyData<bool>(123, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'isCollapsePluginsListImmutable'
        QtMocHelpers::PropertyData<bool>(124, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCollapsePluginsListValue'
        QtMocHelpers::PropertyData<bool>(125, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'forceBreezeTheme'
        QtMocHelpers::PropertyData<bool>(126, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'isForceBreezeThemeImmutable'
        QtMocHelpers::PropertyData<bool>(127, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultForceBreezeThemeValue'
        QtMocHelpers::PropertyData<bool>(128, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ignorePresetBlocklist'
        QtMocHelpers::PropertyData<bool>(129, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 25),
        // property 'isIgnorePresetBlocklistImmutable'
        QtMocHelpers::PropertyData<bool>(130, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIgnorePresetBlocklistValue'
        QtMocHelpers::PropertyData<bool>(131, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastLoadedInputPreset'
        QtMocHelpers::PropertyData<QString>(132, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 26),
        // property 'isLastLoadedInputPresetImmutable'
        QtMocHelpers::PropertyData<bool>(133, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLastLoadedInputPresetValue'
        QtMocHelpers::PropertyData<QString>(134, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastLoadedOutputPreset'
        QtMocHelpers::PropertyData<QString>(135, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 27),
        // property 'isLastLoadedOutputPresetImmutable'
        QtMocHelpers::PropertyData<bool>(136, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLastLoadedOutputPresetValue'
        QtMocHelpers::PropertyData<QString>(137, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastLoadedInputCommunityPackage'
        QtMocHelpers::PropertyData<QString>(138, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 28),
        // property 'isLastLoadedInputCommunityPackageImmutable'
        QtMocHelpers::PropertyData<bool>(139, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLastLoadedInputCommunityPackageValue'
        QtMocHelpers::PropertyData<QString>(140, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastLoadedOutputCommunityPackage'
        QtMocHelpers::PropertyData<QString>(141, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 29),
        // property 'isLastLoadedOutputCommunityPackageImmutable'
        QtMocHelpers::PropertyData<bool>(142, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLastLoadedOutputCommunityPackageValue'
        QtMocHelpers::PropertyData<QString>(143, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bypass'
        QtMocHelpers::PropertyData<bool>(144, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 30),
        // property 'isBypassImmutable'
        QtMocHelpers::PropertyData<bool>(145, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassValue'
        QtMocHelpers::PropertyData<bool>(146, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'processAllOutputs'
        QtMocHelpers::PropertyData<bool>(147, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 31),
        // property 'isProcessAllOutputsImmutable'
        QtMocHelpers::PropertyData<bool>(148, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProcessAllOutputsValue'
        QtMocHelpers::PropertyData<bool>(149, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'processAllInputs'
        QtMocHelpers::PropertyData<bool>(150, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 32),
        // property 'isProcessAllInputsImmutable'
        QtMocHelpers::PropertyData<bool>(151, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProcessAllInputsValue'
        QtMocHelpers::PropertyData<bool>(152, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'excludeMonitorStreams'
        QtMocHelpers::PropertyData<bool>(153, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 33),
        // property 'isExcludeMonitorStreamsImmutable'
        QtMocHelpers::PropertyData<bool>(154, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultExcludeMonitorStreamsValue'
        QtMocHelpers::PropertyData<bool>(155, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useCubicVolumes'
        QtMocHelpers::PropertyData<bool>(156, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 34),
        // property 'isUseCubicVolumesImmutable'
        QtMocHelpers::PropertyData<bool>(157, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultUseCubicVolumesValue'
        QtMocHelpers::PropertyData<bool>(158, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ignoreSystemNotifications'
        QtMocHelpers::PropertyData<bool>(159, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 35),
        // property 'isIgnoreSystemNotificationsImmutable'
        QtMocHelpers::PropertyData<bool>(160, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIgnoreSystemNotificationsValue'
        QtMocHelpers::PropertyData<bool>(161, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'linkDelayEnable'
        QtMocHelpers::PropertyData<bool>(162, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 36),
        // property 'isLinkDelayEnableImmutable'
        QtMocHelpers::PropertyData<bool>(163, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLinkDelayEnableValue'
        QtMocHelpers::PropertyData<bool>(164, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'linkDelay'
        QtMocHelpers::PropertyData<int>(165, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 37),
        // property 'isLinkDelayImmutable'
        QtMocHelpers::PropertyData<bool>(166, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLinkDelayValue'
        QtMocHelpers::PropertyData<int>(167, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inactivityTimerEnable'
        QtMocHelpers::PropertyData<bool>(168, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 38),
        // property 'isInactivityTimerEnableImmutable'
        QtMocHelpers::PropertyData<bool>(169, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInactivityTimerEnableValue'
        QtMocHelpers::PropertyData<bool>(170, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inactivityTimeout'
        QtMocHelpers::PropertyData<int>(171, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 39),
        // property 'isInactivityTimeoutImmutable'
        QtMocHelpers::PropertyData<bool>(172, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInactivityTimeoutValue'
        QtMocHelpers::PropertyData<int>(173, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'levelMetersLabelTimer'
        QtMocHelpers::PropertyData<int>(174, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 40),
        // property 'isLevelMetersLabelTimerImmutable'
        QtMocHelpers::PropertyData<bool>(175, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLevelMetersLabelTimerValue'
        QtMocHelpers::PropertyData<int>(176, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enableLevelMetersAnimation'
        QtMocHelpers::PropertyData<bool>(177, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 41),
        // property 'isEnableLevelMetersAnimationImmutable'
        QtMocHelpers::PropertyData<bool>(178, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnableLevelMetersAnimationValue'
        QtMocHelpers::PropertyData<bool>(179, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'levelMetersAnimationDuration'
        QtMocHelpers::PropertyData<int>(180, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 42),
        // property 'isLevelMetersAnimationDurationImmutable'
        QtMocHelpers::PropertyData<bool>(181, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLevelMetersAnimationDurationValue'
        QtMocHelpers::PropertyData<int>(182, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'levelMetersFpsCap'
        QtMocHelpers::PropertyData<int>(183, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 43),
        // property 'isLevelMetersFpsCapImmutable'
        QtMocHelpers::PropertyData<bool>(184, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLevelMetersFpsCapValue'
        QtMocHelpers::PropertyData<int>(185, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'copyFilterInputBuffers'
        QtMocHelpers::PropertyData<bool>(186, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 44),
        // property 'isCopyFilterInputBuffersImmutable'
        QtMocHelpers::PropertyData<bool>(187, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCopyFilterInputBuffersValue'
        QtMocHelpers::PropertyData<bool>(188, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'activateMonitorChannelVolumes'
        QtMocHelpers::PropertyData<bool>(189, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 45),
        // property 'isActivateMonitorChannelVolumesImmutable'
        QtMocHelpers::PropertyData<bool>(190, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultActivateMonitorChannelVolumesValue'
        QtMocHelpers::PropertyData<bool>(191, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showNativePluginUi'
        QtMocHelpers::PropertyData<bool>(192, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 46),
        // property 'isShowNativePluginUiImmutable'
        QtMocHelpers::PropertyData<bool>(193, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowNativePluginUiValue'
        QtMocHelpers::PropertyData<bool>(194, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lv2uiUpdateFrequency'
        QtMocHelpers::PropertyData<int>(195, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 47),
        // property 'isLv2uiUpdateFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(196, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLv2uiUpdateFrequencyValue'
        QtMocHelpers::PropertyData<int>(197, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DbMain, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbMain::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6DbMainE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6DbMainE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6DbMainE_t>.metaTypes,
    nullptr
} };

void DbMain::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbMain *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->widthChanged(); break;
        case 1: _t->heightChanged(); break;
        case 2: _t->visibilityChanged(); break;
        case 3: _t->enableServiceModeChanged(); break;
        case 4: _t->showTrayIconChanged(); break;
        case 5: _t->autostartOnLoginChanged(); break;
        case 6: _t->noWindowAfterStartingChanged(); break;
        case 7: _t->englishLanguageChanged(); break;
        case 8: _t->reducePluginsListControlsChanged(); break;
        case 9: _t->xdgGlobalShortcutsChanged(); break;
        case 10: _t->xdgGlobalShortcutsBoundChanged(); break;
        case 11: _t->databaseAutosaveIntervalChanged(); break;
        case 12: _t->presetsAutoloadIntervalChanged(); break;
        case 13: _t->maxMostUsedPresetsChanged(); break;
        case 14: _t->autoHideInlineMessageTimeoutChanged(); break;
        case 15: _t->inputAutoloadingUsesFallbackChanged(); break;
        case 16: _t->outputAutoloadingUsesFallbackChanged(); break;
        case 17: _t->inputAutoloadingFallbackPresetChanged(); break;
        case 18: _t->outputAutoloadingFallbackPresetChanged(); break;
        case 19: _t->visiblePageChanged(); break;
        case 20: _t->visiblePresetSheetPageChanged(); break;
        case 21: _t->visibleAutoloadingTabChanged(); break;
        case 22: _t->visiblePipeWirePageChanged(); break;
        case 23: _t->collapsePluginsListChanged(); break;
        case 24: _t->forceBreezeThemeChanged(); break;
        case 25: _t->ignorePresetBlocklistChanged(); break;
        case 26: _t->lastLoadedInputPresetChanged(); break;
        case 27: _t->lastLoadedOutputPresetChanged(); break;
        case 28: _t->lastLoadedInputCommunityPackageChanged(); break;
        case 29: _t->lastLoadedOutputCommunityPackageChanged(); break;
        case 30: _t->bypassChanged(); break;
        case 31: _t->processAllOutputsChanged(); break;
        case 32: _t->processAllInputsChanged(); break;
        case 33: _t->excludeMonitorStreamsChanged(); break;
        case 34: _t->useCubicVolumesChanged(); break;
        case 35: _t->ignoreSystemNotificationsChanged(); break;
        case 36: _t->linkDelayEnableChanged(); break;
        case 37: _t->linkDelayChanged(); break;
        case 38: _t->inactivityTimerEnableChanged(); break;
        case 39: _t->inactivityTimeoutChanged(); break;
        case 40: _t->levelMetersLabelTimerChanged(); break;
        case 41: _t->enableLevelMetersAnimationChanged(); break;
        case 42: _t->levelMetersAnimationDurationChanged(); break;
        case 43: _t->levelMetersFpsCapChanged(); break;
        case 44: _t->copyFilterInputBuffersChanged(); break;
        case 45: _t->activateMonitorChannelVolumesChanged(); break;
        case 46: _t->showNativePluginUiChanged(); break;
        case 47: _t->lv2uiUpdateFrequencyChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::widthChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::heightChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::visibilityChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::enableServiceModeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::showTrayIconChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::autostartOnLoginChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::noWindowAfterStartingChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::englishLanguageChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::reducePluginsListControlsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::xdgGlobalShortcutsChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::xdgGlobalShortcutsBoundChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::databaseAutosaveIntervalChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::presetsAutoloadIntervalChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::maxMostUsedPresetsChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::autoHideInlineMessageTimeoutChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::inputAutoloadingUsesFallbackChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::outputAutoloadingUsesFallbackChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::inputAutoloadingFallbackPresetChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::outputAutoloadingFallbackPresetChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::visiblePageChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::visiblePresetSheetPageChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::visibleAutoloadingTabChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::visiblePipeWirePageChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::collapsePluginsListChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::forceBreezeThemeChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::ignorePresetBlocklistChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::lastLoadedInputPresetChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::lastLoadedOutputPresetChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::lastLoadedInputCommunityPackageChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::lastLoadedOutputCommunityPackageChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::bypassChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::processAllOutputsChanged, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::processAllInputsChanged, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::excludeMonitorStreamsChanged, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::useCubicVolumesChanged, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::ignoreSystemNotificationsChanged, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::linkDelayEnableChanged, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::linkDelayChanged, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::inactivityTimerEnableChanged, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::inactivityTimeoutChanged, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::levelMetersLabelTimerChanged, 40))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::enableLevelMetersAnimationChanged, 41))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::levelMetersAnimationDurationChanged, 42))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::levelMetersFpsCapChanged, 43))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::copyFilterInputBuffersChanged, 44))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::activateMonitorChannelVolumesChanged, 45))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::showNativePluginUiChanged, 46))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMain::*)()>(_a, &DbMain::lv2uiUpdateFrequencyChanged, 47))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->width(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isWidthImmutable(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->defaultWidthValue(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->height(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isHeightImmutable(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->defaultHeightValue(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->visibility(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isVisibilityImmutable(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->defaultVisibilityValue(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->enableServiceMode(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isEnableServiceModeImmutable(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->defaultEnableServiceModeValue(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->showTrayIcon(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isShowTrayIconImmutable(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->defaultShowTrayIconValue(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->autostartOnLogin(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isAutostartOnLoginImmutable(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->defaultAutostartOnLoginValue(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->noWindowAfterStarting(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isNoWindowAfterStartingImmutable(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->defaultNoWindowAfterStartingValue(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->englishLanguage(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isEnglishLanguageImmutable(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->defaultEnglishLanguageValue(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->reducePluginsListControls(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isReducePluginsListControlsImmutable(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->defaultReducePluginsListControlsValue(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->xdgGlobalShortcuts(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isXdgGlobalShortcutsImmutable(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->defaultXdgGlobalShortcutsValue(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->xdgGlobalShortcutsBound(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isXdgGlobalShortcutsBoundImmutable(); break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->defaultXdgGlobalShortcutsBoundValue(); break;
        case 33: *reinterpret_cast<int*>(_v) = _t->databaseAutosaveInterval(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isDatabaseAutosaveIntervalImmutable(); break;
        case 35: *reinterpret_cast<int*>(_v) = _t->defaultDatabaseAutosaveIntervalValue(); break;
        case 36: *reinterpret_cast<int*>(_v) = _t->presetsAutoloadInterval(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isPresetsAutoloadIntervalImmutable(); break;
        case 38: *reinterpret_cast<int*>(_v) = _t->defaultPresetsAutoloadIntervalValue(); break;
        case 39: *reinterpret_cast<int*>(_v) = _t->maxMostUsedPresets(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->isMaxMostUsedPresetsImmutable(); break;
        case 41: *reinterpret_cast<int*>(_v) = _t->defaultMaxMostUsedPresetsValue(); break;
        case 42: *reinterpret_cast<int*>(_v) = _t->autoHideInlineMessageTimeout(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->isAutoHideInlineMessageTimeoutImmutable(); break;
        case 44: *reinterpret_cast<int*>(_v) = _t->defaultAutoHideInlineMessageTimeoutValue(); break;
        case 45: *reinterpret_cast<bool*>(_v) = _t->inputAutoloadingUsesFallback(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->isInputAutoloadingUsesFallbackImmutable(); break;
        case 47: *reinterpret_cast<bool*>(_v) = _t->defaultInputAutoloadingUsesFallbackValue(); break;
        case 48: *reinterpret_cast<bool*>(_v) = _t->outputAutoloadingUsesFallback(); break;
        case 49: *reinterpret_cast<bool*>(_v) = _t->isOutputAutoloadingUsesFallbackImmutable(); break;
        case 50: *reinterpret_cast<bool*>(_v) = _t->defaultOutputAutoloadingUsesFallbackValue(); break;
        case 51: *reinterpret_cast<QString*>(_v) = _t->inputAutoloadingFallbackPreset(); break;
        case 52: *reinterpret_cast<bool*>(_v) = _t->isInputAutoloadingFallbackPresetImmutable(); break;
        case 53: *reinterpret_cast<QString*>(_v) = _t->defaultInputAutoloadingFallbackPresetValue(); break;
        case 54: *reinterpret_cast<QString*>(_v) = _t->outputAutoloadingFallbackPreset(); break;
        case 55: *reinterpret_cast<bool*>(_v) = _t->isOutputAutoloadingFallbackPresetImmutable(); break;
        case 56: *reinterpret_cast<QString*>(_v) = _t->defaultOutputAutoloadingFallbackPresetValue(); break;
        case 57: *reinterpret_cast<int*>(_v) = _t->visiblePage(); break;
        case 58: *reinterpret_cast<bool*>(_v) = _t->isVisiblePageImmutable(); break;
        case 59: *reinterpret_cast<int*>(_v) = _t->defaultVisiblePageValue(); break;
        case 60: *reinterpret_cast<int*>(_v) = _t->visiblePresetSheetPage(); break;
        case 61: *reinterpret_cast<bool*>(_v) = _t->isVisiblePresetSheetPageImmutable(); break;
        case 62: *reinterpret_cast<int*>(_v) = _t->defaultVisiblePresetSheetPageValue(); break;
        case 63: *reinterpret_cast<int*>(_v) = _t->visibleAutoloadingTab(); break;
        case 64: *reinterpret_cast<bool*>(_v) = _t->isVisibleAutoloadingTabImmutable(); break;
        case 65: *reinterpret_cast<int*>(_v) = _t->defaultVisibleAutoloadingTabValue(); break;
        case 66: *reinterpret_cast<int*>(_v) = _t->visiblePipeWirePage(); break;
        case 67: *reinterpret_cast<bool*>(_v) = _t->isVisiblePipeWirePageImmutable(); break;
        case 68: *reinterpret_cast<int*>(_v) = _t->defaultVisiblePipeWirePageValue(); break;
        case 69: *reinterpret_cast<bool*>(_v) = _t->collapsePluginsList(); break;
        case 70: *reinterpret_cast<bool*>(_v) = _t->isCollapsePluginsListImmutable(); break;
        case 71: *reinterpret_cast<bool*>(_v) = _t->defaultCollapsePluginsListValue(); break;
        case 72: *reinterpret_cast<bool*>(_v) = _t->forceBreezeTheme(); break;
        case 73: *reinterpret_cast<bool*>(_v) = _t->isForceBreezeThemeImmutable(); break;
        case 74: *reinterpret_cast<bool*>(_v) = _t->defaultForceBreezeThemeValue(); break;
        case 75: *reinterpret_cast<bool*>(_v) = _t->ignorePresetBlocklist(); break;
        case 76: *reinterpret_cast<bool*>(_v) = _t->isIgnorePresetBlocklistImmutable(); break;
        case 77: *reinterpret_cast<bool*>(_v) = _t->defaultIgnorePresetBlocklistValue(); break;
        case 78: *reinterpret_cast<QString*>(_v) = _t->lastLoadedInputPreset(); break;
        case 79: *reinterpret_cast<bool*>(_v) = _t->isLastLoadedInputPresetImmutable(); break;
        case 80: *reinterpret_cast<QString*>(_v) = _t->defaultLastLoadedInputPresetValue(); break;
        case 81: *reinterpret_cast<QString*>(_v) = _t->lastLoadedOutputPreset(); break;
        case 82: *reinterpret_cast<bool*>(_v) = _t->isLastLoadedOutputPresetImmutable(); break;
        case 83: *reinterpret_cast<QString*>(_v) = _t->defaultLastLoadedOutputPresetValue(); break;
        case 84: *reinterpret_cast<QString*>(_v) = _t->lastLoadedInputCommunityPackage(); break;
        case 85: *reinterpret_cast<bool*>(_v) = _t->isLastLoadedInputCommunityPackageImmutable(); break;
        case 86: *reinterpret_cast<QString*>(_v) = _t->defaultLastLoadedInputCommunityPackageValue(); break;
        case 87: *reinterpret_cast<QString*>(_v) = _t->lastLoadedOutputCommunityPackage(); break;
        case 88: *reinterpret_cast<bool*>(_v) = _t->isLastLoadedOutputCommunityPackageImmutable(); break;
        case 89: *reinterpret_cast<QString*>(_v) = _t->defaultLastLoadedOutputCommunityPackageValue(); break;
        case 90: *reinterpret_cast<bool*>(_v) = _t->bypass(); break;
        case 91: *reinterpret_cast<bool*>(_v) = _t->isBypassImmutable(); break;
        case 92: *reinterpret_cast<bool*>(_v) = _t->defaultBypassValue(); break;
        case 93: *reinterpret_cast<bool*>(_v) = _t->processAllOutputs(); break;
        case 94: *reinterpret_cast<bool*>(_v) = _t->isProcessAllOutputsImmutable(); break;
        case 95: *reinterpret_cast<bool*>(_v) = _t->defaultProcessAllOutputsValue(); break;
        case 96: *reinterpret_cast<bool*>(_v) = _t->processAllInputs(); break;
        case 97: *reinterpret_cast<bool*>(_v) = _t->isProcessAllInputsImmutable(); break;
        case 98: *reinterpret_cast<bool*>(_v) = _t->defaultProcessAllInputsValue(); break;
        case 99: *reinterpret_cast<bool*>(_v) = _t->excludeMonitorStreams(); break;
        case 100: *reinterpret_cast<bool*>(_v) = _t->isExcludeMonitorStreamsImmutable(); break;
        case 101: *reinterpret_cast<bool*>(_v) = _t->defaultExcludeMonitorStreamsValue(); break;
        case 102: *reinterpret_cast<bool*>(_v) = _t->useCubicVolumes(); break;
        case 103: *reinterpret_cast<bool*>(_v) = _t->isUseCubicVolumesImmutable(); break;
        case 104: *reinterpret_cast<bool*>(_v) = _t->defaultUseCubicVolumesValue(); break;
        case 105: *reinterpret_cast<bool*>(_v) = _t->ignoreSystemNotifications(); break;
        case 106: *reinterpret_cast<bool*>(_v) = _t->isIgnoreSystemNotificationsImmutable(); break;
        case 107: *reinterpret_cast<bool*>(_v) = _t->defaultIgnoreSystemNotificationsValue(); break;
        case 108: *reinterpret_cast<bool*>(_v) = _t->linkDelayEnable(); break;
        case 109: *reinterpret_cast<bool*>(_v) = _t->isLinkDelayEnableImmutable(); break;
        case 110: *reinterpret_cast<bool*>(_v) = _t->defaultLinkDelayEnableValue(); break;
        case 111: *reinterpret_cast<int*>(_v) = _t->linkDelay(); break;
        case 112: *reinterpret_cast<bool*>(_v) = _t->isLinkDelayImmutable(); break;
        case 113: *reinterpret_cast<int*>(_v) = _t->defaultLinkDelayValue(); break;
        case 114: *reinterpret_cast<bool*>(_v) = _t->inactivityTimerEnable(); break;
        case 115: *reinterpret_cast<bool*>(_v) = _t->isInactivityTimerEnableImmutable(); break;
        case 116: *reinterpret_cast<bool*>(_v) = _t->defaultInactivityTimerEnableValue(); break;
        case 117: *reinterpret_cast<int*>(_v) = _t->inactivityTimeout(); break;
        case 118: *reinterpret_cast<bool*>(_v) = _t->isInactivityTimeoutImmutable(); break;
        case 119: *reinterpret_cast<int*>(_v) = _t->defaultInactivityTimeoutValue(); break;
        case 120: *reinterpret_cast<int*>(_v) = _t->levelMetersLabelTimer(); break;
        case 121: *reinterpret_cast<bool*>(_v) = _t->isLevelMetersLabelTimerImmutable(); break;
        case 122: *reinterpret_cast<int*>(_v) = _t->defaultLevelMetersLabelTimerValue(); break;
        case 123: *reinterpret_cast<bool*>(_v) = _t->enableLevelMetersAnimation(); break;
        case 124: *reinterpret_cast<bool*>(_v) = _t->isEnableLevelMetersAnimationImmutable(); break;
        case 125: *reinterpret_cast<bool*>(_v) = _t->defaultEnableLevelMetersAnimationValue(); break;
        case 126: *reinterpret_cast<int*>(_v) = _t->levelMetersAnimationDuration(); break;
        case 127: *reinterpret_cast<bool*>(_v) = _t->isLevelMetersAnimationDurationImmutable(); break;
        case 128: *reinterpret_cast<int*>(_v) = _t->defaultLevelMetersAnimationDurationValue(); break;
        case 129: *reinterpret_cast<int*>(_v) = _t->levelMetersFpsCap(); break;
        case 130: *reinterpret_cast<bool*>(_v) = _t->isLevelMetersFpsCapImmutable(); break;
        case 131: *reinterpret_cast<int*>(_v) = _t->defaultLevelMetersFpsCapValue(); break;
        case 132: *reinterpret_cast<bool*>(_v) = _t->copyFilterInputBuffers(); break;
        case 133: *reinterpret_cast<bool*>(_v) = _t->isCopyFilterInputBuffersImmutable(); break;
        case 134: *reinterpret_cast<bool*>(_v) = _t->defaultCopyFilterInputBuffersValue(); break;
        case 135: *reinterpret_cast<bool*>(_v) = _t->activateMonitorChannelVolumes(); break;
        case 136: *reinterpret_cast<bool*>(_v) = _t->isActivateMonitorChannelVolumesImmutable(); break;
        case 137: *reinterpret_cast<bool*>(_v) = _t->defaultActivateMonitorChannelVolumesValue(); break;
        case 138: *reinterpret_cast<bool*>(_v) = _t->showNativePluginUi(); break;
        case 139: *reinterpret_cast<bool*>(_v) = _t->isShowNativePluginUiImmutable(); break;
        case 140: *reinterpret_cast<bool*>(_v) = _t->defaultShowNativePluginUiValue(); break;
        case 141: *reinterpret_cast<int*>(_v) = _t->lv2uiUpdateFrequency(); break;
        case 142: *reinterpret_cast<bool*>(_v) = _t->isLv2uiUpdateFrequencyImmutable(); break;
        case 143: *reinterpret_cast<int*>(_v) = _t->defaultLv2uiUpdateFrequencyValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setWidth(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setHeight(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setVisibility(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setEnableServiceMode(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setShowTrayIcon(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setAutostartOnLogin(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setNoWindowAfterStarting(*reinterpret_cast<bool*>(_v)); break;
        case 21: _t->setEnglishLanguage(*reinterpret_cast<bool*>(_v)); break;
        case 24: _t->setReducePluginsListControls(*reinterpret_cast<bool*>(_v)); break;
        case 27: _t->setXdgGlobalShortcuts(*reinterpret_cast<bool*>(_v)); break;
        case 30: _t->setXdgGlobalShortcutsBound(*reinterpret_cast<bool*>(_v)); break;
        case 33: _t->setDatabaseAutosaveInterval(*reinterpret_cast<int*>(_v)); break;
        case 36: _t->setPresetsAutoloadInterval(*reinterpret_cast<int*>(_v)); break;
        case 39: _t->setMaxMostUsedPresets(*reinterpret_cast<int*>(_v)); break;
        case 42: _t->setAutoHideInlineMessageTimeout(*reinterpret_cast<int*>(_v)); break;
        case 45: _t->setInputAutoloadingUsesFallback(*reinterpret_cast<bool*>(_v)); break;
        case 48: _t->setOutputAutoloadingUsesFallback(*reinterpret_cast<bool*>(_v)); break;
        case 51: _t->setInputAutoloadingFallbackPreset(*reinterpret_cast<QString*>(_v)); break;
        case 54: _t->setOutputAutoloadingFallbackPreset(*reinterpret_cast<QString*>(_v)); break;
        case 57: _t->setVisiblePage(*reinterpret_cast<int*>(_v)); break;
        case 60: _t->setVisiblePresetSheetPage(*reinterpret_cast<int*>(_v)); break;
        case 63: _t->setVisibleAutoloadingTab(*reinterpret_cast<int*>(_v)); break;
        case 66: _t->setVisiblePipeWirePage(*reinterpret_cast<int*>(_v)); break;
        case 69: _t->setCollapsePluginsList(*reinterpret_cast<bool*>(_v)); break;
        case 72: _t->setForceBreezeTheme(*reinterpret_cast<bool*>(_v)); break;
        case 75: _t->setIgnorePresetBlocklist(*reinterpret_cast<bool*>(_v)); break;
        case 78: _t->setLastLoadedInputPreset(*reinterpret_cast<QString*>(_v)); break;
        case 81: _t->setLastLoadedOutputPreset(*reinterpret_cast<QString*>(_v)); break;
        case 84: _t->setLastLoadedInputCommunityPackage(*reinterpret_cast<QString*>(_v)); break;
        case 87: _t->setLastLoadedOutputCommunityPackage(*reinterpret_cast<QString*>(_v)); break;
        case 90: _t->setBypass(*reinterpret_cast<bool*>(_v)); break;
        case 93: _t->setProcessAllOutputs(*reinterpret_cast<bool*>(_v)); break;
        case 96: _t->setProcessAllInputs(*reinterpret_cast<bool*>(_v)); break;
        case 99: _t->setExcludeMonitorStreams(*reinterpret_cast<bool*>(_v)); break;
        case 102: _t->setUseCubicVolumes(*reinterpret_cast<bool*>(_v)); break;
        case 105: _t->setIgnoreSystemNotifications(*reinterpret_cast<bool*>(_v)); break;
        case 108: _t->setLinkDelayEnable(*reinterpret_cast<bool*>(_v)); break;
        case 111: _t->setLinkDelay(*reinterpret_cast<int*>(_v)); break;
        case 114: _t->setInactivityTimerEnable(*reinterpret_cast<bool*>(_v)); break;
        case 117: _t->setInactivityTimeout(*reinterpret_cast<int*>(_v)); break;
        case 120: _t->setLevelMetersLabelTimer(*reinterpret_cast<int*>(_v)); break;
        case 123: _t->setEnableLevelMetersAnimation(*reinterpret_cast<bool*>(_v)); break;
        case 126: _t->setLevelMetersAnimationDuration(*reinterpret_cast<int*>(_v)); break;
        case 129: _t->setLevelMetersFpsCap(*reinterpret_cast<int*>(_v)); break;
        case 132: _t->setCopyFilterInputBuffers(*reinterpret_cast<bool*>(_v)); break;
        case 135: _t->setActivateMonitorChannelVolumes(*reinterpret_cast<bool*>(_v)); break;
        case 138: _t->setShowNativePluginUi(*reinterpret_cast<bool*>(_v)); break;
        case 141: _t->setLv2uiUpdateFrequency(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbMain::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbMain::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6DbMainE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbMain::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 48)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 48;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 48)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 48;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 144;
    }
    return _id;
}

// SIGNAL 0
void DbMain::widthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbMain::heightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbMain::visibilityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbMain::enableServiceModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DbMain::showTrayIconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DbMain::autostartOnLoginChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DbMain::noWindowAfterStartingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DbMain::englishLanguageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DbMain::reducePluginsListControlsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DbMain::xdgGlobalShortcutsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DbMain::xdgGlobalShortcutsBoundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DbMain::databaseAutosaveIntervalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void DbMain::presetsAutoloadIntervalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void DbMain::maxMostUsedPresetsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void DbMain::autoHideInlineMessageTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void DbMain::inputAutoloadingUsesFallbackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void DbMain::outputAutoloadingUsesFallbackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void DbMain::inputAutoloadingFallbackPresetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void DbMain::outputAutoloadingFallbackPresetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void DbMain::visiblePageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void DbMain::visiblePresetSheetPageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void DbMain::visibleAutoloadingTabChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void DbMain::visiblePipeWirePageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void DbMain::collapsePluginsListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void DbMain::forceBreezeThemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void DbMain::ignorePresetBlocklistChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void DbMain::lastLoadedInputPresetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void DbMain::lastLoadedOutputPresetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void DbMain::lastLoadedInputCommunityPackageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void DbMain::lastLoadedOutputCommunityPackageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void DbMain::bypassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void DbMain::processAllOutputsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void DbMain::processAllInputsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}

// SIGNAL 33
void DbMain::excludeMonitorStreamsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 33, nullptr);
}

// SIGNAL 34
void DbMain::useCubicVolumesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 34, nullptr);
}

// SIGNAL 35
void DbMain::ignoreSystemNotificationsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 35, nullptr);
}

// SIGNAL 36
void DbMain::linkDelayEnableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 36, nullptr);
}

// SIGNAL 37
void DbMain::linkDelayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 37, nullptr);
}

// SIGNAL 38
void DbMain::inactivityTimerEnableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 38, nullptr);
}

// SIGNAL 39
void DbMain::inactivityTimeoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 39, nullptr);
}

// SIGNAL 40
void DbMain::levelMetersLabelTimerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 40, nullptr);
}

// SIGNAL 41
void DbMain::enableLevelMetersAnimationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 41, nullptr);
}

// SIGNAL 42
void DbMain::levelMetersAnimationDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 42, nullptr);
}

// SIGNAL 43
void DbMain::levelMetersFpsCapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 43, nullptr);
}

// SIGNAL 44
void DbMain::copyFilterInputBuffersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 44, nullptr);
}

// SIGNAL 45
void DbMain::activateMonitorChannelVolumesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 45, nullptr);
}

// SIGNAL 46
void DbMain::showNativePluginUiChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 46, nullptr);
}

// SIGNAL 47
void DbMain::lv2uiUpdateFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 47, nullptr);
}
QT_WARNING_POP
