/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db_test_signals.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db_test_signals.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db_test_signals.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13DbTestSignalsE_t {};
} // unnamed namespace

template <> constexpr inline auto DbTestSignals::qt_create_metaobjectdata<qt_meta_tag_ZN13DbTestSignalsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbTestSignals",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "enableChanged",
        "",
        "frequencyChanged",
        "channelsChanged",
        "signalTypeChanged",
        "enable",
        "isEnableImmutable",
        "defaultEnableValue",
        "frequency",
        "isFrequencyImmutable",
        "defaultFrequencyValue",
        "channels",
        "isChannelsImmutable",
        "defaultChannelsValue",
        "signalType",
        "isSignalTypeImmutable",
        "defaultSignalTypeValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enableChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'frequencyChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'channelsChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalTypeChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'enable'
        QtMocHelpers::PropertyData<bool>(10, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isEnableImmutable'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnableValue'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'frequency'
        QtMocHelpers::PropertyData<double>(13, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFrequencyValue'
        QtMocHelpers::PropertyData<double>(15, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'channels'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isChannelsImmutable'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultChannelsValue'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'signalType'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isSignalTypeImmutable'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSignalTypeValue'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DbTestSignals, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbTestSignals::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DbTestSignalsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DbTestSignalsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DbTestSignalsE_t>.metaTypes,
    nullptr
} };

void DbTestSignals::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbTestSignals *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enableChanged(); break;
        case 1: _t->frequencyChanged(); break;
        case 2: _t->channelsChanged(); break;
        case 3: _t->signalTypeChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbTestSignals::*)()>(_a, &DbTestSignals::enableChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbTestSignals::*)()>(_a, &DbTestSignals::frequencyChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbTestSignals::*)()>(_a, &DbTestSignals::channelsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbTestSignals::*)()>(_a, &DbTestSignals::signalTypeChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->enable(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isEnableImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultEnableValue(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->frequency(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isFrequencyImmutable(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->defaultFrequencyValue(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->channels(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isChannelsImmutable(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->defaultChannelsValue(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->signalType(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isSignalTypeImmutable(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->defaultSignalTypeValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setEnable(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setFrequency(*reinterpret_cast<double*>(_v)); break;
        case 6: _t->setChannels(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setSignalType(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbTestSignals::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbTestSignals::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DbTestSignalsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbTestSignals::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void DbTestSignals::enableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbTestSignals::frequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbTestSignals::channelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbTestSignals::signalTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
