/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db_loudness.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db_loudness.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db_loudness.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10DbLoudnessE_t {};
} // unnamed namespace

template <> constexpr inline auto DbLoudness::qt_create_metaobjectdata<qt_meta_tag_ZN10DbLoudnessE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbLoudness",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "bypassChanged",
        "inputGainChanged",
        "outputGainChanged",
        "modeLabelsChanged",
        "modeChanged",
        "fftLabelsChanged",
        "fftChanged",
        "stdLabelsChanged",
        "stdChanged",
        "volumeChanged",
        "clippingChanged",
        "clippingRangeChanged",
        "iirApproximationLabelsChanged",
        "iirApproximationChanged",
        "bypass",
        "isBypassImmutable",
        "defaultBypassValue",
        "inputGain",
        "isInputGainImmutable",
        "defaultInputGainValue",
        "outputGain",
        "isOutputGainImmutable",
        "defaultOutputGainValue",
        "modeLabels",
        "isModeLabelsImmutable",
        "defaultModeLabelsValue",
        "mode",
        "isModeImmutable",
        "defaultModeValue",
        "fftLabels",
        "isFftLabelsImmutable",
        "defaultFftLabelsValue",
        "fft",
        "isFftImmutable",
        "defaultFftValue",
        "stdLabels",
        "isStdLabelsImmutable",
        "defaultStdLabelsValue",
        "std",
        "isStdImmutable",
        "defaultStdValue",
        "volume",
        "isVolumeImmutable",
        "defaultVolumeValue",
        "clipping",
        "isClippingImmutable",
        "defaultClippingValue",
        "clippingRange",
        "isClippingRangeImmutable",
        "defaultClippingRangeValue",
        "iirApproximationLabels",
        "isIirApproximationLabelsImmutable",
        "defaultIirApproximationLabelsValue",
        "iirApproximation",
        "isIirApproximationImmutable",
        "defaultIirApproximationValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bypassChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputGainChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputGainChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeLabelsChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fftLabelsChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fftChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stdLabelsChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stdChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'volumeChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clippingChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clippingRangeChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iirApproximationLabelsChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iirApproximationChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bypass'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isBypassImmutable'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassValue'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputGain'
        QtMocHelpers::PropertyData<double>(24, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isInputGainImmutable'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputGainValue'
        QtMocHelpers::PropertyData<double>(26, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'outputGain'
        QtMocHelpers::PropertyData<double>(27, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isOutputGainImmutable'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOutputGainValue'
        QtMocHelpers::PropertyData<double>(29, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'modeLabels'
        QtMocHelpers::PropertyData<QStringList>(30, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isModeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultModeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(32, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mode'
        QtMocHelpers::PropertyData<int>(33, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isModeImmutable'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultModeValue'
        QtMocHelpers::PropertyData<int>(35, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fftLabels'
        QtMocHelpers::PropertyData<QStringList>(36, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isFftLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFftLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(38, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fft'
        QtMocHelpers::PropertyData<int>(39, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isFftImmutable'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFftValue'
        QtMocHelpers::PropertyData<int>(41, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stdLabels'
        QtMocHelpers::PropertyData<QStringList>(42, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isStdLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultStdLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(44, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'std'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isStdImmutable'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultStdValue'
        QtMocHelpers::PropertyData<int>(47, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'volume'
        QtMocHelpers::PropertyData<double>(48, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isVolumeImmutable'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVolumeValue'
        QtMocHelpers::PropertyData<double>(50, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'clipping'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isClippingImmutable'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultClippingValue'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'clippingRange'
        QtMocHelpers::PropertyData<double>(54, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isClippingRangeImmutable'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultClippingRangeValue'
        QtMocHelpers::PropertyData<double>(56, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iirApproximationLabels'
        QtMocHelpers::PropertyData<QStringList>(57, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isIirApproximationLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIirApproximationLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(59, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iirApproximation'
        QtMocHelpers::PropertyData<int>(60, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isIirApproximationImmutable'
        QtMocHelpers::PropertyData<bool>(61, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIirApproximationValue'
        QtMocHelpers::PropertyData<int>(62, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DbLoudness, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbLoudness::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10DbLoudnessE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10DbLoudnessE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10DbLoudnessE_t>.metaTypes,
    nullptr
} };

void DbLoudness::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbLoudness *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bypassChanged(); break;
        case 1: _t->inputGainChanged(); break;
        case 2: _t->outputGainChanged(); break;
        case 3: _t->modeLabelsChanged(); break;
        case 4: _t->modeChanged(); break;
        case 5: _t->fftLabelsChanged(); break;
        case 6: _t->fftChanged(); break;
        case 7: _t->stdLabelsChanged(); break;
        case 8: _t->stdChanged(); break;
        case 9: _t->volumeChanged(); break;
        case 10: _t->clippingChanged(); break;
        case 11: _t->clippingRangeChanged(); break;
        case 12: _t->iirApproximationLabelsChanged(); break;
        case 13: _t->iirApproximationChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbLoudness::*)()>(_a, &DbLoudness::bypassChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLoudness::*)()>(_a, &DbLoudness::inputGainChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLoudness::*)()>(_a, &DbLoudness::outputGainChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLoudness::*)()>(_a, &DbLoudness::modeLabelsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLoudness::*)()>(_a, &DbLoudness::modeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLoudness::*)()>(_a, &DbLoudness::fftLabelsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLoudness::*)()>(_a, &DbLoudness::fftChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLoudness::*)()>(_a, &DbLoudness::stdLabelsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLoudness::*)()>(_a, &DbLoudness::stdChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLoudness::*)()>(_a, &DbLoudness::volumeChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLoudness::*)()>(_a, &DbLoudness::clippingChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLoudness::*)()>(_a, &DbLoudness::clippingRangeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLoudness::*)()>(_a, &DbLoudness::iirApproximationLabelsChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbLoudness::*)()>(_a, &DbLoudness::iirApproximationChanged, 13))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bypass(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isBypassImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultBypassValue(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->inputGain(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isInputGainImmutable(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->defaultInputGainValue(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->outputGain(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isOutputGainImmutable(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->defaultOutputGainValue(); break;
        case 9: *reinterpret_cast<QStringList*>(_v) = _t->modeLabels(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isModeLabelsImmutable(); break;
        case 11: *reinterpret_cast<QStringList*>(_v) = _t->defaultModeLabelsValue(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->mode(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isModeImmutable(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->defaultModeValue(); break;
        case 15: *reinterpret_cast<QStringList*>(_v) = _t->fftLabels(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isFftLabelsImmutable(); break;
        case 17: *reinterpret_cast<QStringList*>(_v) = _t->defaultFftLabelsValue(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->fft(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isFftImmutable(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->defaultFftValue(); break;
        case 21: *reinterpret_cast<QStringList*>(_v) = _t->stdLabels(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isStdLabelsImmutable(); break;
        case 23: *reinterpret_cast<QStringList*>(_v) = _t->defaultStdLabelsValue(); break;
        case 24: *reinterpret_cast<int*>(_v) = _t->std(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isStdImmutable(); break;
        case 26: *reinterpret_cast<int*>(_v) = _t->defaultStdValue(); break;
        case 27: *reinterpret_cast<double*>(_v) = _t->volume(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isVolumeImmutable(); break;
        case 29: *reinterpret_cast<double*>(_v) = _t->defaultVolumeValue(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->clipping(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isClippingImmutable(); break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->defaultClippingValue(); break;
        case 33: *reinterpret_cast<double*>(_v) = _t->clippingRange(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isClippingRangeImmutable(); break;
        case 35: *reinterpret_cast<double*>(_v) = _t->defaultClippingRangeValue(); break;
        case 36: *reinterpret_cast<QStringList*>(_v) = _t->iirApproximationLabels(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isIirApproximationLabelsImmutable(); break;
        case 38: *reinterpret_cast<QStringList*>(_v) = _t->defaultIirApproximationLabelsValue(); break;
        case 39: *reinterpret_cast<int*>(_v) = _t->iirApproximation(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->isIirApproximationImmutable(); break;
        case 41: *reinterpret_cast<int*>(_v) = _t->defaultIirApproximationValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBypass(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setInputGain(*reinterpret_cast<double*>(_v)); break;
        case 6: _t->setOutputGain(*reinterpret_cast<double*>(_v)); break;
        case 9: _t->setModeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 12: _t->setMode(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setFftLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 18: _t->setFft(*reinterpret_cast<int*>(_v)); break;
        case 21: _t->setStdLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 24: _t->setStd(*reinterpret_cast<int*>(_v)); break;
        case 27: _t->setVolume(*reinterpret_cast<double*>(_v)); break;
        case 30: _t->setClipping(*reinterpret_cast<bool*>(_v)); break;
        case 33: _t->setClippingRange(*reinterpret_cast<double*>(_v)); break;
        case 36: _t->setIirApproximationLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 39: _t->setIirApproximation(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbLoudness::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbLoudness::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10DbLoudnessE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbLoudness::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 42;
    }
    return _id;
}

// SIGNAL 0
void DbLoudness::bypassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbLoudness::inputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbLoudness::outputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbLoudness::modeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DbLoudness::modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DbLoudness::fftLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DbLoudness::fftChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DbLoudness::stdLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DbLoudness::stdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DbLoudness::volumeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DbLoudness::clippingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DbLoudness::clippingRangeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void DbLoudness::iirApproximationLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void DbLoudness::iirApproximationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}
QT_WARNING_POP
