/****************************************************************************
** Meta object code from reading C++ file 'presets_manager.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../easyeffects-8.2.8/src/presets_manager.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'presets_manager.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7presets7ManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto presets::Manager::qt_create_metaobjectdata<qt_meta_tag_ZN7presets7ManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "presets::Manager",
        "QML.Element",
        "PresetsManager",
        "QML.Singleton",
        "true",
        "presetLoadError",
        "",
        "msg1",
        "msg2",
        "add",
        "PipelineType",
        "pipeline_type",
        "name",
        "savePresetFile",
        "remove",
        "renameLocalPresetFile",
        "newName",
        "loadLocalPresetFile",
        "importPresets",
        "url_list",
        "exportPresets",
        "dirUrl",
        "importImpulses",
        "importRNNoiseModel",
        "removeImpulseFile",
        "filePath",
        "renameImpulseFile",
        "removeRNNoiseModel",
        "refreshCommunityPresets",
        "loadCommunityPresetFile",
        "file_path",
        "package_name",
        "importFromCommunityPackage",
        "package",
        "addAutoload",
        "pipelineType",
        "presetName",
        "deviceName",
        "deviceDescription",
        "deviceProfile",
        "removeAutoload",
        "sortedInputListModel",
        "QSortFilterProxyModel*",
        "sortedOutputListModel",
        "sortedCommunityInputListModel",
        "sortedCommunityOutputListModel",
        "sortedAutoloadInputListModel",
        "sortedAutoloadOutputListModel",
        "sortedImpulseListModel",
        "sortedRNNoiseListModel"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'presetLoadError'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Method 'add'
        QtMocHelpers::MethodData<bool(const PipelineType &, const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QString, 12 },
        }}),
        // Method 'savePresetFile'
        QtMocHelpers::MethodData<bool(const PipelineType &, const QString &)>(13, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QString, 12 },
        }}),
        // Method 'remove'
        QtMocHelpers::MethodData<bool(const PipelineType &, const QString &)>(14, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QString, 12 },
        }}),
        // Method 'renameLocalPresetFile'
        QtMocHelpers::MethodData<bool(const PipelineType &, const QString &, const QString &)>(15, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 16 },
        }}),
        // Method 'loadLocalPresetFile'
        QtMocHelpers::MethodData<bool(const PipelineType &, const QString &)>(17, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QString, 12 },
        }}),
        // Method 'importPresets'
        QtMocHelpers::MethodData<bool(const PipelineType &, const QList<QString> &)>(18, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QStringList, 19 },
        }}),
        // Method 'exportPresets'
        QtMocHelpers::MethodData<bool(const PipelineType &, const QString &)>(20, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QString, 21 },
        }}),
        // Method 'importImpulses'
        QtMocHelpers::MethodData<int(const QList<QString> &)>(22, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QStringList, 19 },
        }}),
        // Method 'importRNNoiseModel'
        QtMocHelpers::MethodData<int(const QList<QString> &)>(23, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QStringList, 19 },
        }}),
        // Method 'removeImpulseFile'
        QtMocHelpers::MethodData<bool(const QString &)>(24, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 25 },
        }}),
        // Method 'renameImpulseFile'
        QtMocHelpers::MethodData<bool(const QString &, const QString &)>(26, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 16 },
        }}),
        // Method 'removeRNNoiseModel'
        QtMocHelpers::MethodData<bool(const QString &)>(27, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 25 },
        }}),
        // Method 'refreshCommunityPresets'
        QtMocHelpers::MethodData<void(const PipelineType &)>(28, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Method 'loadCommunityPresetFile'
        QtMocHelpers::MethodData<bool(const PipelineType &, const QString &, const QString &)>(29, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QString, 30 }, { QMetaType::QString, 31 },
        }}),
        // Method 'importFromCommunityPackage'
        QtMocHelpers::MethodData<bool(const PipelineType &, const QString &, const QString &)>(32, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QString, 30 }, { QMetaType::QString, 33 },
        }}),
        // Method 'addAutoload'
        QtMocHelpers::MethodData<void(const PipelineType &, const QString &, const QString &, const QString &, const QString &)>(34, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 35 }, { QMetaType::QString, 36 }, { QMetaType::QString, 37 }, { QMetaType::QString, 38 },
            { QMetaType::QString, 39 },
        }}),
        // Method 'removeAutoload'
        QtMocHelpers::MethodData<void(const PipelineType &, const QString &, const QString &, const QString &)>(40, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 35 }, { QMetaType::QString, 36 }, { QMetaType::QString, 37 }, { QMetaType::QString, 39 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sortedInputListModel'
        QtMocHelpers::PropertyData<QSortFilterProxyModel*>(41, 0x80000000 | 42, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sortedOutputListModel'
        QtMocHelpers::PropertyData<QSortFilterProxyModel*>(43, 0x80000000 | 42, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sortedCommunityInputListModel'
        QtMocHelpers::PropertyData<QSortFilterProxyModel*>(44, 0x80000000 | 42, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sortedCommunityOutputListModel'
        QtMocHelpers::PropertyData<QSortFilterProxyModel*>(45, 0x80000000 | 42, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sortedAutoloadInputListModel'
        QtMocHelpers::PropertyData<QSortFilterProxyModel*>(46, 0x80000000 | 42, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sortedAutoloadOutputListModel'
        QtMocHelpers::PropertyData<QSortFilterProxyModel*>(47, 0x80000000 | 42, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sortedImpulseListModel'
        QtMocHelpers::PropertyData<QSortFilterProxyModel*>(48, 0x80000000 | 42, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sortedRNNoiseListModel'
        QtMocHelpers::PropertyData<QSortFilterProxyModel*>(49, 0x80000000 | 42, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Manager, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject presets::Manager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7presets7ManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7presets7ManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7presets7ManagerE_t>.metaTypes,
    nullptr
} };

void presets::Manager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Manager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->presetLoadError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: { bool _r = _t->add((*reinterpret_cast<std::add_pointer_t<PipelineType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->savePresetFile((*reinterpret_cast<std::add_pointer_t<PipelineType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->remove((*reinterpret_cast<std::add_pointer_t<PipelineType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->renameLocalPresetFile((*reinterpret_cast<std::add_pointer_t<PipelineType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->loadLocalPresetFile((*reinterpret_cast<std::add_pointer_t<PipelineType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->importPresets((*reinterpret_cast<std::add_pointer_t<PipelineType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->exportPresets((*reinterpret_cast<std::add_pointer_t<PipelineType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { int _r = _t->importImpulses((*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: { int _r = _t->importRNNoiseModel((*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->removeImpulseFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->renameImpulseFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->removeRNNoiseModel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->refreshCommunityPresets((*reinterpret_cast<std::add_pointer_t<PipelineType>>(_a[1]))); break;
        case 14: { bool _r = _t->loadCommunityPresetFile((*reinterpret_cast<std::add_pointer_t<PipelineType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->importFromCommunityPackage((*reinterpret_cast<std::add_pointer_t<PipelineType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->addAutoload((*reinterpret_cast<std::add_pointer_t<PipelineType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 17: _t->removeAutoload((*reinterpret_cast<std::add_pointer_t<PipelineType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(const QString & , const QString & )>(_a, &Manager::presetLoadError, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
        case 6:
        case 5:
        case 4:
        case 3:
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QSortFilterProxyModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QSortFilterProxyModel**>(_v) = _t->proxyInputListModel; break;
        case 1: *reinterpret_cast<QSortFilterProxyModel**>(_v) = _t->proxyOutputListModel; break;
        case 2: *reinterpret_cast<QSortFilterProxyModel**>(_v) = _t->proxyCommunityInputListModel; break;
        case 3: *reinterpret_cast<QSortFilterProxyModel**>(_v) = _t->proxyCommunityOutputListModel; break;
        case 4: *reinterpret_cast<QSortFilterProxyModel**>(_v) = _t->proxyAutoloadInputListModel; break;
        case 5: *reinterpret_cast<QSortFilterProxyModel**>(_v) = _t->proxyAutoloadOutputListModel; break;
        case 6: *reinterpret_cast<QSortFilterProxyModel**>(_v) = _t->proxyImpulseListModel; break;
        case 7: *reinterpret_cast<QSortFilterProxyModel**>(_v) = _t->proxyRNNoiseListModel; break;
        default: break;
        }
    }
}

const QMetaObject *presets::Manager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *presets::Manager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7presets7ManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int presets::Manager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void presets::Manager::presetLoadError(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
QT_WARNING_POP
