// This file is generated by kconfig_compiler_kf6 from easyeffects_db.kcfg.
// All changes you do to this file will be lost.
#ifndef DBMAIN_H
#define DBMAIN_H

#include "kconfig_base_ee.hpp"

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>
#include <qqmlintegration.h>

class QQmlEngine;
class QJSEngine;

class DbMain : public KConfigBaseEE
{
  Q_OBJECT
  QML_ELEMENT
  QML_SINGLETON
  public:
    class EnumVisiblePage
    {
      public:
      enum type { outputPage, inputPage, pwPage, COUNT };
    };
    class EnumVisiblePresetSheetPage
    {
      public:
      enum type { localPage, communityPage, autoloadingPage, COUNT };
    };
    class EnumVisibleAutoloadingTab
    {
      public:
      enum type { outputTab, inputTab, COUNT };
    };
    class EnumVisiblePipeWirePage
    {
      public:
      enum type { generalPage, modulesPage, clientsPage, testSignalsPage, COUNT };
    };

    static DbMain *self();
    static DbMain *create(QQmlEngine *, QJSEngine *);
    ~DbMain() override;

    /**
      Set Width of the main window.
    */
    static
    void setWidth( int v )
    {
      if (v != self()->mWidth && !self()->isWidthImmutable()) {
        self()->mWidth = v;
        Q_EMIT self()->widthChanged();
      }
    }

    Q_PROPERTY(int width READ width WRITE setWidth NOTIFY widthChanged)
    Q_PROPERTY(bool isWidthImmutable READ isWidthImmutable CONSTANT)
    Q_PROPERTY(int defaultWidthValue READ defaultWidthValue CONSTANT)
    /**
      Get Width of the main window.
    */
    static
    int width()
    {
      return self()->mWidth;
    }

    /**
      Is Width of the main window. Immutable
    */
    static
    bool isWidthImmutable()
    {
      return self()->isImmutable( QStringLiteral( "width" ) );
    }

    /**
      Get Width of the main window. default value
    */
    static
    int defaultWidthValue()
    {
        return defaultWidthValue_helper();
    }

    /**
      Set Height of the main window.
    */
    static
    void setHeight( int v )
    {
      if (v != self()->mHeight && !self()->isHeightImmutable()) {
        self()->mHeight = v;
        Q_EMIT self()->heightChanged();
      }
    }

    Q_PROPERTY(int height READ height WRITE setHeight NOTIFY heightChanged)
    Q_PROPERTY(bool isHeightImmutable READ isHeightImmutable CONSTANT)
    Q_PROPERTY(int defaultHeightValue READ defaultHeightValue CONSTANT)
    /**
      Get Height of the main window.
    */
    static
    int height()
    {
      return self()->mHeight;
    }

    /**
      Is Height of the main window. Immutable
    */
    static
    bool isHeightImmutable()
    {
      return self()->isImmutable( QStringLiteral( "height" ) );
    }

    /**
      Get Height of the main window. default value
    */
    static
    int defaultHeightValue()
    {
        return defaultHeightValue_helper();
    }

    /**
      Set Visibility of the main window.
    */
    static
    void setVisibility( int v )
    {
      if (v != self()->mVisibility && !self()->isVisibilityImmutable()) {
        self()->mVisibility = v;
        Q_EMIT self()->visibilityChanged();
      }
    }

    Q_PROPERTY(int visibility READ visibility WRITE setVisibility NOTIFY visibilityChanged)
    Q_PROPERTY(bool isVisibilityImmutable READ isVisibilityImmutable CONSTANT)
    Q_PROPERTY(int defaultVisibilityValue READ defaultVisibilityValue CONSTANT)
    /**
      Get Visibility of the main window.
    */
    static
    int visibility()
    {
      return self()->mVisibility;
    }

    /**
      Is Visibility of the main window. Immutable
    */
    static
    bool isVisibilityImmutable()
    {
      return self()->isImmutable( QStringLiteral( "visibility" ) );
    }

    /**
      Get Visibility of the main window. default value
    */
    static
    int defaultVisibilityValue()
    {
        return defaultVisibilityValue_helper();
    }

    /**
      Set Enable Service Mode
    */
    static
    void setEnableServiceMode( bool v )
    {
      if (v != self()->mEnableServiceMode && !self()->isEnableServiceModeImmutable()) {
        self()->mEnableServiceMode = v;
        Q_EMIT self()->enableServiceModeChanged();
      }
    }

    Q_PROPERTY(bool enableServiceMode READ enableServiceMode WRITE setEnableServiceMode NOTIFY enableServiceModeChanged)
    Q_PROPERTY(bool isEnableServiceModeImmutable READ isEnableServiceModeImmutable CONSTANT)
    Q_PROPERTY(bool defaultEnableServiceModeValue READ defaultEnableServiceModeValue CONSTANT)
    /**
      Get Enable Service Mode
    */
    static
    bool enableServiceMode()
    {
      return self()->mEnableServiceMode;
    }

    /**
      Is Enable Service Mode Immutable
    */
    static
    bool isEnableServiceModeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "enableServiceMode" ) );
    }

    /**
      Get Enable Service Mode default value
    */
    static
    bool defaultEnableServiceModeValue()
    {
        return defaultEnableServiceModeValue_helper();
    }

    /**
      Set Show the Tray Icon
    */
    static
    void setShowTrayIcon( bool v )
    {
      if (v != self()->mShowTrayIcon && !self()->isShowTrayIconImmutable()) {
        self()->mShowTrayIcon = v;
        Q_EMIT self()->showTrayIconChanged();
      }
    }

    Q_PROPERTY(bool showTrayIcon READ showTrayIcon WRITE setShowTrayIcon NOTIFY showTrayIconChanged)
    Q_PROPERTY(bool isShowTrayIconImmutable READ isShowTrayIconImmutable CONSTANT)
    Q_PROPERTY(bool defaultShowTrayIconValue READ defaultShowTrayIconValue CONSTANT)
    /**
      Get Show the Tray Icon
    */
    static
    bool showTrayIcon()
    {
      return self()->mShowTrayIcon;
    }

    /**
      Is Show the Tray Icon Immutable
    */
    static
    bool isShowTrayIconImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showTrayIcon" ) );
    }

    /**
      Get Show the Tray Icon default value
    */
    static
    bool defaultShowTrayIconValue()
    {
        return defaultShowTrayIconValue_helper();
    }

    /**
      Set Automatically start on desktop login
    */
    static
    void setAutostartOnLogin( bool v )
    {
      if (v != self()->mAutostartOnLogin && !self()->isAutostartOnLoginImmutable()) {
        self()->mAutostartOnLogin = v;
        Q_EMIT self()->autostartOnLoginChanged();
      }
    }

    Q_PROPERTY(bool autostartOnLogin READ autostartOnLogin WRITE setAutostartOnLogin NOTIFY autostartOnLoginChanged)
    Q_PROPERTY(bool isAutostartOnLoginImmutable READ isAutostartOnLoginImmutable CONSTANT)
    Q_PROPERTY(bool defaultAutostartOnLoginValue READ defaultAutostartOnLoginValue CONSTANT)
    /**
      Get Automatically start on desktop login
    */
    static
    bool autostartOnLogin()
    {
      return self()->mAutostartOnLogin;
    }

    /**
      Is Automatically start on desktop login Immutable
    */
    static
    bool isAutostartOnLoginImmutable()
    {
      return self()->isImmutable( QStringLiteral( "autostartOnLogin" ) );
    }

    /**
      Get Automatically start on desktop login default value
    */
    static
    bool defaultAutostartOnLoginValue()
    {
        return defaultAutostartOnLoginValue_helper();
    }

    /**
      Set Never show our window after the application initialization when running in service mode.
    */
    static
    void setNoWindowAfterStarting( bool v )
    {
      if (v != self()->mNoWindowAfterStarting && !self()->isNoWindowAfterStartingImmutable()) {
        self()->mNoWindowAfterStarting = v;
        Q_EMIT self()->noWindowAfterStartingChanged();
      }
    }

    Q_PROPERTY(bool noWindowAfterStarting READ noWindowAfterStarting WRITE setNoWindowAfterStarting NOTIFY noWindowAfterStartingChanged)
    Q_PROPERTY(bool isNoWindowAfterStartingImmutable READ isNoWindowAfterStartingImmutable CONSTANT)
    Q_PROPERTY(bool defaultNoWindowAfterStartingValue READ defaultNoWindowAfterStartingValue CONSTANT)
    /**
      Get Never show our window after the application initialization when running in service mode.
    */
    static
    bool noWindowAfterStarting()
    {
      return self()->mNoWindowAfterStarting;
    }

    /**
      Is Never show our window after the application initialization when running in service mode. Immutable
    */
    static
    bool isNoWindowAfterStartingImmutable()
    {
      return self()->isImmutable( QStringLiteral( "noWindowAfterStarting" ) );
    }

    /**
      Get Never show our window after the application initialization when running in service mode. default value
    */
    static
    bool defaultNoWindowAfterStartingValue()
    {
        return defaultNoWindowAfterStartingValue_helper();
    }

    /**
      Set Do not translate the user interface and show the application in the original English language.
    */
    static
    void setEnglishLanguage( bool v )
    {
      if (v != self()->mEnglishLanguage && !self()->isEnglishLanguageImmutable()) {
        self()->mEnglishLanguage = v;
        Q_EMIT self()->englishLanguageChanged();
      }
    }

    Q_PROPERTY(bool englishLanguage READ englishLanguage WRITE setEnglishLanguage NOTIFY englishLanguageChanged)
    Q_PROPERTY(bool isEnglishLanguageImmutable READ isEnglishLanguageImmutable CONSTANT)
    Q_PROPERTY(bool defaultEnglishLanguageValue READ defaultEnglishLanguageValue CONSTANT)
    /**
      Get Do not translate the user interface and show the application in the original English language.
    */
    static
    bool englishLanguage()
    {
      return self()->mEnglishLanguage;
    }

    /**
      Is Do not translate the user interface and show the application in the original English language. Immutable
    */
    static
    bool isEnglishLanguageImmutable()
    {
      return self()->isImmutable( QStringLiteral( "englishLanguage" ) );
    }

    /**
      Get Do not translate the user interface and show the application in the original English language. default value
    */
    static
    bool defaultEnglishLanguageValue()
    {
        return defaultEnglishLanguageValue_helper();
    }

    /**
      Set Effect controls in the plugins list are shown inside a context menu
    */
    static
    void setReducePluginsListControls( bool v )
    {
      if (v != self()->mReducePluginsListControls && !self()->isReducePluginsListControlsImmutable()) {
        self()->mReducePluginsListControls = v;
        Q_EMIT self()->reducePluginsListControlsChanged();
      }
    }

    Q_PROPERTY(bool reducePluginsListControls READ reducePluginsListControls WRITE setReducePluginsListControls NOTIFY reducePluginsListControlsChanged)
    Q_PROPERTY(bool isReducePluginsListControlsImmutable READ isReducePluginsListControlsImmutable CONSTANT)
    Q_PROPERTY(bool defaultReducePluginsListControlsValue READ defaultReducePluginsListControlsValue CONSTANT)
    /**
      Get Effect controls in the plugins list are shown inside a context menu
    */
    static
    bool reducePluginsListControls()
    {
      return self()->mReducePluginsListControls;
    }

    /**
      Is Effect controls in the plugins list are shown inside a context menu Immutable
    */
    static
    bool isReducePluginsListControlsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "reducePluginsListControls" ) );
    }

    /**
      Get Effect controls in the plugins list are shown inside a context menu default value
    */
    static
    bool defaultReducePluginsListControlsValue()
    {
        return defaultReducePluginsListControlsValue_helper();
    }

    /**
      Set Enable support for XDG Global Shortcuts
    */
    static
    void setXdgGlobalShortcuts( bool v )
    {
      if (v != self()->mXdgGlobalShortcuts && !self()->isXdgGlobalShortcutsImmutable()) {
        self()->mXdgGlobalShortcuts = v;
        Q_EMIT self()->xdgGlobalShortcutsChanged();
      }
    }

    Q_PROPERTY(bool xdgGlobalShortcuts READ xdgGlobalShortcuts WRITE setXdgGlobalShortcuts NOTIFY xdgGlobalShortcutsChanged)
    Q_PROPERTY(bool isXdgGlobalShortcutsImmutable READ isXdgGlobalShortcutsImmutable CONSTANT)
    Q_PROPERTY(bool defaultXdgGlobalShortcutsValue READ defaultXdgGlobalShortcutsValue CONSTANT)
    /**
      Get Enable support for XDG Global Shortcuts
    */
    static
    bool xdgGlobalShortcuts()
    {
      return self()->mXdgGlobalShortcuts;
    }

    /**
      Is Enable support for XDG Global Shortcuts Immutable
    */
    static
    bool isXdgGlobalShortcutsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "xdgGlobalShortcuts" ) );
    }

    /**
      Get Enable support for XDG Global Shortcuts default value
    */
    static
    bool defaultXdgGlobalShortcutsValue()
    {
        return defaultXdgGlobalShortcutsValue_helper();
    }

    /**
      Set True if global shortcuts have already been bound
    */
    static
    void setXdgGlobalShortcutsBound( bool v )
    {
      if (v != self()->mXdgGlobalShortcutsBound && !self()->isXdgGlobalShortcutsBoundImmutable()) {
        self()->mXdgGlobalShortcutsBound = v;
        Q_EMIT self()->xdgGlobalShortcutsBoundChanged();
      }
    }

    Q_PROPERTY(bool xdgGlobalShortcutsBound READ xdgGlobalShortcutsBound WRITE setXdgGlobalShortcutsBound NOTIFY xdgGlobalShortcutsBoundChanged)
    Q_PROPERTY(bool isXdgGlobalShortcutsBoundImmutable READ isXdgGlobalShortcutsBoundImmutable CONSTANT)
    Q_PROPERTY(bool defaultXdgGlobalShortcutsBoundValue READ defaultXdgGlobalShortcutsBoundValue CONSTANT)
    /**
      Get True if global shortcuts have already been bound
    */
    static
    bool xdgGlobalShortcutsBound()
    {
      return self()->mXdgGlobalShortcutsBound;
    }

    /**
      Is True if global shortcuts have already been bound Immutable
    */
    static
    bool isXdgGlobalShortcutsBoundImmutable()
    {
      return self()->isImmutable( QStringLiteral( "xdgGlobalShortcutsBound" ) );
    }

    /**
      Get True if global shortcuts have already been bound default value
    */
    static
    bool defaultXdgGlobalShortcutsBoundValue()
    {
        return defaultXdgGlobalShortcutsBoundValue_helper();
    }

    /**
      Set Autosave interval. This timer is active only when our window is opened.
    */
    static
    void setDatabaseAutosaveInterval( int v )
    {
      if (v < 1000)
      {
        qDebug() << "setDatabaseAutosaveInterval: value " << v << " is less than the minimum value of 1000";
        v = 1000;
      }

      if (v > 60000)
      {
        qDebug() << "setDatabaseAutosaveInterval: value " << v << " is greater than the maximum value of 60000";
        v = 60000;
      }

      if (v != self()->mDatabaseAutosaveInterval && !self()->isDatabaseAutosaveIntervalImmutable()) {
        self()->mDatabaseAutosaveInterval = v;
        Q_EMIT self()->databaseAutosaveIntervalChanged();
      }
    }

    Q_PROPERTY(int databaseAutosaveInterval READ databaseAutosaveInterval WRITE setDatabaseAutosaveInterval NOTIFY databaseAutosaveIntervalChanged)
    Q_PROPERTY(bool isDatabaseAutosaveIntervalImmutable READ isDatabaseAutosaveIntervalImmutable CONSTANT)
    Q_PROPERTY(int defaultDatabaseAutosaveIntervalValue READ defaultDatabaseAutosaveIntervalValue CONSTANT)
    /**
      Get Autosave interval. This timer is active only when our window is opened.
    */
    static
    int databaseAutosaveInterval()
    {
      return self()->mDatabaseAutosaveInterval;
    }

    /**
      Is Autosave interval. This timer is active only when our window is opened. Immutable
    */
    static
    bool isDatabaseAutosaveIntervalImmutable()
    {
      return self()->isImmutable( QStringLiteral( "databaseAutosaveInterval" ) );
    }

    /**
      Get Autosave interval. This timer is active only when our window is opened. default value
    */
    static
    int defaultDatabaseAutosaveIntervalValue()
    {
        return defaultDatabaseAutosaveIntervalValue_helper();
    }

    /**
      Set Delay between receiving a new device route and the call to autoload a preset.
    */
    static
    void setPresetsAutoloadInterval( int v )
    {
      if (v < 0)
      {
        qDebug() << "setPresetsAutoloadInterval: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 60000)
      {
        qDebug() << "setPresetsAutoloadInterval: value " << v << " is greater than the maximum value of 60000";
        v = 60000;
      }

      if (v != self()->mPresetsAutoloadInterval && !self()->isPresetsAutoloadIntervalImmutable()) {
        self()->mPresetsAutoloadInterval = v;
        Q_EMIT self()->presetsAutoloadIntervalChanged();
      }
    }

    Q_PROPERTY(int presetsAutoloadInterval READ presetsAutoloadInterval WRITE setPresetsAutoloadInterval NOTIFY presetsAutoloadIntervalChanged)
    Q_PROPERTY(bool isPresetsAutoloadIntervalImmutable READ isPresetsAutoloadIntervalImmutable CONSTANT)
    Q_PROPERTY(int defaultPresetsAutoloadIntervalValue READ defaultPresetsAutoloadIntervalValue CONSTANT)
    /**
      Get Delay between receiving a new device route and the call to autoload a preset.
    */
    static
    int presetsAutoloadInterval()
    {
      return self()->mPresetsAutoloadInterval;
    }

    /**
      Is Delay between receiving a new device route and the call to autoload a preset. Immutable
    */
    static
    bool isPresetsAutoloadIntervalImmutable()
    {
      return self()->isImmutable( QStringLiteral( "presetsAutoloadInterval" ) );
    }

    /**
      Get Delay between receiving a new device route and the call to autoload a preset. default value
    */
    static
    int defaultPresetsAutoloadIntervalValue()
    {
        return defaultPresetsAutoloadIntervalValue_helper();
    }

    /**
      Set How many presets to show in our most used presets list
    */
    static
    void setMaxMostUsedPresets( int v )
    {
      if (v < 1)
      {
        qDebug() << "setMaxMostUsedPresets: value " << v << " is less than the minimum value of 1";
        v = 1;
      }

      if (v > 100)
      {
        qDebug() << "setMaxMostUsedPresets: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != self()->mMaxMostUsedPresets && !self()->isMaxMostUsedPresetsImmutable()) {
        self()->mMaxMostUsedPresets = v;
        Q_EMIT self()->maxMostUsedPresetsChanged();
      }
    }

    Q_PROPERTY(int maxMostUsedPresets READ maxMostUsedPresets WRITE setMaxMostUsedPresets NOTIFY maxMostUsedPresetsChanged)
    Q_PROPERTY(bool isMaxMostUsedPresetsImmutable READ isMaxMostUsedPresetsImmutable CONSTANT)
    Q_PROPERTY(int defaultMaxMostUsedPresetsValue READ defaultMaxMostUsedPresetsValue CONSTANT)
    /**
      Get How many presets to show in our most used presets list
    */
    static
    int maxMostUsedPresets()
    {
      return self()->mMaxMostUsedPresets;
    }

    /**
      Is How many presets to show in our most used presets list Immutable
    */
    static
    bool isMaxMostUsedPresetsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "maxMostUsedPresets" ) );
    }

    /**
      Get How many presets to show in our most used presets list default value
    */
    static
    int defaultMaxMostUsedPresetsValue()
    {
        return defaultMaxMostUsedPresetsValue_helper();
    }

    /**
      Set The amount of time in milliseconds an inline message is visible when the autohiding mode is enabled.
    */
    static
    void setAutoHideInlineMessageTimeout( int v )
    {
      if (v != self()->mAutoHideInlineMessageTimeout && !self()->isAutoHideInlineMessageTimeoutImmutable()) {
        self()->mAutoHideInlineMessageTimeout = v;
        Q_EMIT self()->autoHideInlineMessageTimeoutChanged();
      }
    }

    Q_PROPERTY(int autoHideInlineMessageTimeout READ autoHideInlineMessageTimeout WRITE setAutoHideInlineMessageTimeout NOTIFY autoHideInlineMessageTimeoutChanged)
    Q_PROPERTY(bool isAutoHideInlineMessageTimeoutImmutable READ isAutoHideInlineMessageTimeoutImmutable CONSTANT)
    Q_PROPERTY(int defaultAutoHideInlineMessageTimeoutValue READ defaultAutoHideInlineMessageTimeoutValue CONSTANT)
    /**
      Get The amount of time in milliseconds an inline message is visible when the autohiding mode is enabled.
    */
    static
    int autoHideInlineMessageTimeout()
    {
      return self()->mAutoHideInlineMessageTimeout;
    }

    /**
      Is The amount of time in milliseconds an inline message is visible when the autohiding mode is enabled. Immutable
    */
    static
    bool isAutoHideInlineMessageTimeoutImmutable()
    {
      return self()->isImmutable( QStringLiteral( "autoHideInlineMessageTimeout" ) );
    }

    /**
      Get The amount of time in milliseconds an inline message is visible when the autohiding mode is enabled. default value
    */
    static
    int defaultAutoHideInlineMessageTimeoutValue()
    {
        return defaultAutoHideInlineMessageTimeoutValue_helper();
    }

    /**
      Set When enabled presets autoloading will use a fallback when no profile is available for the target device.
    */
    static
    void setInputAutoloadingUsesFallback( bool v )
    {
      if (v != self()->mInputAutoloadingUsesFallback && !self()->isInputAutoloadingUsesFallbackImmutable()) {
        self()->mInputAutoloadingUsesFallback = v;
        Q_EMIT self()->inputAutoloadingUsesFallbackChanged();
      }
    }

    Q_PROPERTY(bool inputAutoloadingUsesFallback READ inputAutoloadingUsesFallback WRITE setInputAutoloadingUsesFallback NOTIFY inputAutoloadingUsesFallbackChanged)
    Q_PROPERTY(bool isInputAutoloadingUsesFallbackImmutable READ isInputAutoloadingUsesFallbackImmutable CONSTANT)
    Q_PROPERTY(bool defaultInputAutoloadingUsesFallbackValue READ defaultInputAutoloadingUsesFallbackValue CONSTANT)
    /**
      Get When enabled presets autoloading will use a fallback when no profile is available for the target device.
    */
    static
    bool inputAutoloadingUsesFallback()
    {
      return self()->mInputAutoloadingUsesFallback;
    }

    /**
      Is When enabled presets autoloading will use a fallback when no profile is available for the target device. Immutable
    */
    static
    bool isInputAutoloadingUsesFallbackImmutable()
    {
      return self()->isImmutable( QStringLiteral( "inputAutoloadingUsesFallback" ) );
    }

    /**
      Get When enabled presets autoloading will use a fallback when no profile is available for the target device. default value
    */
    static
    bool defaultInputAutoloadingUsesFallbackValue()
    {
        return defaultInputAutoloadingUsesFallbackValue_helper();
    }

    /**
      Set When enabled presets autoloading will use a fallback when no profile is available for the target device.
    */
    static
    void setOutputAutoloadingUsesFallback( bool v )
    {
      if (v != self()->mOutputAutoloadingUsesFallback && !self()->isOutputAutoloadingUsesFallbackImmutable()) {
        self()->mOutputAutoloadingUsesFallback = v;
        Q_EMIT self()->outputAutoloadingUsesFallbackChanged();
      }
    }

    Q_PROPERTY(bool outputAutoloadingUsesFallback READ outputAutoloadingUsesFallback WRITE setOutputAutoloadingUsesFallback NOTIFY outputAutoloadingUsesFallbackChanged)
    Q_PROPERTY(bool isOutputAutoloadingUsesFallbackImmutable READ isOutputAutoloadingUsesFallbackImmutable CONSTANT)
    Q_PROPERTY(bool defaultOutputAutoloadingUsesFallbackValue READ defaultOutputAutoloadingUsesFallbackValue CONSTANT)
    /**
      Get When enabled presets autoloading will use a fallback when no profile is available for the target device.
    */
    static
    bool outputAutoloadingUsesFallback()
    {
      return self()->mOutputAutoloadingUsesFallback;
    }

    /**
      Is When enabled presets autoloading will use a fallback when no profile is available for the target device. Immutable
    */
    static
    bool isOutputAutoloadingUsesFallbackImmutable()
    {
      return self()->isImmutable( QStringLiteral( "outputAutoloadingUsesFallback" ) );
    }

    /**
      Get When enabled presets autoloading will use a fallback when no profile is available for the target device. default value
    */
    static
    bool defaultOutputAutoloadingUsesFallbackValue()
    {
        return defaultOutputAutoloadingUsesFallbackValue_helper();
    }

    /**
      Set Fallback preset used when no profile is available for the target device
    */
    static
    void setInputAutoloadingFallbackPreset( const QString & v )
    {
      if (v != self()->mInputAutoloadingFallbackPreset && !self()->isInputAutoloadingFallbackPresetImmutable()) {
        self()->mInputAutoloadingFallbackPreset = v;
        Q_EMIT self()->inputAutoloadingFallbackPresetChanged();
      }
    }

    Q_PROPERTY(QString inputAutoloadingFallbackPreset READ inputAutoloadingFallbackPreset WRITE setInputAutoloadingFallbackPreset NOTIFY inputAutoloadingFallbackPresetChanged)
    Q_PROPERTY(bool isInputAutoloadingFallbackPresetImmutable READ isInputAutoloadingFallbackPresetImmutable CONSTANT)
    Q_PROPERTY(QString defaultInputAutoloadingFallbackPresetValue READ defaultInputAutoloadingFallbackPresetValue CONSTANT)
    /**
      Get Fallback preset used when no profile is available for the target device
    */
    static
    QString inputAutoloadingFallbackPreset()
    {
      return self()->mInputAutoloadingFallbackPreset;
    }

    /**
      Is Fallback preset used when no profile is available for the target device Immutable
    */
    static
    bool isInputAutoloadingFallbackPresetImmutable()
    {
      return self()->isImmutable( QStringLiteral( "inputAutoloadingFallbackPreset" ) );
    }

    /**
      Get Fallback preset used when no profile is available for the target device default value
    */
    static
    QString defaultInputAutoloadingFallbackPresetValue()
    {
        return defaultInputAutoloadingFallbackPresetValue_helper();
    }

    /**
      Set Fallback preset used when no profile is available for the target device
    */
    static
    void setOutputAutoloadingFallbackPreset( const QString & v )
    {
      if (v != self()->mOutputAutoloadingFallbackPreset && !self()->isOutputAutoloadingFallbackPresetImmutable()) {
        self()->mOutputAutoloadingFallbackPreset = v;
        Q_EMIT self()->outputAutoloadingFallbackPresetChanged();
      }
    }

    Q_PROPERTY(QString outputAutoloadingFallbackPreset READ outputAutoloadingFallbackPreset WRITE setOutputAutoloadingFallbackPreset NOTIFY outputAutoloadingFallbackPresetChanged)
    Q_PROPERTY(bool isOutputAutoloadingFallbackPresetImmutable READ isOutputAutoloadingFallbackPresetImmutable CONSTANT)
    Q_PROPERTY(QString defaultOutputAutoloadingFallbackPresetValue READ defaultOutputAutoloadingFallbackPresetValue CONSTANT)
    /**
      Get Fallback preset used when no profile is available for the target device
    */
    static
    QString outputAutoloadingFallbackPreset()
    {
      return self()->mOutputAutoloadingFallbackPreset;
    }

    /**
      Is Fallback preset used when no profile is available for the target device Immutable
    */
    static
    bool isOutputAutoloadingFallbackPresetImmutable()
    {
      return self()->isImmutable( QStringLiteral( "outputAutoloadingFallbackPreset" ) );
    }

    /**
      Get Fallback preset used when no profile is available for the target device default value
    */
    static
    QString defaultOutputAutoloadingFallbackPresetValue()
    {
        return defaultOutputAutoloadingFallbackPresetValue_helper();
    }

    /**
      Set Saves the last viewed page.
    */
    static
    void setVisiblePage( int v )
    {
      if (v != self()->mVisiblePage && !self()->isVisiblePageImmutable()) {
        self()->mVisiblePage = v;
        Q_EMIT self()->visiblePageChanged();
      }
    }

    Q_PROPERTY(int visiblePage READ visiblePage WRITE setVisiblePage NOTIFY visiblePageChanged)
    Q_PROPERTY(bool isVisiblePageImmutable READ isVisiblePageImmutable CONSTANT)
    Q_PROPERTY(int defaultVisiblePageValue READ defaultVisiblePageValue CONSTANT)
    /**
      Get Saves the last viewed page.
    */
    static
    int visiblePage()
    {
      return self()->mVisiblePage;
    }

    /**
      Is Saves the last viewed page. Immutable
    */
    static
    bool isVisiblePageImmutable()
    {
      return self()->isImmutable( QStringLiteral( "visiblePage" ) );
    }

    /**
      Get Saves the last viewed page. default value
    */
    static
    int defaultVisiblePageValue()
    {
        return defaultVisiblePageValue_helper();
    }

    /**
      Set Saves the last viewed page.
    */
    static
    void setVisiblePresetSheetPage( int v )
    {
      if (v != self()->mVisiblePresetSheetPage && !self()->isVisiblePresetSheetPageImmutable()) {
        self()->mVisiblePresetSheetPage = v;
        Q_EMIT self()->visiblePresetSheetPageChanged();
      }
    }

    Q_PROPERTY(int visiblePresetSheetPage READ visiblePresetSheetPage WRITE setVisiblePresetSheetPage NOTIFY visiblePresetSheetPageChanged)
    Q_PROPERTY(bool isVisiblePresetSheetPageImmutable READ isVisiblePresetSheetPageImmutable CONSTANT)
    Q_PROPERTY(int defaultVisiblePresetSheetPageValue READ defaultVisiblePresetSheetPageValue CONSTANT)
    /**
      Get Saves the last viewed page.
    */
    static
    int visiblePresetSheetPage()
    {
      return self()->mVisiblePresetSheetPage;
    }

    /**
      Is Saves the last viewed page. Immutable
    */
    static
    bool isVisiblePresetSheetPageImmutable()
    {
      return self()->isImmutable( QStringLiteral( "visiblePresetSheetPage" ) );
    }

    /**
      Get Saves the last viewed page. default value
    */
    static
    int defaultVisiblePresetSheetPageValue()
    {
        return defaultVisiblePresetSheetPageValue_helper();
    }

    /**
      Set Saves the last viewed tab.
    */
    static
    void setVisibleAutoloadingTab( int v )
    {
      if (v != self()->mVisibleAutoloadingTab && !self()->isVisibleAutoloadingTabImmutable()) {
        self()->mVisibleAutoloadingTab = v;
        Q_EMIT self()->visibleAutoloadingTabChanged();
      }
    }

    Q_PROPERTY(int visibleAutoloadingTab READ visibleAutoloadingTab WRITE setVisibleAutoloadingTab NOTIFY visibleAutoloadingTabChanged)
    Q_PROPERTY(bool isVisibleAutoloadingTabImmutable READ isVisibleAutoloadingTabImmutable CONSTANT)
    Q_PROPERTY(int defaultVisibleAutoloadingTabValue READ defaultVisibleAutoloadingTabValue CONSTANT)
    /**
      Get Saves the last viewed tab.
    */
    static
    int visibleAutoloadingTab()
    {
      return self()->mVisibleAutoloadingTab;
    }

    /**
      Is Saves the last viewed tab. Immutable
    */
    static
    bool isVisibleAutoloadingTabImmutable()
    {
      return self()->isImmutable( QStringLiteral( "visibleAutoloadingTab" ) );
    }

    /**
      Get Saves the last viewed tab. default value
    */
    static
    int defaultVisibleAutoloadingTabValue()
    {
        return defaultVisibleAutoloadingTabValue_helper();
    }

    /**
      Set Saves the last viewed page.
    */
    static
    void setVisiblePipeWirePage( int v )
    {
      if (v != self()->mVisiblePipeWirePage && !self()->isVisiblePipeWirePageImmutable()) {
        self()->mVisiblePipeWirePage = v;
        Q_EMIT self()->visiblePipeWirePageChanged();
      }
    }

    Q_PROPERTY(int visiblePipeWirePage READ visiblePipeWirePage WRITE setVisiblePipeWirePage NOTIFY visiblePipeWirePageChanged)
    Q_PROPERTY(bool isVisiblePipeWirePageImmutable READ isVisiblePipeWirePageImmutable CONSTANT)
    Q_PROPERTY(int defaultVisiblePipeWirePageValue READ defaultVisiblePipeWirePageValue CONSTANT)
    /**
      Get Saves the last viewed page.
    */
    static
    int visiblePipeWirePage()
    {
      return self()->mVisiblePipeWirePage;
    }

    /**
      Is Saves the last viewed page. Immutable
    */
    static
    bool isVisiblePipeWirePageImmutable()
    {
      return self()->isImmutable( QStringLiteral( "visiblePipeWirePage" ) );
    }

    /**
      Get Saves the last viewed page. default value
    */
    static
    int defaultVisiblePipeWirePageValue()
    {
        return defaultVisiblePipeWirePageValue_helper();
    }

    /**
      Set Horizontally collapse plugins list sidebar
    */
    static
    void setCollapsePluginsList( bool v )
    {
      if (v != self()->mCollapsePluginsList && !self()->isCollapsePluginsListImmutable()) {
        self()->mCollapsePluginsList = v;
        Q_EMIT self()->collapsePluginsListChanged();
      }
    }

    Q_PROPERTY(bool collapsePluginsList READ collapsePluginsList WRITE setCollapsePluginsList NOTIFY collapsePluginsListChanged)
    Q_PROPERTY(bool isCollapsePluginsListImmutable READ isCollapsePluginsListImmutable CONSTANT)
    Q_PROPERTY(bool defaultCollapsePluginsListValue READ defaultCollapsePluginsListValue CONSTANT)
    /**
      Get Horizontally collapse plugins list sidebar
    */
    static
    bool collapsePluginsList()
    {
      return self()->mCollapsePluginsList;
    }

    /**
      Is Horizontally collapse plugins list sidebar Immutable
    */
    static
    bool isCollapsePluginsListImmutable()
    {
      return self()->isImmutable( QStringLiteral( "collapsePluginsList" ) );
    }

    /**
      Get Horizontally collapse plugins list sidebar default value
    */
    static
    bool defaultCollapsePluginsListValue()
    {
        return defaultCollapsePluginsListValue_helper();
    }

    /**
      Set Force KDE Breeze theme when Easy Effects starts
    */
    static
    void setForceBreezeTheme( bool v )
    {
      if (v != self()->mForceBreezeTheme && !self()->isForceBreezeThemeImmutable()) {
        self()->mForceBreezeTheme = v;
        Q_EMIT self()->forceBreezeThemeChanged();
      }
    }

    Q_PROPERTY(bool forceBreezeTheme READ forceBreezeTheme WRITE setForceBreezeTheme NOTIFY forceBreezeThemeChanged)
    Q_PROPERTY(bool isForceBreezeThemeImmutable READ isForceBreezeThemeImmutable CONSTANT)
    Q_PROPERTY(bool defaultForceBreezeThemeValue READ defaultForceBreezeThemeValue CONSTANT)
    /**
      Get Force KDE Breeze theme when Easy Effects starts
    */
    static
    bool forceBreezeTheme()
    {
      return self()->mForceBreezeTheme;
    }

    /**
      Is Force KDE Breeze theme when Easy Effects starts Immutable
    */
    static
    bool isForceBreezeThemeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "forceBreezeTheme" ) );
    }

    /**
      Get Force KDE Breeze theme when Easy Effects starts default value
    */
    static
    bool defaultForceBreezeThemeValue()
    {
        return defaultForceBreezeThemeValue_helper();
    }

    /**
      Set Ignore the preset blocklist field when loading the preset file.
    */
    static
    void setIgnorePresetBlocklist( bool v )
    {
      if (v != self()->mIgnorePresetBlocklist && !self()->isIgnorePresetBlocklistImmutable()) {
        self()->mIgnorePresetBlocklist = v;
        Q_EMIT self()->ignorePresetBlocklistChanged();
      }
    }

    Q_PROPERTY(bool ignorePresetBlocklist READ ignorePresetBlocklist WRITE setIgnorePresetBlocklist NOTIFY ignorePresetBlocklistChanged)
    Q_PROPERTY(bool isIgnorePresetBlocklistImmutable READ isIgnorePresetBlocklistImmutable CONSTANT)
    Q_PROPERTY(bool defaultIgnorePresetBlocklistValue READ defaultIgnorePresetBlocklistValue CONSTANT)
    /**
      Get Ignore the preset blocklist field when loading the preset file.
    */
    static
    bool ignorePresetBlocklist()
    {
      return self()->mIgnorePresetBlocklist;
    }

    /**
      Is Ignore the preset blocklist field when loading the preset file. Immutable
    */
    static
    bool isIgnorePresetBlocklistImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ignorePresetBlocklist" ) );
    }

    /**
      Get Ignore the preset blocklist field when loading the preset file. default value
    */
    static
    bool defaultIgnorePresetBlocklistValue()
    {
        return defaultIgnorePresetBlocklistValue_helper();
    }

    /**
      Set Last used input preset.
    */
    static
    void setLastLoadedInputPreset( const QString & v )
    {
      if (v != self()->mLastLoadedInputPreset && !self()->isLastLoadedInputPresetImmutable()) {
        self()->mLastLoadedInputPreset = v;
        Q_EMIT self()->lastLoadedInputPresetChanged();
      }
    }

    Q_PROPERTY(QString lastLoadedInputPreset READ lastLoadedInputPreset WRITE setLastLoadedInputPreset NOTIFY lastLoadedInputPresetChanged)
    Q_PROPERTY(bool isLastLoadedInputPresetImmutable READ isLastLoadedInputPresetImmutable CONSTANT)
    Q_PROPERTY(QString defaultLastLoadedInputPresetValue READ defaultLastLoadedInputPresetValue CONSTANT)
    /**
      Get Last used input preset.
    */
    static
    QString lastLoadedInputPreset()
    {
      return self()->mLastLoadedInputPreset;
    }

    /**
      Is Last used input preset. Immutable
    */
    static
    bool isLastLoadedInputPresetImmutable()
    {
      return self()->isImmutable( QStringLiteral( "lastLoadedInputPreset" ) );
    }

    /**
      Get Last used input preset. default value
    */
    static
    QString defaultLastLoadedInputPresetValue()
    {
        return defaultLastLoadedInputPresetValue_helper();
    }

    /**
      Set Last used output preset.
    */
    static
    void setLastLoadedOutputPreset( const QString & v )
    {
      if (v != self()->mLastLoadedOutputPreset && !self()->isLastLoadedOutputPresetImmutable()) {
        self()->mLastLoadedOutputPreset = v;
        Q_EMIT self()->lastLoadedOutputPresetChanged();
      }
    }

    Q_PROPERTY(QString lastLoadedOutputPreset READ lastLoadedOutputPreset WRITE setLastLoadedOutputPreset NOTIFY lastLoadedOutputPresetChanged)
    Q_PROPERTY(bool isLastLoadedOutputPresetImmutable READ isLastLoadedOutputPresetImmutable CONSTANT)
    Q_PROPERTY(QString defaultLastLoadedOutputPresetValue READ defaultLastLoadedOutputPresetValue CONSTANT)
    /**
      Get Last used output preset.
    */
    static
    QString lastLoadedOutputPreset()
    {
      return self()->mLastLoadedOutputPreset;
    }

    /**
      Is Last used output preset. Immutable
    */
    static
    bool isLastLoadedOutputPresetImmutable()
    {
      return self()->isImmutable( QStringLiteral( "lastLoadedOutputPreset" ) );
    }

    /**
      Get Last used output preset. default value
    */
    static
    QString defaultLastLoadedOutputPresetValue()
    {
        return defaultLastLoadedOutputPresetValue_helper();
    }

    /**
      Set Last used input community package.
    */
    static
    void setLastLoadedInputCommunityPackage( const QString & v )
    {
      if (v != self()->mLastLoadedInputCommunityPackage && !self()->isLastLoadedInputCommunityPackageImmutable()) {
        self()->mLastLoadedInputCommunityPackage = v;
        Q_EMIT self()->lastLoadedInputCommunityPackageChanged();
      }
    }

    Q_PROPERTY(QString lastLoadedInputCommunityPackage READ lastLoadedInputCommunityPackage WRITE setLastLoadedInputCommunityPackage NOTIFY lastLoadedInputCommunityPackageChanged)
    Q_PROPERTY(bool isLastLoadedInputCommunityPackageImmutable READ isLastLoadedInputCommunityPackageImmutable CONSTANT)
    Q_PROPERTY(QString defaultLastLoadedInputCommunityPackageValue READ defaultLastLoadedInputCommunityPackageValue CONSTANT)
    /**
      Get Last used input community package.
    */
    static
    QString lastLoadedInputCommunityPackage()
    {
      return self()->mLastLoadedInputCommunityPackage;
    }

    /**
      Is Last used input community package. Immutable
    */
    static
    bool isLastLoadedInputCommunityPackageImmutable()
    {
      return self()->isImmutable( QStringLiteral( "lastLoadedInputCommunityPackage" ) );
    }

    /**
      Get Last used input community package. default value
    */
    static
    QString defaultLastLoadedInputCommunityPackageValue()
    {
        return defaultLastLoadedInputCommunityPackageValue_helper();
    }

    /**
      Set Last used output community package.
    */
    static
    void setLastLoadedOutputCommunityPackage( const QString & v )
    {
      if (v != self()->mLastLoadedOutputCommunityPackage && !self()->isLastLoadedOutputCommunityPackageImmutable()) {
        self()->mLastLoadedOutputCommunityPackage = v;
        Q_EMIT self()->lastLoadedOutputCommunityPackageChanged();
      }
    }

    Q_PROPERTY(QString lastLoadedOutputCommunityPackage READ lastLoadedOutputCommunityPackage WRITE setLastLoadedOutputCommunityPackage NOTIFY lastLoadedOutputCommunityPackageChanged)
    Q_PROPERTY(bool isLastLoadedOutputCommunityPackageImmutable READ isLastLoadedOutputCommunityPackageImmutable CONSTANT)
    Q_PROPERTY(QString defaultLastLoadedOutputCommunityPackageValue READ defaultLastLoadedOutputCommunityPackageValue CONSTANT)
    /**
      Get Last used output community package.
    */
    static
    QString lastLoadedOutputCommunityPackage()
    {
      return self()->mLastLoadedOutputCommunityPackage;
    }

    /**
      Is Last used output community package. Immutable
    */
    static
    bool isLastLoadedOutputCommunityPackageImmutable()
    {
      return self()->isImmutable( QStringLiteral( "lastLoadedOutputCommunityPackage" ) );
    }

    /**
      Get Last used output community package. default value
    */
    static
    QString defaultLastLoadedOutputCommunityPackageValue()
    {
        return defaultLastLoadedOutputCommunityPackageValue_helper();
    }

    /**
      Set Global Bypass: Puts the Effects Pipelines in Passthrough Mode.
    */
    static
    void setBypass( bool v )
    {
      if (v != self()->mBypass && !self()->isBypassImmutable()) {
        self()->mBypass = v;
        Q_EMIT self()->bypassChanged();
      }
    }

    Q_PROPERTY(bool bypass READ bypass WRITE setBypass NOTIFY bypassChanged)
    Q_PROPERTY(bool isBypassImmutable READ isBypassImmutable CONSTANT)
    Q_PROPERTY(bool defaultBypassValue READ defaultBypassValue CONSTANT)
    /**
      Get Global Bypass: Puts the Effects Pipelines in Passthrough Mode.
    */
    static
    bool bypass()
    {
      return self()->mBypass;
    }

    /**
      Is Global Bypass: Puts the Effects Pipelines in Passthrough Mode. Immutable
    */
    static
    bool isBypassImmutable()
    {
      return self()->isImmutable( QStringLiteral( "bypass" ) );
    }

    /**
      Get Global Bypass: Puts the Effects Pipelines in Passthrough Mode. default value
    */
    static
    bool defaultBypassValue()
    {
        return defaultBypassValue_helper();
    }

    /**
      Set Automatically moves Audio Streams to Easy Effects Virtual Sink.
    */
    static
    void setProcessAllOutputs( bool v )
    {
      if (v != self()->mProcessAllOutputs && !self()->isProcessAllOutputsImmutable()) {
        self()->mProcessAllOutputs = v;
        Q_EMIT self()->processAllOutputsChanged();
      }
    }

    Q_PROPERTY(bool processAllOutputs READ processAllOutputs WRITE setProcessAllOutputs NOTIFY processAllOutputsChanged)
    Q_PROPERTY(bool isProcessAllOutputsImmutable READ isProcessAllOutputsImmutable CONSTANT)
    Q_PROPERTY(bool defaultProcessAllOutputsValue READ defaultProcessAllOutputsValue CONSTANT)
    /**
      Get Automatically moves Audio Streams to Easy Effects Virtual Sink.
    */
    static
    bool processAllOutputs()
    {
      return self()->mProcessAllOutputs;
    }

    /**
      Is Automatically moves Audio Streams to Easy Effects Virtual Sink. Immutable
    */
    static
    bool isProcessAllOutputsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "processAllOutputs" ) );
    }

    /**
      Get Automatically moves Audio Streams to Easy Effects Virtual Sink. default value
    */
    static
    bool defaultProcessAllOutputsValue()
    {
        return defaultProcessAllOutputsValue_helper();
    }

    /**
      Set Automatically moves Audio Streams to Easy Effects Virtual Source.
    */
    static
    void setProcessAllInputs( bool v )
    {
      if (v != self()->mProcessAllInputs && !self()->isProcessAllInputsImmutable()) {
        self()->mProcessAllInputs = v;
        Q_EMIT self()->processAllInputsChanged();
      }
    }

    Q_PROPERTY(bool processAllInputs READ processAllInputs WRITE setProcessAllInputs NOTIFY processAllInputsChanged)
    Q_PROPERTY(bool isProcessAllInputsImmutable READ isProcessAllInputsImmutable CONSTANT)
    Q_PROPERTY(bool defaultProcessAllInputsValue READ defaultProcessAllInputsValue CONSTANT)
    /**
      Get Automatically moves Audio Streams to Easy Effects Virtual Source.
    */
    static
    bool processAllInputs()
    {
      return self()->mProcessAllInputs;
    }

    /**
      Is Automatically moves Audio Streams to Easy Effects Virtual Source. Immutable
    */
    static
    bool isProcessAllInputsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "processAllInputs" ) );
    }

    /**
      Get Automatically moves Audio Streams to Easy Effects Virtual Source. default value
    */
    static
    bool defaultProcessAllInputsValue()
    {
        return defaultProcessAllInputsValue_helper();
    }

    /**
      Set Ignore Streams from Monitor of Devices.
    */
    static
    void setExcludeMonitorStreams( bool v )
    {
      if (v != self()->mExcludeMonitorStreams && !self()->isExcludeMonitorStreamsImmutable()) {
        self()->mExcludeMonitorStreams = v;
        Q_EMIT self()->excludeMonitorStreamsChanged();
      }
    }

    Q_PROPERTY(bool excludeMonitorStreams READ excludeMonitorStreams WRITE setExcludeMonitorStreams NOTIFY excludeMonitorStreamsChanged)
    Q_PROPERTY(bool isExcludeMonitorStreamsImmutable READ isExcludeMonitorStreamsImmutable CONSTANT)
    Q_PROPERTY(bool defaultExcludeMonitorStreamsValue READ defaultExcludeMonitorStreamsValue CONSTANT)
    /**
      Get Ignore Streams from Monitor of Devices.
    */
    static
    bool excludeMonitorStreams()
    {
      return self()->mExcludeMonitorStreams;
    }

    /**
      Is Ignore Streams from Monitor of Devices. Immutable
    */
    static
    bool isExcludeMonitorStreamsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "excludeMonitorStreams" ) );
    }

    /**
      Get Ignore Streams from Monitor of Devices. default value
    */
    static
    bool defaultExcludeMonitorStreamsValue()
    {
        return defaultExcludeMonitorStreamsValue_helper();
    }

    /**
      Set Use Cubic Volume.
    */
    static
    void setUseCubicVolumes( bool v )
    {
      if (v != self()->mUseCubicVolumes && !self()->isUseCubicVolumesImmutable()) {
        self()->mUseCubicVolumes = v;
        Q_EMIT self()->useCubicVolumesChanged();
      }
    }

    Q_PROPERTY(bool useCubicVolumes READ useCubicVolumes WRITE setUseCubicVolumes NOTIFY useCubicVolumesChanged)
    Q_PROPERTY(bool isUseCubicVolumesImmutable READ isUseCubicVolumesImmutable CONSTANT)
    Q_PROPERTY(bool defaultUseCubicVolumesValue READ defaultUseCubicVolumesValue CONSTANT)
    /**
      Get Use Cubic Volume.
    */
    static
    bool useCubicVolumes()
    {
      return self()->mUseCubicVolumes;
    }

    /**
      Is Use Cubic Volume. Immutable
    */
    static
    bool isUseCubicVolumesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "useCubicVolumes" ) );
    }

    /**
      Get Use Cubic Volume. default value
    */
    static
    bool defaultUseCubicVolumesValue()
    {
        return defaultUseCubicVolumesValue_helper();
    }

    /**
      Set Do not apply effects to system notifications.
    */
    static
    void setIgnoreSystemNotifications( bool v )
    {
      if (v != self()->mIgnoreSystemNotifications && !self()->isIgnoreSystemNotificationsImmutable()) {
        self()->mIgnoreSystemNotifications = v;
        Q_EMIT self()->ignoreSystemNotificationsChanged();
      }
    }

    Q_PROPERTY(bool ignoreSystemNotifications READ ignoreSystemNotifications WRITE setIgnoreSystemNotifications NOTIFY ignoreSystemNotificationsChanged)
    Q_PROPERTY(bool isIgnoreSystemNotificationsImmutable READ isIgnoreSystemNotificationsImmutable CONSTANT)
    Q_PROPERTY(bool defaultIgnoreSystemNotificationsValue READ defaultIgnoreSystemNotificationsValue CONSTANT)
    /**
      Get Do not apply effects to system notifications.
    */
    static
    bool ignoreSystemNotifications()
    {
      return self()->mIgnoreSystemNotifications;
    }

    /**
      Is Do not apply effects to system notifications. Immutable
    */
    static
    bool isIgnoreSystemNotificationsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ignoreSystemNotifications" ) );
    }

    /**
      Get Do not apply effects to system notifications. default value
    */
    static
    bool defaultIgnoreSystemNotificationsValue()
    {
        return defaultIgnoreSystemNotificationsValue_helper();
    }

    /**
      Set Enable the Link Delay
    */
    static
    void setLinkDelayEnable( bool v )
    {
      if (v != self()->mLinkDelayEnable && !self()->isLinkDelayEnableImmutable()) {
        self()->mLinkDelayEnable = v;
        Q_EMIT self()->linkDelayEnableChanged();
      }
    }

    Q_PROPERTY(bool linkDelayEnable READ linkDelayEnable WRITE setLinkDelayEnable NOTIFY linkDelayEnableChanged)
    Q_PROPERTY(bool isLinkDelayEnableImmutable READ isLinkDelayEnableImmutable CONSTANT)
    Q_PROPERTY(bool defaultLinkDelayEnableValue READ defaultLinkDelayEnableValue CONSTANT)
    /**
      Get Enable the Link Delay
    */
    static
    bool linkDelayEnable()
    {
      return self()->mLinkDelayEnable;
    }

    /**
      Is Enable the Link Delay Immutable
    */
    static
    bool isLinkDelayEnableImmutable()
    {
      return self()->isImmutable( QStringLiteral( "linkDelayEnable" ) );
    }

    /**
      Get Enable the Link Delay default value
    */
    static
    bool defaultLinkDelayEnableValue()
    {
        return defaultLinkDelayEnableValue_helper();
    }

    /**
      Set Delay applied before linking the audio filters
    */
    static
    void setLinkDelay( int v )
    {
      if (v < 1)
      {
        qDebug() << "setLinkDelay: value " << v << " is less than the minimum value of 1";
        v = 1;
      }

      if (v > 1000)
      {
        qDebug() << "setLinkDelay: value " << v << " is greater than the maximum value of 1000";
        v = 1000;
      }

      if (v != self()->mLinkDelay && !self()->isLinkDelayImmutable()) {
        self()->mLinkDelay = v;
        Q_EMIT self()->linkDelayChanged();
      }
    }

    Q_PROPERTY(int linkDelay READ linkDelay WRITE setLinkDelay NOTIFY linkDelayChanged)
    Q_PROPERTY(bool isLinkDelayImmutable READ isLinkDelayImmutable CONSTANT)
    Q_PROPERTY(int defaultLinkDelayValue READ defaultLinkDelayValue CONSTANT)
    /**
      Get Delay applied before linking the audio filters
    */
    static
    int linkDelay()
    {
      return self()->mLinkDelay;
    }

    /**
      Is Delay applied before linking the audio filters Immutable
    */
    static
    bool isLinkDelayImmutable()
    {
      return self()->isImmutable( QStringLiteral( "linkDelay" ) );
    }

    /**
      Get Delay applied before linking the audio filters default value
    */
    static
    int defaultLinkDelayValue()
    {
        return defaultLinkDelayValue_helper();
    }

    /**
      Set Enable the Inactivity Timeout
    */
    static
    void setInactivityTimerEnable( bool v )
    {
      if (v != self()->mInactivityTimerEnable && !self()->isInactivityTimerEnableImmutable()) {
        self()->mInactivityTimerEnable = v;
        Q_EMIT self()->inactivityTimerEnableChanged();
      }
    }

    Q_PROPERTY(bool inactivityTimerEnable READ inactivityTimerEnable WRITE setInactivityTimerEnable NOTIFY inactivityTimerEnableChanged)
    Q_PROPERTY(bool isInactivityTimerEnableImmutable READ isInactivityTimerEnableImmutable CONSTANT)
    Q_PROPERTY(bool defaultInactivityTimerEnableValue READ defaultInactivityTimerEnableValue CONSTANT)
    /**
      Get Enable the Inactivity Timeout
    */
    static
    bool inactivityTimerEnable()
    {
      return self()->mInactivityTimerEnable;
    }

    /**
      Is Enable the Inactivity Timeout Immutable
    */
    static
    bool isInactivityTimerEnableImmutable()
    {
      return self()->isImmutable( QStringLiteral( "inactivityTimerEnable" ) );
    }

    /**
      Get Enable the Inactivity Timeout default value
    */
    static
    bool defaultInactivityTimerEnableValue()
    {
        return defaultInactivityTimerEnableValue_helper();
    }

    /**
      Set Inactivity Timeout.
    */
    static
    void setInactivityTimeout( int v )
    {
      if (v < 1)
      {
        qDebug() << "setInactivityTimeout: value " << v << " is less than the minimum value of 1";
        v = 1;
      }

      if (v > 3600)
      {
        qDebug() << "setInactivityTimeout: value " << v << " is greater than the maximum value of 3600";
        v = 3600;
      }

      if (v != self()->mInactivityTimeout && !self()->isInactivityTimeoutImmutable()) {
        self()->mInactivityTimeout = v;
        Q_EMIT self()->inactivityTimeoutChanged();
      }
    }

    Q_PROPERTY(int inactivityTimeout READ inactivityTimeout WRITE setInactivityTimeout NOTIFY inactivityTimeoutChanged)
    Q_PROPERTY(bool isInactivityTimeoutImmutable READ isInactivityTimeoutImmutable CONSTANT)
    Q_PROPERTY(int defaultInactivityTimeoutValue READ defaultInactivityTimeoutValue CONSTANT)
    /**
      Get Inactivity Timeout.
    */
    static
    int inactivityTimeout()
    {
      return self()->mInactivityTimeout;
    }

    /**
      Is Inactivity Timeout. Immutable
    */
    static
    bool isInactivityTimeoutImmutable()
    {
      return self()->isImmutable( QStringLiteral( "inactivityTimeout" ) );
    }

    /**
      Get Inactivity Timeout. default value
    */
    static
    int defaultInactivityTimeoutValue()
    {
        return defaultInactivityTimeoutValue_helper();
    }

    /**
      Set Time it takes for the level meters label to be updated. This is only used while the current level is below the last highest level.
    */
    static
    void setLevelMetersLabelTimer( int v )
    {
      if (v < 1)
      {
        qDebug() << "setLevelMetersLabelTimer: value " << v << " is less than the minimum value of 1";
        v = 1;
      }

      if (v > 10000)
      {
        qDebug() << "setLevelMetersLabelTimer: value " << v << " is greater than the maximum value of 10000";
        v = 10000;
      }

      if (v != self()->mLevelMetersLabelTimer && !self()->isLevelMetersLabelTimerImmutable()) {
        self()->mLevelMetersLabelTimer = v;
        Q_EMIT self()->levelMetersLabelTimerChanged();
      }
    }

    Q_PROPERTY(int levelMetersLabelTimer READ levelMetersLabelTimer WRITE setLevelMetersLabelTimer NOTIFY levelMetersLabelTimerChanged)
    Q_PROPERTY(bool isLevelMetersLabelTimerImmutable READ isLevelMetersLabelTimerImmutable CONSTANT)
    Q_PROPERTY(int defaultLevelMetersLabelTimerValue READ defaultLevelMetersLabelTimerValue CONSTANT)
    /**
      Get Time it takes for the level meters label to be updated. This is only used while the current level is below the last highest level.
    */
    static
    int levelMetersLabelTimer()
    {
      return self()->mLevelMetersLabelTimer;
    }

    /**
      Is Time it takes for the level meters label to be updated. This is only used while the current level is below the last highest level. Immutable
    */
    static
    bool isLevelMetersLabelTimerImmutable()
    {
      return self()->isImmutable( QStringLiteral( "levelMetersLabelTimer" ) );
    }

    /**
      Get Time it takes for the level meters label to be updated. This is only used while the current level is below the last highest level. default value
    */
    static
    int defaultLevelMetersLabelTimerValue()
    {
        return defaultLevelMetersLabelTimerValue_helper();
    }

    /**
      Set Enable or disable animations for the level meters
    */
    static
    void setEnableLevelMetersAnimation( bool v )
    {
      if (v != self()->mEnableLevelMetersAnimation && !self()->isEnableLevelMetersAnimationImmutable()) {
        self()->mEnableLevelMetersAnimation = v;
        Q_EMIT self()->enableLevelMetersAnimationChanged();
      }
    }

    Q_PROPERTY(bool enableLevelMetersAnimation READ enableLevelMetersAnimation WRITE setEnableLevelMetersAnimation NOTIFY enableLevelMetersAnimationChanged)
    Q_PROPERTY(bool isEnableLevelMetersAnimationImmutable READ isEnableLevelMetersAnimationImmutable CONSTANT)
    Q_PROPERTY(bool defaultEnableLevelMetersAnimationValue READ defaultEnableLevelMetersAnimationValue CONSTANT)
    /**
      Get Enable or disable animations for the level meters
    */
    static
    bool enableLevelMetersAnimation()
    {
      return self()->mEnableLevelMetersAnimation;
    }

    /**
      Is Enable or disable animations for the level meters Immutable
    */
    static
    bool isEnableLevelMetersAnimationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "enableLevelMetersAnimation" ) );
    }

    /**
      Get Enable or disable animations for the level meters default value
    */
    static
    bool defaultEnableLevelMetersAnimationValue()
    {
        return defaultEnableLevelMetersAnimationValue_helper();
    }

    /**
      Set Duration of the animation used in the level meters.
    */
    static
    void setLevelMetersAnimationDuration( int v )
    {
      if (v < 1)
      {
        qDebug() << "setLevelMetersAnimationDuration: value " << v << " is less than the minimum value of 1";
        v = 1;
      }

      if (v > 10000)
      {
        qDebug() << "setLevelMetersAnimationDuration: value " << v << " is greater than the maximum value of 10000";
        v = 10000;
      }

      if (v != self()->mLevelMetersAnimationDuration && !self()->isLevelMetersAnimationDurationImmutable()) {
        self()->mLevelMetersAnimationDuration = v;
        Q_EMIT self()->levelMetersAnimationDurationChanged();
      }
    }

    Q_PROPERTY(int levelMetersAnimationDuration READ levelMetersAnimationDuration WRITE setLevelMetersAnimationDuration NOTIFY levelMetersAnimationDurationChanged)
    Q_PROPERTY(bool isLevelMetersAnimationDurationImmutable READ isLevelMetersAnimationDurationImmutable CONSTANT)
    Q_PROPERTY(int defaultLevelMetersAnimationDurationValue READ defaultLevelMetersAnimationDurationValue CONSTANT)
    /**
      Get Duration of the animation used in the level meters.
    */
    static
    int levelMetersAnimationDuration()
    {
      return self()->mLevelMetersAnimationDuration;
    }

    /**
      Is Duration of the animation used in the level meters. Immutable
    */
    static
    bool isLevelMetersAnimationDurationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "levelMetersAnimationDuration" ) );
    }

    /**
      Get Duration of the animation used in the level meters. default value
    */
    static
    int defaultLevelMetersAnimationDurationValue()
    {
        return defaultLevelMetersAnimationDurationValue_helper();
    }

    /**
      Set Maximum level meter update rate.
    */
    static
    void setLevelMetersFpsCap( int v )
    {
      if (v < 1)
      {
        qDebug() << "setLevelMetersFpsCap: value " << v << " is less than the minimum value of 1";
        v = 1;
      }

      if (v > 240)
      {
        qDebug() << "setLevelMetersFpsCap: value " << v << " is greater than the maximum value of 240";
        v = 240;
      }

      if (v != self()->mLevelMetersFpsCap && !self()->isLevelMetersFpsCapImmutable()) {
        self()->mLevelMetersFpsCap = v;
        Q_EMIT self()->levelMetersFpsCapChanged();
      }
    }

    Q_PROPERTY(int levelMetersFpsCap READ levelMetersFpsCap WRITE setLevelMetersFpsCap NOTIFY levelMetersFpsCapChanged)
    Q_PROPERTY(bool isLevelMetersFpsCapImmutable READ isLevelMetersFpsCapImmutable CONSTANT)
    Q_PROPERTY(int defaultLevelMetersFpsCapValue READ defaultLevelMetersFpsCapValue CONSTANT)
    /**
      Get Maximum level meter update rate.
    */
    static
    int levelMetersFpsCap()
    {
      return self()->mLevelMetersFpsCap;
    }

    /**
      Is Maximum level meter update rate. Immutable
    */
    static
    bool isLevelMetersFpsCapImmutable()
    {
      return self()->isImmutable( QStringLiteral( "levelMetersFpsCap" ) );
    }

    /**
      Get Maximum level meter update rate. default value
    */
    static
    int defaultLevelMetersFpsCapValue()
    {
        return defaultLevelMetersFpsCapValue_helper();
    }

    /**
      Set Use a copy of the input buffer given by PipeWire when applying effects inside each audio plugin. This fixes audio glitches that can happen when external applications are recording from our virtual devices monitors.
    */
    static
    void setCopyFilterInputBuffers( bool v )
    {
      if (v != self()->mCopyFilterInputBuffers && !self()->isCopyFilterInputBuffersImmutable()) {
        self()->mCopyFilterInputBuffers = v;
        Q_EMIT self()->copyFilterInputBuffersChanged();
      }
    }

    Q_PROPERTY(bool copyFilterInputBuffers READ copyFilterInputBuffers WRITE setCopyFilterInputBuffers NOTIFY copyFilterInputBuffersChanged)
    Q_PROPERTY(bool isCopyFilterInputBuffersImmutable READ isCopyFilterInputBuffersImmutable CONSTANT)
    Q_PROPERTY(bool defaultCopyFilterInputBuffersValue READ defaultCopyFilterInputBuffersValue CONSTANT)
    /**
      Get Use a copy of the input buffer given by PipeWire when applying effects inside each audio plugin. This fixes audio glitches that can happen when external applications are recording from our virtual devices monitors.
    */
    static
    bool copyFilterInputBuffers()
    {
      return self()->mCopyFilterInputBuffers;
    }

    /**
      Is Use a copy of the input buffer given by PipeWire when applying effects inside each audio plugin. This fixes audio glitches that can happen when external applications are recording from our virtual devices monitors. Immutable
    */
    static
    bool isCopyFilterInputBuffersImmutable()
    {
      return self()->isImmutable( QStringLiteral( "copyFilterInputBuffers" ) );
    }

    /**
      Get Use a copy of the input buffer given by PipeWire when applying effects inside each audio plugin. This fixes audio glitches that can happen when external applications are recording from our virtual devices monitors. default value
    */
    static
    bool defaultCopyFilterInputBuffersValue()
    {
        return defaultCopyFilterInputBuffersValue_helper();
    }

    /**
      Set Activate Monitor Channel Volumes. In other words our virtual devices volume and mute state can be controlled.
    */
    static
    void setActivateMonitorChannelVolumes( bool v )
    {
      if (v != self()->mActivateMonitorChannelVolumes && !self()->isActivateMonitorChannelVolumesImmutable()) {
        self()->mActivateMonitorChannelVolumes = v;
        Q_EMIT self()->activateMonitorChannelVolumesChanged();
      }
    }

    Q_PROPERTY(bool activateMonitorChannelVolumes READ activateMonitorChannelVolumes WRITE setActivateMonitorChannelVolumes NOTIFY activateMonitorChannelVolumesChanged)
    Q_PROPERTY(bool isActivateMonitorChannelVolumesImmutable READ isActivateMonitorChannelVolumesImmutable CONSTANT)
    Q_PROPERTY(bool defaultActivateMonitorChannelVolumesValue READ defaultActivateMonitorChannelVolumesValue CONSTANT)
    /**
      Get Activate Monitor Channel Volumes. In other words our virtual devices volume and mute state can be controlled.
    */
    static
    bool activateMonitorChannelVolumes()
    {
      return self()->mActivateMonitorChannelVolumes;
    }

    /**
      Is Activate Monitor Channel Volumes. In other words our virtual devices volume and mute state can be controlled. Immutable
    */
    static
    bool isActivateMonitorChannelVolumesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "activateMonitorChannelVolumes" ) );
    }

    /**
      Get Activate Monitor Channel Volumes. In other words our virtual devices volume and mute state can be controlled. default value
    */
    static
    bool defaultActivateMonitorChannelVolumesValue()
    {
        return defaultActivateMonitorChannelVolumesValue_helper();
    }

    /**
      Set Show Plugin's Native Window
    */
    static
    void setShowNativePluginUi( bool v )
    {
      if (v != self()->mShowNativePluginUi && !self()->isShowNativePluginUiImmutable()) {
        self()->mShowNativePluginUi = v;
        Q_EMIT self()->showNativePluginUiChanged();
      }
    }

    Q_PROPERTY(bool showNativePluginUi READ showNativePluginUi WRITE setShowNativePluginUi NOTIFY showNativePluginUiChanged)
    Q_PROPERTY(bool isShowNativePluginUiImmutable READ isShowNativePluginUiImmutable CONSTANT)
    Q_PROPERTY(bool defaultShowNativePluginUiValue READ defaultShowNativePluginUiValue CONSTANT)
    /**
      Get Show Plugin's Native Window
    */
    static
    bool showNativePluginUi()
    {
      return self()->mShowNativePluginUi;
    }

    /**
      Is Show Plugin's Native Window Immutable
    */
    static
    bool isShowNativePluginUiImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showNativePluginUi" ) );
    }

    /**
      Get Show Plugin's Native Window default value
    */
    static
    bool defaultShowNativePluginUiValue()
    {
        return defaultShowNativePluginUiValue_helper();
    }

    /**
      Set LV2 Native Window Update Frequency
    */
    static
    void setLv2uiUpdateFrequency( int v )
    {
      if (v < 1)
      {
        qDebug() << "setLv2uiUpdateFrequency: value " << v << " is less than the minimum value of 1";
        v = 1;
      }

      if (v > 60)
      {
        qDebug() << "setLv2uiUpdateFrequency: value " << v << " is greater than the maximum value of 60";
        v = 60;
      }

      if (v != self()->mLv2uiUpdateFrequency && !self()->isLv2uiUpdateFrequencyImmutable()) {
        self()->mLv2uiUpdateFrequency = v;
        Q_EMIT self()->lv2uiUpdateFrequencyChanged();
      }
    }

    Q_PROPERTY(int lv2uiUpdateFrequency READ lv2uiUpdateFrequency WRITE setLv2uiUpdateFrequency NOTIFY lv2uiUpdateFrequencyChanged)
    Q_PROPERTY(bool isLv2uiUpdateFrequencyImmutable READ isLv2uiUpdateFrequencyImmutable CONSTANT)
    Q_PROPERTY(int defaultLv2uiUpdateFrequencyValue READ defaultLv2uiUpdateFrequencyValue CONSTANT)
    /**
      Get LV2 Native Window Update Frequency
    */
    static
    int lv2uiUpdateFrequency()
    {
      return self()->mLv2uiUpdateFrequency;
    }

    /**
      Is LV2 Native Window Update Frequency Immutable
    */
    static
    bool isLv2uiUpdateFrequencyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "lv2uiUpdateFrequency" ) );
    }

    /**
      Get LV2 Native Window Update Frequency default value
    */
    static
    int defaultLv2uiUpdateFrequencyValue()
    {
        return defaultLv2uiUpdateFrequencyValue_helper();
    }


    enum {
      signalWidthChanged = 1,
      signalHeightChanged = 2,
      signalVisibilityChanged = 3,
      signalEnableServiceModeChanged = 4,
      signalShowTrayIconChanged = 5,
      signalAutostartOnLoginChanged = 6,
      signalNoWindowAfterStartingChanged = 7,
      signalEnglishLanguageChanged = 8,
      signalReducePluginsListControlsChanged = 9,
      signalXdgGlobalShortcutsChanged = 10,
      signalXdgGlobalShortcutsBoundChanged = 11,
      signalDatabaseAutosaveIntervalChanged = 12,
      signalPresetsAutoloadIntervalChanged = 13,
      signalMaxMostUsedPresetsChanged = 14,
      signalAutoHideInlineMessageTimeoutChanged = 15,
      signalInputAutoloadingUsesFallbackChanged = 16,
      signalOutputAutoloadingUsesFallbackChanged = 17,
      signalInputAutoloadingFallbackPresetChanged = 18,
      signalOutputAutoloadingFallbackPresetChanged = 19,
      signalVisiblePageChanged = 20,
      signalVisiblePresetSheetPageChanged = 21,
      signalVisibleAutoloadingTabChanged = 22,
      signalVisiblePipeWirePageChanged = 23,
      signalCollapsePluginsListChanged = 24,
      signalForceBreezeThemeChanged = 25,
      signalIgnorePresetBlocklistChanged = 26,
      signalLastLoadedInputPresetChanged = 27,
      signalLastLoadedOutputPresetChanged = 28,
      signalLastLoadedInputCommunityPackageChanged = 29,
      signalLastLoadedOutputCommunityPackageChanged = 30,
      signalBypassChanged = 31,
      signalProcessAllOutputsChanged = 32,
      signalProcessAllInputsChanged = 33,
      signalExcludeMonitorStreamsChanged = 34,
      signalUseCubicVolumesChanged = 35,
      signalIgnoreSystemNotificationsChanged = 36,
      signalLinkDelayEnableChanged = 37,
      signalLinkDelayChanged = 38,
      signalInactivityTimerEnableChanged = 39,
      signalInactivityTimeoutChanged = 40,
      signalLevelMetersLabelTimerChanged = 41,
      signalEnableLevelMetersAnimationChanged = 42,
      signalLevelMetersAnimationDurationChanged = 43,
      signalLevelMetersFpsCapChanged = 44,
      signalCopyFilterInputBuffersChanged = 45,
      signalActivateMonitorChannelVolumesChanged = 46,
      signalShowNativePluginUiChanged = 47,
      signalLv2uiUpdateFrequencyChanged = 48
    };

  Q_SIGNALS:
    void widthChanged();

    void heightChanged();

    void visibilityChanged();

    void enableServiceModeChanged();

    void showTrayIconChanged();

    void autostartOnLoginChanged();

    void noWindowAfterStartingChanged();

    void englishLanguageChanged();

    void reducePluginsListControlsChanged();

    void xdgGlobalShortcutsChanged();

    void xdgGlobalShortcutsBoundChanged();

    void databaseAutosaveIntervalChanged();

    void presetsAutoloadIntervalChanged();

    void maxMostUsedPresetsChanged();

    void autoHideInlineMessageTimeoutChanged();

    void inputAutoloadingUsesFallbackChanged();

    void outputAutoloadingUsesFallbackChanged();

    void inputAutoloadingFallbackPresetChanged();

    void outputAutoloadingFallbackPresetChanged();

    void visiblePageChanged();

    void visiblePresetSheetPageChanged();

    void visibleAutoloadingTabChanged();

    void visiblePipeWirePageChanged();

    void collapsePluginsListChanged();

    void forceBreezeThemeChanged();

    void ignorePresetBlocklistChanged();

    void lastLoadedInputPresetChanged();

    void lastLoadedOutputPresetChanged();

    void lastLoadedInputCommunityPackageChanged();

    void lastLoadedOutputCommunityPackageChanged();

    void bypassChanged();

    void processAllOutputsChanged();

    void processAllInputsChanged();

    void excludeMonitorStreamsChanged();

    void useCubicVolumesChanged();

    void ignoreSystemNotificationsChanged();

    void linkDelayEnableChanged();

    void linkDelayChanged();

    void inactivityTimerEnableChanged();

    void inactivityTimeoutChanged();

    void levelMetersLabelTimerChanged();

    void enableLevelMetersAnimationChanged();

    void levelMetersAnimationDurationChanged();

    void levelMetersFpsCapChanged();

    void copyFilterInputBuffersChanged();

    void activateMonitorChannelVolumesChanged();

    void showNativePluginUiChanged();

    void lv2uiUpdateFrequencyChanged();

  private:
    void itemChanged(quint64 signalFlag);

  protected:
    DbMain();
    friend class DbMainHelper;


    // Window
    int mWidth;
    static int defaultWidthValue_helper();
    int mHeight;
    static int defaultHeightValue_helper();
    int mVisibility;
    static int defaultVisibilityValue_helper();
    bool mEnableServiceMode;
    static bool defaultEnableServiceModeValue_helper();
    bool mShowTrayIcon;
    static bool defaultShowTrayIconValue_helper();
    bool mAutostartOnLogin;
    static bool defaultAutostartOnLoginValue_helper();
    bool mNoWindowAfterStarting;
    static bool defaultNoWindowAfterStartingValue_helper();
    bool mEnglishLanguage;
    static bool defaultEnglishLanguageValue_helper();
    bool mReducePluginsListControls;
    static bool defaultReducePluginsListControlsValue_helper();
    bool mXdgGlobalShortcuts;
    static bool defaultXdgGlobalShortcutsValue_helper();
    bool mXdgGlobalShortcutsBound;
    static bool defaultXdgGlobalShortcutsBoundValue_helper();
    int mDatabaseAutosaveInterval;
    static int defaultDatabaseAutosaveIntervalValue_helper();
    int mPresetsAutoloadInterval;
    static int defaultPresetsAutoloadIntervalValue_helper();
    int mMaxMostUsedPresets;
    static int defaultMaxMostUsedPresetsValue_helper();
    int mAutoHideInlineMessageTimeout;
    static int defaultAutoHideInlineMessageTimeoutValue_helper();
    bool mInputAutoloadingUsesFallback;
    static bool defaultInputAutoloadingUsesFallbackValue_helper();
    bool mOutputAutoloadingUsesFallback;
    static bool defaultOutputAutoloadingUsesFallbackValue_helper();
    QString mInputAutoloadingFallbackPreset;
    static QString defaultInputAutoloadingFallbackPresetValue_helper();
    QString mOutputAutoloadingFallbackPreset;
    static QString defaultOutputAutoloadingFallbackPresetValue_helper();
    int mVisiblePage;
    static int defaultVisiblePageValue_helper();
    int mVisiblePresetSheetPage;
    static int defaultVisiblePresetSheetPageValue_helper();
    int mVisibleAutoloadingTab;
    static int defaultVisibleAutoloadingTabValue_helper();
    int mVisiblePipeWirePage;
    static int defaultVisiblePipeWirePageValue_helper();

    // Style
    bool mCollapsePluginsList;
    static bool defaultCollapsePluginsListValue_helper();
    bool mForceBreezeTheme;
    static bool defaultForceBreezeThemeValue_helper();

    // Presets
    bool mIgnorePresetBlocklist;
    static bool defaultIgnorePresetBlocklistValue_helper();
    QString mLastLoadedInputPreset;
    static QString defaultLastLoadedInputPresetValue_helper();
    QString mLastLoadedOutputPreset;
    static QString defaultLastLoadedOutputPresetValue_helper();
    QString mLastLoadedInputCommunityPackage;
    static QString defaultLastLoadedInputCommunityPackageValue_helper();
    QString mLastLoadedOutputCommunityPackage;
    static QString defaultLastLoadedOutputCommunityPackageValue_helper();

    // EffectsPipelines
    bool mBypass;
    static bool defaultBypassValue_helper();
    bool mProcessAllOutputs;
    static bool defaultProcessAllOutputsValue_helper();
    bool mProcessAllInputs;
    static bool defaultProcessAllInputsValue_helper();
    bool mExcludeMonitorStreams;
    static bool defaultExcludeMonitorStreamsValue_helper();
    bool mUseCubicVolumes;
    static bool defaultUseCubicVolumesValue_helper();
    bool mIgnoreSystemNotifications;
    static bool defaultIgnoreSystemNotificationsValue_helper();
    bool mLinkDelayEnable;
    static bool defaultLinkDelayEnableValue_helper();
    int mLinkDelay;
    static int defaultLinkDelayValue_helper();
    bool mInactivityTimerEnable;
    static bool defaultInactivityTimerEnableValue_helper();
    int mInactivityTimeout;
    static int defaultInactivityTimeoutValue_helper();

    // Audio
    int mLevelMetersLabelTimer;
    static int defaultLevelMetersLabelTimerValue_helper();
    bool mEnableLevelMetersAnimation;
    static bool defaultEnableLevelMetersAnimationValue_helper();
    int mLevelMetersAnimationDuration;
    static int defaultLevelMetersAnimationDurationValue_helper();
    int mLevelMetersFpsCap;
    static int defaultLevelMetersFpsCapValue_helper();
    bool mCopyFilterInputBuffers;
    static bool defaultCopyFilterInputBuffersValue_helper();
    bool mActivateMonitorChannelVolumes;
    static bool defaultActivateMonitorChannelVolumesValue_helper();

    // NativePluginWindow
    bool mShowNativePluginUi;
    static bool defaultShowNativePluginUiValue_helper();
    int mLv2uiUpdateFrequency;
    static int defaultLv2uiUpdateFrequencyValue_helper();
};

#endif

