// This file is generated by kconfig_compiler_kf6 from easyeffects_db_delay.kcfg.
// All changes you do to this file will be lost.

#include "easyeffects_db_delay.h"

DbDelay::DbDelay( const QString & masterGroup, const QString & instanceIndex )
  : KConfigBaseEE( QStringLiteral( "easyeffects/db/delayrc" ) )
  , mParammasterGroup(masterGroup)
  , mParaminstanceIndex(instanceIndex)
{
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&DbDelay::itemChanged);

  KConfigGroup cgmasterGroup(this->config(), QStringLiteral( "%1" ).arg( mParammasterGroup ));
  KConfigGroup cgDelayinstanceIndex = cgmasterGroup.group(QStringLiteral( "Delay#%1" ).arg( mParaminstanceIndex ));
  KConfigCompilerSignallingItem  *itemBypass;
  KConfigBaseEE::ItemBool  *innerItemBypass;
  innerItemBypass = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "bypass" ), mBypass, false );
  itemBypass = new KConfigCompilerSignallingItem(innerItemBypass, this, notifyFunction, signalBypassChanged);
  itemBypass->setWriteFlags(KConfigBase::Notify);
  itemBypass->setGroup(cgDelayinstanceIndex);
  addItem( itemBypass, QStringLiteral( "bypass" ) );
  KConfigCompilerSignallingItem  *itemInputGain;
  KConfigBaseEE::ItemDouble  *innerItemInputGain;
  innerItemInputGain = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "inputGain" ), mInputGain, 0 );
  itemInputGain = new KConfigCompilerSignallingItem(innerItemInputGain, this, notifyFunction, signalInputGainChanged);
  innerItemInputGain->setMinValue(-36);
  innerItemInputGain->setMaxValue(36);
  itemInputGain->setWriteFlags(KConfigBase::Notify);
  itemInputGain->setGroup(cgDelayinstanceIndex);
  addItem( itemInputGain, QStringLiteral( "inputGain" ) );
  KConfigCompilerSignallingItem  *itemOutputGain;
  KConfigBaseEE::ItemDouble  *innerItemOutputGain;
  innerItemOutputGain = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "outputGain" ), mOutputGain, 0 );
  itemOutputGain = new KConfigCompilerSignallingItem(innerItemOutputGain, this, notifyFunction, signalOutputGainChanged);
  innerItemOutputGain->setMinValue(-36);
  innerItemOutputGain->setMaxValue(36);
  itemOutputGain->setWriteFlags(KConfigBase::Notify);
  itemOutputGain->setGroup(cgDelayinstanceIndex);
  addItem( itemOutputGain, QStringLiteral( "outputGain" ) );
  KConfigCompilerSignallingItem  *itemDryL;
  KConfigBaseEE::ItemDouble  *innerItemDryL;
  innerItemDryL = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "dryL" ), mDryL, -80.01 );
  itemDryL = new KConfigCompilerSignallingItem(innerItemDryL, this, notifyFunction, signalDryLChanged);
  innerItemDryL->setMinValue(-80.01);
  innerItemDryL->setMaxValue(20);
  itemDryL->setWriteFlags(KConfigBase::Notify);
  itemDryL->setGroup(cgDelayinstanceIndex);
  addItem( itemDryL, QStringLiteral( "dryL" ) );
  KConfigCompilerSignallingItem  *itemDryR;
  KConfigBaseEE::ItemDouble  *innerItemDryR;
  innerItemDryR = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "dryR" ), mDryR, -80.01 );
  itemDryR = new KConfigCompilerSignallingItem(innerItemDryR, this, notifyFunction, signalDryRChanged);
  innerItemDryR->setMinValue(-80.01);
  innerItemDryR->setMaxValue(20);
  itemDryR->setWriteFlags(KConfigBase::Notify);
  itemDryR->setGroup(cgDelayinstanceIndex);
  addItem( itemDryR, QStringLiteral( "dryR" ) );
  KConfigCompilerSignallingItem  *itemWetL;
  KConfigBaseEE::ItemDouble  *innerItemWetL;
  innerItemWetL = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "wetL" ), mWetL, 0 );
  itemWetL = new KConfigCompilerSignallingItem(innerItemWetL, this, notifyFunction, signalWetLChanged);
  innerItemWetL->setMinValue(-80.01);
  innerItemWetL->setMaxValue(20);
  itemWetL->setWriteFlags(KConfigBase::Notify);
  itemWetL->setGroup(cgDelayinstanceIndex);
  addItem( itemWetL, QStringLiteral( "wetL" ) );
  KConfigCompilerSignallingItem  *itemWetR;
  KConfigBaseEE::ItemDouble  *innerItemWetR;
  innerItemWetR = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "wetR" ), mWetR, 0 );
  itemWetR = new KConfigCompilerSignallingItem(innerItemWetR, this, notifyFunction, signalWetRChanged);
  innerItemWetR->setMinValue(-80.01);
  innerItemWetR->setMaxValue(20);
  itemWetR->setWriteFlags(KConfigBase::Notify);
  itemWetR->setGroup(cgDelayinstanceIndex);
  addItem( itemWetR, QStringLiteral( "wetR" ) );
  QStringList defaultmodeLLabels;
  defaultmodeLLabels.append( QString::fromUtf8( "Samples" ) );
  defaultmodeLLabels.append( QString::fromUtf8( "Distance" ) );
  defaultmodeLLabels.append( QString::fromUtf8( "Time" ) );

  KConfigCompilerSignallingItem  *itemModeLLabels;
  KConfigBaseEE::ItemStringList  *innerItemModeLLabels;
  innerItemModeLLabels = new KConfigBaseEE::ItemStringList( currentGroup(), QStringLiteral( "modeLLabels" ), mModeLLabels, defaultmodeLLabels );
  itemModeLLabels = new KConfigCompilerSignallingItem(innerItemModeLLabels, this, notifyFunction, signalModeLLabelsChanged);
  itemModeLLabels->setWriteFlags(KConfigBase::Notify);
  itemModeLLabels->setGroup(cgDelayinstanceIndex);
  addItem( itemModeLLabels, QStringLiteral( "modeLLabels" ) );
  KConfigCompilerSignallingItem  *itemModeL;
  KConfigBaseEE::ItemInt  *innerItemModeL;
  innerItemModeL = new KConfigBaseEE::ItemInt( currentGroup(), QStringLiteral( "modeL" ), mModeL, 2 );
  itemModeL = new KConfigCompilerSignallingItem(innerItemModeL, this, notifyFunction, signalModeLChanged);
  itemModeL->setWriteFlags(KConfigBase::Notify);
  itemModeL->setGroup(cgDelayinstanceIndex);
  addItem( itemModeL, QStringLiteral( "modeL" ) );
  QStringList defaultmodeRLabels;
  defaultmodeRLabels.append( QString::fromUtf8( "Samples" ) );
  defaultmodeRLabels.append( QString::fromUtf8( "Distance" ) );
  defaultmodeRLabels.append( QString::fromUtf8( "Time" ) );

  KConfigCompilerSignallingItem  *itemModeRLabels;
  KConfigBaseEE::ItemStringList  *innerItemModeRLabels;
  innerItemModeRLabels = new KConfigBaseEE::ItemStringList( currentGroup(), QStringLiteral( "modeRLabels" ), mModeRLabels, defaultmodeRLabels );
  itemModeRLabels = new KConfigCompilerSignallingItem(innerItemModeRLabels, this, notifyFunction, signalModeRLabelsChanged);
  itemModeRLabels->setWriteFlags(KConfigBase::Notify);
  itemModeRLabels->setGroup(cgDelayinstanceIndex);
  addItem( itemModeRLabels, QStringLiteral( "modeRLabels" ) );
  KConfigCompilerSignallingItem  *itemModeR;
  KConfigBaseEE::ItemInt  *innerItemModeR;
  innerItemModeR = new KConfigBaseEE::ItemInt( currentGroup(), QStringLiteral( "modeR" ), mModeR, 2 );
  itemModeR = new KConfigCompilerSignallingItem(innerItemModeR, this, notifyFunction, signalModeRChanged);
  itemModeR->setWriteFlags(KConfigBase::Notify);
  itemModeR->setGroup(cgDelayinstanceIndex);
  addItem( itemModeR, QStringLiteral( "modeR" ) );
  KConfigCompilerSignallingItem  *itemTimeL;
  KConfigBaseEE::ItemDouble  *innerItemTimeL;
  innerItemTimeL = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "timeL" ), mTimeL, 0 );
  itemTimeL = new KConfigCompilerSignallingItem(innerItemTimeL, this, notifyFunction, signalTimeLChanged);
  innerItemTimeL->setMinValue(0);
  innerItemTimeL->setMaxValue(1000);
  itemTimeL->setWriteFlags(KConfigBase::Notify);
  itemTimeL->setGroup(cgDelayinstanceIndex);
  addItem( itemTimeL, QStringLiteral( "timeL" ) );
  KConfigCompilerSignallingItem  *itemTimeR;
  KConfigBaseEE::ItemDouble  *innerItemTimeR;
  innerItemTimeR = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "timeR" ), mTimeR, 0 );
  itemTimeR = new KConfigCompilerSignallingItem(innerItemTimeR, this, notifyFunction, signalTimeRChanged);
  innerItemTimeR->setMinValue(0);
  innerItemTimeR->setMaxValue(1000);
  itemTimeR->setWriteFlags(KConfigBase::Notify);
  itemTimeR->setGroup(cgDelayinstanceIndex);
  addItem( itemTimeR, QStringLiteral( "timeR" ) );
  KConfigCompilerSignallingItem  *itemInvertPhaseL;
  KConfigBaseEE::ItemBool  *innerItemInvertPhaseL;
  innerItemInvertPhaseL = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "invertPhaseL" ), mInvertPhaseL, false );
  itemInvertPhaseL = new KConfigCompilerSignallingItem(innerItemInvertPhaseL, this, notifyFunction, signalInvertPhaseLChanged);
  itemInvertPhaseL->setWriteFlags(KConfigBase::Notify);
  itemInvertPhaseL->setGroup(cgDelayinstanceIndex);
  addItem( itemInvertPhaseL, QStringLiteral( "invertPhaseL" ) );
  KConfigCompilerSignallingItem  *itemInvertPhaseR;
  KConfigBaseEE::ItemBool  *innerItemInvertPhaseR;
  innerItemInvertPhaseR = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "invertPhaseR" ), mInvertPhaseR, false );
  itemInvertPhaseR = new KConfigCompilerSignallingItem(innerItemInvertPhaseR, this, notifyFunction, signalInvertPhaseRChanged);
  itemInvertPhaseR->setWriteFlags(KConfigBase::Notify);
  itemInvertPhaseR->setGroup(cgDelayinstanceIndex);
  addItem( itemInvertPhaseR, QStringLiteral( "invertPhaseR" ) );
  KConfigCompilerSignallingItem  *itemSampleL;
  KConfigBaseEE::ItemDouble  *innerItemSampleL;
  innerItemSampleL = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "sampleL" ), mSampleL, 0 );
  itemSampleL = new KConfigCompilerSignallingItem(innerItemSampleL, this, notifyFunction, signalSampleLChanged);
  innerItemSampleL->setMinValue(0);
  innerItemSampleL->setMaxValue(10000);
  itemSampleL->setWriteFlags(KConfigBase::Notify);
  itemSampleL->setGroup(cgDelayinstanceIndex);
  addItem( itemSampleL, QStringLiteral( "sampleL" ) );
  KConfigCompilerSignallingItem  *itemSampleR;
  KConfigBaseEE::ItemDouble  *innerItemSampleR;
  innerItemSampleR = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "sampleR" ), mSampleR, 0 );
  itemSampleR = new KConfigCompilerSignallingItem(innerItemSampleR, this, notifyFunction, signalSampleRChanged);
  innerItemSampleR->setMinValue(0);
  innerItemSampleR->setMaxValue(10000);
  itemSampleR->setWriteFlags(KConfigBase::Notify);
  itemSampleR->setGroup(cgDelayinstanceIndex);
  addItem( itemSampleR, QStringLiteral( "sampleR" ) );
  KConfigCompilerSignallingItem  *itemMetersL;
  KConfigBaseEE::ItemDouble  *innerItemMetersL;
  innerItemMetersL = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "metersL" ), mMetersL, 0 );
  itemMetersL = new KConfigCompilerSignallingItem(innerItemMetersL, this, notifyFunction, signalMetersLChanged);
  innerItemMetersL->setMinValue(0);
  innerItemMetersL->setMaxValue(200);
  itemMetersL->setWriteFlags(KConfigBase::Notify);
  itemMetersL->setGroup(cgDelayinstanceIndex);
  addItem( itemMetersL, QStringLiteral( "metersL" ) );
  KConfigCompilerSignallingItem  *itemMetersR;
  KConfigBaseEE::ItemDouble  *innerItemMetersR;
  innerItemMetersR = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "metersR" ), mMetersR, 0 );
  itemMetersR = new KConfigCompilerSignallingItem(innerItemMetersR, this, notifyFunction, signalMetersRChanged);
  innerItemMetersR->setMinValue(0);
  innerItemMetersR->setMaxValue(200);
  itemMetersR->setWriteFlags(KConfigBase::Notify);
  itemMetersR->setGroup(cgDelayinstanceIndex);
  addItem( itemMetersR, QStringLiteral( "metersR" ) );
  KConfigCompilerSignallingItem  *itemCentimetersL;
  KConfigBaseEE::ItemDouble  *innerItemCentimetersL;
  innerItemCentimetersL = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "centimetersL" ), mCentimetersL, 0 );
  itemCentimetersL = new KConfigCompilerSignallingItem(innerItemCentimetersL, this, notifyFunction, signalCentimetersLChanged);
  innerItemCentimetersL->setMinValue(0);
  innerItemCentimetersL->setMaxValue(100);
  itemCentimetersL->setWriteFlags(KConfigBase::Notify);
  itemCentimetersL->setGroup(cgDelayinstanceIndex);
  addItem( itemCentimetersL, QStringLiteral( "centimetersL" ) );
  KConfigCompilerSignallingItem  *itemCentimetersR;
  KConfigBaseEE::ItemDouble  *innerItemCentimetersR;
  innerItemCentimetersR = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "centimetersR" ), mCentimetersR, 0 );
  itemCentimetersR = new KConfigCompilerSignallingItem(innerItemCentimetersR, this, notifyFunction, signalCentimetersRChanged);
  innerItemCentimetersR->setMinValue(0);
  innerItemCentimetersR->setMaxValue(100);
  itemCentimetersR->setWriteFlags(KConfigBase::Notify);
  itemCentimetersR->setGroup(cgDelayinstanceIndex);
  addItem( itemCentimetersR, QStringLiteral( "centimetersR" ) );
  KConfigCompilerSignallingItem  *itemTemperatureL;
  KConfigBaseEE::ItemDouble  *innerItemTemperatureL;
  innerItemTemperatureL = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "temperatureL" ), mTemperatureL, 20 );
  itemTemperatureL = new KConfigCompilerSignallingItem(innerItemTemperatureL, this, notifyFunction, signalTemperatureLChanged);
  innerItemTemperatureL->setMinValue(-60);
  innerItemTemperatureL->setMaxValue(60);
  itemTemperatureL->setWriteFlags(KConfigBase::Notify);
  itemTemperatureL->setGroup(cgDelayinstanceIndex);
  addItem( itemTemperatureL, QStringLiteral( "temperatureL" ) );
  KConfigCompilerSignallingItem  *itemTemperatureR;
  KConfigBaseEE::ItemDouble  *innerItemTemperatureR;
  innerItemTemperatureR = new KConfigBaseEE::ItemDouble( currentGroup(), QStringLiteral( "temperatureR" ), mTemperatureR, 20 );
  itemTemperatureR = new KConfigCompilerSignallingItem(innerItemTemperatureR, this, notifyFunction, signalTemperatureRChanged);
  innerItemTemperatureR->setMinValue(-60);
  innerItemTemperatureR->setMaxValue(60);
  itemTemperatureR->setWriteFlags(KConfigBase::Notify);
  itemTemperatureR->setGroup(cgDelayinstanceIndex);
  addItem( itemTemperatureR, QStringLiteral( "temperatureR" ) );
}

bool DbDelay::defaultBypassValue_helper() const
{

  return false;
}

double DbDelay::defaultInputGainValue_helper() const
{

  return 0;
}

double DbDelay::defaultOutputGainValue_helper() const
{

  return 0;
}

double DbDelay::defaultDryLValue_helper() const
{

  return -80.01;
}

double DbDelay::defaultDryRValue_helper() const
{

  return -80.01;
}

double DbDelay::defaultWetLValue_helper() const
{

  return 0;
}

double DbDelay::defaultWetRValue_helper() const
{

  return 0;
}

QStringList DbDelay::defaultModeLLabelsValue_helper() const
{
  QStringList defaultmodeLLabels;
  defaultmodeLLabels.append( QString::fromUtf8( "Samples" ) );
  defaultmodeLLabels.append( QString::fromUtf8( "Distance" ) );
  defaultmodeLLabels.append( QString::fromUtf8( "Time" ) );

  return defaultmodeLLabels;
}

int DbDelay::defaultModeLValue_helper() const
{

  return 2;
}

QStringList DbDelay::defaultModeRLabelsValue_helper() const
{
  QStringList defaultmodeRLabels;
  defaultmodeRLabels.append( QString::fromUtf8( "Samples" ) );
  defaultmodeRLabels.append( QString::fromUtf8( "Distance" ) );
  defaultmodeRLabels.append( QString::fromUtf8( "Time" ) );

  return defaultmodeRLabels;
}

int DbDelay::defaultModeRValue_helper() const
{

  return 2;
}

double DbDelay::defaultTimeLValue_helper() const
{

  return 0;
}

double DbDelay::defaultTimeRValue_helper() const
{

  return 0;
}

bool DbDelay::defaultInvertPhaseLValue_helper() const
{

  return false;
}

bool DbDelay::defaultInvertPhaseRValue_helper() const
{

  return false;
}

double DbDelay::defaultSampleLValue_helper() const
{

  return 0;
}

double DbDelay::defaultSampleRValue_helper() const
{

  return 0;
}

double DbDelay::defaultMetersLValue_helper() const
{

  return 0;
}

double DbDelay::defaultMetersRValue_helper() const
{

  return 0;
}

double DbDelay::defaultCentimetersLValue_helper() const
{

  return 0;
}

double DbDelay::defaultCentimetersRValue_helper() const
{

  return 0;
}

double DbDelay::defaultTemperatureLValue_helper() const
{

  return 20;
}

double DbDelay::defaultTemperatureRValue_helper() const
{

  return 20;
}

DbDelay::~DbDelay()
{
}


void DbDelay::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalBypassChanged:
    Q_EMIT bypassChanged();
    break;
  case signalInputGainChanged:
    Q_EMIT inputGainChanged();
    break;
  case signalOutputGainChanged:
    Q_EMIT outputGainChanged();
    break;
  case signalDryLChanged:
    Q_EMIT dryLChanged();
    break;
  case signalDryRChanged:
    Q_EMIT dryRChanged();
    break;
  case signalWetLChanged:
    Q_EMIT wetLChanged();
    break;
  case signalWetRChanged:
    Q_EMIT wetRChanged();
    break;
  case signalModeLLabelsChanged:
    Q_EMIT modeLLabelsChanged();
    break;
  case signalModeLChanged:
    Q_EMIT modeLChanged();
    break;
  case signalModeRLabelsChanged:
    Q_EMIT modeRLabelsChanged();
    break;
  case signalModeRChanged:
    Q_EMIT modeRChanged();
    break;
  case signalTimeLChanged:
    Q_EMIT timeLChanged();
    break;
  case signalTimeRChanged:
    Q_EMIT timeRChanged();
    break;
  case signalInvertPhaseLChanged:
    Q_EMIT invertPhaseLChanged();
    break;
  case signalInvertPhaseRChanged:
    Q_EMIT invertPhaseRChanged();
    break;
  case signalSampleLChanged:
    Q_EMIT sampleLChanged();
    break;
  case signalSampleRChanged:
    Q_EMIT sampleRChanged();
    break;
  case signalMetersLChanged:
    Q_EMIT metersLChanged();
    break;
  case signalMetersRChanged:
    Q_EMIT metersRChanged();
    break;
  case signalCentimetersLChanged:
    Q_EMIT centimetersLChanged();
    break;
  case signalCentimetersRChanged:
    Q_EMIT centimetersRChanged();
    break;
  case signalTemperatureLChanged:
    Q_EMIT temperatureLChanged();
    break;
  case signalTemperatureRChanged:
    Q_EMIT temperatureRChanged();
    break;
  }
}
