/****************************************************************************
** Meta object code from reading C++ file 'command_line_parser.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../easyeffects-8.2.8/src/command_line_parser.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'command_line_parser.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17CommandLineParserE_t {};
} // unnamed namespace

template <> constexpr inline auto CommandLineParser::qt_create_metaobjectdata<qt_meta_tag_ZN17CommandLineParserE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CommandLineParser",
        "onReset",
        "",
        "onQuit",
        "onHideWindow",
        "onLoadPreset",
        "PipelineType",
        "pipeline_type",
        "preset_name",
        "onGetLastLoadedPreset",
        "onGetLastLoadedInputOutputPreset",
        "onSetGlobalBypass",
        "state",
        "onGetGlobalBypass",
        "onToggleGlobalBypass",
        "onInitQML"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'onReset'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'onQuit'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'onHideWindow'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'onLoadPreset'
        QtMocHelpers::SignalData<void(PipelineType, QString)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'onGetLastLoadedPreset'
        QtMocHelpers::SignalData<void(PipelineType)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'onGetLastLoadedInputOutputPreset'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'onSetGlobalBypass'
        QtMocHelpers::SignalData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Signal 'onGetGlobalBypass'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'onToggleGlobalBypass'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'onInitQML'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CommandLineParser, qt_meta_tag_ZN17CommandLineParserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CommandLineParser::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CommandLineParserE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CommandLineParserE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17CommandLineParserE_t>.metaTypes,
    nullptr
} };

void CommandLineParser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CommandLineParser *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onReset(); break;
        case 1: _t->onQuit(); break;
        case 2: _t->onHideWindow(); break;
        case 3: _t->onLoadPreset((*reinterpret_cast<std::add_pointer_t<PipelineType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->onGetLastLoadedPreset((*reinterpret_cast<std::add_pointer_t<PipelineType>>(_a[1]))); break;
        case 5: _t->onGetLastLoadedInputOutputPreset(); break;
        case 6: _t->onSetGlobalBypass((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->onGetGlobalBypass(); break;
        case 8: _t->onToggleGlobalBypass(); break;
        case 9: _t->onInitQML(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CommandLineParser::*)()>(_a, &CommandLineParser::onReset, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommandLineParser::*)()>(_a, &CommandLineParser::onQuit, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommandLineParser::*)()>(_a, &CommandLineParser::onHideWindow, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommandLineParser::*)(PipelineType , QString )>(_a, &CommandLineParser::onLoadPreset, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommandLineParser::*)(PipelineType )>(_a, &CommandLineParser::onGetLastLoadedPreset, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommandLineParser::*)()>(_a, &CommandLineParser::onGetLastLoadedInputOutputPreset, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommandLineParser::*)(bool )>(_a, &CommandLineParser::onSetGlobalBypass, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommandLineParser::*)()>(_a, &CommandLineParser::onGetGlobalBypass, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommandLineParser::*)()>(_a, &CommandLineParser::onToggleGlobalBypass, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommandLineParser::*)()>(_a, &CommandLineParser::onInitQML, 9))
            return;
    }
}

const QMetaObject *CommandLineParser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CommandLineParser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CommandLineParserE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CommandLineParser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void CommandLineParser::onReset()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CommandLineParser::onQuit()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void CommandLineParser::onHideWindow()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void CommandLineParser::onLoadPreset(PipelineType _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void CommandLineParser::onGetLastLoadedPreset(PipelineType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void CommandLineParser::onGetLastLoadedInputOutputPreset()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void CommandLineParser::onSetGlobalBypass(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void CommandLineParser::onGetGlobalBypass()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void CommandLineParser::onToggleGlobalBypass()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void CommandLineParser::onInitQML()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
