#include <QtQml/qqmlprivate.h>
#include <QtCore/qdir.h>
#include <QtCore/qurl.h>
#include <QtCore/qhash.h>
#include <QtCore/qstring.h>

namespace QmlCacheGeneratedCode {
namespace _qt_qml_ee_ui_contents_ui_AboutPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Autogain_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Autotune_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_BassEnhancer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_BassLoudness_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_BlocklistDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Common_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Compressor_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Convolver_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_ConvolverImpulseDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_ConvolverSofaDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Crossfeed_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_CrosstalkCanceller_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Crusher_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Crystalizer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_CrystalizerBand_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Deesser_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Delay_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_DeepFilterNet_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_DelegateClientsList_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_DelegateModulesList_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_DelegatePluginsList_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_DelegateStreamsList_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_EchoCanceller_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_EeCard_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_EeChart_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_EeAudioLevel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_EeInputOutputGain_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_EeListSectionHeader_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_EeMetersReset_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_EeProgressBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_EeSpinBox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_EeSwitch_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Equalizer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_EqualizerBand_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_EqualizerBandMenu_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Exciter_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Expander_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Filter_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Gate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_LevelMeter_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Limiter_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Loudness_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Maximizer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_MultibandCompressor_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_MultibandGate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Main_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_MenuAddPlugins_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_PageStreamsEffects_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Pitch_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_PipeWirePage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_PluginNotAvailable_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_PreferencesSheet_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_LspPreMixDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_PresetsDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_PresetsAutoloadPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_PresetsLocalPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_PresetsCommunityPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Reverb_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_RNNoise_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_ShortcutsSheet_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Speex_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_StereoTools_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_TrayIcon_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_Validators_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_ee_ui_contents_ui_VoiceSuppressor_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}

}
namespace {
struct Registry {
    Registry();
    ~Registry();
    QHash<QString, const QQmlPrivate::CachedQmlUnit*> resourcePathToCachedUnit;
    static const QQmlPrivate::CachedQmlUnit *lookupCachedUnit(const QUrl &url);
};

Q_GLOBAL_STATIC(Registry, unitRegistry)


Registry::Registry() {
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/AboutPage.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_AboutPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Autogain.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Autogain_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Autotune.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Autotune_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/BassEnhancer.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_BassEnhancer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/BassLoudness.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_BassLoudness_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/BlocklistDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_BlocklistDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Common.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Common_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Compressor.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Compressor_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Convolver.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Convolver_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/ConvolverImpulseDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_ConvolverImpulseDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/ConvolverSofaDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_ConvolverSofaDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Crossfeed.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Crossfeed_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/CrosstalkCanceller.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_CrosstalkCanceller_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Crusher.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Crusher_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Crystalizer.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Crystalizer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/CrystalizerBand.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_CrystalizerBand_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Deesser.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Deesser_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Delay.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Delay_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/DeepFilterNet.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_DeepFilterNet_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/DelegateClientsList.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_DelegateClientsList_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/DelegateModulesList.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_DelegateModulesList_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/DelegatePluginsList.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_DelegatePluginsList_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/DelegateStreamsList.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_DelegateStreamsList_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/EchoCanceller.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_EchoCanceller_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/EeCard.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_EeCard_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/EeChart.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_EeChart_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/EeAudioLevel.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_EeAudioLevel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/EeInputOutputGain.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_EeInputOutputGain_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/EeListSectionHeader.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_EeListSectionHeader_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/EeMetersReset.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_EeMetersReset_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/EeProgressBar.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_EeProgressBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/EeSpinBox.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_EeSpinBox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/EeSwitch.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_EeSwitch_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Equalizer.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Equalizer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/EqualizerBand.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_EqualizerBand_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/EqualizerBandMenu.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_EqualizerBandMenu_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Exciter.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Exciter_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Expander.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Expander_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Filter.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Filter_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Gate.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Gate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/LevelMeter.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_LevelMeter_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Limiter.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Limiter_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Loudness.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Loudness_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Maximizer.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Maximizer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/MultibandCompressor.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_MultibandCompressor_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/MultibandGate.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_MultibandGate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Main.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Main_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/MenuAddPlugins.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_MenuAddPlugins_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/PageStreamsEffects.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_PageStreamsEffects_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Pitch.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Pitch_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/PipeWirePage.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_PipeWirePage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/PluginNotAvailable.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_PluginNotAvailable_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/PreferencesSheet.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_PreferencesSheet_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/LspPreMixDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_LspPreMixDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/PresetsDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_PresetsDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/PresetsAutoloadPage.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_PresetsAutoloadPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/PresetsLocalPage.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_PresetsLocalPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/PresetsCommunityPage.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_PresetsCommunityPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Reverb.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Reverb_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/RNNoise.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_RNNoise_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/ShortcutsSheet.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_ShortcutsSheet_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Speex.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Speex_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/StereoTools.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_StereoTools_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/TrayIcon.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_TrayIcon_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/Validators.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_Validators_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/ee/ui/contents/ui/VoiceSuppressor.qml"), &QmlCacheGeneratedCode::_qt_qml_ee_ui_contents_ui_VoiceSuppressor_qml::unit);
    QQmlPrivate::RegisterQmlUnitCacheHook registration;
    registration.structVersion = 0;
    registration.lookupCachedQmlUnit = &lookupCachedUnit;
    QQmlPrivate::qmlregister(QQmlPrivate::QmlUnitCacheHookRegistration, &registration);
}

Registry::~Registry() {
    QQmlPrivate::qmlunregister(QQmlPrivate::QmlUnitCacheHookRegistration, quintptr(&lookupCachedUnit));
}

const QQmlPrivate::CachedQmlUnit *Registry::lookupCachedUnit(const QUrl &url) {
    if (url.scheme() != QLatin1String("qrc"))
        return nullptr;
    QString resourcePath = QDir::cleanPath(url.path());
    if (resourcePath.isEmpty())
        return nullptr;
    if (!resourcePath.startsWith(QLatin1Char('/')))
        resourcePath.prepend(QLatin1Char('/'));
    return unitRegistry()->resourcePathToCachedUnit.value(resourcePath, nullptr);
}
}
int QT_MANGLE_NAMESPACE(qInitResources_qmlcache_easyeffects)() {
    ::unitRegistry();
    return 1;
}
Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_qmlcache_easyeffects))
int QT_MANGLE_NAMESPACE(qCleanupResources_qmlcache_easyeffects)() {
    return 1;
}
