/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db_deesser.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db_deesser.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db_deesser.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9DbDeesserE_t {};
} // unnamed namespace

template <> constexpr inline auto DbDeesser::qt_create_metaobjectdata<qt_meta_tag_ZN9DbDeesserE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbDeesser",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "bypassChanged",
        "inputGainChanged",
        "outputGainChanged",
        "detectionLabelsChanged",
        "detectionChanged",
        "modeLabelsChanged",
        "modeChanged",
        "thresholdChanged",
        "ratioChanged",
        "laxityChanged",
        "makeupChanged",
        "f1FreqChanged",
        "f2FreqChanged",
        "f1LevelChanged",
        "f2LevelChanged",
        "f2QChanged",
        "scListenChanged",
        "bypass",
        "isBypassImmutable",
        "defaultBypassValue",
        "inputGain",
        "isInputGainImmutable",
        "defaultInputGainValue",
        "outputGain",
        "isOutputGainImmutable",
        "defaultOutputGainValue",
        "detectionLabels",
        "isDetectionLabelsImmutable",
        "defaultDetectionLabelsValue",
        "detection",
        "isDetectionImmutable",
        "defaultDetectionValue",
        "modeLabels",
        "isModeLabelsImmutable",
        "defaultModeLabelsValue",
        "mode",
        "isModeImmutable",
        "defaultModeValue",
        "threshold",
        "isThresholdImmutable",
        "defaultThresholdValue",
        "ratio",
        "isRatioImmutable",
        "defaultRatioValue",
        "laxity",
        "isLaxityImmutable",
        "defaultLaxityValue",
        "makeup",
        "isMakeupImmutable",
        "defaultMakeupValue",
        "f1Freq",
        "isF1FreqImmutable",
        "defaultF1FreqValue",
        "f2Freq",
        "isF2FreqImmutable",
        "defaultF2FreqValue",
        "f1Level",
        "isF1LevelImmutable",
        "defaultF1LevelValue",
        "f2Level",
        "isF2LevelImmutable",
        "defaultF2LevelValue",
        "f2Q",
        "isF2QImmutable",
        "defaultF2QValue",
        "scListen",
        "isScListenImmutable",
        "defaultScListenValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bypassChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputGainChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputGainChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'detectionLabelsChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'detectionChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeLabelsChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'thresholdChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ratioChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'laxityChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'makeupChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'f1FreqChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'f2FreqChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'f1LevelChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'f2LevelChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'f2QChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scListenChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bypass'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isBypassImmutable'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassValue'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputGain'
        QtMocHelpers::PropertyData<double>(27, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isInputGainImmutable'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputGainValue'
        QtMocHelpers::PropertyData<double>(29, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'outputGain'
        QtMocHelpers::PropertyData<double>(30, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isOutputGainImmutable'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOutputGainValue'
        QtMocHelpers::PropertyData<double>(32, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'detectionLabels'
        QtMocHelpers::PropertyData<QStringList>(33, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isDetectionLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDetectionLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(35, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'detection'
        QtMocHelpers::PropertyData<int>(36, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isDetectionImmutable'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDetectionValue'
        QtMocHelpers::PropertyData<int>(38, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'modeLabels'
        QtMocHelpers::PropertyData<QStringList>(39, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isModeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultModeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(41, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mode'
        QtMocHelpers::PropertyData<int>(42, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isModeImmutable'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultModeValue'
        QtMocHelpers::PropertyData<int>(44, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'threshold'
        QtMocHelpers::PropertyData<double>(45, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultThresholdValue'
        QtMocHelpers::PropertyData<double>(47, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ratio'
        QtMocHelpers::PropertyData<double>(48, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isRatioImmutable'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRatioValue'
        QtMocHelpers::PropertyData<double>(50, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'laxity'
        QtMocHelpers::PropertyData<int>(51, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isLaxityImmutable'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLaxityValue'
        QtMocHelpers::PropertyData<int>(53, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'makeup'
        QtMocHelpers::PropertyData<double>(54, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isMakeupImmutable'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMakeupValue'
        QtMocHelpers::PropertyData<double>(56, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'f1Freq'
        QtMocHelpers::PropertyData<double>(57, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isF1FreqImmutable'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultF1FreqValue'
        QtMocHelpers::PropertyData<double>(59, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'f2Freq'
        QtMocHelpers::PropertyData<double>(60, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isF2FreqImmutable'
        QtMocHelpers::PropertyData<bool>(61, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultF2FreqValue'
        QtMocHelpers::PropertyData<double>(62, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'f1Level'
        QtMocHelpers::PropertyData<double>(63, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isF1LevelImmutable'
        QtMocHelpers::PropertyData<bool>(64, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultF1LevelValue'
        QtMocHelpers::PropertyData<double>(65, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'f2Level'
        QtMocHelpers::PropertyData<double>(66, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isF2LevelImmutable'
        QtMocHelpers::PropertyData<bool>(67, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultF2LevelValue'
        QtMocHelpers::PropertyData<double>(68, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'f2Q'
        QtMocHelpers::PropertyData<double>(69, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isF2QImmutable'
        QtMocHelpers::PropertyData<bool>(70, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultF2QValue'
        QtMocHelpers::PropertyData<double>(71, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'scListen'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isScListenImmutable'
        QtMocHelpers::PropertyData<bool>(73, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultScListenValue'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DbDeesser, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbDeesser::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DbDeesserE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DbDeesserE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9DbDeesserE_t>.metaTypes,
    nullptr
} };

void DbDeesser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbDeesser *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bypassChanged(); break;
        case 1: _t->inputGainChanged(); break;
        case 2: _t->outputGainChanged(); break;
        case 3: _t->detectionLabelsChanged(); break;
        case 4: _t->detectionChanged(); break;
        case 5: _t->modeLabelsChanged(); break;
        case 6: _t->modeChanged(); break;
        case 7: _t->thresholdChanged(); break;
        case 8: _t->ratioChanged(); break;
        case 9: _t->laxityChanged(); break;
        case 10: _t->makeupChanged(); break;
        case 11: _t->f1FreqChanged(); break;
        case 12: _t->f2FreqChanged(); break;
        case 13: _t->f1LevelChanged(); break;
        case 14: _t->f2LevelChanged(); break;
        case 15: _t->f2QChanged(); break;
        case 16: _t->scListenChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbDeesser::*)()>(_a, &DbDeesser::bypassChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbDeesser::*)()>(_a, &DbDeesser::inputGainChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbDeesser::*)()>(_a, &DbDeesser::outputGainChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbDeesser::*)()>(_a, &DbDeesser::detectionLabelsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbDeesser::*)()>(_a, &DbDeesser::detectionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbDeesser::*)()>(_a, &DbDeesser::modeLabelsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbDeesser::*)()>(_a, &DbDeesser::modeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbDeesser::*)()>(_a, &DbDeesser::thresholdChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbDeesser::*)()>(_a, &DbDeesser::ratioChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbDeesser::*)()>(_a, &DbDeesser::laxityChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbDeesser::*)()>(_a, &DbDeesser::makeupChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbDeesser::*)()>(_a, &DbDeesser::f1FreqChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbDeesser::*)()>(_a, &DbDeesser::f2FreqChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbDeesser::*)()>(_a, &DbDeesser::f1LevelChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbDeesser::*)()>(_a, &DbDeesser::f2LevelChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbDeesser::*)()>(_a, &DbDeesser::f2QChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbDeesser::*)()>(_a, &DbDeesser::scListenChanged, 16))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bypass(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isBypassImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultBypassValue(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->inputGain(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isInputGainImmutable(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->defaultInputGainValue(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->outputGain(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isOutputGainImmutable(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->defaultOutputGainValue(); break;
        case 9: *reinterpret_cast<QStringList*>(_v) = _t->detectionLabels(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isDetectionLabelsImmutable(); break;
        case 11: *reinterpret_cast<QStringList*>(_v) = _t->defaultDetectionLabelsValue(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->detection(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isDetectionImmutable(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->defaultDetectionValue(); break;
        case 15: *reinterpret_cast<QStringList*>(_v) = _t->modeLabels(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isModeLabelsImmutable(); break;
        case 17: *reinterpret_cast<QStringList*>(_v) = _t->defaultModeLabelsValue(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->mode(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isModeImmutable(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->defaultModeValue(); break;
        case 21: *reinterpret_cast<double*>(_v) = _t->threshold(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isThresholdImmutable(); break;
        case 23: *reinterpret_cast<double*>(_v) = _t->defaultThresholdValue(); break;
        case 24: *reinterpret_cast<double*>(_v) = _t->ratio(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isRatioImmutable(); break;
        case 26: *reinterpret_cast<double*>(_v) = _t->defaultRatioValue(); break;
        case 27: *reinterpret_cast<int*>(_v) = _t->laxity(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isLaxityImmutable(); break;
        case 29: *reinterpret_cast<int*>(_v) = _t->defaultLaxityValue(); break;
        case 30: *reinterpret_cast<double*>(_v) = _t->makeup(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isMakeupImmutable(); break;
        case 32: *reinterpret_cast<double*>(_v) = _t->defaultMakeupValue(); break;
        case 33: *reinterpret_cast<double*>(_v) = _t->f1Freq(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isF1FreqImmutable(); break;
        case 35: *reinterpret_cast<double*>(_v) = _t->defaultF1FreqValue(); break;
        case 36: *reinterpret_cast<double*>(_v) = _t->f2Freq(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isF2FreqImmutable(); break;
        case 38: *reinterpret_cast<double*>(_v) = _t->defaultF2FreqValue(); break;
        case 39: *reinterpret_cast<double*>(_v) = _t->f1Level(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->isF1LevelImmutable(); break;
        case 41: *reinterpret_cast<double*>(_v) = _t->defaultF1LevelValue(); break;
        case 42: *reinterpret_cast<double*>(_v) = _t->f2Level(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->isF2LevelImmutable(); break;
        case 44: *reinterpret_cast<double*>(_v) = _t->defaultF2LevelValue(); break;
        case 45: *reinterpret_cast<double*>(_v) = _t->f2Q(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->isF2QImmutable(); break;
        case 47: *reinterpret_cast<double*>(_v) = _t->defaultF2QValue(); break;
        case 48: *reinterpret_cast<bool*>(_v) = _t->scListen(); break;
        case 49: *reinterpret_cast<bool*>(_v) = _t->isScListenImmutable(); break;
        case 50: *reinterpret_cast<bool*>(_v) = _t->defaultScListenValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBypass(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setInputGain(*reinterpret_cast<double*>(_v)); break;
        case 6: _t->setOutputGain(*reinterpret_cast<double*>(_v)); break;
        case 9: _t->setDetectionLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 12: _t->setDetection(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setModeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 18: _t->setMode(*reinterpret_cast<int*>(_v)); break;
        case 21: _t->setThreshold(*reinterpret_cast<double*>(_v)); break;
        case 24: _t->setRatio(*reinterpret_cast<double*>(_v)); break;
        case 27: _t->setLaxity(*reinterpret_cast<int*>(_v)); break;
        case 30: _t->setMakeup(*reinterpret_cast<double*>(_v)); break;
        case 33: _t->setF1Freq(*reinterpret_cast<double*>(_v)); break;
        case 36: _t->setF2Freq(*reinterpret_cast<double*>(_v)); break;
        case 39: _t->setF1Level(*reinterpret_cast<double*>(_v)); break;
        case 42: _t->setF2Level(*reinterpret_cast<double*>(_v)); break;
        case 45: _t->setF2Q(*reinterpret_cast<double*>(_v)); break;
        case 48: _t->setScListen(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbDeesser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbDeesser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DbDeesserE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbDeesser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 51;
    }
    return _id;
}

// SIGNAL 0
void DbDeesser::bypassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbDeesser::inputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbDeesser::outputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbDeesser::detectionLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DbDeesser::detectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DbDeesser::modeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DbDeesser::modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DbDeesser::thresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DbDeesser::ratioChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DbDeesser::laxityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DbDeesser::makeupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DbDeesser::f1FreqChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void DbDeesser::f2FreqChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void DbDeesser::f1LevelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void DbDeesser::f2LevelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void DbDeesser::f2QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void DbDeesser::scListenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}
QT_WARNING_POP
