/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db_autotune.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db_autotune.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db_autotune.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10DbAutotuneE_t {};
} // unnamed namespace

template <> constexpr inline auto DbAutotune::qt_create_metaobjectdata<qt_meta_tag_ZN10DbAutotuneE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbAutotune",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "bypassChanged",
        "inputGainChanged",
        "outputGainChanged",
        "modeLabelsChanged",
        "modeChanged",
        "channelFilterChanged",
        "tuningChanged",
        "biasChanged",
        "filterChanged",
        "correctionChanged",
        "offsetChanged",
        "bendRangeChanged",
        "fastModeChanged",
        "noteCChanged",
        "noteCSharpChanged",
        "noteDChanged",
        "noteDSharpChanged",
        "noteEChanged",
        "noteFChanged",
        "noteFSharpChanged",
        "noteGChanged",
        "noteGSharpChanged",
        "noteAChanged",
        "noteASharpChanged",
        "noteBChanged",
        "bypass",
        "isBypassImmutable",
        "defaultBypassValue",
        "inputGain",
        "isInputGainImmutable",
        "defaultInputGainValue",
        "outputGain",
        "isOutputGainImmutable",
        "defaultOutputGainValue",
        "modeLabels",
        "isModeLabelsImmutable",
        "defaultModeLabelsValue",
        "mode",
        "isModeImmutable",
        "defaultModeValue",
        "channelFilter",
        "isChannelFilterImmutable",
        "defaultChannelFilterValue",
        "tuning",
        "isTuningImmutable",
        "defaultTuningValue",
        "bias",
        "isBiasImmutable",
        "defaultBiasValue",
        "filter",
        "isFilterImmutable",
        "defaultFilterValue",
        "correction",
        "isCorrectionImmutable",
        "defaultCorrectionValue",
        "offset",
        "isOffsetImmutable",
        "defaultOffsetValue",
        "bendRange",
        "isBendRangeImmutable",
        "defaultBendRangeValue",
        "fastMode",
        "isFastModeImmutable",
        "defaultFastModeValue",
        "noteC",
        "isNoteCImmutable",
        "defaultNoteCValue",
        "noteCSharp",
        "isNoteCSharpImmutable",
        "defaultNoteCSharpValue",
        "noteD",
        "isNoteDImmutable",
        "defaultNoteDValue",
        "noteDSharp",
        "isNoteDSharpImmutable",
        "defaultNoteDSharpValue",
        "noteE",
        "isNoteEImmutable",
        "defaultNoteEValue",
        "noteF",
        "isNoteFImmutable",
        "defaultNoteFValue",
        "noteFSharp",
        "isNoteFSharpImmutable",
        "defaultNoteFSharpValue",
        "noteG",
        "isNoteGImmutable",
        "defaultNoteGValue",
        "noteGSharp",
        "isNoteGSharpImmutable",
        "defaultNoteGSharpValue",
        "noteA",
        "isNoteAImmutable",
        "defaultNoteAValue",
        "noteASharp",
        "isNoteASharpImmutable",
        "defaultNoteASharpValue",
        "noteB",
        "isNoteBImmutable",
        "defaultNoteBValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bypassChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputGainChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputGainChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeLabelsChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'channelFilterChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tuningChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'biasChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'correctionChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'offsetChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bendRangeChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fastModeChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noteCChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noteCSharpChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noteDChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noteDSharpChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noteEChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noteFChanged'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noteFSharpChanged'
        QtMocHelpers::SignalData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noteGChanged'
        QtMocHelpers::SignalData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noteGSharpChanged'
        QtMocHelpers::SignalData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noteAChanged'
        QtMocHelpers::SignalData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noteASharpChanged'
        QtMocHelpers::SignalData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noteBChanged'
        QtMocHelpers::SignalData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bypass'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isBypassImmutable'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassValue'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputGain'
        QtMocHelpers::PropertyData<double>(35, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isInputGainImmutable'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputGainValue'
        QtMocHelpers::PropertyData<double>(37, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'outputGain'
        QtMocHelpers::PropertyData<double>(38, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isOutputGainImmutable'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOutputGainValue'
        QtMocHelpers::PropertyData<double>(40, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'modeLabels'
        QtMocHelpers::PropertyData<QStringList>(41, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isModeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultModeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(43, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mode'
        QtMocHelpers::PropertyData<int>(44, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isModeImmutable'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultModeValue'
        QtMocHelpers::PropertyData<int>(46, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'channelFilter'
        QtMocHelpers::PropertyData<int>(47, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isChannelFilterImmutable'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultChannelFilterValue'
        QtMocHelpers::PropertyData<int>(49, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tuning'
        QtMocHelpers::PropertyData<double>(50, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isTuningImmutable'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTuningValue'
        QtMocHelpers::PropertyData<double>(52, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bias'
        QtMocHelpers::PropertyData<double>(53, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isBiasImmutable'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBiasValue'
        QtMocHelpers::PropertyData<double>(55, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'filter'
        QtMocHelpers::PropertyData<double>(56, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isFilterImmutable'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFilterValue'
        QtMocHelpers::PropertyData<double>(58, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'correction'
        QtMocHelpers::PropertyData<double>(59, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isCorrectionImmutable'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCorrectionValue'
        QtMocHelpers::PropertyData<double>(61, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'offset'
        QtMocHelpers::PropertyData<double>(62, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isOffsetImmutable'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOffsetValue'
        QtMocHelpers::PropertyData<double>(64, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bendRange'
        QtMocHelpers::PropertyData<double>(65, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isBendRangeImmutable'
        QtMocHelpers::PropertyData<bool>(66, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBendRangeValue'
        QtMocHelpers::PropertyData<double>(67, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fastMode'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isFastModeImmutable'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFastModeValue'
        QtMocHelpers::PropertyData<bool>(70, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'noteC'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isNoteCImmutable'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNoteCValue'
        QtMocHelpers::PropertyData<bool>(73, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'noteCSharp'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isNoteCSharpImmutable'
        QtMocHelpers::PropertyData<bool>(75, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNoteCSharpValue'
        QtMocHelpers::PropertyData<bool>(76, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'noteD'
        QtMocHelpers::PropertyData<bool>(77, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isNoteDImmutable'
        QtMocHelpers::PropertyData<bool>(78, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNoteDValue'
        QtMocHelpers::PropertyData<bool>(79, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'noteDSharp'
        QtMocHelpers::PropertyData<bool>(80, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isNoteDSharpImmutable'
        QtMocHelpers::PropertyData<bool>(81, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNoteDSharpValue'
        QtMocHelpers::PropertyData<bool>(82, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'noteE'
        QtMocHelpers::PropertyData<bool>(83, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'isNoteEImmutable'
        QtMocHelpers::PropertyData<bool>(84, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNoteEValue'
        QtMocHelpers::PropertyData<bool>(85, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'noteF'
        QtMocHelpers::PropertyData<bool>(86, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'isNoteFImmutable'
        QtMocHelpers::PropertyData<bool>(87, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNoteFValue'
        QtMocHelpers::PropertyData<bool>(88, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'noteFSharp'
        QtMocHelpers::PropertyData<bool>(89, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'isNoteFSharpImmutable'
        QtMocHelpers::PropertyData<bool>(90, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNoteFSharpValue'
        QtMocHelpers::PropertyData<bool>(91, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'noteG'
        QtMocHelpers::PropertyData<bool>(92, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'isNoteGImmutable'
        QtMocHelpers::PropertyData<bool>(93, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNoteGValue'
        QtMocHelpers::PropertyData<bool>(94, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'noteGSharp'
        QtMocHelpers::PropertyData<bool>(95, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'isNoteGSharpImmutable'
        QtMocHelpers::PropertyData<bool>(96, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNoteGSharpValue'
        QtMocHelpers::PropertyData<bool>(97, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'noteA'
        QtMocHelpers::PropertyData<bool>(98, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'isNoteAImmutable'
        QtMocHelpers::PropertyData<bool>(99, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNoteAValue'
        QtMocHelpers::PropertyData<bool>(100, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'noteASharp'
        QtMocHelpers::PropertyData<bool>(101, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'isNoteASharpImmutable'
        QtMocHelpers::PropertyData<bool>(102, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNoteASharpValue'
        QtMocHelpers::PropertyData<bool>(103, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'noteB'
        QtMocHelpers::PropertyData<bool>(104, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'isNoteBImmutable'
        QtMocHelpers::PropertyData<bool>(105, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNoteBValue'
        QtMocHelpers::PropertyData<bool>(106, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DbAutotune, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbAutotune::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10DbAutotuneE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10DbAutotuneE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10DbAutotuneE_t>.metaTypes,
    nullptr
} };

void DbAutotune::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbAutotune *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bypassChanged(); break;
        case 1: _t->inputGainChanged(); break;
        case 2: _t->outputGainChanged(); break;
        case 3: _t->modeLabelsChanged(); break;
        case 4: _t->modeChanged(); break;
        case 5: _t->channelFilterChanged(); break;
        case 6: _t->tuningChanged(); break;
        case 7: _t->biasChanged(); break;
        case 8: _t->filterChanged(); break;
        case 9: _t->correctionChanged(); break;
        case 10: _t->offsetChanged(); break;
        case 11: _t->bendRangeChanged(); break;
        case 12: _t->fastModeChanged(); break;
        case 13: _t->noteCChanged(); break;
        case 14: _t->noteCSharpChanged(); break;
        case 15: _t->noteDChanged(); break;
        case 16: _t->noteDSharpChanged(); break;
        case 17: _t->noteEChanged(); break;
        case 18: _t->noteFChanged(); break;
        case 19: _t->noteFSharpChanged(); break;
        case 20: _t->noteGChanged(); break;
        case 21: _t->noteGSharpChanged(); break;
        case 22: _t->noteAChanged(); break;
        case 23: _t->noteASharpChanged(); break;
        case 24: _t->noteBChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::bypassChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::inputGainChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::outputGainChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::modeLabelsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::modeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::channelFilterChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::tuningChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::biasChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::filterChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::correctionChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::offsetChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::bendRangeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::fastModeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::noteCChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::noteCSharpChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::noteDChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::noteDSharpChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::noteEChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::noteFChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::noteFSharpChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::noteGChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::noteGSharpChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::noteAChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::noteASharpChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbAutotune::*)()>(_a, &DbAutotune::noteBChanged, 24))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bypass(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isBypassImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultBypassValue(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->inputGain(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isInputGainImmutable(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->defaultInputGainValue(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->outputGain(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isOutputGainImmutable(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->defaultOutputGainValue(); break;
        case 9: *reinterpret_cast<QStringList*>(_v) = _t->modeLabels(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isModeLabelsImmutable(); break;
        case 11: *reinterpret_cast<QStringList*>(_v) = _t->defaultModeLabelsValue(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->mode(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isModeImmutable(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->defaultModeValue(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->channelFilter(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isChannelFilterImmutable(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->defaultChannelFilterValue(); break;
        case 18: *reinterpret_cast<double*>(_v) = _t->tuning(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isTuningImmutable(); break;
        case 20: *reinterpret_cast<double*>(_v) = _t->defaultTuningValue(); break;
        case 21: *reinterpret_cast<double*>(_v) = _t->bias(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isBiasImmutable(); break;
        case 23: *reinterpret_cast<double*>(_v) = _t->defaultBiasValue(); break;
        case 24: *reinterpret_cast<double*>(_v) = _t->filter(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isFilterImmutable(); break;
        case 26: *reinterpret_cast<double*>(_v) = _t->defaultFilterValue(); break;
        case 27: *reinterpret_cast<double*>(_v) = _t->correction(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isCorrectionImmutable(); break;
        case 29: *reinterpret_cast<double*>(_v) = _t->defaultCorrectionValue(); break;
        case 30: *reinterpret_cast<double*>(_v) = _t->offset(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isOffsetImmutable(); break;
        case 32: *reinterpret_cast<double*>(_v) = _t->defaultOffsetValue(); break;
        case 33: *reinterpret_cast<double*>(_v) = _t->bendRange(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isBendRangeImmutable(); break;
        case 35: *reinterpret_cast<double*>(_v) = _t->defaultBendRangeValue(); break;
        case 36: *reinterpret_cast<bool*>(_v) = _t->fastMode(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isFastModeImmutable(); break;
        case 38: *reinterpret_cast<bool*>(_v) = _t->defaultFastModeValue(); break;
        case 39: *reinterpret_cast<bool*>(_v) = _t->noteC(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->isNoteCImmutable(); break;
        case 41: *reinterpret_cast<bool*>(_v) = _t->defaultNoteCValue(); break;
        case 42: *reinterpret_cast<bool*>(_v) = _t->noteCSharp(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->isNoteCSharpImmutable(); break;
        case 44: *reinterpret_cast<bool*>(_v) = _t->defaultNoteCSharpValue(); break;
        case 45: *reinterpret_cast<bool*>(_v) = _t->noteD(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->isNoteDImmutable(); break;
        case 47: *reinterpret_cast<bool*>(_v) = _t->defaultNoteDValue(); break;
        case 48: *reinterpret_cast<bool*>(_v) = _t->noteDSharp(); break;
        case 49: *reinterpret_cast<bool*>(_v) = _t->isNoteDSharpImmutable(); break;
        case 50: *reinterpret_cast<bool*>(_v) = _t->defaultNoteDSharpValue(); break;
        case 51: *reinterpret_cast<bool*>(_v) = _t->noteE(); break;
        case 52: *reinterpret_cast<bool*>(_v) = _t->isNoteEImmutable(); break;
        case 53: *reinterpret_cast<bool*>(_v) = _t->defaultNoteEValue(); break;
        case 54: *reinterpret_cast<bool*>(_v) = _t->noteF(); break;
        case 55: *reinterpret_cast<bool*>(_v) = _t->isNoteFImmutable(); break;
        case 56: *reinterpret_cast<bool*>(_v) = _t->defaultNoteFValue(); break;
        case 57: *reinterpret_cast<bool*>(_v) = _t->noteFSharp(); break;
        case 58: *reinterpret_cast<bool*>(_v) = _t->isNoteFSharpImmutable(); break;
        case 59: *reinterpret_cast<bool*>(_v) = _t->defaultNoteFSharpValue(); break;
        case 60: *reinterpret_cast<bool*>(_v) = _t->noteG(); break;
        case 61: *reinterpret_cast<bool*>(_v) = _t->isNoteGImmutable(); break;
        case 62: *reinterpret_cast<bool*>(_v) = _t->defaultNoteGValue(); break;
        case 63: *reinterpret_cast<bool*>(_v) = _t->noteGSharp(); break;
        case 64: *reinterpret_cast<bool*>(_v) = _t->isNoteGSharpImmutable(); break;
        case 65: *reinterpret_cast<bool*>(_v) = _t->defaultNoteGSharpValue(); break;
        case 66: *reinterpret_cast<bool*>(_v) = _t->noteA(); break;
        case 67: *reinterpret_cast<bool*>(_v) = _t->isNoteAImmutable(); break;
        case 68: *reinterpret_cast<bool*>(_v) = _t->defaultNoteAValue(); break;
        case 69: *reinterpret_cast<bool*>(_v) = _t->noteASharp(); break;
        case 70: *reinterpret_cast<bool*>(_v) = _t->isNoteASharpImmutable(); break;
        case 71: *reinterpret_cast<bool*>(_v) = _t->defaultNoteASharpValue(); break;
        case 72: *reinterpret_cast<bool*>(_v) = _t->noteB(); break;
        case 73: *reinterpret_cast<bool*>(_v) = _t->isNoteBImmutable(); break;
        case 74: *reinterpret_cast<bool*>(_v) = _t->defaultNoteBValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBypass(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setInputGain(*reinterpret_cast<double*>(_v)); break;
        case 6: _t->setOutputGain(*reinterpret_cast<double*>(_v)); break;
        case 9: _t->setModeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 12: _t->setMode(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setChannelFilter(*reinterpret_cast<int*>(_v)); break;
        case 18: _t->setTuning(*reinterpret_cast<double*>(_v)); break;
        case 21: _t->setBias(*reinterpret_cast<double*>(_v)); break;
        case 24: _t->setFilter(*reinterpret_cast<double*>(_v)); break;
        case 27: _t->setCorrection(*reinterpret_cast<double*>(_v)); break;
        case 30: _t->setOffset(*reinterpret_cast<double*>(_v)); break;
        case 33: _t->setBendRange(*reinterpret_cast<double*>(_v)); break;
        case 36: _t->setFastMode(*reinterpret_cast<bool*>(_v)); break;
        case 39: _t->setNoteC(*reinterpret_cast<bool*>(_v)); break;
        case 42: _t->setNoteCSharp(*reinterpret_cast<bool*>(_v)); break;
        case 45: _t->setNoteD(*reinterpret_cast<bool*>(_v)); break;
        case 48: _t->setNoteDSharp(*reinterpret_cast<bool*>(_v)); break;
        case 51: _t->setNoteE(*reinterpret_cast<bool*>(_v)); break;
        case 54: _t->setNoteF(*reinterpret_cast<bool*>(_v)); break;
        case 57: _t->setNoteFSharp(*reinterpret_cast<bool*>(_v)); break;
        case 60: _t->setNoteG(*reinterpret_cast<bool*>(_v)); break;
        case 63: _t->setNoteGSharp(*reinterpret_cast<bool*>(_v)); break;
        case 66: _t->setNoteA(*reinterpret_cast<bool*>(_v)); break;
        case 69: _t->setNoteASharp(*reinterpret_cast<bool*>(_v)); break;
        case 72: _t->setNoteB(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbAutotune::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbAutotune::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10DbAutotuneE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbAutotune::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 25;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 75;
    }
    return _id;
}

// SIGNAL 0
void DbAutotune::bypassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbAutotune::inputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbAutotune::outputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbAutotune::modeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DbAutotune::modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DbAutotune::channelFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DbAutotune::tuningChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DbAutotune::biasChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DbAutotune::filterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DbAutotune::correctionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DbAutotune::offsetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DbAutotune::bendRangeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void DbAutotune::fastModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void DbAutotune::noteCChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void DbAutotune::noteCSharpChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void DbAutotune::noteDChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void DbAutotune::noteDSharpChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void DbAutotune::noteEChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void DbAutotune::noteFChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void DbAutotune::noteFSharpChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void DbAutotune::noteGChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void DbAutotune::noteGSharpChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void DbAutotune::noteAChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void DbAutotune::noteASharpChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void DbAutotune::noteBChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}
QT_WARNING_POP
