/****************************************************************************
** Meta object code from reading C++ file 'effects_base.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../easyeffects-8.2.8/src/effects_base.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'effects_base.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17EffectsBaseWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto EffectsBaseWorker::qt_create_metaobjectdata<qt_meta_tag_ZN17EffectsBaseWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EffectsBaseWorker"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EffectsBaseWorker, qt_meta_tag_ZN17EffectsBaseWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EffectsBaseWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17EffectsBaseWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17EffectsBaseWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17EffectsBaseWorkerE_t>.metaTypes,
    nullptr
} };

void EffectsBaseWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EffectsBaseWorker *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *EffectsBaseWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EffectsBaseWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17EffectsBaseWorkerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int EffectsBaseWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN11EffectsBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto EffectsBase::qt_create_metaobjectdata<qt_meta_tag_ZN11EffectsBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EffectsBase",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Use the c++ instance",
        "pipelineChanged",
        "",
        "newSpectrumData",
        "QList<QPointF>",
        "newData",
        "filtersLinkedChanged",
        "getPluginInstance",
        "QVariant",
        "pluginName",
        "getPipeLineRate",
        "getPipeLineLatency",
        "getOutputLevelLeft",
        "getOutputLevelRight",
        "requestSpectrumData",
        "setUpdateLevelMeters",
        "state",
        "setSpectrumBypass",
        "filtersLinked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pipelineChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newSpectrumData'
        QtMocHelpers::SignalData<void(QList<QPointF>)>(9, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'filtersLinkedChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'getPluginInstance'
        QtMocHelpers::MethodData<QVariant(const QString &)>(13, 8, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 15 },
        }}),
        // Method 'getPipeLineRate'
        QtMocHelpers::MethodData<uint() const>(16, 8, QMC::AccessPublic, QMetaType::UInt),
        // Method 'getPipeLineLatency'
        QtMocHelpers::MethodData<uint()>(17, 8, QMC::AccessPublic, QMetaType::UInt),
        // Method 'getOutputLevelLeft'
        QtMocHelpers::MethodData<float() const>(18, 8, QMC::AccessPublic, QMetaType::Float),
        // Method 'getOutputLevelRight'
        QtMocHelpers::MethodData<float() const>(19, 8, QMC::AccessPublic, QMetaType::Float),
        // Method 'requestSpectrumData'
        QtMocHelpers::MethodData<void()>(20, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'setUpdateLevelMeters'
        QtMocHelpers::MethodData<void(const bool &)>(21, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Method 'setSpectrumBypass'
        QtMocHelpers::MethodData<void(const bool &)>(23, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'filtersLinked'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<EffectsBase, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject EffectsBase::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11EffectsBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11EffectsBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11EffectsBaseE_t>.metaTypes,
    nullptr
} };

void EffectsBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EffectsBase *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pipelineChanged(); break;
        case 1: _t->newSpectrumData((*reinterpret_cast<std::add_pointer_t<QList<QPointF>>>(_a[1]))); break;
        case 2: _t->filtersLinkedChanged(); break;
        case 3: { QVariant _r = _t->getPluginInstance((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 4: { uint _r = _t->getPipeLineRate();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 5: { uint _r = _t->getPipeLineLatency();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 6: { float _r = _t->getOutputLevelLeft();
            if (_a[0]) *reinterpret_cast<float*>(_a[0]) = std::move(_r); }  break;
        case 7: { float _r = _t->getOutputLevelRight();
            if (_a[0]) *reinterpret_cast<float*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->requestSpectrumData(); break;
        case 9: _t->setUpdateLevelMeters((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->setSpectrumBypass((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EffectsBase::*)()>(_a, &EffectsBase::pipelineChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (EffectsBase::*)(QList<QPointF> )>(_a, &EffectsBase::newSpectrumData, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (EffectsBase::*)()>(_a, &EffectsBase::filtersLinkedChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->filtersLinked; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->filtersLinked, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->filtersLinkedChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *EffectsBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EffectsBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11EffectsBaseE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int EffectsBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void EffectsBase::pipelineChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void EffectsBase::newSpectrumData(QList<QPointF> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void EffectsBase::filtersLinkedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
