/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db_crystalizer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db_crystalizer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db_crystalizer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13DbCrystalizerE_t {};
} // unnamed namespace

template <> constexpr inline auto DbCrystalizer::qt_create_metaobjectdata<qt_meta_tag_ZN13DbCrystalizerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbCrystalizer",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "bypassChanged",
        "inputGainChanged",
        "outputGainChanged",
        "adaptiveIntensityChanged",
        "oversamplingChanged",
        "oversamplingQualityChanged",
        "useFixedQuantumChanged",
        "transitionBandChanged",
        "intensityBand0Changed",
        "intensityBand1Changed",
        "intensityBand2Changed",
        "intensityBand3Changed",
        "intensityBand4Changed",
        "intensityBand5Changed",
        "intensityBand6Changed",
        "intensityBand7Changed",
        "intensityBand8Changed",
        "intensityBand9Changed",
        "intensityBand10Changed",
        "intensityBand11Changed",
        "intensityBand12Changed",
        "muteBand0Changed",
        "muteBand1Changed",
        "muteBand2Changed",
        "muteBand3Changed",
        "muteBand4Changed",
        "muteBand5Changed",
        "muteBand6Changed",
        "muteBand7Changed",
        "muteBand8Changed",
        "muteBand9Changed",
        "muteBand10Changed",
        "muteBand11Changed",
        "muteBand12Changed",
        "bypassBand0Changed",
        "bypassBand1Changed",
        "bypassBand2Changed",
        "bypassBand3Changed",
        "bypassBand4Changed",
        "bypassBand5Changed",
        "bypassBand6Changed",
        "bypassBand7Changed",
        "bypassBand8Changed",
        "bypassBand9Changed",
        "bypassBand10Changed",
        "bypassBand11Changed",
        "bypassBand12Changed",
        "bypass",
        "isBypassImmutable",
        "defaultBypassValue",
        "inputGain",
        "isInputGainImmutable",
        "defaultInputGainValue",
        "outputGain",
        "isOutputGainImmutable",
        "defaultOutputGainValue",
        "adaptiveIntensity",
        "isAdaptiveIntensityImmutable",
        "defaultAdaptiveIntensityValue",
        "oversampling",
        "isOversamplingImmutable",
        "defaultOversamplingValue",
        "oversamplingQuality",
        "isOversamplingQualityImmutable",
        "defaultOversamplingQualityValue",
        "useFixedQuantum",
        "isUseFixedQuantumImmutable",
        "defaultUseFixedQuantumValue",
        "transitionBand",
        "isTransitionBandImmutable",
        "defaultTransitionBandValue",
        "intensityBand0",
        "isIntensityBand0Immutable",
        "defaultIntensityBand0Value",
        "intensityBand1",
        "isIntensityBand1Immutable",
        "defaultIntensityBand1Value",
        "intensityBand2",
        "isIntensityBand2Immutable",
        "defaultIntensityBand2Value",
        "intensityBand3",
        "isIntensityBand3Immutable",
        "defaultIntensityBand3Value",
        "intensityBand4",
        "isIntensityBand4Immutable",
        "defaultIntensityBand4Value",
        "intensityBand5",
        "isIntensityBand5Immutable",
        "defaultIntensityBand5Value",
        "intensityBand6",
        "isIntensityBand6Immutable",
        "defaultIntensityBand6Value",
        "intensityBand7",
        "isIntensityBand7Immutable",
        "defaultIntensityBand7Value",
        "intensityBand8",
        "isIntensityBand8Immutable",
        "defaultIntensityBand8Value",
        "intensityBand9",
        "isIntensityBand9Immutable",
        "defaultIntensityBand9Value",
        "intensityBand10",
        "isIntensityBand10Immutable",
        "defaultIntensityBand10Value",
        "intensityBand11",
        "isIntensityBand11Immutable",
        "defaultIntensityBand11Value",
        "intensityBand12",
        "isIntensityBand12Immutable",
        "defaultIntensityBand12Value",
        "muteBand0",
        "isMuteBand0Immutable",
        "defaultMuteBand0Value",
        "muteBand1",
        "isMuteBand1Immutable",
        "defaultMuteBand1Value",
        "muteBand2",
        "isMuteBand2Immutable",
        "defaultMuteBand2Value",
        "muteBand3",
        "isMuteBand3Immutable",
        "defaultMuteBand3Value",
        "muteBand4",
        "isMuteBand4Immutable",
        "defaultMuteBand4Value",
        "muteBand5",
        "isMuteBand5Immutable",
        "defaultMuteBand5Value",
        "muteBand6",
        "isMuteBand6Immutable",
        "defaultMuteBand6Value",
        "muteBand7",
        "isMuteBand7Immutable",
        "defaultMuteBand7Value",
        "muteBand8",
        "isMuteBand8Immutable",
        "defaultMuteBand8Value",
        "muteBand9",
        "isMuteBand9Immutable",
        "defaultMuteBand9Value",
        "muteBand10",
        "isMuteBand10Immutable",
        "defaultMuteBand10Value",
        "muteBand11",
        "isMuteBand11Immutable",
        "defaultMuteBand11Value",
        "muteBand12",
        "isMuteBand12Immutable",
        "defaultMuteBand12Value",
        "bypassBand0",
        "isBypassBand0Immutable",
        "defaultBypassBand0Value",
        "bypassBand1",
        "isBypassBand1Immutable",
        "defaultBypassBand1Value",
        "bypassBand2",
        "isBypassBand2Immutable",
        "defaultBypassBand2Value",
        "bypassBand3",
        "isBypassBand3Immutable",
        "defaultBypassBand3Value",
        "bypassBand4",
        "isBypassBand4Immutable",
        "defaultBypassBand4Value",
        "bypassBand5",
        "isBypassBand5Immutable",
        "defaultBypassBand5Value",
        "bypassBand6",
        "isBypassBand6Immutable",
        "defaultBypassBand6Value",
        "bypassBand7",
        "isBypassBand7Immutable",
        "defaultBypassBand7Value",
        "bypassBand8",
        "isBypassBand8Immutable",
        "defaultBypassBand8Value",
        "bypassBand9",
        "isBypassBand9Immutable",
        "defaultBypassBand9Value",
        "bypassBand10",
        "isBypassBand10Immutable",
        "defaultBypassBand10Value",
        "bypassBand11",
        "isBypassBand11Immutable",
        "defaultBypassBand11Value",
        "bypassBand12",
        "isBypassBand12Immutable",
        "defaultBypassBand12Value"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bypassChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputGainChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputGainChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'adaptiveIntensityChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'oversamplingChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'oversamplingQualityChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useFixedQuantumChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transitionBandChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'intensityBand0Changed'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'intensityBand1Changed'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'intensityBand2Changed'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'intensityBand3Changed'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'intensityBand4Changed'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'intensityBand5Changed'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'intensityBand6Changed'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'intensityBand7Changed'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'intensityBand8Changed'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'intensityBand9Changed'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'intensityBand10Changed'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'intensityBand11Changed'
        QtMocHelpers::SignalData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'intensityBand12Changed'
        QtMocHelpers::SignalData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'muteBand0Changed'
        QtMocHelpers::SignalData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'muteBand1Changed'
        QtMocHelpers::SignalData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'muteBand2Changed'
        QtMocHelpers::SignalData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'muteBand3Changed'
        QtMocHelpers::SignalData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'muteBand4Changed'
        QtMocHelpers::SignalData<void()>(32, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'muteBand5Changed'
        QtMocHelpers::SignalData<void()>(33, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'muteBand6Changed'
        QtMocHelpers::SignalData<void()>(34, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'muteBand7Changed'
        QtMocHelpers::SignalData<void()>(35, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'muteBand8Changed'
        QtMocHelpers::SignalData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'muteBand9Changed'
        QtMocHelpers::SignalData<void()>(37, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'muteBand10Changed'
        QtMocHelpers::SignalData<void()>(38, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'muteBand11Changed'
        QtMocHelpers::SignalData<void()>(39, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'muteBand12Changed'
        QtMocHelpers::SignalData<void()>(40, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bypassBand0Changed'
        QtMocHelpers::SignalData<void()>(41, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bypassBand1Changed'
        QtMocHelpers::SignalData<void()>(42, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bypassBand2Changed'
        QtMocHelpers::SignalData<void()>(43, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bypassBand3Changed'
        QtMocHelpers::SignalData<void()>(44, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bypassBand4Changed'
        QtMocHelpers::SignalData<void()>(45, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bypassBand5Changed'
        QtMocHelpers::SignalData<void()>(46, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bypassBand6Changed'
        QtMocHelpers::SignalData<void()>(47, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bypassBand7Changed'
        QtMocHelpers::SignalData<void()>(48, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bypassBand8Changed'
        QtMocHelpers::SignalData<void()>(49, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bypassBand9Changed'
        QtMocHelpers::SignalData<void()>(50, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bypassBand10Changed'
        QtMocHelpers::SignalData<void()>(51, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bypassBand11Changed'
        QtMocHelpers::SignalData<void()>(52, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bypassBand12Changed'
        QtMocHelpers::SignalData<void()>(53, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bypass'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isBypassImmutable'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassValue'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputGain'
        QtMocHelpers::PropertyData<double>(57, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isInputGainImmutable'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputGainValue'
        QtMocHelpers::PropertyData<double>(59, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'outputGain'
        QtMocHelpers::PropertyData<double>(60, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isOutputGainImmutable'
        QtMocHelpers::PropertyData<bool>(61, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOutputGainValue'
        QtMocHelpers::PropertyData<double>(62, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'adaptiveIntensity'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isAdaptiveIntensityImmutable'
        QtMocHelpers::PropertyData<bool>(64, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAdaptiveIntensityValue'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'oversampling'
        QtMocHelpers::PropertyData<bool>(66, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isOversamplingImmutable'
        QtMocHelpers::PropertyData<bool>(67, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOversamplingValue'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'oversamplingQuality'
        QtMocHelpers::PropertyData<double>(69, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isOversamplingQualityImmutable'
        QtMocHelpers::PropertyData<bool>(70, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOversamplingQualityValue'
        QtMocHelpers::PropertyData<double>(71, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useFixedQuantum'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isUseFixedQuantumImmutable'
        QtMocHelpers::PropertyData<bool>(73, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultUseFixedQuantumValue'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'transitionBand'
        QtMocHelpers::PropertyData<double>(75, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isTransitionBandImmutable'
        QtMocHelpers::PropertyData<bool>(76, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTransitionBandValue'
        QtMocHelpers::PropertyData<double>(77, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'intensityBand0'
        QtMocHelpers::PropertyData<double>(78, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isIntensityBand0Immutable'
        QtMocHelpers::PropertyData<bool>(79, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIntensityBand0Value'
        QtMocHelpers::PropertyData<double>(80, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'intensityBand1'
        QtMocHelpers::PropertyData<double>(81, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isIntensityBand1Immutable'
        QtMocHelpers::PropertyData<bool>(82, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIntensityBand1Value'
        QtMocHelpers::PropertyData<double>(83, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'intensityBand2'
        QtMocHelpers::PropertyData<double>(84, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isIntensityBand2Immutable'
        QtMocHelpers::PropertyData<bool>(85, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIntensityBand2Value'
        QtMocHelpers::PropertyData<double>(86, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'intensityBand3'
        QtMocHelpers::PropertyData<double>(87, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isIntensityBand3Immutable'
        QtMocHelpers::PropertyData<bool>(88, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIntensityBand3Value'
        QtMocHelpers::PropertyData<double>(89, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'intensityBand4'
        QtMocHelpers::PropertyData<double>(90, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isIntensityBand4Immutable'
        QtMocHelpers::PropertyData<bool>(91, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIntensityBand4Value'
        QtMocHelpers::PropertyData<double>(92, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'intensityBand5'
        QtMocHelpers::PropertyData<double>(93, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isIntensityBand5Immutable'
        QtMocHelpers::PropertyData<bool>(94, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIntensityBand5Value'
        QtMocHelpers::PropertyData<double>(95, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'intensityBand6'
        QtMocHelpers::PropertyData<double>(96, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isIntensityBand6Immutable'
        QtMocHelpers::PropertyData<bool>(97, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIntensityBand6Value'
        QtMocHelpers::PropertyData<double>(98, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'intensityBand7'
        QtMocHelpers::PropertyData<double>(99, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isIntensityBand7Immutable'
        QtMocHelpers::PropertyData<bool>(100, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIntensityBand7Value'
        QtMocHelpers::PropertyData<double>(101, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'intensityBand8'
        QtMocHelpers::PropertyData<double>(102, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isIntensityBand8Immutable'
        QtMocHelpers::PropertyData<bool>(103, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIntensityBand8Value'
        QtMocHelpers::PropertyData<double>(104, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'intensityBand9'
        QtMocHelpers::PropertyData<double>(105, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'isIntensityBand9Immutable'
        QtMocHelpers::PropertyData<bool>(106, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIntensityBand9Value'
        QtMocHelpers::PropertyData<double>(107, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'intensityBand10'
        QtMocHelpers::PropertyData<double>(108, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'isIntensityBand10Immutable'
        QtMocHelpers::PropertyData<bool>(109, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIntensityBand10Value'
        QtMocHelpers::PropertyData<double>(110, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'intensityBand11'
        QtMocHelpers::PropertyData<double>(111, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'isIntensityBand11Immutable'
        QtMocHelpers::PropertyData<bool>(112, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIntensityBand11Value'
        QtMocHelpers::PropertyData<double>(113, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'intensityBand12'
        QtMocHelpers::PropertyData<double>(114, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'isIntensityBand12Immutable'
        QtMocHelpers::PropertyData<bool>(115, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIntensityBand12Value'
        QtMocHelpers::PropertyData<double>(116, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'muteBand0'
        QtMocHelpers::PropertyData<bool>(117, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'isMuteBand0Immutable'
        QtMocHelpers::PropertyData<bool>(118, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMuteBand0Value'
        QtMocHelpers::PropertyData<bool>(119, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'muteBand1'
        QtMocHelpers::PropertyData<bool>(120, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'isMuteBand1Immutable'
        QtMocHelpers::PropertyData<bool>(121, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMuteBand1Value'
        QtMocHelpers::PropertyData<bool>(122, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'muteBand2'
        QtMocHelpers::PropertyData<bool>(123, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'isMuteBand2Immutable'
        QtMocHelpers::PropertyData<bool>(124, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMuteBand2Value'
        QtMocHelpers::PropertyData<bool>(125, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'muteBand3'
        QtMocHelpers::PropertyData<bool>(126, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'isMuteBand3Immutable'
        QtMocHelpers::PropertyData<bool>(127, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMuteBand3Value'
        QtMocHelpers::PropertyData<bool>(128, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'muteBand4'
        QtMocHelpers::PropertyData<bool>(129, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 25),
        // property 'isMuteBand4Immutable'
        QtMocHelpers::PropertyData<bool>(130, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMuteBand4Value'
        QtMocHelpers::PropertyData<bool>(131, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'muteBand5'
        QtMocHelpers::PropertyData<bool>(132, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 26),
        // property 'isMuteBand5Immutable'
        QtMocHelpers::PropertyData<bool>(133, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMuteBand5Value'
        QtMocHelpers::PropertyData<bool>(134, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'muteBand6'
        QtMocHelpers::PropertyData<bool>(135, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 27),
        // property 'isMuteBand6Immutable'
        QtMocHelpers::PropertyData<bool>(136, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMuteBand6Value'
        QtMocHelpers::PropertyData<bool>(137, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'muteBand7'
        QtMocHelpers::PropertyData<bool>(138, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 28),
        // property 'isMuteBand7Immutable'
        QtMocHelpers::PropertyData<bool>(139, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMuteBand7Value'
        QtMocHelpers::PropertyData<bool>(140, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'muteBand8'
        QtMocHelpers::PropertyData<bool>(141, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 29),
        // property 'isMuteBand8Immutable'
        QtMocHelpers::PropertyData<bool>(142, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMuteBand8Value'
        QtMocHelpers::PropertyData<bool>(143, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'muteBand9'
        QtMocHelpers::PropertyData<bool>(144, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 30),
        // property 'isMuteBand9Immutable'
        QtMocHelpers::PropertyData<bool>(145, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMuteBand9Value'
        QtMocHelpers::PropertyData<bool>(146, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'muteBand10'
        QtMocHelpers::PropertyData<bool>(147, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 31),
        // property 'isMuteBand10Immutable'
        QtMocHelpers::PropertyData<bool>(148, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMuteBand10Value'
        QtMocHelpers::PropertyData<bool>(149, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'muteBand11'
        QtMocHelpers::PropertyData<bool>(150, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 32),
        // property 'isMuteBand11Immutable'
        QtMocHelpers::PropertyData<bool>(151, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMuteBand11Value'
        QtMocHelpers::PropertyData<bool>(152, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'muteBand12'
        QtMocHelpers::PropertyData<bool>(153, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 33),
        // property 'isMuteBand12Immutable'
        QtMocHelpers::PropertyData<bool>(154, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMuteBand12Value'
        QtMocHelpers::PropertyData<bool>(155, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bypassBand0'
        QtMocHelpers::PropertyData<bool>(156, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 34),
        // property 'isBypassBand0Immutable'
        QtMocHelpers::PropertyData<bool>(157, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassBand0Value'
        QtMocHelpers::PropertyData<bool>(158, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bypassBand1'
        QtMocHelpers::PropertyData<bool>(159, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 35),
        // property 'isBypassBand1Immutable'
        QtMocHelpers::PropertyData<bool>(160, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassBand1Value'
        QtMocHelpers::PropertyData<bool>(161, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bypassBand2'
        QtMocHelpers::PropertyData<bool>(162, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 36),
        // property 'isBypassBand2Immutable'
        QtMocHelpers::PropertyData<bool>(163, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassBand2Value'
        QtMocHelpers::PropertyData<bool>(164, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bypassBand3'
        QtMocHelpers::PropertyData<bool>(165, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 37),
        // property 'isBypassBand3Immutable'
        QtMocHelpers::PropertyData<bool>(166, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassBand3Value'
        QtMocHelpers::PropertyData<bool>(167, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bypassBand4'
        QtMocHelpers::PropertyData<bool>(168, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 38),
        // property 'isBypassBand4Immutable'
        QtMocHelpers::PropertyData<bool>(169, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassBand4Value'
        QtMocHelpers::PropertyData<bool>(170, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bypassBand5'
        QtMocHelpers::PropertyData<bool>(171, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 39),
        // property 'isBypassBand5Immutable'
        QtMocHelpers::PropertyData<bool>(172, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassBand5Value'
        QtMocHelpers::PropertyData<bool>(173, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bypassBand6'
        QtMocHelpers::PropertyData<bool>(174, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 40),
        // property 'isBypassBand6Immutable'
        QtMocHelpers::PropertyData<bool>(175, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassBand6Value'
        QtMocHelpers::PropertyData<bool>(176, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bypassBand7'
        QtMocHelpers::PropertyData<bool>(177, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 41),
        // property 'isBypassBand7Immutable'
        QtMocHelpers::PropertyData<bool>(178, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassBand7Value'
        QtMocHelpers::PropertyData<bool>(179, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bypassBand8'
        QtMocHelpers::PropertyData<bool>(180, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 42),
        // property 'isBypassBand8Immutable'
        QtMocHelpers::PropertyData<bool>(181, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassBand8Value'
        QtMocHelpers::PropertyData<bool>(182, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bypassBand9'
        QtMocHelpers::PropertyData<bool>(183, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 43),
        // property 'isBypassBand9Immutable'
        QtMocHelpers::PropertyData<bool>(184, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassBand9Value'
        QtMocHelpers::PropertyData<bool>(185, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bypassBand10'
        QtMocHelpers::PropertyData<bool>(186, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 44),
        // property 'isBypassBand10Immutable'
        QtMocHelpers::PropertyData<bool>(187, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassBand10Value'
        QtMocHelpers::PropertyData<bool>(188, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bypassBand11'
        QtMocHelpers::PropertyData<bool>(189, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 45),
        // property 'isBypassBand11Immutable'
        QtMocHelpers::PropertyData<bool>(190, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassBand11Value'
        QtMocHelpers::PropertyData<bool>(191, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bypassBand12'
        QtMocHelpers::PropertyData<bool>(192, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 46),
        // property 'isBypassBand12Immutable'
        QtMocHelpers::PropertyData<bool>(193, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassBand12Value'
        QtMocHelpers::PropertyData<bool>(194, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DbCrystalizer, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbCrystalizer::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DbCrystalizerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DbCrystalizerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DbCrystalizerE_t>.metaTypes,
    nullptr
} };

void DbCrystalizer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbCrystalizer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bypassChanged(); break;
        case 1: _t->inputGainChanged(); break;
        case 2: _t->outputGainChanged(); break;
        case 3: _t->adaptiveIntensityChanged(); break;
        case 4: _t->oversamplingChanged(); break;
        case 5: _t->oversamplingQualityChanged(); break;
        case 6: _t->useFixedQuantumChanged(); break;
        case 7: _t->transitionBandChanged(); break;
        case 8: _t->intensityBand0Changed(); break;
        case 9: _t->intensityBand1Changed(); break;
        case 10: _t->intensityBand2Changed(); break;
        case 11: _t->intensityBand3Changed(); break;
        case 12: _t->intensityBand4Changed(); break;
        case 13: _t->intensityBand5Changed(); break;
        case 14: _t->intensityBand6Changed(); break;
        case 15: _t->intensityBand7Changed(); break;
        case 16: _t->intensityBand8Changed(); break;
        case 17: _t->intensityBand9Changed(); break;
        case 18: _t->intensityBand10Changed(); break;
        case 19: _t->intensityBand11Changed(); break;
        case 20: _t->intensityBand12Changed(); break;
        case 21: _t->muteBand0Changed(); break;
        case 22: _t->muteBand1Changed(); break;
        case 23: _t->muteBand2Changed(); break;
        case 24: _t->muteBand3Changed(); break;
        case 25: _t->muteBand4Changed(); break;
        case 26: _t->muteBand5Changed(); break;
        case 27: _t->muteBand6Changed(); break;
        case 28: _t->muteBand7Changed(); break;
        case 29: _t->muteBand8Changed(); break;
        case 30: _t->muteBand9Changed(); break;
        case 31: _t->muteBand10Changed(); break;
        case 32: _t->muteBand11Changed(); break;
        case 33: _t->muteBand12Changed(); break;
        case 34: _t->bypassBand0Changed(); break;
        case 35: _t->bypassBand1Changed(); break;
        case 36: _t->bypassBand2Changed(); break;
        case 37: _t->bypassBand3Changed(); break;
        case 38: _t->bypassBand4Changed(); break;
        case 39: _t->bypassBand5Changed(); break;
        case 40: _t->bypassBand6Changed(); break;
        case 41: _t->bypassBand7Changed(); break;
        case 42: _t->bypassBand8Changed(); break;
        case 43: _t->bypassBand9Changed(); break;
        case 44: _t->bypassBand10Changed(); break;
        case 45: _t->bypassBand11Changed(); break;
        case 46: _t->bypassBand12Changed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::bypassChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::inputGainChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::outputGainChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::adaptiveIntensityChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::oversamplingChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::oversamplingQualityChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::useFixedQuantumChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::transitionBandChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::intensityBand0Changed, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::intensityBand1Changed, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::intensityBand2Changed, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::intensityBand3Changed, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::intensityBand4Changed, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::intensityBand5Changed, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::intensityBand6Changed, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::intensityBand7Changed, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::intensityBand8Changed, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::intensityBand9Changed, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::intensityBand10Changed, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::intensityBand11Changed, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::intensityBand12Changed, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::muteBand0Changed, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::muteBand1Changed, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::muteBand2Changed, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::muteBand3Changed, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::muteBand4Changed, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::muteBand5Changed, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::muteBand6Changed, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::muteBand7Changed, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::muteBand8Changed, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::muteBand9Changed, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::muteBand10Changed, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::muteBand11Changed, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::muteBand12Changed, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::bypassBand0Changed, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::bypassBand1Changed, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::bypassBand2Changed, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::bypassBand3Changed, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::bypassBand4Changed, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::bypassBand5Changed, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::bypassBand6Changed, 40))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::bypassBand7Changed, 41))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::bypassBand8Changed, 42))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::bypassBand9Changed, 43))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::bypassBand10Changed, 44))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::bypassBand11Changed, 45))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCrystalizer::*)()>(_a, &DbCrystalizer::bypassBand12Changed, 46))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bypass(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isBypassImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultBypassValue(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->inputGain(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isInputGainImmutable(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->defaultInputGainValue(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->outputGain(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isOutputGainImmutable(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->defaultOutputGainValue(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->adaptiveIntensity(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isAdaptiveIntensityImmutable(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->defaultAdaptiveIntensityValue(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->oversampling(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isOversamplingImmutable(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->defaultOversamplingValue(); break;
        case 15: *reinterpret_cast<double*>(_v) = _t->oversamplingQuality(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isOversamplingQualityImmutable(); break;
        case 17: *reinterpret_cast<double*>(_v) = _t->defaultOversamplingQualityValue(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->useFixedQuantum(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isUseFixedQuantumImmutable(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->defaultUseFixedQuantumValue(); break;
        case 21: *reinterpret_cast<double*>(_v) = _t->transitionBand(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isTransitionBandImmutable(); break;
        case 23: *reinterpret_cast<double*>(_v) = _t->defaultTransitionBandValue(); break;
        case 24: *reinterpret_cast<double*>(_v) = _t->intensityBand0(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isIntensityBand0Immutable(); break;
        case 26: *reinterpret_cast<double*>(_v) = _t->defaultIntensityBand0Value(); break;
        case 27: *reinterpret_cast<double*>(_v) = _t->intensityBand1(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isIntensityBand1Immutable(); break;
        case 29: *reinterpret_cast<double*>(_v) = _t->defaultIntensityBand1Value(); break;
        case 30: *reinterpret_cast<double*>(_v) = _t->intensityBand2(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isIntensityBand2Immutable(); break;
        case 32: *reinterpret_cast<double*>(_v) = _t->defaultIntensityBand2Value(); break;
        case 33: *reinterpret_cast<double*>(_v) = _t->intensityBand3(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isIntensityBand3Immutable(); break;
        case 35: *reinterpret_cast<double*>(_v) = _t->defaultIntensityBand3Value(); break;
        case 36: *reinterpret_cast<double*>(_v) = _t->intensityBand4(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isIntensityBand4Immutable(); break;
        case 38: *reinterpret_cast<double*>(_v) = _t->defaultIntensityBand4Value(); break;
        case 39: *reinterpret_cast<double*>(_v) = _t->intensityBand5(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->isIntensityBand5Immutable(); break;
        case 41: *reinterpret_cast<double*>(_v) = _t->defaultIntensityBand5Value(); break;
        case 42: *reinterpret_cast<double*>(_v) = _t->intensityBand6(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->isIntensityBand6Immutable(); break;
        case 44: *reinterpret_cast<double*>(_v) = _t->defaultIntensityBand6Value(); break;
        case 45: *reinterpret_cast<double*>(_v) = _t->intensityBand7(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->isIntensityBand7Immutable(); break;
        case 47: *reinterpret_cast<double*>(_v) = _t->defaultIntensityBand7Value(); break;
        case 48: *reinterpret_cast<double*>(_v) = _t->intensityBand8(); break;
        case 49: *reinterpret_cast<bool*>(_v) = _t->isIntensityBand8Immutable(); break;
        case 50: *reinterpret_cast<double*>(_v) = _t->defaultIntensityBand8Value(); break;
        case 51: *reinterpret_cast<double*>(_v) = _t->intensityBand9(); break;
        case 52: *reinterpret_cast<bool*>(_v) = _t->isIntensityBand9Immutable(); break;
        case 53: *reinterpret_cast<double*>(_v) = _t->defaultIntensityBand9Value(); break;
        case 54: *reinterpret_cast<double*>(_v) = _t->intensityBand10(); break;
        case 55: *reinterpret_cast<bool*>(_v) = _t->isIntensityBand10Immutable(); break;
        case 56: *reinterpret_cast<double*>(_v) = _t->defaultIntensityBand10Value(); break;
        case 57: *reinterpret_cast<double*>(_v) = _t->intensityBand11(); break;
        case 58: *reinterpret_cast<bool*>(_v) = _t->isIntensityBand11Immutable(); break;
        case 59: *reinterpret_cast<double*>(_v) = _t->defaultIntensityBand11Value(); break;
        case 60: *reinterpret_cast<double*>(_v) = _t->intensityBand12(); break;
        case 61: *reinterpret_cast<bool*>(_v) = _t->isIntensityBand12Immutable(); break;
        case 62: *reinterpret_cast<double*>(_v) = _t->defaultIntensityBand12Value(); break;
        case 63: *reinterpret_cast<bool*>(_v) = _t->muteBand0(); break;
        case 64: *reinterpret_cast<bool*>(_v) = _t->isMuteBand0Immutable(); break;
        case 65: *reinterpret_cast<bool*>(_v) = _t->defaultMuteBand0Value(); break;
        case 66: *reinterpret_cast<bool*>(_v) = _t->muteBand1(); break;
        case 67: *reinterpret_cast<bool*>(_v) = _t->isMuteBand1Immutable(); break;
        case 68: *reinterpret_cast<bool*>(_v) = _t->defaultMuteBand1Value(); break;
        case 69: *reinterpret_cast<bool*>(_v) = _t->muteBand2(); break;
        case 70: *reinterpret_cast<bool*>(_v) = _t->isMuteBand2Immutable(); break;
        case 71: *reinterpret_cast<bool*>(_v) = _t->defaultMuteBand2Value(); break;
        case 72: *reinterpret_cast<bool*>(_v) = _t->muteBand3(); break;
        case 73: *reinterpret_cast<bool*>(_v) = _t->isMuteBand3Immutable(); break;
        case 74: *reinterpret_cast<bool*>(_v) = _t->defaultMuteBand3Value(); break;
        case 75: *reinterpret_cast<bool*>(_v) = _t->muteBand4(); break;
        case 76: *reinterpret_cast<bool*>(_v) = _t->isMuteBand4Immutable(); break;
        case 77: *reinterpret_cast<bool*>(_v) = _t->defaultMuteBand4Value(); break;
        case 78: *reinterpret_cast<bool*>(_v) = _t->muteBand5(); break;
        case 79: *reinterpret_cast<bool*>(_v) = _t->isMuteBand5Immutable(); break;
        case 80: *reinterpret_cast<bool*>(_v) = _t->defaultMuteBand5Value(); break;
        case 81: *reinterpret_cast<bool*>(_v) = _t->muteBand6(); break;
        case 82: *reinterpret_cast<bool*>(_v) = _t->isMuteBand6Immutable(); break;
        case 83: *reinterpret_cast<bool*>(_v) = _t->defaultMuteBand6Value(); break;
        case 84: *reinterpret_cast<bool*>(_v) = _t->muteBand7(); break;
        case 85: *reinterpret_cast<bool*>(_v) = _t->isMuteBand7Immutable(); break;
        case 86: *reinterpret_cast<bool*>(_v) = _t->defaultMuteBand7Value(); break;
        case 87: *reinterpret_cast<bool*>(_v) = _t->muteBand8(); break;
        case 88: *reinterpret_cast<bool*>(_v) = _t->isMuteBand8Immutable(); break;
        case 89: *reinterpret_cast<bool*>(_v) = _t->defaultMuteBand8Value(); break;
        case 90: *reinterpret_cast<bool*>(_v) = _t->muteBand9(); break;
        case 91: *reinterpret_cast<bool*>(_v) = _t->isMuteBand9Immutable(); break;
        case 92: *reinterpret_cast<bool*>(_v) = _t->defaultMuteBand9Value(); break;
        case 93: *reinterpret_cast<bool*>(_v) = _t->muteBand10(); break;
        case 94: *reinterpret_cast<bool*>(_v) = _t->isMuteBand10Immutable(); break;
        case 95: *reinterpret_cast<bool*>(_v) = _t->defaultMuteBand10Value(); break;
        case 96: *reinterpret_cast<bool*>(_v) = _t->muteBand11(); break;
        case 97: *reinterpret_cast<bool*>(_v) = _t->isMuteBand11Immutable(); break;
        case 98: *reinterpret_cast<bool*>(_v) = _t->defaultMuteBand11Value(); break;
        case 99: *reinterpret_cast<bool*>(_v) = _t->muteBand12(); break;
        case 100: *reinterpret_cast<bool*>(_v) = _t->isMuteBand12Immutable(); break;
        case 101: *reinterpret_cast<bool*>(_v) = _t->defaultMuteBand12Value(); break;
        case 102: *reinterpret_cast<bool*>(_v) = _t->bypassBand0(); break;
        case 103: *reinterpret_cast<bool*>(_v) = _t->isBypassBand0Immutable(); break;
        case 104: *reinterpret_cast<bool*>(_v) = _t->defaultBypassBand0Value(); break;
        case 105: *reinterpret_cast<bool*>(_v) = _t->bypassBand1(); break;
        case 106: *reinterpret_cast<bool*>(_v) = _t->isBypassBand1Immutable(); break;
        case 107: *reinterpret_cast<bool*>(_v) = _t->defaultBypassBand1Value(); break;
        case 108: *reinterpret_cast<bool*>(_v) = _t->bypassBand2(); break;
        case 109: *reinterpret_cast<bool*>(_v) = _t->isBypassBand2Immutable(); break;
        case 110: *reinterpret_cast<bool*>(_v) = _t->defaultBypassBand2Value(); break;
        case 111: *reinterpret_cast<bool*>(_v) = _t->bypassBand3(); break;
        case 112: *reinterpret_cast<bool*>(_v) = _t->isBypassBand3Immutable(); break;
        case 113: *reinterpret_cast<bool*>(_v) = _t->defaultBypassBand3Value(); break;
        case 114: *reinterpret_cast<bool*>(_v) = _t->bypassBand4(); break;
        case 115: *reinterpret_cast<bool*>(_v) = _t->isBypassBand4Immutable(); break;
        case 116: *reinterpret_cast<bool*>(_v) = _t->defaultBypassBand4Value(); break;
        case 117: *reinterpret_cast<bool*>(_v) = _t->bypassBand5(); break;
        case 118: *reinterpret_cast<bool*>(_v) = _t->isBypassBand5Immutable(); break;
        case 119: *reinterpret_cast<bool*>(_v) = _t->defaultBypassBand5Value(); break;
        case 120: *reinterpret_cast<bool*>(_v) = _t->bypassBand6(); break;
        case 121: *reinterpret_cast<bool*>(_v) = _t->isBypassBand6Immutable(); break;
        case 122: *reinterpret_cast<bool*>(_v) = _t->defaultBypassBand6Value(); break;
        case 123: *reinterpret_cast<bool*>(_v) = _t->bypassBand7(); break;
        case 124: *reinterpret_cast<bool*>(_v) = _t->isBypassBand7Immutable(); break;
        case 125: *reinterpret_cast<bool*>(_v) = _t->defaultBypassBand7Value(); break;
        case 126: *reinterpret_cast<bool*>(_v) = _t->bypassBand8(); break;
        case 127: *reinterpret_cast<bool*>(_v) = _t->isBypassBand8Immutable(); break;
        case 128: *reinterpret_cast<bool*>(_v) = _t->defaultBypassBand8Value(); break;
        case 129: *reinterpret_cast<bool*>(_v) = _t->bypassBand9(); break;
        case 130: *reinterpret_cast<bool*>(_v) = _t->isBypassBand9Immutable(); break;
        case 131: *reinterpret_cast<bool*>(_v) = _t->defaultBypassBand9Value(); break;
        case 132: *reinterpret_cast<bool*>(_v) = _t->bypassBand10(); break;
        case 133: *reinterpret_cast<bool*>(_v) = _t->isBypassBand10Immutable(); break;
        case 134: *reinterpret_cast<bool*>(_v) = _t->defaultBypassBand10Value(); break;
        case 135: *reinterpret_cast<bool*>(_v) = _t->bypassBand11(); break;
        case 136: *reinterpret_cast<bool*>(_v) = _t->isBypassBand11Immutable(); break;
        case 137: *reinterpret_cast<bool*>(_v) = _t->defaultBypassBand11Value(); break;
        case 138: *reinterpret_cast<bool*>(_v) = _t->bypassBand12(); break;
        case 139: *reinterpret_cast<bool*>(_v) = _t->isBypassBand12Immutable(); break;
        case 140: *reinterpret_cast<bool*>(_v) = _t->defaultBypassBand12Value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBypass(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setInputGain(*reinterpret_cast<double*>(_v)); break;
        case 6: _t->setOutputGain(*reinterpret_cast<double*>(_v)); break;
        case 9: _t->setAdaptiveIntensity(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setOversampling(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setOversamplingQuality(*reinterpret_cast<double*>(_v)); break;
        case 18: _t->setUseFixedQuantum(*reinterpret_cast<bool*>(_v)); break;
        case 21: _t->setTransitionBand(*reinterpret_cast<double*>(_v)); break;
        case 24: _t->setIntensityBand0(*reinterpret_cast<double*>(_v)); break;
        case 27: _t->setIntensityBand1(*reinterpret_cast<double*>(_v)); break;
        case 30: _t->setIntensityBand2(*reinterpret_cast<double*>(_v)); break;
        case 33: _t->setIntensityBand3(*reinterpret_cast<double*>(_v)); break;
        case 36: _t->setIntensityBand4(*reinterpret_cast<double*>(_v)); break;
        case 39: _t->setIntensityBand5(*reinterpret_cast<double*>(_v)); break;
        case 42: _t->setIntensityBand6(*reinterpret_cast<double*>(_v)); break;
        case 45: _t->setIntensityBand7(*reinterpret_cast<double*>(_v)); break;
        case 48: _t->setIntensityBand8(*reinterpret_cast<double*>(_v)); break;
        case 51: _t->setIntensityBand9(*reinterpret_cast<double*>(_v)); break;
        case 54: _t->setIntensityBand10(*reinterpret_cast<double*>(_v)); break;
        case 57: _t->setIntensityBand11(*reinterpret_cast<double*>(_v)); break;
        case 60: _t->setIntensityBand12(*reinterpret_cast<double*>(_v)); break;
        case 63: _t->setMuteBand0(*reinterpret_cast<bool*>(_v)); break;
        case 66: _t->setMuteBand1(*reinterpret_cast<bool*>(_v)); break;
        case 69: _t->setMuteBand2(*reinterpret_cast<bool*>(_v)); break;
        case 72: _t->setMuteBand3(*reinterpret_cast<bool*>(_v)); break;
        case 75: _t->setMuteBand4(*reinterpret_cast<bool*>(_v)); break;
        case 78: _t->setMuteBand5(*reinterpret_cast<bool*>(_v)); break;
        case 81: _t->setMuteBand6(*reinterpret_cast<bool*>(_v)); break;
        case 84: _t->setMuteBand7(*reinterpret_cast<bool*>(_v)); break;
        case 87: _t->setMuteBand8(*reinterpret_cast<bool*>(_v)); break;
        case 90: _t->setMuteBand9(*reinterpret_cast<bool*>(_v)); break;
        case 93: _t->setMuteBand10(*reinterpret_cast<bool*>(_v)); break;
        case 96: _t->setMuteBand11(*reinterpret_cast<bool*>(_v)); break;
        case 99: _t->setMuteBand12(*reinterpret_cast<bool*>(_v)); break;
        case 102: _t->setBypassBand0(*reinterpret_cast<bool*>(_v)); break;
        case 105: _t->setBypassBand1(*reinterpret_cast<bool*>(_v)); break;
        case 108: _t->setBypassBand2(*reinterpret_cast<bool*>(_v)); break;
        case 111: _t->setBypassBand3(*reinterpret_cast<bool*>(_v)); break;
        case 114: _t->setBypassBand4(*reinterpret_cast<bool*>(_v)); break;
        case 117: _t->setBypassBand5(*reinterpret_cast<bool*>(_v)); break;
        case 120: _t->setBypassBand6(*reinterpret_cast<bool*>(_v)); break;
        case 123: _t->setBypassBand7(*reinterpret_cast<bool*>(_v)); break;
        case 126: _t->setBypassBand8(*reinterpret_cast<bool*>(_v)); break;
        case 129: _t->setBypassBand9(*reinterpret_cast<bool*>(_v)); break;
        case 132: _t->setBypassBand10(*reinterpret_cast<bool*>(_v)); break;
        case 135: _t->setBypassBand11(*reinterpret_cast<bool*>(_v)); break;
        case 138: _t->setBypassBand12(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbCrystalizer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbCrystalizer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DbCrystalizerE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbCrystalizer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 47)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 47;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 47)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 47;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 141;
    }
    return _id;
}

// SIGNAL 0
void DbCrystalizer::bypassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbCrystalizer::inputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbCrystalizer::outputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbCrystalizer::adaptiveIntensityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DbCrystalizer::oversamplingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DbCrystalizer::oversamplingQualityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DbCrystalizer::useFixedQuantumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DbCrystalizer::transitionBandChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DbCrystalizer::intensityBand0Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DbCrystalizer::intensityBand1Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DbCrystalizer::intensityBand2Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DbCrystalizer::intensityBand3Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void DbCrystalizer::intensityBand4Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void DbCrystalizer::intensityBand5Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void DbCrystalizer::intensityBand6Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void DbCrystalizer::intensityBand7Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void DbCrystalizer::intensityBand8Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void DbCrystalizer::intensityBand9Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void DbCrystalizer::intensityBand10Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void DbCrystalizer::intensityBand11Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void DbCrystalizer::intensityBand12Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void DbCrystalizer::muteBand0Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void DbCrystalizer::muteBand1Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void DbCrystalizer::muteBand2Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void DbCrystalizer::muteBand3Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void DbCrystalizer::muteBand4Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void DbCrystalizer::muteBand5Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void DbCrystalizer::muteBand6Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void DbCrystalizer::muteBand7Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void DbCrystalizer::muteBand8Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void DbCrystalizer::muteBand9Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void DbCrystalizer::muteBand10Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void DbCrystalizer::muteBand11Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}

// SIGNAL 33
void DbCrystalizer::muteBand12Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 33, nullptr);
}

// SIGNAL 34
void DbCrystalizer::bypassBand0Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 34, nullptr);
}

// SIGNAL 35
void DbCrystalizer::bypassBand1Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 35, nullptr);
}

// SIGNAL 36
void DbCrystalizer::bypassBand2Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 36, nullptr);
}

// SIGNAL 37
void DbCrystalizer::bypassBand3Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 37, nullptr);
}

// SIGNAL 38
void DbCrystalizer::bypassBand4Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 38, nullptr);
}

// SIGNAL 39
void DbCrystalizer::bypassBand5Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 39, nullptr);
}

// SIGNAL 40
void DbCrystalizer::bypassBand6Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 40, nullptr);
}

// SIGNAL 41
void DbCrystalizer::bypassBand7Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 41, nullptr);
}

// SIGNAL 42
void DbCrystalizer::bypassBand8Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 42, nullptr);
}

// SIGNAL 43
void DbCrystalizer::bypassBand9Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 43, nullptr);
}

// SIGNAL 44
void DbCrystalizer::bypassBand10Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 44, nullptr);
}

// SIGNAL 45
void DbCrystalizer::bypassBand11Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 45, nullptr);
}

// SIGNAL 46
void DbCrystalizer::bypassBand12Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 46, nullptr);
}
QT_WARNING_POP
