/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db_stereo_tools.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db_stereo_tools.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db_stereo_tools.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13DbStereoToolsE_t {};
} // unnamed namespace

template <> constexpr inline auto DbStereoTools::qt_create_metaobjectdata<qt_meta_tag_ZN13DbStereoToolsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbStereoTools",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "bypassChanged",
        "inputGainChanged",
        "outputGainChanged",
        "balanceInChanged",
        "balanceOutChanged",
        "softclipChanged",
        "mutelChanged",
        "muterChanged",
        "phaselChanged",
        "phaserChanged",
        "modeLabelsChanged",
        "modeChanged",
        "slevChanged",
        "sbalChanged",
        "mlevChanged",
        "mpanChanged",
        "stereoBaseChanged",
        "delayChanged",
        "scLevelChanged",
        "stereoPhaseChanged",
        "dryChanged",
        "wetChanged",
        "bypass",
        "isBypassImmutable",
        "defaultBypassValue",
        "inputGain",
        "isInputGainImmutable",
        "defaultInputGainValue",
        "outputGain",
        "isOutputGainImmutable",
        "defaultOutputGainValue",
        "balanceIn",
        "isBalanceInImmutable",
        "defaultBalanceInValue",
        "balanceOut",
        "isBalanceOutImmutable",
        "defaultBalanceOutValue",
        "softclip",
        "isSoftclipImmutable",
        "defaultSoftclipValue",
        "mutel",
        "isMutelImmutable",
        "defaultMutelValue",
        "muter",
        "isMuterImmutable",
        "defaultMuterValue",
        "phasel",
        "isPhaselImmutable",
        "defaultPhaselValue",
        "phaser",
        "isPhaserImmutable",
        "defaultPhaserValue",
        "modeLabels",
        "isModeLabelsImmutable",
        "defaultModeLabelsValue",
        "mode",
        "isModeImmutable",
        "defaultModeValue",
        "slev",
        "isSlevImmutable",
        "defaultSlevValue",
        "sbal",
        "isSbalImmutable",
        "defaultSbalValue",
        "mlev",
        "isMlevImmutable",
        "defaultMlevValue",
        "mpan",
        "isMpanImmutable",
        "defaultMpanValue",
        "stereoBase",
        "isStereoBaseImmutable",
        "defaultStereoBaseValue",
        "delay",
        "isDelayImmutable",
        "defaultDelayValue",
        "scLevel",
        "isScLevelImmutable",
        "defaultScLevelValue",
        "stereoPhase",
        "isStereoPhaseImmutable",
        "defaultStereoPhaseValue",
        "dry",
        "isDryImmutable",
        "defaultDryValue",
        "wet",
        "isWetImmutable",
        "defaultWetValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bypassChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputGainChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputGainChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'balanceInChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'balanceOutChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'softclipChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mutelChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'muterChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'phaselChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'phaserChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeLabelsChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'slevChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sbalChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mlevChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mpanChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stereoBaseChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'delayChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scLevelChanged'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stereoPhaseChanged'
        QtMocHelpers::SignalData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dryChanged'
        QtMocHelpers::SignalData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wetChanged'
        QtMocHelpers::SignalData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bypass'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isBypassImmutable'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassValue'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputGain'
        QtMocHelpers::PropertyData<double>(32, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isInputGainImmutable'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputGainValue'
        QtMocHelpers::PropertyData<double>(34, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'outputGain'
        QtMocHelpers::PropertyData<double>(35, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isOutputGainImmutable'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOutputGainValue'
        QtMocHelpers::PropertyData<double>(37, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'balanceIn'
        QtMocHelpers::PropertyData<double>(38, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isBalanceInImmutable'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBalanceInValue'
        QtMocHelpers::PropertyData<double>(40, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'balanceOut'
        QtMocHelpers::PropertyData<double>(41, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isBalanceOutImmutable'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBalanceOutValue'
        QtMocHelpers::PropertyData<double>(43, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'softclip'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isSoftclipImmutable'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSoftclipValue'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mutel'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isMutelImmutable'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMutelValue'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'muter'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isMuterImmutable'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMuterValue'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'phasel'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isPhaselImmutable'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPhaselValue'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'phaser'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isPhaserImmutable'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPhaserValue'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'modeLabels'
        QtMocHelpers::PropertyData<QStringList>(59, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isModeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultModeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(61, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mode'
        QtMocHelpers::PropertyData<int>(62, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isModeImmutable'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultModeValue'
        QtMocHelpers::PropertyData<int>(64, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'slev'
        QtMocHelpers::PropertyData<double>(65, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isSlevImmutable'
        QtMocHelpers::PropertyData<bool>(66, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSlevValue'
        QtMocHelpers::PropertyData<double>(67, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sbal'
        QtMocHelpers::PropertyData<double>(68, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isSbalImmutable'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSbalValue'
        QtMocHelpers::PropertyData<double>(70, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mlev'
        QtMocHelpers::PropertyData<double>(71, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isMlevImmutable'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMlevValue'
        QtMocHelpers::PropertyData<double>(73, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mpan'
        QtMocHelpers::PropertyData<double>(74, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isMpanImmutable'
        QtMocHelpers::PropertyData<bool>(75, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMpanValue'
        QtMocHelpers::PropertyData<double>(76, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stereoBase'
        QtMocHelpers::PropertyData<double>(77, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isStereoBaseImmutable'
        QtMocHelpers::PropertyData<bool>(78, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultStereoBaseValue'
        QtMocHelpers::PropertyData<double>(79, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'delay'
        QtMocHelpers::PropertyData<double>(80, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'isDelayImmutable'
        QtMocHelpers::PropertyData<bool>(81, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDelayValue'
        QtMocHelpers::PropertyData<double>(82, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'scLevel'
        QtMocHelpers::PropertyData<double>(83, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'isScLevelImmutable'
        QtMocHelpers::PropertyData<bool>(84, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultScLevelValue'
        QtMocHelpers::PropertyData<double>(85, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stereoPhase'
        QtMocHelpers::PropertyData<double>(86, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'isStereoPhaseImmutable'
        QtMocHelpers::PropertyData<bool>(87, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultStereoPhaseValue'
        QtMocHelpers::PropertyData<double>(88, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dry'
        QtMocHelpers::PropertyData<double>(89, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'isDryImmutable'
        QtMocHelpers::PropertyData<bool>(90, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDryValue'
        QtMocHelpers::PropertyData<double>(91, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'wet'
        QtMocHelpers::PropertyData<double>(92, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'isWetImmutable'
        QtMocHelpers::PropertyData<bool>(93, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWetValue'
        QtMocHelpers::PropertyData<double>(94, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DbStereoTools, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbStereoTools::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DbStereoToolsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DbStereoToolsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DbStereoToolsE_t>.metaTypes,
    nullptr
} };

void DbStereoTools::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbStereoTools *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bypassChanged(); break;
        case 1: _t->inputGainChanged(); break;
        case 2: _t->outputGainChanged(); break;
        case 3: _t->balanceInChanged(); break;
        case 4: _t->balanceOutChanged(); break;
        case 5: _t->softclipChanged(); break;
        case 6: _t->mutelChanged(); break;
        case 7: _t->muterChanged(); break;
        case 8: _t->phaselChanged(); break;
        case 9: _t->phaserChanged(); break;
        case 10: _t->modeLabelsChanged(); break;
        case 11: _t->modeChanged(); break;
        case 12: _t->slevChanged(); break;
        case 13: _t->sbalChanged(); break;
        case 14: _t->mlevChanged(); break;
        case 15: _t->mpanChanged(); break;
        case 16: _t->stereoBaseChanged(); break;
        case 17: _t->delayChanged(); break;
        case 18: _t->scLevelChanged(); break;
        case 19: _t->stereoPhaseChanged(); break;
        case 20: _t->dryChanged(); break;
        case 21: _t->wetChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::bypassChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::inputGainChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::outputGainChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::balanceInChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::balanceOutChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::softclipChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::mutelChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::muterChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::phaselChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::phaserChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::modeLabelsChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::modeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::slevChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::sbalChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::mlevChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::mpanChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::stereoBaseChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::delayChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::scLevelChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::stereoPhaseChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::dryChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbStereoTools::*)()>(_a, &DbStereoTools::wetChanged, 21))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bypass(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isBypassImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultBypassValue(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->inputGain(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isInputGainImmutable(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->defaultInputGainValue(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->outputGain(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isOutputGainImmutable(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->defaultOutputGainValue(); break;
        case 9: *reinterpret_cast<double*>(_v) = _t->balanceIn(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isBalanceInImmutable(); break;
        case 11: *reinterpret_cast<double*>(_v) = _t->defaultBalanceInValue(); break;
        case 12: *reinterpret_cast<double*>(_v) = _t->balanceOut(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isBalanceOutImmutable(); break;
        case 14: *reinterpret_cast<double*>(_v) = _t->defaultBalanceOutValue(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->softclip(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isSoftclipImmutable(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->defaultSoftclipValue(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->mutel(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isMutelImmutable(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->defaultMutelValue(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->muter(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isMuterImmutable(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->defaultMuterValue(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->phasel(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isPhaselImmutable(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->defaultPhaselValue(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->phaser(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isPhaserImmutable(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->defaultPhaserValue(); break;
        case 30: *reinterpret_cast<QStringList*>(_v) = _t->modeLabels(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isModeLabelsImmutable(); break;
        case 32: *reinterpret_cast<QStringList*>(_v) = _t->defaultModeLabelsValue(); break;
        case 33: *reinterpret_cast<int*>(_v) = _t->mode(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isModeImmutable(); break;
        case 35: *reinterpret_cast<int*>(_v) = _t->defaultModeValue(); break;
        case 36: *reinterpret_cast<double*>(_v) = _t->slev(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isSlevImmutable(); break;
        case 38: *reinterpret_cast<double*>(_v) = _t->defaultSlevValue(); break;
        case 39: *reinterpret_cast<double*>(_v) = _t->sbal(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->isSbalImmutable(); break;
        case 41: *reinterpret_cast<double*>(_v) = _t->defaultSbalValue(); break;
        case 42: *reinterpret_cast<double*>(_v) = _t->mlev(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->isMlevImmutable(); break;
        case 44: *reinterpret_cast<double*>(_v) = _t->defaultMlevValue(); break;
        case 45: *reinterpret_cast<double*>(_v) = _t->mpan(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->isMpanImmutable(); break;
        case 47: *reinterpret_cast<double*>(_v) = _t->defaultMpanValue(); break;
        case 48: *reinterpret_cast<double*>(_v) = _t->stereoBase(); break;
        case 49: *reinterpret_cast<bool*>(_v) = _t->isStereoBaseImmutable(); break;
        case 50: *reinterpret_cast<double*>(_v) = _t->defaultStereoBaseValue(); break;
        case 51: *reinterpret_cast<double*>(_v) = _t->delay(); break;
        case 52: *reinterpret_cast<bool*>(_v) = _t->isDelayImmutable(); break;
        case 53: *reinterpret_cast<double*>(_v) = _t->defaultDelayValue(); break;
        case 54: *reinterpret_cast<double*>(_v) = _t->scLevel(); break;
        case 55: *reinterpret_cast<bool*>(_v) = _t->isScLevelImmutable(); break;
        case 56: *reinterpret_cast<double*>(_v) = _t->defaultScLevelValue(); break;
        case 57: *reinterpret_cast<double*>(_v) = _t->stereoPhase(); break;
        case 58: *reinterpret_cast<bool*>(_v) = _t->isStereoPhaseImmutable(); break;
        case 59: *reinterpret_cast<double*>(_v) = _t->defaultStereoPhaseValue(); break;
        case 60: *reinterpret_cast<double*>(_v) = _t->dry(); break;
        case 61: *reinterpret_cast<bool*>(_v) = _t->isDryImmutable(); break;
        case 62: *reinterpret_cast<double*>(_v) = _t->defaultDryValue(); break;
        case 63: *reinterpret_cast<double*>(_v) = _t->wet(); break;
        case 64: *reinterpret_cast<bool*>(_v) = _t->isWetImmutable(); break;
        case 65: *reinterpret_cast<double*>(_v) = _t->defaultWetValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBypass(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setInputGain(*reinterpret_cast<double*>(_v)); break;
        case 6: _t->setOutputGain(*reinterpret_cast<double*>(_v)); break;
        case 9: _t->setBalanceIn(*reinterpret_cast<double*>(_v)); break;
        case 12: _t->setBalanceOut(*reinterpret_cast<double*>(_v)); break;
        case 15: _t->setSoftclip(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setMutel(*reinterpret_cast<bool*>(_v)); break;
        case 21: _t->setMuter(*reinterpret_cast<bool*>(_v)); break;
        case 24: _t->setPhasel(*reinterpret_cast<bool*>(_v)); break;
        case 27: _t->setPhaser(*reinterpret_cast<bool*>(_v)); break;
        case 30: _t->setModeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 33: _t->setMode(*reinterpret_cast<int*>(_v)); break;
        case 36: _t->setSlev(*reinterpret_cast<double*>(_v)); break;
        case 39: _t->setSbal(*reinterpret_cast<double*>(_v)); break;
        case 42: _t->setMlev(*reinterpret_cast<double*>(_v)); break;
        case 45: _t->setMpan(*reinterpret_cast<double*>(_v)); break;
        case 48: _t->setStereoBase(*reinterpret_cast<double*>(_v)); break;
        case 51: _t->setDelay(*reinterpret_cast<double*>(_v)); break;
        case 54: _t->setScLevel(*reinterpret_cast<double*>(_v)); break;
        case 57: _t->setStereoPhase(*reinterpret_cast<double*>(_v)); break;
        case 60: _t->setDry(*reinterpret_cast<double*>(_v)); break;
        case 63: _t->setWet(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbStereoTools::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbStereoTools::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DbStereoToolsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbStereoTools::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 22;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 66;
    }
    return _id;
}

// SIGNAL 0
void DbStereoTools::bypassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbStereoTools::inputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbStereoTools::outputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbStereoTools::balanceInChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DbStereoTools::balanceOutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DbStereoTools::softclipChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DbStereoTools::mutelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DbStereoTools::muterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DbStereoTools::phaselChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DbStereoTools::phaserChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DbStereoTools::modeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DbStereoTools::modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void DbStereoTools::slevChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void DbStereoTools::sbalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void DbStereoTools::mlevChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void DbStereoTools::mpanChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void DbStereoTools::stereoBaseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void DbStereoTools::delayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void DbStereoTools::scLevelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void DbStereoTools::stereoPhaseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void DbStereoTools::dryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void DbStereoTools::wetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}
QT_WARNING_POP
