/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db_graph.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db_graph.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db_graph.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7DbGraphE_t {};
} // unnamed namespace

template <> constexpr inline auto DbGraph::qt_create_metaobjectdata<qt_meta_tag_ZN7DbGraphE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbGraph",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "colorSchemeChanged",
        "",
        "colorThemeChanged",
        "plotAreaBackgroundColorChanged",
        "backgroundColorChanged",
        "seriesColorsChanged",
        "labelTextColorChanged",
        "labelBackgroundColorChanged",
        "borderColorsChanged",
        "lineWidthChanged",
        "gridVisibleChanged",
        "colorScheme",
        "isColorSchemeImmutable",
        "defaultColorSchemeValue",
        "colorTheme",
        "isColorThemeImmutable",
        "defaultColorThemeValue",
        "plotAreaBackgroundColor",
        "QColor",
        "isPlotAreaBackgroundColorImmutable",
        "defaultPlotAreaBackgroundColorValue",
        "backgroundColor",
        "isBackgroundColorImmutable",
        "defaultBackgroundColorValue",
        "seriesColors",
        "isSeriesColorsImmutable",
        "defaultSeriesColorsValue",
        "labelTextColor",
        "isLabelTextColorImmutable",
        "defaultLabelTextColorValue",
        "labelBackgroundColor",
        "isLabelBackgroundColorImmutable",
        "defaultLabelBackgroundColorValue",
        "borderColors",
        "isBorderColorsImmutable",
        "defaultBorderColorsValue",
        "lineWidth",
        "isLineWidthImmutable",
        "defaultLineWidthValue",
        "gridVisible",
        "isGridVisibleImmutable",
        "defaultGridVisibleValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'colorSchemeChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorThemeChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'plotAreaBackgroundColorChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backgroundColorChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seriesColorsChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'labelTextColorChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'labelBackgroundColorChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'borderColorsChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lineWidthChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gridVisibleChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'colorScheme'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isColorSchemeImmutable'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultColorSchemeValue'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'colorTheme'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isColorThemeImmutable'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultColorThemeValue'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'plotAreaBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'isPlotAreaBackgroundColorImmutable'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPlotAreaBackgroundColorValue'
        QtMocHelpers::PropertyData<QColor>(25, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'backgroundColor'
        QtMocHelpers::PropertyData<QColor>(26, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'isBackgroundColorImmutable'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBackgroundColorValue'
        QtMocHelpers::PropertyData<QColor>(28, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'seriesColors'
        QtMocHelpers::PropertyData<QColor>(29, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'isSeriesColorsImmutable'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSeriesColorsValue'
        QtMocHelpers::PropertyData<QColor>(31, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'labelTextColor'
        QtMocHelpers::PropertyData<QColor>(32, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'isLabelTextColorImmutable'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLabelTextColorValue'
        QtMocHelpers::PropertyData<QColor>(34, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'labelBackgroundColor'
        QtMocHelpers::PropertyData<QColor>(35, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'isLabelBackgroundColorImmutable'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLabelBackgroundColorValue'
        QtMocHelpers::PropertyData<QColor>(37, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'borderColors'
        QtMocHelpers::PropertyData<QColor>(38, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'isBorderColorsImmutable'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBorderColorsValue'
        QtMocHelpers::PropertyData<QColor>(40, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'lineWidth'
        QtMocHelpers::PropertyData<double>(41, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isLineWidthImmutable'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLineWidthValue'
        QtMocHelpers::PropertyData<double>(43, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gridVisible'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isGridVisibleImmutable'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGridVisibleValue'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DbGraph, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbGraph::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7DbGraphE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7DbGraphE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7DbGraphE_t>.metaTypes,
    nullptr
} };

void DbGraph::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbGraph *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->colorSchemeChanged(); break;
        case 1: _t->colorThemeChanged(); break;
        case 2: _t->plotAreaBackgroundColorChanged(); break;
        case 3: _t->backgroundColorChanged(); break;
        case 4: _t->seriesColorsChanged(); break;
        case 5: _t->labelTextColorChanged(); break;
        case 6: _t->labelBackgroundColorChanged(); break;
        case 7: _t->borderColorsChanged(); break;
        case 8: _t->lineWidthChanged(); break;
        case 9: _t->gridVisibleChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbGraph::*)()>(_a, &DbGraph::colorSchemeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbGraph::*)()>(_a, &DbGraph::colorThemeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbGraph::*)()>(_a, &DbGraph::plotAreaBackgroundColorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbGraph::*)()>(_a, &DbGraph::backgroundColorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbGraph::*)()>(_a, &DbGraph::seriesColorsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbGraph::*)()>(_a, &DbGraph::labelTextColorChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbGraph::*)()>(_a, &DbGraph::labelBackgroundColorChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbGraph::*)()>(_a, &DbGraph::borderColorsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbGraph::*)()>(_a, &DbGraph::lineWidthChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbGraph::*)()>(_a, &DbGraph::gridVisibleChanged, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->colorScheme(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isColorSchemeImmutable(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->defaultColorSchemeValue(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->colorTheme(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isColorThemeImmutable(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->defaultColorThemeValue(); break;
        case 6: *reinterpret_cast<QColor*>(_v) = _t->plotAreaBackgroundColor(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isPlotAreaBackgroundColorImmutable(); break;
        case 8: *reinterpret_cast<QColor*>(_v) = _t->defaultPlotAreaBackgroundColorValue(); break;
        case 9: *reinterpret_cast<QColor*>(_v) = _t->backgroundColor(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isBackgroundColorImmutable(); break;
        case 11: *reinterpret_cast<QColor*>(_v) = _t->defaultBackgroundColorValue(); break;
        case 12: *reinterpret_cast<QColor*>(_v) = _t->seriesColors(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isSeriesColorsImmutable(); break;
        case 14: *reinterpret_cast<QColor*>(_v) = _t->defaultSeriesColorsValue(); break;
        case 15: *reinterpret_cast<QColor*>(_v) = _t->labelTextColor(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isLabelTextColorImmutable(); break;
        case 17: *reinterpret_cast<QColor*>(_v) = _t->defaultLabelTextColorValue(); break;
        case 18: *reinterpret_cast<QColor*>(_v) = _t->labelBackgroundColor(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isLabelBackgroundColorImmutable(); break;
        case 20: *reinterpret_cast<QColor*>(_v) = _t->defaultLabelBackgroundColorValue(); break;
        case 21: *reinterpret_cast<QColor*>(_v) = _t->borderColors(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isBorderColorsImmutable(); break;
        case 23: *reinterpret_cast<QColor*>(_v) = _t->defaultBorderColorsValue(); break;
        case 24: *reinterpret_cast<double*>(_v) = _t->lineWidth(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isLineWidthImmutable(); break;
        case 26: *reinterpret_cast<double*>(_v) = _t->defaultLineWidthValue(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->gridVisible(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isGridVisibleImmutable(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->defaultGridVisibleValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setColorScheme(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setColorTheme(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setPlotAreaBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 9: _t->setBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 12: _t->setSeriesColors(*reinterpret_cast<QColor*>(_v)); break;
        case 15: _t->setLabelTextColor(*reinterpret_cast<QColor*>(_v)); break;
        case 18: _t->setLabelBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 21: _t->setBorderColors(*reinterpret_cast<QColor*>(_v)); break;
        case 24: _t->setLineWidth(*reinterpret_cast<double*>(_v)); break;
        case 27: _t->setGridVisible(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbGraph::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbGraph::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7DbGraphE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbGraph::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    return _id;
}

// SIGNAL 0
void DbGraph::colorSchemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbGraph::colorThemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbGraph::plotAreaBackgroundColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbGraph::backgroundColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DbGraph::seriesColorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DbGraph::labelTextColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DbGraph::labelBackgroundColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DbGraph::borderColorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DbGraph::lineWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DbGraph::gridVisibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
