/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db_convolver.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db_convolver.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db_convolver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11DbConvolverE_t {};
} // unnamed namespace

template <> constexpr inline auto DbConvolver::qt_create_metaobjectdata<qt_meta_tag_ZN11DbConvolverE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbConvolver",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "bypassChanged",
        "inputGainChanged",
        "outputGainChanged",
        "kernelNameChanged",
        "irWidthChanged",
        "autogainChanged",
        "dryChanged",
        "wetChanged",
        "targetSofaAzimuthChanged",
        "targetSofaElevationChanged",
        "targetSofaRadiusChanged",
        "bypass",
        "isBypassImmutable",
        "defaultBypassValue",
        "inputGain",
        "isInputGainImmutable",
        "defaultInputGainValue",
        "outputGain",
        "isOutputGainImmutable",
        "defaultOutputGainValue",
        "kernelName",
        "isKernelNameImmutable",
        "defaultKernelNameValue",
        "irWidth",
        "isIrWidthImmutable",
        "defaultIrWidthValue",
        "autogain",
        "isAutogainImmutable",
        "defaultAutogainValue",
        "dry",
        "isDryImmutable",
        "defaultDryValue",
        "wet",
        "isWetImmutable",
        "defaultWetValue",
        "targetSofaAzimuth",
        "isTargetSofaAzimuthImmutable",
        "defaultTargetSofaAzimuthValue",
        "targetSofaElevation",
        "isTargetSofaElevationImmutable",
        "defaultTargetSofaElevationValue",
        "targetSofaRadius",
        "isTargetSofaRadiusImmutable",
        "defaultTargetSofaRadiusValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bypassChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputGainChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputGainChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'kernelNameChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'irWidthChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autogainChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dryChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wetChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'targetSofaAzimuthChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'targetSofaElevationChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'targetSofaRadiusChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bypass'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isBypassImmutable'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassValue'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputGain'
        QtMocHelpers::PropertyData<double>(21, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isInputGainImmutable'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputGainValue'
        QtMocHelpers::PropertyData<double>(23, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'outputGain'
        QtMocHelpers::PropertyData<double>(24, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isOutputGainImmutable'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOutputGainValue'
        QtMocHelpers::PropertyData<double>(26, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'kernelName'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isKernelNameImmutable'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultKernelNameValue'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'irWidth'
        QtMocHelpers::PropertyData<int>(30, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isIrWidthImmutable'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIrWidthValue'
        QtMocHelpers::PropertyData<int>(32, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autogain'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isAutogainImmutable'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutogainValue'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dry'
        QtMocHelpers::PropertyData<double>(36, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isDryImmutable'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDryValue'
        QtMocHelpers::PropertyData<double>(38, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'wet'
        QtMocHelpers::PropertyData<double>(39, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isWetImmutable'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWetValue'
        QtMocHelpers::PropertyData<double>(41, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'targetSofaAzimuth'
        QtMocHelpers::PropertyData<double>(42, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isTargetSofaAzimuthImmutable'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTargetSofaAzimuthValue'
        QtMocHelpers::PropertyData<double>(44, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'targetSofaElevation'
        QtMocHelpers::PropertyData<double>(45, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isTargetSofaElevationImmutable'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTargetSofaElevationValue'
        QtMocHelpers::PropertyData<double>(47, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'targetSofaRadius'
        QtMocHelpers::PropertyData<double>(48, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isTargetSofaRadiusImmutable'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTargetSofaRadiusValue'
        QtMocHelpers::PropertyData<double>(50, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DbConvolver, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbConvolver::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DbConvolverE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DbConvolverE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11DbConvolverE_t>.metaTypes,
    nullptr
} };

void DbConvolver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbConvolver *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bypassChanged(); break;
        case 1: _t->inputGainChanged(); break;
        case 2: _t->outputGainChanged(); break;
        case 3: _t->kernelNameChanged(); break;
        case 4: _t->irWidthChanged(); break;
        case 5: _t->autogainChanged(); break;
        case 6: _t->dryChanged(); break;
        case 7: _t->wetChanged(); break;
        case 8: _t->targetSofaAzimuthChanged(); break;
        case 9: _t->targetSofaElevationChanged(); break;
        case 10: _t->targetSofaRadiusChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbConvolver::*)()>(_a, &DbConvolver::bypassChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbConvolver::*)()>(_a, &DbConvolver::inputGainChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbConvolver::*)()>(_a, &DbConvolver::outputGainChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbConvolver::*)()>(_a, &DbConvolver::kernelNameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbConvolver::*)()>(_a, &DbConvolver::irWidthChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbConvolver::*)()>(_a, &DbConvolver::autogainChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbConvolver::*)()>(_a, &DbConvolver::dryChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbConvolver::*)()>(_a, &DbConvolver::wetChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbConvolver::*)()>(_a, &DbConvolver::targetSofaAzimuthChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbConvolver::*)()>(_a, &DbConvolver::targetSofaElevationChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbConvolver::*)()>(_a, &DbConvolver::targetSofaRadiusChanged, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bypass(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isBypassImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultBypassValue(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->inputGain(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isInputGainImmutable(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->defaultInputGainValue(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->outputGain(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isOutputGainImmutable(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->defaultOutputGainValue(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->kernelName(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isKernelNameImmutable(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->defaultKernelNameValue(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->irWidth(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isIrWidthImmutable(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->defaultIrWidthValue(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->autogain(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isAutogainImmutable(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->defaultAutogainValue(); break;
        case 18: *reinterpret_cast<double*>(_v) = _t->dry(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isDryImmutable(); break;
        case 20: *reinterpret_cast<double*>(_v) = _t->defaultDryValue(); break;
        case 21: *reinterpret_cast<double*>(_v) = _t->wet(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isWetImmutable(); break;
        case 23: *reinterpret_cast<double*>(_v) = _t->defaultWetValue(); break;
        case 24: *reinterpret_cast<double*>(_v) = _t->targetSofaAzimuth(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isTargetSofaAzimuthImmutable(); break;
        case 26: *reinterpret_cast<double*>(_v) = _t->defaultTargetSofaAzimuthValue(); break;
        case 27: *reinterpret_cast<double*>(_v) = _t->targetSofaElevation(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isTargetSofaElevationImmutable(); break;
        case 29: *reinterpret_cast<double*>(_v) = _t->defaultTargetSofaElevationValue(); break;
        case 30: *reinterpret_cast<double*>(_v) = _t->targetSofaRadius(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isTargetSofaRadiusImmutable(); break;
        case 32: *reinterpret_cast<double*>(_v) = _t->defaultTargetSofaRadiusValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBypass(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setInputGain(*reinterpret_cast<double*>(_v)); break;
        case 6: _t->setOutputGain(*reinterpret_cast<double*>(_v)); break;
        case 9: _t->setKernelName(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setIrWidth(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setAutogain(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setDry(*reinterpret_cast<double*>(_v)); break;
        case 21: _t->setWet(*reinterpret_cast<double*>(_v)); break;
        case 24: _t->setTargetSofaAzimuth(*reinterpret_cast<double*>(_v)); break;
        case 27: _t->setTargetSofaElevation(*reinterpret_cast<double*>(_v)); break;
        case 30: _t->setTargetSofaRadius(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbConvolver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbConvolver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DbConvolverE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbConvolver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    return _id;
}

// SIGNAL 0
void DbConvolver::bypassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbConvolver::inputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbConvolver::outputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbConvolver::kernelNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DbConvolver::irWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DbConvolver::autogainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DbConvolver::dryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DbConvolver::wetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DbConvolver::targetSofaAzimuthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DbConvolver::targetSofaElevationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DbConvolver::targetSofaRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
