/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db_filter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db_filter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db_filter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8DbFilterE_t {};
} // unnamed namespace

template <> constexpr inline auto DbFilter::qt_create_metaobjectdata<qt_meta_tag_ZN8DbFilterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbFilter",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "bypassChanged",
        "inputGainChanged",
        "outputGainChanged",
        "typeLabelsChanged",
        "typeChanged",
        "equalModeLabelsChanged",
        "equalModeChanged",
        "modeLabelsChanged",
        "modeChanged",
        "slopeLabelsChanged",
        "slopeChanged",
        "frequencyChanged",
        "widthChanged",
        "qualityChanged",
        "gainChanged",
        "balanceChanged",
        "decrampLabelsChanged",
        "decrampChanged",
        "bypass",
        "isBypassImmutable",
        "defaultBypassValue",
        "inputGain",
        "isInputGainImmutable",
        "defaultInputGainValue",
        "outputGain",
        "isOutputGainImmutable",
        "defaultOutputGainValue",
        "typeLabels",
        "isTypeLabelsImmutable",
        "defaultTypeLabelsValue",
        "type",
        "isTypeImmutable",
        "defaultTypeValue",
        "equalModeLabels",
        "isEqualModeLabelsImmutable",
        "defaultEqualModeLabelsValue",
        "equalMode",
        "isEqualModeImmutable",
        "defaultEqualModeValue",
        "modeLabels",
        "isModeLabelsImmutable",
        "defaultModeLabelsValue",
        "mode",
        "isModeImmutable",
        "defaultModeValue",
        "slopeLabels",
        "isSlopeLabelsImmutable",
        "defaultSlopeLabelsValue",
        "slope",
        "isSlopeImmutable",
        "defaultSlopeValue",
        "frequency",
        "isFrequencyImmutable",
        "defaultFrequencyValue",
        "width",
        "isWidthImmutable",
        "defaultWidthValue",
        "quality",
        "isQualityImmutable",
        "defaultQualityValue",
        "gain",
        "isGainImmutable",
        "defaultGainValue",
        "balance",
        "isBalanceImmutable",
        "defaultBalanceValue",
        "decrampLabels",
        "isDecrampLabelsImmutable",
        "defaultDecrampLabelsValue",
        "decramp",
        "isDecrampImmutable",
        "defaultDecrampValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bypassChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputGainChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputGainChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'typeLabelsChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'equalModeLabelsChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'equalModeChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeLabelsChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'slopeLabelsChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'slopeChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'frequencyChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'widthChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'qualityChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gainChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'balanceChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'decrampLabelsChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'decrampChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bypass'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isBypassImmutable'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassValue'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputGain'
        QtMocHelpers::PropertyData<double>(28, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isInputGainImmutable'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputGainValue'
        QtMocHelpers::PropertyData<double>(30, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'outputGain'
        QtMocHelpers::PropertyData<double>(31, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isOutputGainImmutable'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOutputGainValue'
        QtMocHelpers::PropertyData<double>(33, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'typeLabels'
        QtMocHelpers::PropertyData<QStringList>(34, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isTypeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTypeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(36, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'type'
        QtMocHelpers::PropertyData<int>(37, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isTypeImmutable'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTypeValue'
        QtMocHelpers::PropertyData<int>(39, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'equalModeLabels'
        QtMocHelpers::PropertyData<QStringList>(40, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isEqualModeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEqualModeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(42, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'equalMode'
        QtMocHelpers::PropertyData<int>(43, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isEqualModeImmutable'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEqualModeValue'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'modeLabels'
        QtMocHelpers::PropertyData<QStringList>(46, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isModeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultModeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(48, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mode'
        QtMocHelpers::PropertyData<int>(49, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isModeImmutable'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultModeValue'
        QtMocHelpers::PropertyData<int>(51, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'slopeLabels'
        QtMocHelpers::PropertyData<QStringList>(52, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isSlopeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSlopeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(54, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'slope'
        QtMocHelpers::PropertyData<int>(55, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isSlopeImmutable'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSlopeValue'
        QtMocHelpers::PropertyData<int>(57, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'frequency'
        QtMocHelpers::PropertyData<double>(58, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFrequencyValue'
        QtMocHelpers::PropertyData<double>(60, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'width'
        QtMocHelpers::PropertyData<double>(61, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isWidthImmutable'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWidthValue'
        QtMocHelpers::PropertyData<double>(63, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'quality'
        QtMocHelpers::PropertyData<double>(64, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isQualityImmutable'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultQualityValue'
        QtMocHelpers::PropertyData<double>(66, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gain'
        QtMocHelpers::PropertyData<double>(67, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isGainImmutable'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGainValue'
        QtMocHelpers::PropertyData<double>(69, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'balance'
        QtMocHelpers::PropertyData<double>(70, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isBalanceImmutable'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBalanceValue'
        QtMocHelpers::PropertyData<double>(72, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'decrampLabels'
        QtMocHelpers::PropertyData<QStringList>(73, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isDecrampLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDecrampLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(75, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'decramp'
        QtMocHelpers::PropertyData<int>(76, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'isDecrampImmutable'
        QtMocHelpers::PropertyData<bool>(77, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDecrampValue'
        QtMocHelpers::PropertyData<int>(78, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DbFilter, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbFilter::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8DbFilterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8DbFilterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8DbFilterE_t>.metaTypes,
    nullptr
} };

void DbFilter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbFilter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bypassChanged(); break;
        case 1: _t->inputGainChanged(); break;
        case 2: _t->outputGainChanged(); break;
        case 3: _t->typeLabelsChanged(); break;
        case 4: _t->typeChanged(); break;
        case 5: _t->equalModeLabelsChanged(); break;
        case 6: _t->equalModeChanged(); break;
        case 7: _t->modeLabelsChanged(); break;
        case 8: _t->modeChanged(); break;
        case 9: _t->slopeLabelsChanged(); break;
        case 10: _t->slopeChanged(); break;
        case 11: _t->frequencyChanged(); break;
        case 12: _t->widthChanged(); break;
        case 13: _t->qualityChanged(); break;
        case 14: _t->gainChanged(); break;
        case 15: _t->balanceChanged(); break;
        case 16: _t->decrampLabelsChanged(); break;
        case 17: _t->decrampChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbFilter::*)()>(_a, &DbFilter::bypassChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbFilter::*)()>(_a, &DbFilter::inputGainChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbFilter::*)()>(_a, &DbFilter::outputGainChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbFilter::*)()>(_a, &DbFilter::typeLabelsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbFilter::*)()>(_a, &DbFilter::typeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbFilter::*)()>(_a, &DbFilter::equalModeLabelsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbFilter::*)()>(_a, &DbFilter::equalModeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbFilter::*)()>(_a, &DbFilter::modeLabelsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbFilter::*)()>(_a, &DbFilter::modeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbFilter::*)()>(_a, &DbFilter::slopeLabelsChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbFilter::*)()>(_a, &DbFilter::slopeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbFilter::*)()>(_a, &DbFilter::frequencyChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbFilter::*)()>(_a, &DbFilter::widthChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbFilter::*)()>(_a, &DbFilter::qualityChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbFilter::*)()>(_a, &DbFilter::gainChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbFilter::*)()>(_a, &DbFilter::balanceChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbFilter::*)()>(_a, &DbFilter::decrampLabelsChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbFilter::*)()>(_a, &DbFilter::decrampChanged, 17))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bypass(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isBypassImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultBypassValue(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->inputGain(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isInputGainImmutable(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->defaultInputGainValue(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->outputGain(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isOutputGainImmutable(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->defaultOutputGainValue(); break;
        case 9: *reinterpret_cast<QStringList*>(_v) = _t->typeLabels(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isTypeLabelsImmutable(); break;
        case 11: *reinterpret_cast<QStringList*>(_v) = _t->defaultTypeLabelsValue(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->type(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isTypeImmutable(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->defaultTypeValue(); break;
        case 15: *reinterpret_cast<QStringList*>(_v) = _t->equalModeLabels(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isEqualModeLabelsImmutable(); break;
        case 17: *reinterpret_cast<QStringList*>(_v) = _t->defaultEqualModeLabelsValue(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->equalMode(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isEqualModeImmutable(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->defaultEqualModeValue(); break;
        case 21: *reinterpret_cast<QStringList*>(_v) = _t->modeLabels(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isModeLabelsImmutable(); break;
        case 23: *reinterpret_cast<QStringList*>(_v) = _t->defaultModeLabelsValue(); break;
        case 24: *reinterpret_cast<int*>(_v) = _t->mode(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isModeImmutable(); break;
        case 26: *reinterpret_cast<int*>(_v) = _t->defaultModeValue(); break;
        case 27: *reinterpret_cast<QStringList*>(_v) = _t->slopeLabels(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isSlopeLabelsImmutable(); break;
        case 29: *reinterpret_cast<QStringList*>(_v) = _t->defaultSlopeLabelsValue(); break;
        case 30: *reinterpret_cast<int*>(_v) = _t->slope(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isSlopeImmutable(); break;
        case 32: *reinterpret_cast<int*>(_v) = _t->defaultSlopeValue(); break;
        case 33: *reinterpret_cast<double*>(_v) = _t->frequency(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isFrequencyImmutable(); break;
        case 35: *reinterpret_cast<double*>(_v) = _t->defaultFrequencyValue(); break;
        case 36: *reinterpret_cast<double*>(_v) = _t->width(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isWidthImmutable(); break;
        case 38: *reinterpret_cast<double*>(_v) = _t->defaultWidthValue(); break;
        case 39: *reinterpret_cast<double*>(_v) = _t->quality(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->isQualityImmutable(); break;
        case 41: *reinterpret_cast<double*>(_v) = _t->defaultQualityValue(); break;
        case 42: *reinterpret_cast<double*>(_v) = _t->gain(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->isGainImmutable(); break;
        case 44: *reinterpret_cast<double*>(_v) = _t->defaultGainValue(); break;
        case 45: *reinterpret_cast<double*>(_v) = _t->balance(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->isBalanceImmutable(); break;
        case 47: *reinterpret_cast<double*>(_v) = _t->defaultBalanceValue(); break;
        case 48: *reinterpret_cast<QStringList*>(_v) = _t->decrampLabels(); break;
        case 49: *reinterpret_cast<bool*>(_v) = _t->isDecrampLabelsImmutable(); break;
        case 50: *reinterpret_cast<QStringList*>(_v) = _t->defaultDecrampLabelsValue(); break;
        case 51: *reinterpret_cast<int*>(_v) = _t->decramp(); break;
        case 52: *reinterpret_cast<bool*>(_v) = _t->isDecrampImmutable(); break;
        case 53: *reinterpret_cast<int*>(_v) = _t->defaultDecrampValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBypass(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setInputGain(*reinterpret_cast<double*>(_v)); break;
        case 6: _t->setOutputGain(*reinterpret_cast<double*>(_v)); break;
        case 9: _t->setTypeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 12: _t->setType(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setEqualModeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 18: _t->setEqualMode(*reinterpret_cast<int*>(_v)); break;
        case 21: _t->setModeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 24: _t->setMode(*reinterpret_cast<int*>(_v)); break;
        case 27: _t->setSlopeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 30: _t->setSlope(*reinterpret_cast<int*>(_v)); break;
        case 33: _t->setFrequency(*reinterpret_cast<double*>(_v)); break;
        case 36: _t->setWidth(*reinterpret_cast<double*>(_v)); break;
        case 39: _t->setQuality(*reinterpret_cast<double*>(_v)); break;
        case 42: _t->setGain(*reinterpret_cast<double*>(_v)); break;
        case 45: _t->setBalance(*reinterpret_cast<double*>(_v)); break;
        case 48: _t->setDecrampLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 51: _t->setDecramp(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbFilter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbFilter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8DbFilterE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbFilter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 54;
    }
    return _id;
}

// SIGNAL 0
void DbFilter::bypassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbFilter::inputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbFilter::outputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbFilter::typeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DbFilter::typeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DbFilter::equalModeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DbFilter::equalModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DbFilter::modeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DbFilter::modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DbFilter::slopeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DbFilter::slopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DbFilter::frequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void DbFilter::widthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void DbFilter::qualityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void DbFilter::gainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void DbFilter::balanceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void DbFilter::decrampLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void DbFilter::decrampChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}
QT_WARNING_POP
