/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db_reverb.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db_reverb.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db_reverb.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8DbReverbE_t {};
} // unnamed namespace

template <> constexpr inline auto DbReverb::qt_create_metaobjectdata<qt_meta_tag_ZN8DbReverbE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbReverb",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "bypassChanged",
        "inputGainChanged",
        "outputGainChanged",
        "roomSizeLabelsChanged",
        "roomSizeChanged",
        "decayTimeChanged",
        "hfDampChanged",
        "diffusionChanged",
        "amountChanged",
        "dryChanged",
        "predelayChanged",
        "bassCutChanged",
        "trebleCutChanged",
        "bypass",
        "isBypassImmutable",
        "defaultBypassValue",
        "inputGain",
        "isInputGainImmutable",
        "defaultInputGainValue",
        "outputGain",
        "isOutputGainImmutable",
        "defaultOutputGainValue",
        "roomSizeLabels",
        "isRoomSizeLabelsImmutable",
        "defaultRoomSizeLabelsValue",
        "roomSize",
        "isRoomSizeImmutable",
        "defaultRoomSizeValue",
        "decayTime",
        "isDecayTimeImmutable",
        "defaultDecayTimeValue",
        "hfDamp",
        "isHfDampImmutable",
        "defaultHfDampValue",
        "diffusion",
        "isDiffusionImmutable",
        "defaultDiffusionValue",
        "amount",
        "isAmountImmutable",
        "defaultAmountValue",
        "dry",
        "isDryImmutable",
        "defaultDryValue",
        "predelay",
        "isPredelayImmutable",
        "defaultPredelayValue",
        "bassCut",
        "isBassCutImmutable",
        "defaultBassCutValue",
        "trebleCut",
        "isTrebleCutImmutable",
        "defaultTrebleCutValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bypassChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputGainChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputGainChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'roomSizeLabelsChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'roomSizeChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'decayTimeChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hfDampChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'diffusionChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'amountChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dryChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'predelayChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bassCutChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trebleCutChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bypass'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isBypassImmutable'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassValue'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputGain'
        QtMocHelpers::PropertyData<double>(23, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isInputGainImmutable'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputGainValue'
        QtMocHelpers::PropertyData<double>(25, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'outputGain'
        QtMocHelpers::PropertyData<double>(26, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isOutputGainImmutable'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOutputGainValue'
        QtMocHelpers::PropertyData<double>(28, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'roomSizeLabels'
        QtMocHelpers::PropertyData<QStringList>(29, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isRoomSizeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRoomSizeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(31, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'roomSize'
        QtMocHelpers::PropertyData<int>(32, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isRoomSizeImmutable'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRoomSizeValue'
        QtMocHelpers::PropertyData<int>(34, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'decayTime'
        QtMocHelpers::PropertyData<double>(35, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isDecayTimeImmutable'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDecayTimeValue'
        QtMocHelpers::PropertyData<double>(37, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hfDamp'
        QtMocHelpers::PropertyData<double>(38, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isHfDampImmutable'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultHfDampValue'
        QtMocHelpers::PropertyData<double>(40, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'diffusion'
        QtMocHelpers::PropertyData<double>(41, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isDiffusionImmutable'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDiffusionValue'
        QtMocHelpers::PropertyData<double>(43, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'amount'
        QtMocHelpers::PropertyData<double>(44, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isAmountImmutable'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAmountValue'
        QtMocHelpers::PropertyData<double>(46, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dry'
        QtMocHelpers::PropertyData<double>(47, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isDryImmutable'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDryValue'
        QtMocHelpers::PropertyData<double>(49, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'predelay'
        QtMocHelpers::PropertyData<double>(50, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isPredelayImmutable'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPredelayValue'
        QtMocHelpers::PropertyData<double>(52, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bassCut'
        QtMocHelpers::PropertyData<double>(53, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isBassCutImmutable'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBassCutValue'
        QtMocHelpers::PropertyData<double>(55, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'trebleCut'
        QtMocHelpers::PropertyData<double>(56, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isTrebleCutImmutable'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTrebleCutValue'
        QtMocHelpers::PropertyData<double>(58, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DbReverb, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbReverb::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8DbReverbE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8DbReverbE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8DbReverbE_t>.metaTypes,
    nullptr
} };

void DbReverb::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbReverb *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bypassChanged(); break;
        case 1: _t->inputGainChanged(); break;
        case 2: _t->outputGainChanged(); break;
        case 3: _t->roomSizeLabelsChanged(); break;
        case 4: _t->roomSizeChanged(); break;
        case 5: _t->decayTimeChanged(); break;
        case 6: _t->hfDampChanged(); break;
        case 7: _t->diffusionChanged(); break;
        case 8: _t->amountChanged(); break;
        case 9: _t->dryChanged(); break;
        case 10: _t->predelayChanged(); break;
        case 11: _t->bassCutChanged(); break;
        case 12: _t->trebleCutChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbReverb::*)()>(_a, &DbReverb::bypassChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbReverb::*)()>(_a, &DbReverb::inputGainChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbReverb::*)()>(_a, &DbReverb::outputGainChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbReverb::*)()>(_a, &DbReverb::roomSizeLabelsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbReverb::*)()>(_a, &DbReverb::roomSizeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbReverb::*)()>(_a, &DbReverb::decayTimeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbReverb::*)()>(_a, &DbReverb::hfDampChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbReverb::*)()>(_a, &DbReverb::diffusionChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbReverb::*)()>(_a, &DbReverb::amountChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbReverb::*)()>(_a, &DbReverb::dryChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbReverb::*)()>(_a, &DbReverb::predelayChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbReverb::*)()>(_a, &DbReverb::bassCutChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbReverb::*)()>(_a, &DbReverb::trebleCutChanged, 12))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bypass(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isBypassImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultBypassValue(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->inputGain(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isInputGainImmutable(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->defaultInputGainValue(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->outputGain(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isOutputGainImmutable(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->defaultOutputGainValue(); break;
        case 9: *reinterpret_cast<QStringList*>(_v) = _t->roomSizeLabels(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isRoomSizeLabelsImmutable(); break;
        case 11: *reinterpret_cast<QStringList*>(_v) = _t->defaultRoomSizeLabelsValue(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->roomSize(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isRoomSizeImmutable(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->defaultRoomSizeValue(); break;
        case 15: *reinterpret_cast<double*>(_v) = _t->decayTime(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isDecayTimeImmutable(); break;
        case 17: *reinterpret_cast<double*>(_v) = _t->defaultDecayTimeValue(); break;
        case 18: *reinterpret_cast<double*>(_v) = _t->hfDamp(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isHfDampImmutable(); break;
        case 20: *reinterpret_cast<double*>(_v) = _t->defaultHfDampValue(); break;
        case 21: *reinterpret_cast<double*>(_v) = _t->diffusion(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isDiffusionImmutable(); break;
        case 23: *reinterpret_cast<double*>(_v) = _t->defaultDiffusionValue(); break;
        case 24: *reinterpret_cast<double*>(_v) = _t->amount(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isAmountImmutable(); break;
        case 26: *reinterpret_cast<double*>(_v) = _t->defaultAmountValue(); break;
        case 27: *reinterpret_cast<double*>(_v) = _t->dry(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isDryImmutable(); break;
        case 29: *reinterpret_cast<double*>(_v) = _t->defaultDryValue(); break;
        case 30: *reinterpret_cast<double*>(_v) = _t->predelay(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isPredelayImmutable(); break;
        case 32: *reinterpret_cast<double*>(_v) = _t->defaultPredelayValue(); break;
        case 33: *reinterpret_cast<double*>(_v) = _t->bassCut(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isBassCutImmutable(); break;
        case 35: *reinterpret_cast<double*>(_v) = _t->defaultBassCutValue(); break;
        case 36: *reinterpret_cast<double*>(_v) = _t->trebleCut(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isTrebleCutImmutable(); break;
        case 38: *reinterpret_cast<double*>(_v) = _t->defaultTrebleCutValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBypass(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setInputGain(*reinterpret_cast<double*>(_v)); break;
        case 6: _t->setOutputGain(*reinterpret_cast<double*>(_v)); break;
        case 9: _t->setRoomSizeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 12: _t->setRoomSize(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setDecayTime(*reinterpret_cast<double*>(_v)); break;
        case 18: _t->setHfDamp(*reinterpret_cast<double*>(_v)); break;
        case 21: _t->setDiffusion(*reinterpret_cast<double*>(_v)); break;
        case 24: _t->setAmount(*reinterpret_cast<double*>(_v)); break;
        case 27: _t->setDry(*reinterpret_cast<double*>(_v)); break;
        case 30: _t->setPredelay(*reinterpret_cast<double*>(_v)); break;
        case 33: _t->setBassCut(*reinterpret_cast<double*>(_v)); break;
        case 36: _t->setTrebleCut(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbReverb::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbReverb::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8DbReverbE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbReverb::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    return _id;
}

// SIGNAL 0
void DbReverb::bypassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbReverb::inputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbReverb::outputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbReverb::roomSizeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DbReverb::roomSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DbReverb::decayTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DbReverb::hfDampChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DbReverb::diffusionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DbReverb::amountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DbReverb::dryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DbReverb::predelayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DbReverb::bassCutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void DbReverb::trebleCutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
