/****************************************************************************
** Meta object code from reading C++ file 'pw_manager.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../easyeffects-8.2.8/src/pw_manager.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pw_manager.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2pw7ManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto pw::Manager::qt_create_metaobjectdata<qt_meta_tag_ZN2pw7ManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "pw::Manager",
        "QML.Element",
        "PwManager",
        "QML.Singleton",
        "true",
        "headerVersionChanged",
        "",
        "libraryVersionChanged",
        "runtimeVersionChanged",
        "defaultClockRateChanged",
        "defaultMinQuantumChanged",
        "defaultMaxQuantumChanged",
        "defaultQuantumChanged",
        "defaultInputDeviceNameChanged",
        "defaultOutputDeviceNameChanged",
        "sourceAdded",
        "NodeInfo",
        "node",
        "sinkAdded",
        "sinkRouteChanged",
        "sourceRouteChanged",
        "linkChanged",
        "LinkInfo",
        "link",
        "linkRemoved",
        "setNodeMute",
        "serial",
        "state",
        "setNodeVolume",
        "n_vol_ch",
        "value",
        "connectStreamOutput",
        "id",
        "connectStreamInput",
        "disconnectStream",
        "headerVersion",
        "libraryVersion",
        "runtimeVersion",
        "defaultClockRate",
        "defaultMinQuantum",
        "defaultMaxQuantum",
        "defaultQuantum",
        "defaultOutputDeviceName",
        "defaultInputDeviceName"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'headerVersionChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'libraryVersionChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'runtimeVersionChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultClockRateChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultMinQuantumChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultMaxQuantumChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultQuantumChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultInputDeviceNameChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultOutputDeviceNameChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceAdded'
        QtMocHelpers::SignalData<void(NodeInfo)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'sinkAdded'
        QtMocHelpers::SignalData<void(NodeInfo)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'sinkRouteChanged'
        QtMocHelpers::SignalData<void(NodeInfo)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'sourceRouteChanged'
        QtMocHelpers::SignalData<void(NodeInfo)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'linkChanged'
        QtMocHelpers::SignalData<void(LinkInfo)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Signal 'linkRemoved'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'setNodeMute'
        QtMocHelpers::MethodData<void(const uint &, const bool &)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 26 }, { QMetaType::Bool, 27 },
        }}),
        // Method 'setNodeVolume'
        QtMocHelpers::MethodData<void(const uint &, const uint &, const float &)>(28, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 26 }, { QMetaType::UInt, 29 }, { QMetaType::Float, 30 },
        }}),
        // Method 'connectStreamOutput'
        QtMocHelpers::MethodData<void(const uint &) const>(31, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 32 },
        }}),
        // Method 'connectStreamInput'
        QtMocHelpers::MethodData<void(const uint &) const>(33, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 32 },
        }}),
        // Method 'disconnectStream'
        QtMocHelpers::MethodData<void(const uint &) const>(34, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 32 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'headerVersion'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'libraryVersion'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'runtimeVersion'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'defaultClockRate'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 3),
        // property 'defaultMinQuantum'
        QtMocHelpers::PropertyData<QString>(39, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 4),
        // property 'defaultMaxQuantum'
        QtMocHelpers::PropertyData<QString>(40, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 5),
        // property 'defaultQuantum'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 6),
        // property 'defaultOutputDeviceName'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 8),
        // property 'defaultInputDeviceName'
        QtMocHelpers::PropertyData<QString>(43, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Manager, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject pw::Manager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2pw7ManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2pw7ManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2pw7ManagerE_t>.metaTypes,
    nullptr
} };

void pw::Manager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Manager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->headerVersionChanged(); break;
        case 1: _t->libraryVersionChanged(); break;
        case 2: _t->runtimeVersionChanged(); break;
        case 3: _t->defaultClockRateChanged(); break;
        case 4: _t->defaultMinQuantumChanged(); break;
        case 5: _t->defaultMaxQuantumChanged(); break;
        case 6: _t->defaultQuantumChanged(); break;
        case 7: _t->defaultInputDeviceNameChanged(); break;
        case 8: _t->defaultOutputDeviceNameChanged(); break;
        case 9: _t->sourceAdded((*reinterpret_cast<std::add_pointer_t<NodeInfo>>(_a[1]))); break;
        case 10: _t->sinkAdded((*reinterpret_cast<std::add_pointer_t<NodeInfo>>(_a[1]))); break;
        case 11: _t->sinkRouteChanged((*reinterpret_cast<std::add_pointer_t<NodeInfo>>(_a[1]))); break;
        case 12: _t->sourceRouteChanged((*reinterpret_cast<std::add_pointer_t<NodeInfo>>(_a[1]))); break;
        case 13: _t->linkChanged((*reinterpret_cast<std::add_pointer_t<LinkInfo>>(_a[1]))); break;
        case 14: _t->linkRemoved(); break;
        case 15: _t->setNodeMute((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 16: _t->setNodeVolume((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[3]))); break;
        case 17: _t->connectStreamOutput((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 18: _t->connectStreamInput((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 19: _t->disconnectStream((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Manager::*)()>(_a, &Manager::headerVersionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)()>(_a, &Manager::libraryVersionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)()>(_a, &Manager::runtimeVersionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)()>(_a, &Manager::defaultClockRateChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)()>(_a, &Manager::defaultMinQuantumChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)()>(_a, &Manager::defaultMaxQuantumChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)()>(_a, &Manager::defaultQuantumChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)()>(_a, &Manager::defaultInputDeviceNameChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)()>(_a, &Manager::defaultOutputDeviceNameChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(NodeInfo )>(_a, &Manager::sourceAdded, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(NodeInfo )>(_a, &Manager::sinkAdded, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(NodeInfo )>(_a, &Manager::sinkRouteChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(NodeInfo )>(_a, &Manager::sourceRouteChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(LinkInfo )>(_a, &Manager::linkChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)()>(_a, &Manager::linkRemoved, 14))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->headerVersion; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->libraryVersion; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->runtimeVersion; break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->defaultClockRate; break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->defaultMinQuantum; break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->defaultMaxQuantum; break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->defaultQuantum; break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->defaultOutputDeviceName; break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->defaultInputDeviceName; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->headerVersion, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->headerVersionChanged();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->libraryVersion, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->libraryVersionChanged();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->runtimeVersion, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->runtimeVersionChanged();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->defaultClockRate, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->defaultClockRateChanged();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->defaultMinQuantum, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->defaultMinQuantumChanged();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->defaultMaxQuantum, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->defaultMaxQuantumChanged();
            break;
        case 6:
            if (QtMocHelpers::setProperty(_t->defaultQuantum, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->defaultQuantumChanged();
            break;
        case 7:
            if (QtMocHelpers::setProperty(_t->defaultOutputDeviceName, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->defaultOutputDeviceNameChanged();
            break;
        case 8:
            if (QtMocHelpers::setProperty(_t->defaultInputDeviceName, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->defaultInputDeviceNameChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *pw::Manager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *pw::Manager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2pw7ManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int pw::Manager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void pw::Manager::headerVersionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void pw::Manager::libraryVersionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void pw::Manager::runtimeVersionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void pw::Manager::defaultClockRateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void pw::Manager::defaultMinQuantumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void pw::Manager::defaultMaxQuantumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void pw::Manager::defaultQuantumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void pw::Manager::defaultInputDeviceNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void pw::Manager::defaultOutputDeviceNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void pw::Manager::sourceAdded(NodeInfo _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void pw::Manager::sinkAdded(NodeInfo _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void pw::Manager::sinkRouteChanged(NodeInfo _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void pw::Manager::sourceRouteChanged(NodeInfo _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void pw::Manager::linkChanged(LinkInfo _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void pw::Manager::linkRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}
QT_WARNING_POP
