/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db_pitch.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db_pitch.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db_pitch.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7DbPitchE_t {};
} // unnamed namespace

template <> constexpr inline auto DbPitch::qt_create_metaobjectdata<qt_meta_tag_ZN7DbPitchE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbPitch",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "bypassChanged",
        "inputGainChanged",
        "outputGainChanged",
        "dryChanged",
        "wetChanged",
        "centsChanged",
        "semitonesChanged",
        "octavesChanged",
        "quickSeekChanged",
        "antiAliasChanged",
        "sequenceLengthChanged",
        "seekWindowChanged",
        "overlapLengthChanged",
        "tempoDifferenceChanged",
        "rateDifferenceChanged",
        "bypass",
        "isBypassImmutable",
        "defaultBypassValue",
        "inputGain",
        "isInputGainImmutable",
        "defaultInputGainValue",
        "outputGain",
        "isOutputGainImmutable",
        "defaultOutputGainValue",
        "dry",
        "isDryImmutable",
        "defaultDryValue",
        "wet",
        "isWetImmutable",
        "defaultWetValue",
        "cents",
        "isCentsImmutable",
        "defaultCentsValue",
        "semitones",
        "isSemitonesImmutable",
        "defaultSemitonesValue",
        "octaves",
        "isOctavesImmutable",
        "defaultOctavesValue",
        "quickSeek",
        "isQuickSeekImmutable",
        "defaultQuickSeekValue",
        "antiAlias",
        "isAntiAliasImmutable",
        "defaultAntiAliasValue",
        "sequenceLength",
        "isSequenceLengthImmutable",
        "defaultSequenceLengthValue",
        "seekWindow",
        "isSeekWindowImmutable",
        "defaultSeekWindowValue",
        "overlapLength",
        "isOverlapLengthImmutable",
        "defaultOverlapLengthValue",
        "tempoDifference",
        "isTempoDifferenceImmutable",
        "defaultTempoDifferenceValue",
        "rateDifference",
        "isRateDifferenceImmutable",
        "defaultRateDifferenceValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bypassChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputGainChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputGainChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dryChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wetChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'centsChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'semitonesChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'octavesChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'quickSeekChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'antiAliasChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sequenceLengthChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seekWindowChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'overlapLengthChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tempoDifferenceChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rateDifferenceChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bypass'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isBypassImmutable'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassValue'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputGain'
        QtMocHelpers::PropertyData<double>(25, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isInputGainImmutable'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputGainValue'
        QtMocHelpers::PropertyData<double>(27, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'outputGain'
        QtMocHelpers::PropertyData<double>(28, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isOutputGainImmutable'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOutputGainValue'
        QtMocHelpers::PropertyData<double>(30, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dry'
        QtMocHelpers::PropertyData<double>(31, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isDryImmutable'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDryValue'
        QtMocHelpers::PropertyData<double>(33, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'wet'
        QtMocHelpers::PropertyData<double>(34, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isWetImmutable'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWetValue'
        QtMocHelpers::PropertyData<double>(36, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'cents'
        QtMocHelpers::PropertyData<double>(37, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isCentsImmutable'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCentsValue'
        QtMocHelpers::PropertyData<double>(39, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'semitones'
        QtMocHelpers::PropertyData<double>(40, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isSemitonesImmutable'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSemitonesValue'
        QtMocHelpers::PropertyData<double>(42, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'octaves'
        QtMocHelpers::PropertyData<double>(43, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isOctavesImmutable'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOctavesValue'
        QtMocHelpers::PropertyData<double>(45, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'quickSeek'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isQuickSeekImmutable'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultQuickSeekValue'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'antiAlias'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isAntiAliasImmutable'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAntiAliasValue'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sequenceLength'
        QtMocHelpers::PropertyData<int>(52, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isSequenceLengthImmutable'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSequenceLengthValue'
        QtMocHelpers::PropertyData<int>(54, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'seekWindow'
        QtMocHelpers::PropertyData<int>(55, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isSeekWindowImmutable'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSeekWindowValue'
        QtMocHelpers::PropertyData<int>(57, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'overlapLength'
        QtMocHelpers::PropertyData<int>(58, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isOverlapLengthImmutable'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOverlapLengthValue'
        QtMocHelpers::PropertyData<int>(60, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tempoDifference'
        QtMocHelpers::PropertyData<double>(61, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isTempoDifferenceImmutable'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTempoDifferenceValue'
        QtMocHelpers::PropertyData<double>(63, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rateDifference'
        QtMocHelpers::PropertyData<double>(64, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isRateDifferenceImmutable'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRateDifferenceValue'
        QtMocHelpers::PropertyData<double>(66, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DbPitch, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbPitch::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7DbPitchE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7DbPitchE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7DbPitchE_t>.metaTypes,
    nullptr
} };

void DbPitch::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbPitch *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bypassChanged(); break;
        case 1: _t->inputGainChanged(); break;
        case 2: _t->outputGainChanged(); break;
        case 3: _t->dryChanged(); break;
        case 4: _t->wetChanged(); break;
        case 5: _t->centsChanged(); break;
        case 6: _t->semitonesChanged(); break;
        case 7: _t->octavesChanged(); break;
        case 8: _t->quickSeekChanged(); break;
        case 9: _t->antiAliasChanged(); break;
        case 10: _t->sequenceLengthChanged(); break;
        case 11: _t->seekWindowChanged(); break;
        case 12: _t->overlapLengthChanged(); break;
        case 13: _t->tempoDifferenceChanged(); break;
        case 14: _t->rateDifferenceChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbPitch::*)()>(_a, &DbPitch::bypassChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbPitch::*)()>(_a, &DbPitch::inputGainChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbPitch::*)()>(_a, &DbPitch::outputGainChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbPitch::*)()>(_a, &DbPitch::dryChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbPitch::*)()>(_a, &DbPitch::wetChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbPitch::*)()>(_a, &DbPitch::centsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbPitch::*)()>(_a, &DbPitch::semitonesChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbPitch::*)()>(_a, &DbPitch::octavesChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbPitch::*)()>(_a, &DbPitch::quickSeekChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbPitch::*)()>(_a, &DbPitch::antiAliasChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbPitch::*)()>(_a, &DbPitch::sequenceLengthChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbPitch::*)()>(_a, &DbPitch::seekWindowChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbPitch::*)()>(_a, &DbPitch::overlapLengthChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbPitch::*)()>(_a, &DbPitch::tempoDifferenceChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbPitch::*)()>(_a, &DbPitch::rateDifferenceChanged, 14))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bypass(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isBypassImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultBypassValue(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->inputGain(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isInputGainImmutable(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->defaultInputGainValue(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->outputGain(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isOutputGainImmutable(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->defaultOutputGainValue(); break;
        case 9: *reinterpret_cast<double*>(_v) = _t->dry(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isDryImmutable(); break;
        case 11: *reinterpret_cast<double*>(_v) = _t->defaultDryValue(); break;
        case 12: *reinterpret_cast<double*>(_v) = _t->wet(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isWetImmutable(); break;
        case 14: *reinterpret_cast<double*>(_v) = _t->defaultWetValue(); break;
        case 15: *reinterpret_cast<double*>(_v) = _t->cents(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isCentsImmutable(); break;
        case 17: *reinterpret_cast<double*>(_v) = _t->defaultCentsValue(); break;
        case 18: *reinterpret_cast<double*>(_v) = _t->semitones(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isSemitonesImmutable(); break;
        case 20: *reinterpret_cast<double*>(_v) = _t->defaultSemitonesValue(); break;
        case 21: *reinterpret_cast<double*>(_v) = _t->octaves(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isOctavesImmutable(); break;
        case 23: *reinterpret_cast<double*>(_v) = _t->defaultOctavesValue(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->quickSeek(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isQuickSeekImmutable(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->defaultQuickSeekValue(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->antiAlias(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isAntiAliasImmutable(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->defaultAntiAliasValue(); break;
        case 30: *reinterpret_cast<int*>(_v) = _t->sequenceLength(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isSequenceLengthImmutable(); break;
        case 32: *reinterpret_cast<int*>(_v) = _t->defaultSequenceLengthValue(); break;
        case 33: *reinterpret_cast<int*>(_v) = _t->seekWindow(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isSeekWindowImmutable(); break;
        case 35: *reinterpret_cast<int*>(_v) = _t->defaultSeekWindowValue(); break;
        case 36: *reinterpret_cast<int*>(_v) = _t->overlapLength(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isOverlapLengthImmutable(); break;
        case 38: *reinterpret_cast<int*>(_v) = _t->defaultOverlapLengthValue(); break;
        case 39: *reinterpret_cast<double*>(_v) = _t->tempoDifference(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->isTempoDifferenceImmutable(); break;
        case 41: *reinterpret_cast<double*>(_v) = _t->defaultTempoDifferenceValue(); break;
        case 42: *reinterpret_cast<double*>(_v) = _t->rateDifference(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->isRateDifferenceImmutable(); break;
        case 44: *reinterpret_cast<double*>(_v) = _t->defaultRateDifferenceValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBypass(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setInputGain(*reinterpret_cast<double*>(_v)); break;
        case 6: _t->setOutputGain(*reinterpret_cast<double*>(_v)); break;
        case 9: _t->setDry(*reinterpret_cast<double*>(_v)); break;
        case 12: _t->setWet(*reinterpret_cast<double*>(_v)); break;
        case 15: _t->setCents(*reinterpret_cast<double*>(_v)); break;
        case 18: _t->setSemitones(*reinterpret_cast<double*>(_v)); break;
        case 21: _t->setOctaves(*reinterpret_cast<double*>(_v)); break;
        case 24: _t->setQuickSeek(*reinterpret_cast<bool*>(_v)); break;
        case 27: _t->setAntiAlias(*reinterpret_cast<bool*>(_v)); break;
        case 30: _t->setSequenceLength(*reinterpret_cast<int*>(_v)); break;
        case 33: _t->setSeekWindow(*reinterpret_cast<int*>(_v)); break;
        case 36: _t->setOverlapLength(*reinterpret_cast<int*>(_v)); break;
        case 39: _t->setTempoDifference(*reinterpret_cast<double*>(_v)); break;
        case 42: _t->setRateDifference(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbPitch::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbPitch::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7DbPitchE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbPitch::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    return _id;
}

// SIGNAL 0
void DbPitch::bypassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbPitch::inputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbPitch::outputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbPitch::dryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DbPitch::wetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DbPitch::centsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DbPitch::semitonesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DbPitch::octavesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DbPitch::quickSeekChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DbPitch::antiAliasChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DbPitch::sequenceLengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DbPitch::seekWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void DbPitch::overlapLengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void DbPitch::tempoDifferenceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void DbPitch::rateDifferenceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}
QT_WARNING_POP
