/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db_equalizer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db_equalizer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db_equalizer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11DbEqualizerE_t {};
} // unnamed namespace

template <> constexpr inline auto DbEqualizer::qt_create_metaobjectdata<qt_meta_tag_ZN11DbEqualizerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbEqualizer",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "bypassChanged",
        "inputGainChanged",
        "outputGainChanged",
        "numBandsChanged",
        "modeLabelsChanged",
        "modeChanged",
        "splitChannelsChanged",
        "balanceChanged",
        "pitchLeftChanged",
        "pitchRightChanged",
        "viewLeftChannelChanged",
        "decrampLabelsChanged",
        "decrampChanged",
        "bypass",
        "isBypassImmutable",
        "defaultBypassValue",
        "inputGain",
        "isInputGainImmutable",
        "defaultInputGainValue",
        "outputGain",
        "isOutputGainImmutable",
        "defaultOutputGainValue",
        "numBands",
        "isNumBandsImmutable",
        "defaultNumBandsValue",
        "modeLabels",
        "isModeLabelsImmutable",
        "defaultModeLabelsValue",
        "mode",
        "isModeImmutable",
        "defaultModeValue",
        "splitChannels",
        "isSplitChannelsImmutable",
        "defaultSplitChannelsValue",
        "balance",
        "isBalanceImmutable",
        "defaultBalanceValue",
        "pitchLeft",
        "isPitchLeftImmutable",
        "defaultPitchLeftValue",
        "pitchRight",
        "isPitchRightImmutable",
        "defaultPitchRightValue",
        "viewLeftChannel",
        "isViewLeftChannelImmutable",
        "defaultViewLeftChannelValue",
        "decrampLabels",
        "isDecrampLabelsImmutable",
        "defaultDecrampLabelsValue",
        "decramp",
        "isDecrampImmutable",
        "defaultDecrampValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bypassChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputGainChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputGainChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'numBandsChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeLabelsChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'splitChannelsChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'balanceChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pitchLeftChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pitchRightChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'viewLeftChannelChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'decrampLabelsChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'decrampChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bypass'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isBypassImmutable'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassValue'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputGain'
        QtMocHelpers::PropertyData<double>(23, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isInputGainImmutable'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputGainValue'
        QtMocHelpers::PropertyData<double>(25, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'outputGain'
        QtMocHelpers::PropertyData<double>(26, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isOutputGainImmutable'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOutputGainValue'
        QtMocHelpers::PropertyData<double>(28, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'numBands'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isNumBandsImmutable'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNumBandsValue'
        QtMocHelpers::PropertyData<int>(31, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'modeLabels'
        QtMocHelpers::PropertyData<QStringList>(32, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isModeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultModeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(34, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mode'
        QtMocHelpers::PropertyData<int>(35, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isModeImmutable'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultModeValue'
        QtMocHelpers::PropertyData<int>(37, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'splitChannels'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isSplitChannelsImmutable'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSplitChannelsValue'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'balance'
        QtMocHelpers::PropertyData<double>(41, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isBalanceImmutable'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBalanceValue'
        QtMocHelpers::PropertyData<double>(43, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pitchLeft'
        QtMocHelpers::PropertyData<double>(44, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isPitchLeftImmutable'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPitchLeftValue'
        QtMocHelpers::PropertyData<double>(46, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pitchRight'
        QtMocHelpers::PropertyData<double>(47, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isPitchRightImmutable'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPitchRightValue'
        QtMocHelpers::PropertyData<double>(49, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'viewLeftChannel'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isViewLeftChannelImmutable'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultViewLeftChannelValue'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'decrampLabels'
        QtMocHelpers::PropertyData<QStringList>(53, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isDecrampLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDecrampLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(55, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'decramp'
        QtMocHelpers::PropertyData<int>(56, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isDecrampImmutable'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDecrampValue'
        QtMocHelpers::PropertyData<int>(58, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DbEqualizer, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbEqualizer::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DbEqualizerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DbEqualizerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11DbEqualizerE_t>.metaTypes,
    nullptr
} };

void DbEqualizer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbEqualizer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bypassChanged(); break;
        case 1: _t->inputGainChanged(); break;
        case 2: _t->outputGainChanged(); break;
        case 3: _t->numBandsChanged(); break;
        case 4: _t->modeLabelsChanged(); break;
        case 5: _t->modeChanged(); break;
        case 6: _t->splitChannelsChanged(); break;
        case 7: _t->balanceChanged(); break;
        case 8: _t->pitchLeftChanged(); break;
        case 9: _t->pitchRightChanged(); break;
        case 10: _t->viewLeftChannelChanged(); break;
        case 11: _t->decrampLabelsChanged(); break;
        case 12: _t->decrampChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbEqualizer::*)()>(_a, &DbEqualizer::bypassChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizer::*)()>(_a, &DbEqualizer::inputGainChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizer::*)()>(_a, &DbEqualizer::outputGainChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizer::*)()>(_a, &DbEqualizer::numBandsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizer::*)()>(_a, &DbEqualizer::modeLabelsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizer::*)()>(_a, &DbEqualizer::modeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizer::*)()>(_a, &DbEqualizer::splitChannelsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizer::*)()>(_a, &DbEqualizer::balanceChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizer::*)()>(_a, &DbEqualizer::pitchLeftChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizer::*)()>(_a, &DbEqualizer::pitchRightChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizer::*)()>(_a, &DbEqualizer::viewLeftChannelChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizer::*)()>(_a, &DbEqualizer::decrampLabelsChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizer::*)()>(_a, &DbEqualizer::decrampChanged, 12))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bypass(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isBypassImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultBypassValue(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->inputGain(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isInputGainImmutable(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->defaultInputGainValue(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->outputGain(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isOutputGainImmutable(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->defaultOutputGainValue(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->numBands(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isNumBandsImmutable(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->defaultNumBandsValue(); break;
        case 12: *reinterpret_cast<QStringList*>(_v) = _t->modeLabels(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isModeLabelsImmutable(); break;
        case 14: *reinterpret_cast<QStringList*>(_v) = _t->defaultModeLabelsValue(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->mode(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isModeImmutable(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->defaultModeValue(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->splitChannels(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isSplitChannelsImmutable(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->defaultSplitChannelsValue(); break;
        case 21: *reinterpret_cast<double*>(_v) = _t->balance(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isBalanceImmutable(); break;
        case 23: *reinterpret_cast<double*>(_v) = _t->defaultBalanceValue(); break;
        case 24: *reinterpret_cast<double*>(_v) = _t->pitchLeft(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isPitchLeftImmutable(); break;
        case 26: *reinterpret_cast<double*>(_v) = _t->defaultPitchLeftValue(); break;
        case 27: *reinterpret_cast<double*>(_v) = _t->pitchRight(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isPitchRightImmutable(); break;
        case 29: *reinterpret_cast<double*>(_v) = _t->defaultPitchRightValue(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->viewLeftChannel(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isViewLeftChannelImmutable(); break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->defaultViewLeftChannelValue(); break;
        case 33: *reinterpret_cast<QStringList*>(_v) = _t->decrampLabels(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isDecrampLabelsImmutable(); break;
        case 35: *reinterpret_cast<QStringList*>(_v) = _t->defaultDecrampLabelsValue(); break;
        case 36: *reinterpret_cast<int*>(_v) = _t->decramp(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isDecrampImmutable(); break;
        case 38: *reinterpret_cast<int*>(_v) = _t->defaultDecrampValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBypass(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setInputGain(*reinterpret_cast<double*>(_v)); break;
        case 6: _t->setOutputGain(*reinterpret_cast<double*>(_v)); break;
        case 9: _t->setNumBands(*reinterpret_cast<int*>(_v)); break;
        case 12: _t->setModeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 15: _t->setMode(*reinterpret_cast<int*>(_v)); break;
        case 18: _t->setSplitChannels(*reinterpret_cast<bool*>(_v)); break;
        case 21: _t->setBalance(*reinterpret_cast<double*>(_v)); break;
        case 24: _t->setPitchLeft(*reinterpret_cast<double*>(_v)); break;
        case 27: _t->setPitchRight(*reinterpret_cast<double*>(_v)); break;
        case 30: _t->setViewLeftChannel(*reinterpret_cast<bool*>(_v)); break;
        case 33: _t->setDecrampLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 36: _t->setDecramp(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbEqualizer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbEqualizer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DbEqualizerE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbEqualizer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    return _id;
}

// SIGNAL 0
void DbEqualizer::bypassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbEqualizer::inputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbEqualizer::outputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbEqualizer::numBandsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DbEqualizer::modeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DbEqualizer::modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DbEqualizer::splitChannelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DbEqualizer::balanceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DbEqualizer::pitchLeftChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DbEqualizer::pitchRightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DbEqualizer::viewLeftChannelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DbEqualizer::decrampLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void DbEqualizer::decrampChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
