/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db_spectrum.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db_spectrum.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db_spectrum.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10DbSpectrumE_t {};
} // unnamed namespace

template <> constexpr inline auto DbSpectrum::qt_create_metaobjectdata<qt_meta_tag_ZN10DbSpectrumE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbSpectrum",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "stateChanged",
        "",
        "dynamicYScaleChanged",
        "logarithmicHorizontalAxisChanged",
        "spectrumShapeChanged",
        "nPointsChanged",
        "heightChanged",
        "minimumFrequencyChanged",
        "maximumFrequencyChanged",
        "avsyncDelayChanged",
        "spectrumFpsCapChanged",
        "state",
        "isStateImmutable",
        "defaultStateValue",
        "dynamicYScale",
        "isDynamicYScaleImmutable",
        "defaultDynamicYScaleValue",
        "logarithmicHorizontalAxis",
        "isLogarithmicHorizontalAxisImmutable",
        "defaultLogarithmicHorizontalAxisValue",
        "spectrumShape",
        "isSpectrumShapeImmutable",
        "defaultSpectrumShapeValue",
        "nPoints",
        "isNPointsImmutable",
        "defaultNPointsValue",
        "height",
        "isHeightImmutable",
        "defaultHeightValue",
        "minimumFrequency",
        "isMinimumFrequencyImmutable",
        "defaultMinimumFrequencyValue",
        "maximumFrequency",
        "isMaximumFrequencyImmutable",
        "defaultMaximumFrequencyValue",
        "avsyncDelay",
        "isAvsyncDelayImmutable",
        "defaultAvsyncDelayValue",
        "spectrumFpsCap",
        "isSpectrumFpsCapImmutable",
        "defaultSpectrumFpsCapValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dynamicYScaleChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'logarithmicHorizontalAxisChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'spectrumShapeChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nPointsChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'heightChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimumFrequencyChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximumFrequencyChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'avsyncDelayChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'spectrumFpsCapChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'state'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isStateImmutable'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultStateValue'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dynamicYScale'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isDynamicYScaleImmutable'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDynamicYScaleValue'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'logarithmicHorizontalAxis'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isLogarithmicHorizontalAxisImmutable'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLogarithmicHorizontalAxisValue'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'spectrumShape'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isSpectrumShapeImmutable'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSpectrumShapeValue'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'nPoints'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isNPointsImmutable'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNPointsValue'
        QtMocHelpers::PropertyData<int>(30, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'height'
        QtMocHelpers::PropertyData<int>(31, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isHeightImmutable'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultHeightValue'
        QtMocHelpers::PropertyData<int>(33, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'minimumFrequency'
        QtMocHelpers::PropertyData<int>(34, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isMinimumFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMinimumFrequencyValue'
        QtMocHelpers::PropertyData<int>(36, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maximumFrequency'
        QtMocHelpers::PropertyData<int>(37, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isMaximumFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMaximumFrequencyValue'
        QtMocHelpers::PropertyData<int>(39, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'avsyncDelay'
        QtMocHelpers::PropertyData<int>(40, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isAvsyncDelayImmutable'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAvsyncDelayValue'
        QtMocHelpers::PropertyData<int>(42, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'spectrumFpsCap'
        QtMocHelpers::PropertyData<int>(43, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isSpectrumFpsCapImmutable'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSpectrumFpsCapValue'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DbSpectrum, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbSpectrum::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10DbSpectrumE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10DbSpectrumE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10DbSpectrumE_t>.metaTypes,
    nullptr
} };

void DbSpectrum::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbSpectrum *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stateChanged(); break;
        case 1: _t->dynamicYScaleChanged(); break;
        case 2: _t->logarithmicHorizontalAxisChanged(); break;
        case 3: _t->spectrumShapeChanged(); break;
        case 4: _t->nPointsChanged(); break;
        case 5: _t->heightChanged(); break;
        case 6: _t->minimumFrequencyChanged(); break;
        case 7: _t->maximumFrequencyChanged(); break;
        case 8: _t->avsyncDelayChanged(); break;
        case 9: _t->spectrumFpsCapChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbSpectrum::*)()>(_a, &DbSpectrum::stateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbSpectrum::*)()>(_a, &DbSpectrum::dynamicYScaleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbSpectrum::*)()>(_a, &DbSpectrum::logarithmicHorizontalAxisChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbSpectrum::*)()>(_a, &DbSpectrum::spectrumShapeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbSpectrum::*)()>(_a, &DbSpectrum::nPointsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbSpectrum::*)()>(_a, &DbSpectrum::heightChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbSpectrum::*)()>(_a, &DbSpectrum::minimumFrequencyChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbSpectrum::*)()>(_a, &DbSpectrum::maximumFrequencyChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbSpectrum::*)()>(_a, &DbSpectrum::avsyncDelayChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbSpectrum::*)()>(_a, &DbSpectrum::spectrumFpsCapChanged, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->state(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isStateImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultStateValue(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->dynamicYScale(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isDynamicYScaleImmutable(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->defaultDynamicYScaleValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->logarithmicHorizontalAxis(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isLogarithmicHorizontalAxisImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultLogarithmicHorizontalAxisValue(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->spectrumShape(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isSpectrumShapeImmutable(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->defaultSpectrumShapeValue(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->nPoints(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isNPointsImmutable(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->defaultNPointsValue(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->height(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isHeightImmutable(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->defaultHeightValue(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->minimumFrequency(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isMinimumFrequencyImmutable(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->defaultMinimumFrequencyValue(); break;
        case 21: *reinterpret_cast<int*>(_v) = _t->maximumFrequency(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isMaximumFrequencyImmutable(); break;
        case 23: *reinterpret_cast<int*>(_v) = _t->defaultMaximumFrequencyValue(); break;
        case 24: *reinterpret_cast<int*>(_v) = _t->avsyncDelay(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isAvsyncDelayImmutable(); break;
        case 26: *reinterpret_cast<int*>(_v) = _t->defaultAvsyncDelayValue(); break;
        case 27: *reinterpret_cast<int*>(_v) = _t->spectrumFpsCap(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isSpectrumFpsCapImmutable(); break;
        case 29: *reinterpret_cast<int*>(_v) = _t->defaultSpectrumFpsCapValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setState(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setDynamicYScale(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setLogarithmicHorizontalAxis(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setSpectrumShape(*reinterpret_cast<int*>(_v)); break;
        case 12: _t->setNPoints(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setHeight(*reinterpret_cast<int*>(_v)); break;
        case 18: _t->setMinimumFrequency(*reinterpret_cast<int*>(_v)); break;
        case 21: _t->setMaximumFrequency(*reinterpret_cast<int*>(_v)); break;
        case 24: _t->setAvsyncDelay(*reinterpret_cast<int*>(_v)); break;
        case 27: _t->setSpectrumFpsCap(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbSpectrum::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbSpectrum::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10DbSpectrumE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbSpectrum::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    return _id;
}

// SIGNAL 0
void DbSpectrum::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbSpectrum::dynamicYScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbSpectrum::logarithmicHorizontalAxisChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbSpectrum::spectrumShapeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DbSpectrum::nPointsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DbSpectrum::heightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DbSpectrum::minimumFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DbSpectrum::maximumFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DbSpectrum::avsyncDelayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DbSpectrum::spectrumFpsCapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
