/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db_echo_canceller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db_echo_canceller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db_echo_canceller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15DbEchoCancellerE_t {};
} // unnamed namespace

template <> constexpr inline auto DbEchoCanceller::qt_create_metaobjectdata<qt_meta_tag_ZN15DbEchoCancellerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbEchoCanceller",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "bypassChanged",
        "inputGainChanged",
        "outputGainChanged",
        "enableEchoCancellerChanged",
        "echoCancellerMobileModeChanged",
        "echoCancellerEnforceHighPassChanged",
        "enableNoiseSuppressionChanged",
        "noiseSuppressionLevelLabelsChanged",
        "noiseSuppressionLevelChanged",
        "enableHighPassFilterChanged",
        "highPassFilterFullBandChanged",
        "enableAGCChanged",
        "bypass",
        "isBypassImmutable",
        "defaultBypassValue",
        "inputGain",
        "isInputGainImmutable",
        "defaultInputGainValue",
        "outputGain",
        "isOutputGainImmutable",
        "defaultOutputGainValue",
        "enableEchoCanceller",
        "isEnableEchoCancellerImmutable",
        "defaultEnableEchoCancellerValue",
        "echoCancellerMobileMode",
        "isEchoCancellerMobileModeImmutable",
        "defaultEchoCancellerMobileModeValue",
        "echoCancellerEnforceHighPass",
        "isEchoCancellerEnforceHighPassImmutable",
        "defaultEchoCancellerEnforceHighPassValue",
        "enableNoiseSuppression",
        "isEnableNoiseSuppressionImmutable",
        "defaultEnableNoiseSuppressionValue",
        "noiseSuppressionLevelLabels",
        "isNoiseSuppressionLevelLabelsImmutable",
        "defaultNoiseSuppressionLevelLabelsValue",
        "noiseSuppressionLevel",
        "isNoiseSuppressionLevelImmutable",
        "defaultNoiseSuppressionLevelValue",
        "enableHighPassFilter",
        "isEnableHighPassFilterImmutable",
        "defaultEnableHighPassFilterValue",
        "highPassFilterFullBand",
        "isHighPassFilterFullBandImmutable",
        "defaultHighPassFilterFullBandValue",
        "enableAGC",
        "isEnableAGCImmutable",
        "defaultEnableAGCValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bypassChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputGainChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputGainChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableEchoCancellerChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'echoCancellerMobileModeChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'echoCancellerEnforceHighPassChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableNoiseSuppressionChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noiseSuppressionLevelLabelsChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'noiseSuppressionLevelChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableHighPassFilterChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'highPassFilterFullBandChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableAGCChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bypass'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isBypassImmutable'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassValue'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputGain'
        QtMocHelpers::PropertyData<double>(22, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isInputGainImmutable'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputGainValue'
        QtMocHelpers::PropertyData<double>(24, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'outputGain'
        QtMocHelpers::PropertyData<double>(25, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isOutputGainImmutable'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOutputGainValue'
        QtMocHelpers::PropertyData<double>(27, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enableEchoCanceller'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isEnableEchoCancellerImmutable'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnableEchoCancellerValue'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'echoCancellerMobileMode'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isEchoCancellerMobileModeImmutable'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEchoCancellerMobileModeValue'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'echoCancellerEnforceHighPass'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isEchoCancellerEnforceHighPassImmutable'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEchoCancellerEnforceHighPassValue'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enableNoiseSuppression'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isEnableNoiseSuppressionImmutable'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnableNoiseSuppressionValue'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'noiseSuppressionLevelLabels'
        QtMocHelpers::PropertyData<QStringList>(40, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isNoiseSuppressionLevelLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNoiseSuppressionLevelLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(42, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'noiseSuppressionLevel'
        QtMocHelpers::PropertyData<int>(43, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isNoiseSuppressionLevelImmutable'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNoiseSuppressionLevelValue'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enableHighPassFilter'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isEnableHighPassFilterImmutable'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnableHighPassFilterValue'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'highPassFilterFullBand'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isHighPassFilterFullBandImmutable'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultHighPassFilterFullBandValue'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enableAGC'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isEnableAGCImmutable'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnableAGCValue'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DbEchoCanceller, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbEchoCanceller::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DbEchoCancellerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DbEchoCancellerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15DbEchoCancellerE_t>.metaTypes,
    nullptr
} };

void DbEchoCanceller::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbEchoCanceller *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bypassChanged(); break;
        case 1: _t->inputGainChanged(); break;
        case 2: _t->outputGainChanged(); break;
        case 3: _t->enableEchoCancellerChanged(); break;
        case 4: _t->echoCancellerMobileModeChanged(); break;
        case 5: _t->echoCancellerEnforceHighPassChanged(); break;
        case 6: _t->enableNoiseSuppressionChanged(); break;
        case 7: _t->noiseSuppressionLevelLabelsChanged(); break;
        case 8: _t->noiseSuppressionLevelChanged(); break;
        case 9: _t->enableHighPassFilterChanged(); break;
        case 10: _t->highPassFilterFullBandChanged(); break;
        case 11: _t->enableAGCChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbEchoCanceller::*)()>(_a, &DbEchoCanceller::bypassChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEchoCanceller::*)()>(_a, &DbEchoCanceller::inputGainChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEchoCanceller::*)()>(_a, &DbEchoCanceller::outputGainChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEchoCanceller::*)()>(_a, &DbEchoCanceller::enableEchoCancellerChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEchoCanceller::*)()>(_a, &DbEchoCanceller::echoCancellerMobileModeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEchoCanceller::*)()>(_a, &DbEchoCanceller::echoCancellerEnforceHighPassChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEchoCanceller::*)()>(_a, &DbEchoCanceller::enableNoiseSuppressionChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEchoCanceller::*)()>(_a, &DbEchoCanceller::noiseSuppressionLevelLabelsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEchoCanceller::*)()>(_a, &DbEchoCanceller::noiseSuppressionLevelChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEchoCanceller::*)()>(_a, &DbEchoCanceller::enableHighPassFilterChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEchoCanceller::*)()>(_a, &DbEchoCanceller::highPassFilterFullBandChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEchoCanceller::*)()>(_a, &DbEchoCanceller::enableAGCChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bypass(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isBypassImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultBypassValue(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->inputGain(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isInputGainImmutable(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->defaultInputGainValue(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->outputGain(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isOutputGainImmutable(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->defaultOutputGainValue(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->enableEchoCanceller(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isEnableEchoCancellerImmutable(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->defaultEnableEchoCancellerValue(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->echoCancellerMobileMode(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isEchoCancellerMobileModeImmutable(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->defaultEchoCancellerMobileModeValue(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->echoCancellerEnforceHighPass(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isEchoCancellerEnforceHighPassImmutable(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->defaultEchoCancellerEnforceHighPassValue(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->enableNoiseSuppression(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isEnableNoiseSuppressionImmutable(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->defaultEnableNoiseSuppressionValue(); break;
        case 21: *reinterpret_cast<QStringList*>(_v) = _t->noiseSuppressionLevelLabels(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isNoiseSuppressionLevelLabelsImmutable(); break;
        case 23: *reinterpret_cast<QStringList*>(_v) = _t->defaultNoiseSuppressionLevelLabelsValue(); break;
        case 24: *reinterpret_cast<int*>(_v) = _t->noiseSuppressionLevel(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isNoiseSuppressionLevelImmutable(); break;
        case 26: *reinterpret_cast<int*>(_v) = _t->defaultNoiseSuppressionLevelValue(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->enableHighPassFilter(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isEnableHighPassFilterImmutable(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->defaultEnableHighPassFilterValue(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->highPassFilterFullBand(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isHighPassFilterFullBandImmutable(); break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->defaultHighPassFilterFullBandValue(); break;
        case 33: *reinterpret_cast<bool*>(_v) = _t->enableAGC(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isEnableAGCImmutable(); break;
        case 35: *reinterpret_cast<bool*>(_v) = _t->defaultEnableAGCValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBypass(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setInputGain(*reinterpret_cast<double*>(_v)); break;
        case 6: _t->setOutputGain(*reinterpret_cast<double*>(_v)); break;
        case 9: _t->setEnableEchoCanceller(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setEchoCancellerMobileMode(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setEchoCancellerEnforceHighPass(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setEnableNoiseSuppression(*reinterpret_cast<bool*>(_v)); break;
        case 21: _t->setNoiseSuppressionLevelLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 24: _t->setNoiseSuppressionLevel(*reinterpret_cast<int*>(_v)); break;
        case 27: _t->setEnableHighPassFilter(*reinterpret_cast<bool*>(_v)); break;
        case 30: _t->setHighPassFilterFullBand(*reinterpret_cast<bool*>(_v)); break;
        case 33: _t->setEnableAGC(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbEchoCanceller::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbEchoCanceller::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DbEchoCancellerE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbEchoCanceller::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    return _id;
}

// SIGNAL 0
void DbEchoCanceller::bypassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbEchoCanceller::inputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbEchoCanceller::outputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbEchoCanceller::enableEchoCancellerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DbEchoCanceller::echoCancellerMobileModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DbEchoCanceller::echoCancellerEnforceHighPassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DbEchoCanceller::enableNoiseSuppressionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DbEchoCanceller::noiseSuppressionLevelLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DbEchoCanceller::noiseSuppressionLevelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DbEchoCanceller::enableHighPassFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DbEchoCanceller::highPassFilterFullBandChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DbEchoCanceller::enableAGCChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
