/****************************************************************************
** Meta object code from reading C++ file 'pw_model_nodes.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../easyeffects-8.2.8/src/pw_model_nodes.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pw_model_nodes.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2pw6models5NodesE_t {};
} // unnamed namespace

template <> constexpr inline auto pw::models::Nodes::qt_create_metaobjectdata<qt_meta_tag_ZN2pw6models5NodesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "pw::models::Nodes",
        "QML.Element",
        "ModelNodes",
        "QML.Singleton",
        "true",
        "getNodeName",
        "",
        "rowIndex",
        "getNodeDescription",
        "nodeName",
        "getModelIndexByName",
        "QModelIndex",
        "inputStreams",
        "QSortFilterProxyModel*",
        "outputStreams",
        "sinkDevices",
        "sourceDevices",
        "Roles",
        "Id",
        "Serial",
        "DeviceId",
        "Name",
        "Description",
        "MediaClass",
        "MediaRole",
        "AppName",
        "AppProcessId",
        "AppProcessBinary",
        "AppIconName",
        "MediaIconName",
        "DeviceIconName",
        "MediaName",
        "Format",
        "ApplicationId",
        "Priority",
        "State",
        "Mute",
        "Connected",
        "NinputPorts",
        "NoutputPorts",
        "Rate",
        "NvolumeChannels",
        "Latency",
        "Volume",
        "IsBlocklisted",
        "DeviceRouteName",
        "DeviceRouteDescription"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'getNodeName'
        QtMocHelpers::MethodData<QString(const uint &)>(5, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::UInt, 7 },
        }}),
        // Method 'getNodeDescription'
        QtMocHelpers::MethodData<QString(QString)>(8, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 9 },
        }}),
        // Method 'getModelIndexByName'
        QtMocHelpers::MethodData<QModelIndex(QString)>(10, 6, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'inputStreams'
        QtMocHelpers::PropertyData<QSortFilterProxyModel*>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'outputStreams'
        QtMocHelpers::PropertyData<QSortFilterProxyModel*>(14, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sinkDevices'
        QtMocHelpers::PropertyData<QSortFilterProxyModel*>(15, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sourceDevices'
        QtMocHelpers::PropertyData<QSortFilterProxyModel*>(16, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(17, 17, QMC::EnumIsScoped).add({
            {   18, Roles::Id },
            {   19, Roles::Serial },
            {   20, Roles::DeviceId },
            {   21, Roles::Name },
            {   22, Roles::Description },
            {   23, Roles::MediaClass },
            {   24, Roles::MediaRole },
            {   25, Roles::AppName },
            {   26, Roles::AppProcessId },
            {   27, Roles::AppProcessBinary },
            {   28, Roles::AppIconName },
            {   29, Roles::MediaIconName },
            {   30, Roles::DeviceIconName },
            {   31, Roles::MediaName },
            {   32, Roles::Format },
            {   33, Roles::ApplicationId },
            {   34, Roles::Priority },
            {   35, Roles::State },
            {   36, Roles::Mute },
            {   37, Roles::Connected },
            {   38, Roles::NinputPorts },
            {   39, Roles::NoutputPorts },
            {   40, Roles::Rate },
            {   41, Roles::NvolumeChannels },
            {   42, Roles::Latency },
            {   43, Roles::Volume },
            {   44, Roles::IsBlocklisted },
            {   45, Roles::DeviceRouteName },
            {   46, Roles::DeviceRouteDescription },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Nodes, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject pw::models::Nodes::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2pw6models5NodesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2pw6models5NodesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2pw6models5NodesE_t>.metaTypes,
    nullptr
} };

void pw::models::Nodes::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Nodes *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->getNodeName((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->getNodeDescription((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QModelIndex _r = _t->getModelIndexByName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QModelIndex*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QSortFilterProxyModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QSortFilterProxyModel**>(_v) = _t->proxy_input_streams; break;
        case 1: *reinterpret_cast<QSortFilterProxyModel**>(_v) = _t->proxy_output_streams; break;
        case 2: *reinterpret_cast<QSortFilterProxyModel**>(_v) = _t->proxy_sink_devices; break;
        case 3: *reinterpret_cast<QSortFilterProxyModel**>(_v) = _t->proxy_source_devices; break;
        default: break;
        }
    }
}

const QMetaObject *pw::models::Nodes::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *pw::models::Nodes::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2pw6models5NodesE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int pw::models::Nodes::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
