// This file is generated by kconfig_compiler_kf6 from easyeffects_db.kcfg.
// All changes you do to this file will be lost.

#include "easyeffects_db.h"

#include <qglobal.h>
#include <QFile>
#include <QQmlEngine>

class DbMainHelper
{
  public:
    DbMainHelper() noexcept : q(nullptr) {}
    ~DbMainHelper() noexcept { delete q; q = nullptr; }
    DbMainHelper(const DbMainHelper&) = delete;
    DbMainHelper& operator=(const DbMainHelper&) = delete;
    DbMain *q;
};
Q_GLOBAL_STATIC(DbMainHelper, s_globalDbMain)
DbMain *DbMain::self()
{
  if (!s_globalDbMain()->q) {
    new DbMain;
    s_globalDbMain()->q->read();
  }

  return s_globalDbMain()->q;
}

DbMain *DbMain::create(QQmlEngine *, QJSEngine *)
{
  QQmlEngine::setObjectOwnership(self(), QQmlEngine::CppOwnership);
  return self();
}

DbMain::DbMain( )
  : KConfigBaseEE( QStringLiteral( "easyeffects/db/easyeffectsrc" ) )
{
  Q_ASSERT(!s_globalDbMain()->q);
  s_globalDbMain()->q = this;
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&DbMain::itemChanged);

  setCurrentGroup( QStringLiteral( "Window" ) );

  KConfigCompilerSignallingItem  *itemWidth;
  KConfigBaseEE::ItemInt  *innerItemWidth;
  innerItemWidth = new KConfigBaseEE::ItemInt( currentGroup(), QStringLiteral( "width" ), mWidth, 800 );
  itemWidth = new KConfigCompilerSignallingItem(innerItemWidth, this, notifyFunction, signalWidthChanged);
  itemWidth->setWriteFlags(KConfigBase::Notify);
  addItem( itemWidth, QStringLiteral( "width" ) );
  KConfigCompilerSignallingItem  *itemHeight;
  KConfigBaseEE::ItemInt  *innerItemHeight;
  innerItemHeight = new KConfigBaseEE::ItemInt( currentGroup(), QStringLiteral( "height" ), mHeight, 600 );
  itemHeight = new KConfigCompilerSignallingItem(innerItemHeight, this, notifyFunction, signalHeightChanged);
  itemHeight->setWriteFlags(KConfigBase::Notify);
  addItem( itemHeight, QStringLiteral( "height" ) );
  KConfigCompilerSignallingItem  *itemVisibility;
  KConfigBaseEE::ItemInt  *innerItemVisibility;
  innerItemVisibility = new KConfigBaseEE::ItemInt( currentGroup(), QStringLiteral( "visibility" ), mVisibility, 1 );
  itemVisibility = new KConfigCompilerSignallingItem(innerItemVisibility, this, notifyFunction, signalVisibilityChanged);
  itemVisibility->setWriteFlags(KConfigBase::Notify);
  addItem( itemVisibility, QStringLiteral( "visibility" ) );
  KConfigCompilerSignallingItem  *itemEnableServiceMode;
  KConfigBaseEE::ItemBool  *innerItemEnableServiceMode;
  innerItemEnableServiceMode = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "enableServiceMode" ), mEnableServiceMode, true );
  itemEnableServiceMode = new KConfigCompilerSignallingItem(innerItemEnableServiceMode, this, notifyFunction, signalEnableServiceModeChanged);
  itemEnableServiceMode->setWriteFlags(KConfigBase::Notify);
  addItem( itemEnableServiceMode, QStringLiteral( "enableServiceMode" ) );
  KConfigCompilerSignallingItem  *itemShowTrayIcon;
  KConfigBaseEE::ItemBool  *innerItemShowTrayIcon;
  innerItemShowTrayIcon = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "showTrayIcon" ), mShowTrayIcon, true );
  itemShowTrayIcon = new KConfigCompilerSignallingItem(innerItemShowTrayIcon, this, notifyFunction, signalShowTrayIconChanged);
  itemShowTrayIcon->setWriteFlags(KConfigBase::Notify);
  addItem( itemShowTrayIcon, QStringLiteral( "showTrayIcon" ) );
  KConfigCompilerSignallingItem  *itemAutostartOnLogin;
  KConfigBaseEE::ItemBool  *innerItemAutostartOnLogin;
  innerItemAutostartOnLogin = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "autostartOnLogin" ), mAutostartOnLogin, false );
  itemAutostartOnLogin = new KConfigCompilerSignallingItem(innerItemAutostartOnLogin, this, notifyFunction, signalAutostartOnLoginChanged);
  itemAutostartOnLogin->setWriteFlags(KConfigBase::Notify);
  addItem( itemAutostartOnLogin, QStringLiteral( "autostartOnLogin" ) );
  KConfigCompilerSignallingItem  *itemNoWindowAfterStarting;
  KConfigBaseEE::ItemBool  *innerItemNoWindowAfterStarting;
  innerItemNoWindowAfterStarting = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "noWindowAfterStarting" ), mNoWindowAfterStarting, false );
  itemNoWindowAfterStarting = new KConfigCompilerSignallingItem(innerItemNoWindowAfterStarting, this, notifyFunction, signalNoWindowAfterStartingChanged);
  itemNoWindowAfterStarting->setWriteFlags(KConfigBase::Notify);
  addItem( itemNoWindowAfterStarting, QStringLiteral( "noWindowAfterStarting" ) );
  KConfigCompilerSignallingItem  *itemEnglishLanguage;
  KConfigBaseEE::ItemBool  *innerItemEnglishLanguage;
  innerItemEnglishLanguage = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "englishLanguage" ), mEnglishLanguage, false );
  itemEnglishLanguage = new KConfigCompilerSignallingItem(innerItemEnglishLanguage, this, notifyFunction, signalEnglishLanguageChanged);
  itemEnglishLanguage->setWriteFlags(KConfigBase::Notify);
  addItem( itemEnglishLanguage, QStringLiteral( "englishLanguage" ) );
  KConfigCompilerSignallingItem  *itemReducePluginsListControls;
  KConfigBaseEE::ItemBool  *innerItemReducePluginsListControls;
  innerItemReducePluginsListControls = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "reducePluginsListControls" ), mReducePluginsListControls, false );
  itemReducePluginsListControls = new KConfigCompilerSignallingItem(innerItemReducePluginsListControls, this, notifyFunction, signalReducePluginsListControlsChanged);
  itemReducePluginsListControls->setWriteFlags(KConfigBase::Notify);
  addItem( itemReducePluginsListControls, QStringLiteral( "reducePluginsListControls" ) );
  KConfigCompilerSignallingItem  *itemXdgGlobalShortcuts;
  KConfigBaseEE::ItemBool  *innerItemXdgGlobalShortcuts;
  innerItemXdgGlobalShortcuts = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "xdgGlobalShortcuts" ), mXdgGlobalShortcuts, false );
  itemXdgGlobalShortcuts = new KConfigCompilerSignallingItem(innerItemXdgGlobalShortcuts, this, notifyFunction, signalXdgGlobalShortcutsChanged);
  itemXdgGlobalShortcuts->setWriteFlags(KConfigBase::Notify);
  addItem( itemXdgGlobalShortcuts, QStringLiteral( "xdgGlobalShortcuts" ) );
  KConfigCompilerSignallingItem  *itemXdgGlobalShortcutsBound;
  KConfigBaseEE::ItemBool  *innerItemXdgGlobalShortcutsBound;
  innerItemXdgGlobalShortcutsBound = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "xdgGlobalShortcutsBound" ), mXdgGlobalShortcutsBound, false );
  itemXdgGlobalShortcutsBound = new KConfigCompilerSignallingItem(innerItemXdgGlobalShortcutsBound, this, notifyFunction, signalXdgGlobalShortcutsBoundChanged);
  itemXdgGlobalShortcutsBound->setWriteFlags(KConfigBase::Notify);
  addItem( itemXdgGlobalShortcutsBound, QStringLiteral( "xdgGlobalShortcutsBound" ) );
  KConfigCompilerSignallingItem  *itemDatabaseAutosaveInterval;
  KConfigBaseEE::ItemInt  *innerItemDatabaseAutosaveInterval;
  innerItemDatabaseAutosaveInterval = new KConfigBaseEE::ItemInt( currentGroup(), QStringLiteral( "databaseAutosaveInterval" ), mDatabaseAutosaveInterval, 30000 );
  itemDatabaseAutosaveInterval = new KConfigCompilerSignallingItem(innerItemDatabaseAutosaveInterval, this, notifyFunction, signalDatabaseAutosaveIntervalChanged);
  innerItemDatabaseAutosaveInterval->setMinValue(1000);
  innerItemDatabaseAutosaveInterval->setMaxValue(60000);
  itemDatabaseAutosaveInterval->setWriteFlags(KConfigBase::Notify);
  addItem( itemDatabaseAutosaveInterval, QStringLiteral( "databaseAutosaveInterval" ) );
  KConfigCompilerSignallingItem  *itemPresetsAutoloadInterval;
  KConfigBaseEE::ItemInt  *innerItemPresetsAutoloadInterval;
  innerItemPresetsAutoloadInterval = new KConfigBaseEE::ItemInt( currentGroup(), QStringLiteral( "presetsAutoloadInterval" ), mPresetsAutoloadInterval, 1000 );
  itemPresetsAutoloadInterval = new KConfigCompilerSignallingItem(innerItemPresetsAutoloadInterval, this, notifyFunction, signalPresetsAutoloadIntervalChanged);
  innerItemPresetsAutoloadInterval->setMinValue(0);
  innerItemPresetsAutoloadInterval->setMaxValue(60000);
  itemPresetsAutoloadInterval->setWriteFlags(KConfigBase::Notify);
  addItem( itemPresetsAutoloadInterval, QStringLiteral( "presetsAutoloadInterval" ) );
  KConfigCompilerSignallingItem  *itemMaxMostUsedPresets;
  KConfigBaseEE::ItemInt  *innerItemMaxMostUsedPresets;
  innerItemMaxMostUsedPresets = new KConfigBaseEE::ItemInt( currentGroup(), QStringLiteral( "maxMostUsedPresets" ), mMaxMostUsedPresets, 5 );
  itemMaxMostUsedPresets = new KConfigCompilerSignallingItem(innerItemMaxMostUsedPresets, this, notifyFunction, signalMaxMostUsedPresetsChanged);
  innerItemMaxMostUsedPresets->setMinValue(1);
  innerItemMaxMostUsedPresets->setMaxValue(100);
  itemMaxMostUsedPresets->setWriteFlags(KConfigBase::Notify);
  addItem( itemMaxMostUsedPresets, QStringLiteral( "maxMostUsedPresets" ) );
  KConfigCompilerSignallingItem  *itemAutoHideInlineMessageTimeout;
  KConfigBaseEE::ItemInt  *innerItemAutoHideInlineMessageTimeout;
  innerItemAutoHideInlineMessageTimeout = new KConfigBaseEE::ItemInt( currentGroup(), QStringLiteral( "autoHideInlineMessageTimeout" ), mAutoHideInlineMessageTimeout, 5000 );
  itemAutoHideInlineMessageTimeout = new KConfigCompilerSignallingItem(innerItemAutoHideInlineMessageTimeout, this, notifyFunction, signalAutoHideInlineMessageTimeoutChanged);
  itemAutoHideInlineMessageTimeout->setWriteFlags(KConfigBase::Notify);
  addItem( itemAutoHideInlineMessageTimeout, QStringLiteral( "autoHideInlineMessageTimeout" ) );
  KConfigCompilerSignallingItem  *itemInputAutoloadingUsesFallback;
  KConfigBaseEE::ItemBool  *innerItemInputAutoloadingUsesFallback;
  innerItemInputAutoloadingUsesFallback = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "inputAutoloadingUsesFallback" ), mInputAutoloadingUsesFallback, false );
  itemInputAutoloadingUsesFallback = new KConfigCompilerSignallingItem(innerItemInputAutoloadingUsesFallback, this, notifyFunction, signalInputAutoloadingUsesFallbackChanged);
  itemInputAutoloadingUsesFallback->setWriteFlags(KConfigBase::Notify);
  addItem( itemInputAutoloadingUsesFallback, QStringLiteral( "inputAutoloadingUsesFallback" ) );
  KConfigCompilerSignallingItem  *itemOutputAutoloadingUsesFallback;
  KConfigBaseEE::ItemBool  *innerItemOutputAutoloadingUsesFallback;
  innerItemOutputAutoloadingUsesFallback = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "outputAutoloadingUsesFallback" ), mOutputAutoloadingUsesFallback, false );
  itemOutputAutoloadingUsesFallback = new KConfigCompilerSignallingItem(innerItemOutputAutoloadingUsesFallback, this, notifyFunction, signalOutputAutoloadingUsesFallbackChanged);
  itemOutputAutoloadingUsesFallback->setWriteFlags(KConfigBase::Notify);
  addItem( itemOutputAutoloadingUsesFallback, QStringLiteral( "outputAutoloadingUsesFallback" ) );
  KConfigCompilerSignallingItem  *itemInputAutoloadingFallbackPreset;
  KConfigBaseEE::ItemString  *innerItemInputAutoloadingFallbackPreset;
  innerItemInputAutoloadingFallbackPreset = new KConfigBaseEE::ItemString( currentGroup(), QStringLiteral( "inputAutoloadingFallbackPreset" ), mInputAutoloadingFallbackPreset, "" );
  itemInputAutoloadingFallbackPreset = new KConfigCompilerSignallingItem(innerItemInputAutoloadingFallbackPreset, this, notifyFunction, signalInputAutoloadingFallbackPresetChanged);
  itemInputAutoloadingFallbackPreset->setWriteFlags(KConfigBase::Notify);
  addItem( itemInputAutoloadingFallbackPreset, QStringLiteral( "inputAutoloadingFallbackPreset" ) );
  KConfigCompilerSignallingItem  *itemOutputAutoloadingFallbackPreset;
  KConfigBaseEE::ItemString  *innerItemOutputAutoloadingFallbackPreset;
  innerItemOutputAutoloadingFallbackPreset = new KConfigBaseEE::ItemString( currentGroup(), QStringLiteral( "outputAutoloadingFallbackPreset" ), mOutputAutoloadingFallbackPreset, "" );
  itemOutputAutoloadingFallbackPreset = new KConfigCompilerSignallingItem(innerItemOutputAutoloadingFallbackPreset, this, notifyFunction, signalOutputAutoloadingFallbackPresetChanged);
  itemOutputAutoloadingFallbackPreset->setWriteFlags(KConfigBase::Notify);
  addItem( itemOutputAutoloadingFallbackPreset, QStringLiteral( "outputAutoloadingFallbackPreset" ) );
  QList<KConfigBaseEE::ItemEnum::Choice> valuesvisiblePage;
  {
    KConfigBaseEE::ItemEnum::Choice choice;
    choice.name = QStringLiteral("outputPage");
    valuesvisiblePage.append( choice );
  }
  {
    KConfigBaseEE::ItemEnum::Choice choice;
    choice.name = QStringLiteral("inputPage");
    valuesvisiblePage.append( choice );
  }
  {
    KConfigBaseEE::ItemEnum::Choice choice;
    choice.name = QStringLiteral("pwPage");
    valuesvisiblePage.append( choice );
  }
  KConfigCompilerSignallingItem  *itemVisiblePage;
  KConfigBaseEE::ItemEnum  *innerItemVisiblePage;
  innerItemVisiblePage = new KConfigBaseEE::ItemEnum( currentGroup(), QStringLiteral( "visiblePage" ), mVisiblePage, valuesvisiblePage, 0 );
  itemVisiblePage = new KConfigCompilerSignallingItem(innerItemVisiblePage, this, notifyFunction, signalVisiblePageChanged);
  itemVisiblePage->setWriteFlags(KConfigBase::Notify);
  addItem( itemVisiblePage, QStringLiteral( "visiblePage" ) );
  QList<KConfigBaseEE::ItemEnum::Choice> valuesvisiblePresetSheetPage;
  {
    KConfigBaseEE::ItemEnum::Choice choice;
    choice.name = QStringLiteral("localPage");
    valuesvisiblePresetSheetPage.append( choice );
  }
  {
    KConfigBaseEE::ItemEnum::Choice choice;
    choice.name = QStringLiteral("communityPage");
    valuesvisiblePresetSheetPage.append( choice );
  }
  {
    KConfigBaseEE::ItemEnum::Choice choice;
    choice.name = QStringLiteral("autoloadingPage");
    valuesvisiblePresetSheetPage.append( choice );
  }
  KConfigCompilerSignallingItem  *itemVisiblePresetSheetPage;
  KConfigBaseEE::ItemEnum  *innerItemVisiblePresetSheetPage;
  innerItemVisiblePresetSheetPage = new KConfigBaseEE::ItemEnum( currentGroup(), QStringLiteral( "visiblePresetSheetPage" ), mVisiblePresetSheetPage, valuesvisiblePresetSheetPage, 0 );
  itemVisiblePresetSheetPage = new KConfigCompilerSignallingItem(innerItemVisiblePresetSheetPage, this, notifyFunction, signalVisiblePresetSheetPageChanged);
  itemVisiblePresetSheetPage->setWriteFlags(KConfigBase::Notify);
  addItem( itemVisiblePresetSheetPage, QStringLiteral( "visiblePresetSheetPage" ) );
  QList<KConfigBaseEE::ItemEnum::Choice> valuesvisibleAutoloadingTab;
  {
    KConfigBaseEE::ItemEnum::Choice choice;
    choice.name = QStringLiteral("outputTab");
    valuesvisibleAutoloadingTab.append( choice );
  }
  {
    KConfigBaseEE::ItemEnum::Choice choice;
    choice.name = QStringLiteral("inputTab");
    valuesvisibleAutoloadingTab.append( choice );
  }
  KConfigCompilerSignallingItem  *itemVisibleAutoloadingTab;
  KConfigBaseEE::ItemEnum  *innerItemVisibleAutoloadingTab;
  innerItemVisibleAutoloadingTab = new KConfigBaseEE::ItemEnum( currentGroup(), QStringLiteral( "visibleAutoloadingTab" ), mVisibleAutoloadingTab, valuesvisibleAutoloadingTab, 0 );
  itemVisibleAutoloadingTab = new KConfigCompilerSignallingItem(innerItemVisibleAutoloadingTab, this, notifyFunction, signalVisibleAutoloadingTabChanged);
  itemVisibleAutoloadingTab->setWriteFlags(KConfigBase::Notify);
  addItem( itemVisibleAutoloadingTab, QStringLiteral( "visibleAutoloadingTab" ) );
  QList<KConfigBaseEE::ItemEnum::Choice> valuesvisiblePipeWirePage;
  {
    KConfigBaseEE::ItemEnum::Choice choice;
    choice.name = QStringLiteral("generalPage");
    valuesvisiblePipeWirePage.append( choice );
  }
  {
    KConfigBaseEE::ItemEnum::Choice choice;
    choice.name = QStringLiteral("modulesPage");
    valuesvisiblePipeWirePage.append( choice );
  }
  {
    KConfigBaseEE::ItemEnum::Choice choice;
    choice.name = QStringLiteral("clientsPage");
    valuesvisiblePipeWirePage.append( choice );
  }
  {
    KConfigBaseEE::ItemEnum::Choice choice;
    choice.name = QStringLiteral("testSignalsPage");
    valuesvisiblePipeWirePage.append( choice );
  }
  KConfigCompilerSignallingItem  *itemVisiblePipeWirePage;
  KConfigBaseEE::ItemEnum  *innerItemVisiblePipeWirePage;
  innerItemVisiblePipeWirePage = new KConfigBaseEE::ItemEnum( currentGroup(), QStringLiteral( "visiblePipeWirePage" ), mVisiblePipeWirePage, valuesvisiblePipeWirePage, 0 );
  itemVisiblePipeWirePage = new KConfigCompilerSignallingItem(innerItemVisiblePipeWirePage, this, notifyFunction, signalVisiblePipeWirePageChanged);
  itemVisiblePipeWirePage->setWriteFlags(KConfigBase::Notify);
  addItem( itemVisiblePipeWirePage, QStringLiteral( "visiblePipeWirePage" ) );

  setCurrentGroup( QStringLiteral( "Style" ) );

  KConfigCompilerSignallingItem  *itemCollapsePluginsList;
  KConfigBaseEE::ItemBool  *innerItemCollapsePluginsList;
  innerItemCollapsePluginsList = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "collapsePluginsList" ), mCollapsePluginsList, false );
  itemCollapsePluginsList = new KConfigCompilerSignallingItem(innerItemCollapsePluginsList, this, notifyFunction, signalCollapsePluginsListChanged);
  itemCollapsePluginsList->setWriteFlags(KConfigBase::Notify);
  addItem( itemCollapsePluginsList, QStringLiteral( "collapsePluginsList" ) );
  KConfigCompilerSignallingItem  *itemForceBreezeTheme;
  KConfigBaseEE::ItemBool  *innerItemForceBreezeTheme;
  innerItemForceBreezeTheme = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "forceBreezeTheme" ), mForceBreezeTheme, true );
  itemForceBreezeTheme = new KConfigCompilerSignallingItem(innerItemForceBreezeTheme, this, notifyFunction, signalForceBreezeThemeChanged);
  itemForceBreezeTheme->setWriteFlags(KConfigBase::Notify);
  addItem( itemForceBreezeTheme, QStringLiteral( "forceBreezeTheme" ) );

  setCurrentGroup( QStringLiteral( "Presets" ) );

  KConfigCompilerSignallingItem  *itemIgnorePresetBlocklist;
  KConfigBaseEE::ItemBool  *innerItemIgnorePresetBlocklist;
  innerItemIgnorePresetBlocklist = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "ignorePresetBlocklist" ), mIgnorePresetBlocklist, false );
  itemIgnorePresetBlocklist = new KConfigCompilerSignallingItem(innerItemIgnorePresetBlocklist, this, notifyFunction, signalIgnorePresetBlocklistChanged);
  itemIgnorePresetBlocklist->setWriteFlags(KConfigBase::Notify);
  addItem( itemIgnorePresetBlocklist, QStringLiteral( "ignorePresetBlocklist" ) );
  KConfigCompilerSignallingItem  *itemLastLoadedInputPreset;
  KConfigBaseEE::ItemString  *innerItemLastLoadedInputPreset;
  innerItemLastLoadedInputPreset = new KConfigBaseEE::ItemString( currentGroup(), QStringLiteral( "lastLoadedInputPreset" ), mLastLoadedInputPreset, "" );
  itemLastLoadedInputPreset = new KConfigCompilerSignallingItem(innerItemLastLoadedInputPreset, this, notifyFunction, signalLastLoadedInputPresetChanged);
  itemLastLoadedInputPreset->setWriteFlags(KConfigBase::Notify);
  addItem( itemLastLoadedInputPreset, QStringLiteral( "lastLoadedInputPreset" ) );
  KConfigCompilerSignallingItem  *itemLastLoadedOutputPreset;
  KConfigBaseEE::ItemString  *innerItemLastLoadedOutputPreset;
  innerItemLastLoadedOutputPreset = new KConfigBaseEE::ItemString( currentGroup(), QStringLiteral( "lastLoadedOutputPreset" ), mLastLoadedOutputPreset, "" );
  itemLastLoadedOutputPreset = new KConfigCompilerSignallingItem(innerItemLastLoadedOutputPreset, this, notifyFunction, signalLastLoadedOutputPresetChanged);
  itemLastLoadedOutputPreset->setWriteFlags(KConfigBase::Notify);
  addItem( itemLastLoadedOutputPreset, QStringLiteral( "lastLoadedOutputPreset" ) );
  KConfigCompilerSignallingItem  *itemLastLoadedInputCommunityPackage;
  KConfigBaseEE::ItemString  *innerItemLastLoadedInputCommunityPackage;
  innerItemLastLoadedInputCommunityPackage = new KConfigBaseEE::ItemString( currentGroup(), QStringLiteral( "lastLoadedInputCommunityPackage" ), mLastLoadedInputCommunityPackage, "" );
  itemLastLoadedInputCommunityPackage = new KConfigCompilerSignallingItem(innerItemLastLoadedInputCommunityPackage, this, notifyFunction, signalLastLoadedInputCommunityPackageChanged);
  itemLastLoadedInputCommunityPackage->setWriteFlags(KConfigBase::Notify);
  addItem( itemLastLoadedInputCommunityPackage, QStringLiteral( "lastLoadedInputCommunityPackage" ) );
  KConfigCompilerSignallingItem  *itemLastLoadedOutputCommunityPackage;
  KConfigBaseEE::ItemString  *innerItemLastLoadedOutputCommunityPackage;
  innerItemLastLoadedOutputCommunityPackage = new KConfigBaseEE::ItemString( currentGroup(), QStringLiteral( "lastLoadedOutputCommunityPackage" ), mLastLoadedOutputCommunityPackage, "" );
  itemLastLoadedOutputCommunityPackage = new KConfigCompilerSignallingItem(innerItemLastLoadedOutputCommunityPackage, this, notifyFunction, signalLastLoadedOutputCommunityPackageChanged);
  itemLastLoadedOutputCommunityPackage->setWriteFlags(KConfigBase::Notify);
  addItem( itemLastLoadedOutputCommunityPackage, QStringLiteral( "lastLoadedOutputCommunityPackage" ) );

  setCurrentGroup( QStringLiteral( "EffectsPipelines" ) );

  KConfigCompilerSignallingItem  *itemBypass;
  KConfigBaseEE::ItemBool  *innerItemBypass;
  innerItemBypass = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "bypass" ), mBypass, false );
  itemBypass = new KConfigCompilerSignallingItem(innerItemBypass, this, notifyFunction, signalBypassChanged);
  itemBypass->setWriteFlags(KConfigBase::Notify);
  addItem( itemBypass, QStringLiteral( "bypass" ) );
  KConfigCompilerSignallingItem  *itemProcessAllOutputs;
  KConfigBaseEE::ItemBool  *innerItemProcessAllOutputs;
  innerItemProcessAllOutputs = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "processAllOutputs" ), mProcessAllOutputs, true );
  itemProcessAllOutputs = new KConfigCompilerSignallingItem(innerItemProcessAllOutputs, this, notifyFunction, signalProcessAllOutputsChanged);
  itemProcessAllOutputs->setWriteFlags(KConfigBase::Notify);
  addItem( itemProcessAllOutputs, QStringLiteral( "processAllOutputs" ) );
  KConfigCompilerSignallingItem  *itemProcessAllInputs;
  KConfigBaseEE::ItemBool  *innerItemProcessAllInputs;
  innerItemProcessAllInputs = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "processAllInputs" ), mProcessAllInputs, true );
  itemProcessAllInputs = new KConfigCompilerSignallingItem(innerItemProcessAllInputs, this, notifyFunction, signalProcessAllInputsChanged);
  itemProcessAllInputs->setWriteFlags(KConfigBase::Notify);
  addItem( itemProcessAllInputs, QStringLiteral( "processAllInputs" ) );
  KConfigCompilerSignallingItem  *itemExcludeMonitorStreams;
  KConfigBaseEE::ItemBool  *innerItemExcludeMonitorStreams;
  innerItemExcludeMonitorStreams = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "excludeMonitorStreams" ), mExcludeMonitorStreams, true );
  itemExcludeMonitorStreams = new KConfigCompilerSignallingItem(innerItemExcludeMonitorStreams, this, notifyFunction, signalExcludeMonitorStreamsChanged);
  itemExcludeMonitorStreams->setWriteFlags(KConfigBase::Notify);
  addItem( itemExcludeMonitorStreams, QStringLiteral( "excludeMonitorStreams" ) );
  KConfigCompilerSignallingItem  *itemUseCubicVolumes;
  KConfigBaseEE::ItemBool  *innerItemUseCubicVolumes;
  innerItemUseCubicVolumes = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "useCubicVolumes" ), mUseCubicVolumes, false );
  itemUseCubicVolumes = new KConfigCompilerSignallingItem(innerItemUseCubicVolumes, this, notifyFunction, signalUseCubicVolumesChanged);
  itemUseCubicVolumes->setWriteFlags(KConfigBase::Notify);
  addItem( itemUseCubicVolumes, QStringLiteral( "useCubicVolumes" ) );
  KConfigCompilerSignallingItem  *itemIgnoreSystemNotifications;
  KConfigBaseEE::ItemBool  *innerItemIgnoreSystemNotifications;
  innerItemIgnoreSystemNotifications = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "ignoreSystemNotifications" ), mIgnoreSystemNotifications, true );
  itemIgnoreSystemNotifications = new KConfigCompilerSignallingItem(innerItemIgnoreSystemNotifications, this, notifyFunction, signalIgnoreSystemNotificationsChanged);
  itemIgnoreSystemNotifications->setWriteFlags(KConfigBase::Notify);
  addItem( itemIgnoreSystemNotifications, QStringLiteral( "ignoreSystemNotifications" ) );
  KConfigCompilerSignallingItem  *itemLinkDelayEnable;
  KConfigBaseEE::ItemBool  *innerItemLinkDelayEnable;
  innerItemLinkDelayEnable = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "linkDelayEnable" ), mLinkDelayEnable, true );
  itemLinkDelayEnable = new KConfigCompilerSignallingItem(innerItemLinkDelayEnable, this, notifyFunction, signalLinkDelayEnableChanged);
  itemLinkDelayEnable->setWriteFlags(KConfigBase::Notify);
  addItem( itemLinkDelayEnable, QStringLiteral( "linkDelayEnable" ) );
  KConfigCompilerSignallingItem  *itemLinkDelay;
  KConfigBaseEE::ItemInt  *innerItemLinkDelay;
  innerItemLinkDelay = new KConfigBaseEE::ItemInt( currentGroup(), QStringLiteral( "linkDelay" ), mLinkDelay, 100 );
  itemLinkDelay = new KConfigCompilerSignallingItem(innerItemLinkDelay, this, notifyFunction, signalLinkDelayChanged);
  innerItemLinkDelay->setMinValue(1);
  innerItemLinkDelay->setMaxValue(1000);
  itemLinkDelay->setWriteFlags(KConfigBase::Notify);
  addItem( itemLinkDelay, QStringLiteral( "linkDelay" ) );
  KConfigCompilerSignallingItem  *itemInactivityTimerEnable;
  KConfigBaseEE::ItemBool  *innerItemInactivityTimerEnable;
  innerItemInactivityTimerEnable = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "inactivityTimerEnable" ), mInactivityTimerEnable, true );
  itemInactivityTimerEnable = new KConfigCompilerSignallingItem(innerItemInactivityTimerEnable, this, notifyFunction, signalInactivityTimerEnableChanged);
  itemInactivityTimerEnable->setWriteFlags(KConfigBase::Notify);
  addItem( itemInactivityTimerEnable, QStringLiteral( "inactivityTimerEnable" ) );
  KConfigCompilerSignallingItem  *itemInactivityTimeout;
  KConfigBaseEE::ItemInt  *innerItemInactivityTimeout;
  innerItemInactivityTimeout = new KConfigBaseEE::ItemInt( currentGroup(), QStringLiteral( "inactivityTimeout" ), mInactivityTimeout, 10 );
  itemInactivityTimeout = new KConfigCompilerSignallingItem(innerItemInactivityTimeout, this, notifyFunction, signalInactivityTimeoutChanged);
  innerItemInactivityTimeout->setMinValue(1);
  innerItemInactivityTimeout->setMaxValue(3600);
  itemInactivityTimeout->setWriteFlags(KConfigBase::Notify);
  addItem( itemInactivityTimeout, QStringLiteral( "inactivityTimeout" ) );

  setCurrentGroup( QStringLiteral( "Audio" ) );

  KConfigCompilerSignallingItem  *itemLevelMetersLabelTimer;
  KConfigBaseEE::ItemInt  *innerItemLevelMetersLabelTimer;
  innerItemLevelMetersLabelTimer = new KConfigBaseEE::ItemInt( currentGroup(), QStringLiteral( "levelMetersLabelTimer" ), mLevelMetersLabelTimer, 2500 );
  itemLevelMetersLabelTimer = new KConfigCompilerSignallingItem(innerItemLevelMetersLabelTimer, this, notifyFunction, signalLevelMetersLabelTimerChanged);
  innerItemLevelMetersLabelTimer->setMinValue(1);
  innerItemLevelMetersLabelTimer->setMaxValue(10000);
  itemLevelMetersLabelTimer->setWriteFlags(KConfigBase::Notify);
  addItem( itemLevelMetersLabelTimer, QStringLiteral( "levelMetersLabelTimer" ) );
  KConfigCompilerSignallingItem  *itemEnableLevelMetersAnimation;
  KConfigBaseEE::ItemBool  *innerItemEnableLevelMetersAnimation;
  innerItemEnableLevelMetersAnimation = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "enableLevelMetersAnimation" ), mEnableLevelMetersAnimation, true );
  itemEnableLevelMetersAnimation = new KConfigCompilerSignallingItem(innerItemEnableLevelMetersAnimation, this, notifyFunction, signalEnableLevelMetersAnimationChanged);
  itemEnableLevelMetersAnimation->setWriteFlags(KConfigBase::Notify);
  addItem( itemEnableLevelMetersAnimation, QStringLiteral( "enableLevelMetersAnimation" ) );
  KConfigCompilerSignallingItem  *itemLevelMetersAnimationDuration;
  KConfigBaseEE::ItemInt  *innerItemLevelMetersAnimationDuration;
  innerItemLevelMetersAnimationDuration = new KConfigBaseEE::ItemInt( currentGroup(), QStringLiteral( "levelMetersAnimationDuration" ), mLevelMetersAnimationDuration, 300 );
  itemLevelMetersAnimationDuration = new KConfigCompilerSignallingItem(innerItemLevelMetersAnimationDuration, this, notifyFunction, signalLevelMetersAnimationDurationChanged);
  innerItemLevelMetersAnimationDuration->setMinValue(1);
  innerItemLevelMetersAnimationDuration->setMaxValue(10000);
  itemLevelMetersAnimationDuration->setWriteFlags(KConfigBase::Notify);
  addItem( itemLevelMetersAnimationDuration, QStringLiteral( "levelMetersAnimationDuration" ) );
  KConfigCompilerSignallingItem  *itemLevelMetersFpsCap;
  KConfigBaseEE::ItemInt  *innerItemLevelMetersFpsCap;
  innerItemLevelMetersFpsCap = new KConfigBaseEE::ItemInt( currentGroup(), QStringLiteral( "levelMetersFpsCap" ), mLevelMetersFpsCap, 60 );
  itemLevelMetersFpsCap = new KConfigCompilerSignallingItem(innerItemLevelMetersFpsCap, this, notifyFunction, signalLevelMetersFpsCapChanged);
  innerItemLevelMetersFpsCap->setMinValue(1);
  innerItemLevelMetersFpsCap->setMaxValue(240);
  itemLevelMetersFpsCap->setWriteFlags(KConfigBase::Notify);
  addItem( itemLevelMetersFpsCap, QStringLiteral( "levelMetersFpsCap" ) );
  KConfigCompilerSignallingItem  *itemCopyFilterInputBuffers;
  KConfigBaseEE::ItemBool  *innerItemCopyFilterInputBuffers;
  innerItemCopyFilterInputBuffers = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "copyFilterInputBuffers" ), mCopyFilterInputBuffers, false );
  itemCopyFilterInputBuffers = new KConfigCompilerSignallingItem(innerItemCopyFilterInputBuffers, this, notifyFunction, signalCopyFilterInputBuffersChanged);
  itemCopyFilterInputBuffers->setWriteFlags(KConfigBase::Notify);
  addItem( itemCopyFilterInputBuffers, QStringLiteral( "copyFilterInputBuffers" ) );
  KConfigCompilerSignallingItem  *itemActivateMonitorChannelVolumes;
  KConfigBaseEE::ItemBool  *innerItemActivateMonitorChannelVolumes;
  innerItemActivateMonitorChannelVolumes = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "activateMonitorChannelVolumes" ), mActivateMonitorChannelVolumes, false );
  itemActivateMonitorChannelVolumes = new KConfigCompilerSignallingItem(innerItemActivateMonitorChannelVolumes, this, notifyFunction, signalActivateMonitorChannelVolumesChanged);
  itemActivateMonitorChannelVolumes->setWriteFlags(KConfigBase::Notify);
  addItem( itemActivateMonitorChannelVolumes, QStringLiteral( "activateMonitorChannelVolumes" ) );

  setCurrentGroup( QStringLiteral( "NativePluginWindow" ) );

  KConfigCompilerSignallingItem  *itemShowNativePluginUi;
  KConfigBaseEE::ItemBool  *innerItemShowNativePluginUi;
  innerItemShowNativePluginUi = new KConfigBaseEE::ItemBool( currentGroup(), QStringLiteral( "showNativePluginUi" ), mShowNativePluginUi, false );
  itemShowNativePluginUi = new KConfigCompilerSignallingItem(innerItemShowNativePluginUi, this, notifyFunction, signalShowNativePluginUiChanged);
  itemShowNativePluginUi->setWriteFlags(KConfigBase::Notify);
  addItem( itemShowNativePluginUi, QStringLiteral( "showNativePluginUi" ) );
  KConfigCompilerSignallingItem  *itemLv2uiUpdateFrequency;
  KConfigBaseEE::ItemInt  *innerItemLv2uiUpdateFrequency;
  innerItemLv2uiUpdateFrequency = new KConfigBaseEE::ItemInt( currentGroup(), QStringLiteral( "lv2uiUpdateFrequency" ), mLv2uiUpdateFrequency, 30 );
  itemLv2uiUpdateFrequency = new KConfigCompilerSignallingItem(innerItemLv2uiUpdateFrequency, this, notifyFunction, signalLv2uiUpdateFrequencyChanged);
  innerItemLv2uiUpdateFrequency->setMinValue(1);
  innerItemLv2uiUpdateFrequency->setMaxValue(60);
  itemLv2uiUpdateFrequency->setWriteFlags(KConfigBase::Notify);
  addItem( itemLv2uiUpdateFrequency, QStringLiteral( "lv2uiUpdateFrequency" ) );
}

int DbMain::defaultWidthValue_helper()
{

  return 800;
}

int DbMain::defaultHeightValue_helper()
{

  return 600;
}

int DbMain::defaultVisibilityValue_helper()
{

  return 1;
}

bool DbMain::defaultEnableServiceModeValue_helper()
{

  return true;
}

bool DbMain::defaultShowTrayIconValue_helper()
{

  return true;
}

bool DbMain::defaultAutostartOnLoginValue_helper()
{

  return false;
}

bool DbMain::defaultNoWindowAfterStartingValue_helper()
{

  return false;
}

bool DbMain::defaultEnglishLanguageValue_helper()
{

  return false;
}

bool DbMain::defaultReducePluginsListControlsValue_helper()
{

  return false;
}

bool DbMain::defaultXdgGlobalShortcutsValue_helper()
{

  return false;
}

bool DbMain::defaultXdgGlobalShortcutsBoundValue_helper()
{

  return false;
}

int DbMain::defaultDatabaseAutosaveIntervalValue_helper()
{

  return 30000;
}

int DbMain::defaultPresetsAutoloadIntervalValue_helper()
{

  return 1000;
}

int DbMain::defaultMaxMostUsedPresetsValue_helper()
{

  return 5;
}

int DbMain::defaultAutoHideInlineMessageTimeoutValue_helper()
{

  return 5000;
}

bool DbMain::defaultInputAutoloadingUsesFallbackValue_helper()
{

  return false;
}

bool DbMain::defaultOutputAutoloadingUsesFallbackValue_helper()
{

  return false;
}

QString DbMain::defaultInputAutoloadingFallbackPresetValue_helper()
{

  return "";
}

QString DbMain::defaultOutputAutoloadingFallbackPresetValue_helper()
{

  return "";
}

int DbMain::defaultVisiblePageValue_helper()
{

  return 0;
}

int DbMain::defaultVisiblePresetSheetPageValue_helper()
{

  return 0;
}

int DbMain::defaultVisibleAutoloadingTabValue_helper()
{

  return 0;
}

int DbMain::defaultVisiblePipeWirePageValue_helper()
{

  return 0;
}

bool DbMain::defaultCollapsePluginsListValue_helper()
{

  return false;
}

bool DbMain::defaultForceBreezeThemeValue_helper()
{

  return true;
}

bool DbMain::defaultIgnorePresetBlocklistValue_helper()
{

  return false;
}

QString DbMain::defaultLastLoadedInputPresetValue_helper()
{

  return "";
}

QString DbMain::defaultLastLoadedOutputPresetValue_helper()
{

  return "";
}

QString DbMain::defaultLastLoadedInputCommunityPackageValue_helper()
{

  return "";
}

QString DbMain::defaultLastLoadedOutputCommunityPackageValue_helper()
{

  return "";
}

bool DbMain::defaultBypassValue_helper()
{

  return false;
}

bool DbMain::defaultProcessAllOutputsValue_helper()
{

  return true;
}

bool DbMain::defaultProcessAllInputsValue_helper()
{

  return true;
}

bool DbMain::defaultExcludeMonitorStreamsValue_helper()
{

  return true;
}

bool DbMain::defaultUseCubicVolumesValue_helper()
{

  return false;
}

bool DbMain::defaultIgnoreSystemNotificationsValue_helper()
{

  return true;
}

bool DbMain::defaultLinkDelayEnableValue_helper()
{

  return true;
}

int DbMain::defaultLinkDelayValue_helper()
{

  return 100;
}

bool DbMain::defaultInactivityTimerEnableValue_helper()
{

  return true;
}

int DbMain::defaultInactivityTimeoutValue_helper()
{

  return 10;
}

int DbMain::defaultLevelMetersLabelTimerValue_helper()
{

  return 2500;
}

bool DbMain::defaultEnableLevelMetersAnimationValue_helper()
{

  return true;
}

int DbMain::defaultLevelMetersAnimationDurationValue_helper()
{

  return 300;
}

int DbMain::defaultLevelMetersFpsCapValue_helper()
{

  return 60;
}

bool DbMain::defaultCopyFilterInputBuffersValue_helper()
{

  return false;
}

bool DbMain::defaultActivateMonitorChannelVolumesValue_helper()
{

  return false;
}

bool DbMain::defaultShowNativePluginUiValue_helper()
{

  return false;
}

int DbMain::defaultLv2uiUpdateFrequencyValue_helper()
{

  return 30;
}

DbMain::~DbMain()
{
  if (s_globalDbMain.exists() && !s_globalDbMain.isDestroyed()) {
    s_globalDbMain()->q = nullptr;
  }
}


void DbMain::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalWidthChanged:
    Q_EMIT widthChanged();
    break;
  case signalHeightChanged:
    Q_EMIT heightChanged();
    break;
  case signalVisibilityChanged:
    Q_EMIT visibilityChanged();
    break;
  case signalEnableServiceModeChanged:
    Q_EMIT enableServiceModeChanged();
    break;
  case signalShowTrayIconChanged:
    Q_EMIT showTrayIconChanged();
    break;
  case signalAutostartOnLoginChanged:
    Q_EMIT autostartOnLoginChanged();
    break;
  case signalNoWindowAfterStartingChanged:
    Q_EMIT noWindowAfterStartingChanged();
    break;
  case signalEnglishLanguageChanged:
    Q_EMIT englishLanguageChanged();
    break;
  case signalReducePluginsListControlsChanged:
    Q_EMIT reducePluginsListControlsChanged();
    break;
  case signalXdgGlobalShortcutsChanged:
    Q_EMIT xdgGlobalShortcutsChanged();
    break;
  case signalXdgGlobalShortcutsBoundChanged:
    Q_EMIT xdgGlobalShortcutsBoundChanged();
    break;
  case signalDatabaseAutosaveIntervalChanged:
    Q_EMIT databaseAutosaveIntervalChanged();
    break;
  case signalPresetsAutoloadIntervalChanged:
    Q_EMIT presetsAutoloadIntervalChanged();
    break;
  case signalMaxMostUsedPresetsChanged:
    Q_EMIT maxMostUsedPresetsChanged();
    break;
  case signalAutoHideInlineMessageTimeoutChanged:
    Q_EMIT autoHideInlineMessageTimeoutChanged();
    break;
  case signalInputAutoloadingUsesFallbackChanged:
    Q_EMIT inputAutoloadingUsesFallbackChanged();
    break;
  case signalOutputAutoloadingUsesFallbackChanged:
    Q_EMIT outputAutoloadingUsesFallbackChanged();
    break;
  case signalInputAutoloadingFallbackPresetChanged:
    Q_EMIT inputAutoloadingFallbackPresetChanged();
    break;
  case signalOutputAutoloadingFallbackPresetChanged:
    Q_EMIT outputAutoloadingFallbackPresetChanged();
    break;
  case signalVisiblePageChanged:
    Q_EMIT visiblePageChanged();
    break;
  case signalVisiblePresetSheetPageChanged:
    Q_EMIT visiblePresetSheetPageChanged();
    break;
  case signalVisibleAutoloadingTabChanged:
    Q_EMIT visibleAutoloadingTabChanged();
    break;
  case signalVisiblePipeWirePageChanged:
    Q_EMIT visiblePipeWirePageChanged();
    break;
  case signalCollapsePluginsListChanged:
    Q_EMIT collapsePluginsListChanged();
    break;
  case signalForceBreezeThemeChanged:
    Q_EMIT forceBreezeThemeChanged();
    break;
  case signalIgnorePresetBlocklistChanged:
    Q_EMIT ignorePresetBlocklistChanged();
    break;
  case signalLastLoadedInputPresetChanged:
    Q_EMIT lastLoadedInputPresetChanged();
    break;
  case signalLastLoadedOutputPresetChanged:
    Q_EMIT lastLoadedOutputPresetChanged();
    break;
  case signalLastLoadedInputCommunityPackageChanged:
    Q_EMIT lastLoadedInputCommunityPackageChanged();
    break;
  case signalLastLoadedOutputCommunityPackageChanged:
    Q_EMIT lastLoadedOutputCommunityPackageChanged();
    break;
  case signalBypassChanged:
    Q_EMIT bypassChanged();
    break;
  case signalProcessAllOutputsChanged:
    Q_EMIT processAllOutputsChanged();
    break;
  case signalProcessAllInputsChanged:
    Q_EMIT processAllInputsChanged();
    break;
  case signalExcludeMonitorStreamsChanged:
    Q_EMIT excludeMonitorStreamsChanged();
    break;
  case signalUseCubicVolumesChanged:
    Q_EMIT useCubicVolumesChanged();
    break;
  case signalIgnoreSystemNotificationsChanged:
    Q_EMIT ignoreSystemNotificationsChanged();
    break;
  case signalLinkDelayEnableChanged:
    Q_EMIT linkDelayEnableChanged();
    break;
  case signalLinkDelayChanged:
    Q_EMIT linkDelayChanged();
    break;
  case signalInactivityTimerEnableChanged:
    Q_EMIT inactivityTimerEnableChanged();
    break;
  case signalInactivityTimeoutChanged:
    Q_EMIT inactivityTimeoutChanged();
    break;
  case signalLevelMetersLabelTimerChanged:
    Q_EMIT levelMetersLabelTimerChanged();
    break;
  case signalEnableLevelMetersAnimationChanged:
    Q_EMIT enableLevelMetersAnimationChanged();
    break;
  case signalLevelMetersAnimationDurationChanged:
    Q_EMIT levelMetersAnimationDurationChanged();
    break;
  case signalLevelMetersFpsCapChanged:
    Q_EMIT levelMetersFpsCapChanged();
    break;
  case signalCopyFilterInputBuffersChanged:
    Q_EMIT copyFilterInputBuffersChanged();
    break;
  case signalActivateMonitorChannelVolumesChanged:
    Q_EMIT activateMonitorChannelVolumesChanged();
    break;
  case signalShowNativePluginUiChanged:
    Q_EMIT showNativePluginUiChanged();
    break;
  case signalLv2uiUpdateFrequencyChanged:
    Q_EMIT lv2uiUpdateFrequencyChanged();
    break;
  }
}
