/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<autogain.hpp>)
#  include <autogain.hpp>
#endif
#if __has_include(<autostart.hpp>)
#  include <autostart.hpp>
#endif
#if __has_include(<autotune.hpp>)
#  include <autotune.hpp>
#endif
#if __has_include(<bass_enhancer.hpp>)
#  include <bass_enhancer.hpp>
#endif
#if __has_include(<bass_loudness.hpp>)
#  include <bass_loudness.hpp>
#endif
#if __has_include(<compressor.hpp>)
#  include <compressor.hpp>
#endif
#if __has_include(<convolver.hpp>)
#  include <convolver.hpp>
#endif
#if __has_include(<crossfeed.hpp>)
#  include <crossfeed.hpp>
#endif
#if __has_include(<crosstalk_canceller.hpp>)
#  include <crosstalk_canceller.hpp>
#endif
#if __has_include(<crusher.hpp>)
#  include <crusher.hpp>
#endif
#if __has_include(<crystalizer.hpp>)
#  include <crystalizer.hpp>
#endif
#if __has_include(<db_manager.hpp>)
#  include <db_manager.hpp>
#endif
#if __has_include(<deepfilternet.hpp>)
#  include <deepfilternet.hpp>
#endif
#if __has_include(<deesser.hpp>)
#  include <deesser.hpp>
#endif
#if __has_include(<delay.hpp>)
#  include <delay.hpp>
#endif
#if __has_include(<easyeffects_db.h>)
#  include <easyeffects_db.h>
#endif
#if __has_include(<easyeffects_db_autogain.h>)
#  include <easyeffects_db_autogain.h>
#endif
#if __has_include(<easyeffects_db_autotune.h>)
#  include <easyeffects_db_autotune.h>
#endif
#if __has_include(<easyeffects_db_bass_enhancer.h>)
#  include <easyeffects_db_bass_enhancer.h>
#endif
#if __has_include(<easyeffects_db_bass_loudness.h>)
#  include <easyeffects_db_bass_loudness.h>
#endif
#if __has_include(<easyeffects_db_compressor.h>)
#  include <easyeffects_db_compressor.h>
#endif
#if __has_include(<easyeffects_db_convolver.h>)
#  include <easyeffects_db_convolver.h>
#endif
#if __has_include(<easyeffects_db_crossfeed.h>)
#  include <easyeffects_db_crossfeed.h>
#endif
#if __has_include(<easyeffects_db_crosstalk_canceller.h>)
#  include <easyeffects_db_crosstalk_canceller.h>
#endif
#if __has_include(<easyeffects_db_crusher.h>)
#  include <easyeffects_db_crusher.h>
#endif
#if __has_include(<easyeffects_db_crystalizer.h>)
#  include <easyeffects_db_crystalizer.h>
#endif
#if __has_include(<easyeffects_db_deepfilternet.h>)
#  include <easyeffects_db_deepfilternet.h>
#endif
#if __has_include(<easyeffects_db_deesser.h>)
#  include <easyeffects_db_deesser.h>
#endif
#if __has_include(<easyeffects_db_delay.h>)
#  include <easyeffects_db_delay.h>
#endif
#if __has_include(<easyeffects_db_echo_canceller.h>)
#  include <easyeffects_db_echo_canceller.h>
#endif
#if __has_include(<easyeffects_db_equalizer.h>)
#  include <easyeffects_db_equalizer.h>
#endif
#if __has_include(<easyeffects_db_equalizer_channel.h>)
#  include <easyeffects_db_equalizer_channel.h>
#endif
#if __has_include(<easyeffects_db_exciter.h>)
#  include <easyeffects_db_exciter.h>
#endif
#if __has_include(<easyeffects_db_expander.h>)
#  include <easyeffects_db_expander.h>
#endif
#if __has_include(<easyeffects_db_filter.h>)
#  include <easyeffects_db_filter.h>
#endif
#if __has_include(<easyeffects_db_gate.h>)
#  include <easyeffects_db_gate.h>
#endif
#if __has_include(<easyeffects_db_graph.h>)
#  include <easyeffects_db_graph.h>
#endif
#if __has_include(<easyeffects_db_level_meter.h>)
#  include <easyeffects_db_level_meter.h>
#endif
#if __has_include(<easyeffects_db_limiter.h>)
#  include <easyeffects_db_limiter.h>
#endif
#if __has_include(<easyeffects_db_loudness.h>)
#  include <easyeffects_db_loudness.h>
#endif
#if __has_include(<easyeffects_db_maximizer.h>)
#  include <easyeffects_db_maximizer.h>
#endif
#if __has_include(<easyeffects_db_multiband_compressor.h>)
#  include <easyeffects_db_multiband_compressor.h>
#endif
#if __has_include(<easyeffects_db_multiband_gate.h>)
#  include <easyeffects_db_multiband_gate.h>
#endif
#if __has_include(<easyeffects_db_pitch.h>)
#  include <easyeffects_db_pitch.h>
#endif
#if __has_include(<easyeffects_db_reverb.h>)
#  include <easyeffects_db_reverb.h>
#endif
#if __has_include(<easyeffects_db_rnnoise.h>)
#  include <easyeffects_db_rnnoise.h>
#endif
#if __has_include(<easyeffects_db_spectrum.h>)
#  include <easyeffects_db_spectrum.h>
#endif
#if __has_include(<easyeffects_db_speex.h>)
#  include <easyeffects_db_speex.h>
#endif
#if __has_include(<easyeffects_db_stereo_tools.h>)
#  include <easyeffects_db_stereo_tools.h>
#endif
#if __has_include(<easyeffects_db_streaminputs.h>)
#  include <easyeffects_db_streaminputs.h>
#endif
#if __has_include(<easyeffects_db_streamoutputs.h>)
#  include <easyeffects_db_streamoutputs.h>
#endif
#if __has_include(<easyeffects_db_test_signals.h>)
#  include <easyeffects_db_test_signals.h>
#endif
#if __has_include(<easyeffects_db_voice_suppressor.h>)
#  include <easyeffects_db_voice_suppressor.h>
#endif
#if __has_include(<echo_canceller.hpp>)
#  include <echo_canceller.hpp>
#endif
#if __has_include(<effects_base.hpp>)
#  include <effects_base.hpp>
#endif
#if __has_include(<equalizer.hpp>)
#  include <equalizer.hpp>
#endif
#if __has_include(<exciter.hpp>)
#  include <exciter.hpp>
#endif
#if __has_include(<expander.hpp>)
#  include <expander.hpp>
#endif
#if __has_include(<filter.hpp>)
#  include <filter.hpp>
#endif
#if __has_include(<gate.hpp>)
#  include <gate.hpp>
#endif
#if __has_include(<global_shortcuts.hpp>)
#  include <global_shortcuts.hpp>
#endif
#if __has_include(<kcolor_manager.hpp>)
#  include <kcolor_manager.hpp>
#endif
#if __has_include(<level_meter.hpp>)
#  include <level_meter.hpp>
#endif
#if __has_include(<limiter.hpp>)
#  include <limiter.hpp>
#endif
#if __has_include(<loudness.hpp>)
#  include <loudness.hpp>
#endif
#if __has_include(<maximizer.hpp>)
#  include <maximizer.hpp>
#endif
#if __has_include(<multiband_compressor.hpp>)
#  include <multiband_compressor.hpp>
#endif
#if __has_include(<multiband_gate.hpp>)
#  include <multiband_gate.hpp>
#endif
#if __has_include(<pitch.hpp>)
#  include <pitch.hpp>
#endif
#if __has_include(<presets_list_model.hpp>)
#  include <presets_list_model.hpp>
#endif
#if __has_include(<presets_manager.hpp>)
#  include <presets_manager.hpp>
#endif
#if __has_include(<pw_manager.hpp>)
#  include <pw_manager.hpp>
#endif
#if __has_include(<pw_model_clients.hpp>)
#  include <pw_model_clients.hpp>
#endif
#if __has_include(<pw_model_modules.hpp>)
#  include <pw_model_modules.hpp>
#endif
#if __has_include(<pw_model_nodes.hpp>)
#  include <pw_model_nodes.hpp>
#endif
#if __has_include(<reverb.hpp>)
#  include <reverb.hpp>
#endif
#if __has_include(<rnnoise.hpp>)
#  include <rnnoise.hpp>
#endif
#if __has_include(<speex.hpp>)
#  include <speex.hpp>
#endif
#if __has_include(<stereo_tools.hpp>)
#  include <stereo_tools.hpp>
#endif
#if __has_include(<stream_input_effects.hpp>)
#  include <stream_input_effects.hpp>
#endif
#if __has_include(<stream_output_effects.hpp>)
#  include <stream_output_effects.hpp>
#endif
#if __has_include(<tags_plugin_name.hpp>)
#  include <tags_plugin_name.hpp>
#endif
#if __has_include(<units.hpp>)
#  include <units.hpp>
#endif
#if __has_include(<voice_suppressor.hpp>)
#  include <voice_suppressor.hpp>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_ee_ui()
{
    qmlRegisterModule("ee.ui", 8, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<Autogain>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<Autostart>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<Autotune>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<BassEnhancer>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<BassLoudness>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<Compressor>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<Convolver>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<Crossfeed>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<CrosstalkCanceller>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<Crusher>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<Crystalizer>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbAutogain>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbAutotune>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbBassEnhancer>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbBassLoudness>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbCompressor>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbConvolver>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbCrossfeed>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbCrosstalkCanceller>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbCrusher>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbCrystalizer>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbDeepFilterNet>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbDeesser>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbDelay>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbEchoCanceller>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbEqualizer>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbEqualizerChannel>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbExciter>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbExpander>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbFilter>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbGate>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbGraph>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbLevelMeter>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbLimiter>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbLoudness>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbMain>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbMaximizer>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbMultibandCompressor>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbMultibandGate>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbPitch>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbRNNoise>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbReverb>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbSpectrum>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbSpeex>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbStereoTools>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbStreamInputs>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbStreamOutputs>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbTestSignals>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DbVoiceSuppressor>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<DeepFilterNet>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<Deesser>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<Delay>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<EchoCanceller>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<EffectsBase>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<Equalizer>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<Exciter>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<Expander>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<Filter>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<Gate>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<GlobalShortcuts>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<KColorManager>("ee.ui", 8);
    QMetaType::fromType<KConfigBaseEE *>().id();
    QMetaType::fromType<KConfigSkeleton *>().id();
    QMetaType::fromType<KCoreConfigSkeleton *>().id();
    qmlRegisterEnum<KCoreConfigSkeleton::DisambiguateConstructor>("KCoreConfigSkeleton::DisambiguateConstructor");
    qmlRegisterTypesAndRevisions<LevelMeter>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<Limiter>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<ListModel>("ee.ui", 8);
    qmlRegisterEnum<ListModel::Roles>("ListModel::Roles");
    qmlRegisterTypesAndRevisions<Loudness>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<Maximizer>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<MultibandCompressor>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<MultibandGate>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<Pitch>("ee.ui", 8);
    QMetaType::fromType<PluginBase *>().id();
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    qmlRegisterTypesAndRevisions<RNNoise>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<Reverb>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<Speex>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<StereoTools>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<StreamInputEffects>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<StreamOutputEffects>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<Units>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<VoiceSuppressor>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<db::Manager>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<presets::Manager>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<pw::Manager>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<pw::models::Clients>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<pw::models::Modules>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<pw::models::Nodes>("ee.ui", 8);
    qmlRegisterEnum<pw::models::Nodes::Roles>("pw::models::Nodes::Roles");
    qmlRegisterTypesAndRevisions<tags::plugin_name::BaseName>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<tags::plugin_name::Model>("ee.ui", 8);
    qmlRegisterTypesAndRevisions<tags::plugin_package::Package>("ee.ui", 8);
    QT_WARNING_POP
    qmlRegisterModule("ee.ui", 8, 2);
}

static const QQmlModuleRegistration eeuiRegistration("ee.ui", qml_register_types_ee_ui);
