/****************************************************************************
** Meta object code from reading C++ file 'tags_plugin_name.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../easyeffects-8.2.8/src/tags_plugin_name.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tags_plugin_name.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4tags14plugin_package7PackageE_t {};
} // unnamed namespace

template <> constexpr inline auto tags::plugin_package::Package::qt_create_metaobjectdata<qt_meta_tag_ZN4tags14plugin_package7PackageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "tags::plugin_package::Package",
        "QML.Element",
        "PluginsPackage",
        "QML.Singleton",
        "true",
        "bs2b",
        "calf",
        "deepfilternet",
        "x42",
        "ebur128",
        "ee",
        "lsp",
        "mda",
        "rnnoise",
        "soundTouch",
        "speex",
        "webrtc",
        "zam",
        "zita"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bs2b'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'calf'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'deepfilternet'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'x42'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ebur128'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ee'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lsp'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mda'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rnnoise'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'soundTouch'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'speex'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'webrtc'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'zam'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'zita'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Package, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject tags::plugin_package::Package::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tags14plugin_package7PackageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tags14plugin_package7PackageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4tags14plugin_package7PackageE_t>.metaTypes,
    nullptr
} };

void tags::plugin_package::Package::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Package *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->bs2b; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->calf; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->deepfilternet; break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->x42; break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->ebur128; break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->ee; break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->lsp; break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->mda; break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->rnnoise; break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->soundTouch; break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->speex; break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->webrtc; break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->zam; break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->zita; break;
        default: break;
        }
    }
}

const QMetaObject *tags::plugin_package::Package::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *tags::plugin_package::Package::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tags14plugin_package7PackageE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int tags::plugin_package::Package::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN4tags11plugin_name8BaseNameE_t {};
} // unnamed namespace

template <> constexpr inline auto tags::plugin_name::BaseName::qt_create_metaobjectdata<qt_meta_tag_ZN4tags11plugin_name8BaseNameE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "tags::plugin_name::BaseName",
        "QML.Element",
        "PluginsBaseName",
        "QML.Singleton",
        "true",
        "autogain",
        "autotune",
        "bassEnhancer",
        "bassLoudness",
        "compressor",
        "convolver",
        "crossfeed",
        "crusher",
        "crystalizer",
        "deepfilternet",
        "deesser",
        "delay",
        "echoCanceller",
        "equalizer",
        "exciter",
        "expander",
        "filter",
        "gate",
        "voiceSuppressor",
        "crosstalkCanceller",
        "levelMeter",
        "limiter",
        "loudness",
        "maximizer",
        "multibandCompressor",
        "multibandGate",
        "outputLevel",
        "pitch",
        "speex",
        "spectrum",
        "reverb",
        "rnnoise",
        "stereoTools"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'autogain'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autotune'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bassEnhancer'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bassLoudness'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'compressor'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'convolver'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'crossfeed'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'crusher'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'crystalizer'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'deepfilternet'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'deesser'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'delay'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'echoCanceller'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'equalizer'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'exciter'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'expander'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'filter'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gate'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'voiceSuppressor'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'crosstalkCanceller'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'levelMeter'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'limiter'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'loudness'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maximizer'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'multibandCompressor'
        QtMocHelpers::PropertyData<QString>(29, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'multibandGate'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'outputLevel'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pitch'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'speex'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'spectrum'
        QtMocHelpers::PropertyData<QString>(34, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'reverb'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rnnoise'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stereoTools'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<BaseName, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject tags::plugin_name::BaseName::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tags11plugin_name8BaseNameE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tags11plugin_name8BaseNameE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4tags11plugin_name8BaseNameE_t>.metaTypes,
    nullptr
} };

void tags::plugin_name::BaseName::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BaseName *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->autogain; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->autotune; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->bassEnhancer; break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->bassLoudness; break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->compressor; break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->convolver; break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->crossfeed; break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->crusher; break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->crystalizer; break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->deepfilternet; break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->deesser; break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->delay; break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->echoCanceller; break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->equalizer; break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->exciter; break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->expander; break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->filter; break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->gate; break;
        case 18: *reinterpret_cast<QString*>(_v) = _t->voiceSuppressor; break;
        case 19: *reinterpret_cast<QString*>(_v) = _t->crosstalkCanceller; break;
        case 20: *reinterpret_cast<QString*>(_v) = _t->levelMeter; break;
        case 21: *reinterpret_cast<QString*>(_v) = _t->limiter; break;
        case 22: *reinterpret_cast<QString*>(_v) = _t->loudness; break;
        case 23: *reinterpret_cast<QString*>(_v) = _t->maximizer; break;
        case 24: *reinterpret_cast<QString*>(_v) = _t->multibandCompressor; break;
        case 25: *reinterpret_cast<QString*>(_v) = _t->multibandGate; break;
        case 26: *reinterpret_cast<QString*>(_v) = _t->outputLevel; break;
        case 27: *reinterpret_cast<QString*>(_v) = _t->pitch; break;
        case 28: *reinterpret_cast<QString*>(_v) = _t->speex; break;
        case 29: *reinterpret_cast<QString*>(_v) = _t->spectrum; break;
        case 30: *reinterpret_cast<QString*>(_v) = _t->reverb; break;
        case 31: *reinterpret_cast<QString*>(_v) = _t->rnnoise; break;
        case 32: *reinterpret_cast<QString*>(_v) = _t->stereoTools; break;
        default: break;
        }
    }
}

const QMetaObject *tags::plugin_name::BaseName::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *tags::plugin_name::BaseName::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tags11plugin_name8BaseNameE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int tags::plugin_name::BaseName::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN4tags11plugin_name5ModelE_t {};
} // unnamed namespace

template <> constexpr inline auto tags::plugin_name::Model::qt_create_metaobjectdata<qt_meta_tag_ZN4tags11plugin_name5ModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "tags::plugin_name::Model",
        "QML.Element",
        "PluginsNameModel",
        "QML.Singleton",
        "true",
        "getBaseNames",
        "",
        "translate",
        "baseName",
        "sortedNameModel",
        "QSortFilterProxyModel*"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'getBaseNames'
        QtMocHelpers::MethodData<QList<QString>()>(5, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'translate'
        QtMocHelpers::MethodData<QString(const QString &)>(7, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sortedNameModel'
        QtMocHelpers::PropertyData<QSortFilterProxyModel*>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Model, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject tags::plugin_name::Model::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tags11plugin_name5ModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tags11plugin_name5ModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4tags11plugin_name5ModelE_t>.metaTypes,
    nullptr
} };

void tags::plugin_name::Model::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Model *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QList<QString> _r = _t->getBaseNames();
            if (_a[0]) *reinterpret_cast<QList<QString>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->translate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QSortFilterProxyModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QSortFilterProxyModel**>(_v) = _t->proxyModel; break;
        default: break;
        }
    }
}

const QMetaObject *tags::plugin_name::Model::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *tags::plugin_name::Model::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4tags11plugin_name5ModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int tags::plugin_name::Model::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
