// This file is autogenerated. Changes will be overwritten.
#include "EJRQKI7XPS/moc_easyeffects_db.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_autogain.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_autotune.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_bass_enhancer.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_bass_loudness.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_compressor.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_convolver.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_crossfeed.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_crosstalk_canceller.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_crusher.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_crystalizer.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_deepfilternet.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_deesser.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_delay.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_echo_canceller.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_equalizer.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_equalizer_channel.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_exciter.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_expander.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_filter.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_gate.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_graph.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_level_meter.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_limiter.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_loudness.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_maximizer.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_multiband_compressor.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_multiband_gate.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_pitch.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_reverb.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_rnnoise.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_spectrum.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_speex.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_stereo_tools.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_streaminputs.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_streamoutputs.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_test_signals.cpp"
#include "EJRQKI7XPS/moc_easyeffects_db_voice_suppressor.cpp"
#include "EWIEGA46WW/moc_autogain.cpp"
#include "EWIEGA46WW/moc_autostart.cpp"
#include "EWIEGA46WW/moc_autotune.cpp"
#include "EWIEGA46WW/moc_bass_enhancer.cpp"
#include "EWIEGA46WW/moc_bass_loudness.cpp"
#include "EWIEGA46WW/moc_command_line_parser.cpp"
#include "EWIEGA46WW/moc_compressor.cpp"
#include "EWIEGA46WW/moc_convolver.cpp"
#include "EWIEGA46WW/moc_crossfeed.cpp"
#include "EWIEGA46WW/moc_crosstalk_canceller.cpp"
#include "EWIEGA46WW/moc_crusher.cpp"
#include "EWIEGA46WW/moc_crystalizer.cpp"
#include "EWIEGA46WW/moc_db_manager.cpp"
#include "EWIEGA46WW/moc_deepfilternet.cpp"
#include "EWIEGA46WW/moc_deesser.cpp"
#include "EWIEGA46WW/moc_delay.cpp"
#include "EWIEGA46WW/moc_echo_canceller.cpp"
#include "EWIEGA46WW/moc_effects_base.cpp"
#include "EWIEGA46WW/moc_equalizer.cpp"
#include "EWIEGA46WW/moc_exciter.cpp"
#include "EWIEGA46WW/moc_expander.cpp"
#include "EWIEGA46WW/moc_filter.cpp"
#include "EWIEGA46WW/moc_gate.cpp"
#include "EWIEGA46WW/moc_global_shortcuts.cpp"
#include "EWIEGA46WW/moc_kcolor_manager.cpp"
#include "EWIEGA46WW/moc_kconfig_base_ee.cpp"
#include "EWIEGA46WW/moc_level_meter.cpp"
#include "EWIEGA46WW/moc_limiter.cpp"
#include "EWIEGA46WW/moc_local_client.cpp"
#include "EWIEGA46WW/moc_local_server.cpp"
#include "EWIEGA46WW/moc_loudness.cpp"
#include "EWIEGA46WW/moc_maximizer.cpp"
#include "EWIEGA46WW/moc_multiband_compressor.cpp"
#include "EWIEGA46WW/moc_multiband_gate.cpp"
#include "EWIEGA46WW/moc_pitch.cpp"
#include "EWIEGA46WW/moc_plugin_base.cpp"
#include "EWIEGA46WW/moc_presets_autoload_manager.cpp"
#include "EWIEGA46WW/moc_presets_community_manager.cpp"
#include "EWIEGA46WW/moc_presets_irs_manager.cpp"
#include "EWIEGA46WW/moc_presets_list_model.cpp"
#include "EWIEGA46WW/moc_presets_manager.cpp"
#include "EWIEGA46WW/moc_presets_rnnoise_manager.cpp"
#include "EWIEGA46WW/moc_pw_client_manager.cpp"
#include "EWIEGA46WW/moc_pw_device_manager.cpp"
#include "EWIEGA46WW/moc_pw_link_manager.cpp"
#include "EWIEGA46WW/moc_pw_manager.cpp"
#include "EWIEGA46WW/moc_pw_metadata_manager.cpp"
#include "EWIEGA46WW/moc_pw_model_clients.cpp"
#include "EWIEGA46WW/moc_pw_model_modules.cpp"
#include "EWIEGA46WW/moc_pw_model_nodes.cpp"
#include "EWIEGA46WW/moc_pw_module_manager.cpp"
#include "EWIEGA46WW/moc_pw_node_manager.cpp"
#include "EWIEGA46WW/moc_reverb.cpp"
#include "EWIEGA46WW/moc_rnnoise.cpp"
#include "EWIEGA46WW/moc_speex.cpp"
#include "EWIEGA46WW/moc_stereo_tools.cpp"
#include "EWIEGA46WW/moc_stream_input_effects.cpp"
#include "EWIEGA46WW/moc_stream_output_effects.cpp"
#include "EWIEGA46WW/moc_tags_plugin_name.cpp"
#include "EWIEGA46WW/moc_test_signals.cpp"
#include "EWIEGA46WW/moc_units.cpp"
#include "EWIEGA46WW/moc_voice_suppressor.cpp"
