/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db_compressor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db_compressor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db_compressor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12DbCompressorE_t {};
} // unnamed namespace

template <> constexpr inline auto DbCompressor::qt_create_metaobjectdata<qt_meta_tag_ZN12DbCompressorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbCompressor",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "bypassChanged",
        "inputGainChanged",
        "outputGainChanged",
        "dryChanged",
        "wetChanged",
        "modeLabelsChanged",
        "modeChanged",
        "attackChanged",
        "releaseChanged",
        "releaseThresholdChanged",
        "thresholdChanged",
        "ratioChanged",
        "kneeChanged",
        "makeupChanged",
        "boostAmountChanged",
        "boostThresholdChanged",
        "sidechainListenChanged",
        "sidechainTypeLabelsChanged",
        "sidechainTypeChanged",
        "sidechainModeLabelsChanged",
        "sidechainModeChanged",
        "stereoSplitChanged",
        "sidechainSourceLabelsChanged",
        "sidechainSourceChanged",
        "stereoSplitSourceLabelsChanged",
        "stereoSplitSourceChanged",
        "sidechainPreampChanged",
        "sidechainReactivityChanged",
        "sidechainLookaheadChanged",
        "hpfModeLabelsChanged",
        "hpfModeChanged",
        "hpfFrequencyChanged",
        "lpfModeLabelsChanged",
        "lpfModeChanged",
        "lpfFrequencyChanged",
        "sidechainInputDeviceChanged",
        "inputToSidechainChanged",
        "inputToLinkChanged",
        "sidechainToInputChanged",
        "sidechainToLinkChanged",
        "linkToSidechainChanged",
        "linkToInputChanged",
        "bypass",
        "isBypassImmutable",
        "defaultBypassValue",
        "inputGain",
        "isInputGainImmutable",
        "defaultInputGainValue",
        "outputGain",
        "isOutputGainImmutable",
        "defaultOutputGainValue",
        "dry",
        "isDryImmutable",
        "defaultDryValue",
        "wet",
        "isWetImmutable",
        "defaultWetValue",
        "modeLabels",
        "isModeLabelsImmutable",
        "defaultModeLabelsValue",
        "mode",
        "isModeImmutable",
        "defaultModeValue",
        "attack",
        "isAttackImmutable",
        "defaultAttackValue",
        "release",
        "isReleaseImmutable",
        "defaultReleaseValue",
        "releaseThreshold",
        "isReleaseThresholdImmutable",
        "defaultReleaseThresholdValue",
        "threshold",
        "isThresholdImmutable",
        "defaultThresholdValue",
        "ratio",
        "isRatioImmutable",
        "defaultRatioValue",
        "knee",
        "isKneeImmutable",
        "defaultKneeValue",
        "makeup",
        "isMakeupImmutable",
        "defaultMakeupValue",
        "boostAmount",
        "isBoostAmountImmutable",
        "defaultBoostAmountValue",
        "boostThreshold",
        "isBoostThresholdImmutable",
        "defaultBoostThresholdValue",
        "sidechainListen",
        "isSidechainListenImmutable",
        "defaultSidechainListenValue",
        "sidechainTypeLabels",
        "isSidechainTypeLabelsImmutable",
        "defaultSidechainTypeLabelsValue",
        "sidechainType",
        "isSidechainTypeImmutable",
        "defaultSidechainTypeValue",
        "sidechainModeLabels",
        "isSidechainModeLabelsImmutable",
        "defaultSidechainModeLabelsValue",
        "sidechainMode",
        "isSidechainModeImmutable",
        "defaultSidechainModeValue",
        "stereoSplit",
        "isStereoSplitImmutable",
        "defaultStereoSplitValue",
        "sidechainSourceLabels",
        "isSidechainSourceLabelsImmutable",
        "defaultSidechainSourceLabelsValue",
        "sidechainSource",
        "isSidechainSourceImmutable",
        "defaultSidechainSourceValue",
        "stereoSplitSourceLabels",
        "isStereoSplitSourceLabelsImmutable",
        "defaultStereoSplitSourceLabelsValue",
        "stereoSplitSource",
        "isStereoSplitSourceImmutable",
        "defaultStereoSplitSourceValue",
        "sidechainPreamp",
        "isSidechainPreampImmutable",
        "defaultSidechainPreampValue",
        "sidechainReactivity",
        "isSidechainReactivityImmutable",
        "defaultSidechainReactivityValue",
        "sidechainLookahead",
        "isSidechainLookaheadImmutable",
        "defaultSidechainLookaheadValue",
        "hpfModeLabels",
        "isHpfModeLabelsImmutable",
        "defaultHpfModeLabelsValue",
        "hpfMode",
        "isHpfModeImmutable",
        "defaultHpfModeValue",
        "hpfFrequency",
        "isHpfFrequencyImmutable",
        "defaultHpfFrequencyValue",
        "lpfModeLabels",
        "isLpfModeLabelsImmutable",
        "defaultLpfModeLabelsValue",
        "lpfMode",
        "isLpfModeImmutable",
        "defaultLpfModeValue",
        "lpfFrequency",
        "isLpfFrequencyImmutable",
        "defaultLpfFrequencyValue",
        "sidechainInputDevice",
        "isSidechainInputDeviceImmutable",
        "defaultSidechainInputDeviceValue",
        "inputToSidechain",
        "isInputToSidechainImmutable",
        "defaultInputToSidechainValue",
        "inputToLink",
        "isInputToLinkImmutable",
        "defaultInputToLinkValue",
        "sidechainToInput",
        "isSidechainToInputImmutable",
        "defaultSidechainToInputValue",
        "sidechainToLink",
        "isSidechainToLinkImmutable",
        "defaultSidechainToLinkValue",
        "linkToSidechain",
        "isLinkToSidechainImmutable",
        "defaultLinkToSidechainValue",
        "linkToInput",
        "isLinkToInputImmutable",
        "defaultLinkToInputValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bypassChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputGainChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputGainChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dryChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wetChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeLabelsChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'attackChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'releaseChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'releaseThresholdChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'thresholdChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ratioChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'kneeChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'makeupChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'boostAmountChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'boostThresholdChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainListenChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainTypeLabelsChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainTypeChanged'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainModeLabelsChanged'
        QtMocHelpers::SignalData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainModeChanged'
        QtMocHelpers::SignalData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stereoSplitChanged'
        QtMocHelpers::SignalData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainSourceLabelsChanged'
        QtMocHelpers::SignalData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainSourceChanged'
        QtMocHelpers::SignalData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stereoSplitSourceLabelsChanged'
        QtMocHelpers::SignalData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stereoSplitSourceChanged'
        QtMocHelpers::SignalData<void()>(32, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainPreampChanged'
        QtMocHelpers::SignalData<void()>(33, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainReactivityChanged'
        QtMocHelpers::SignalData<void()>(34, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainLookaheadChanged'
        QtMocHelpers::SignalData<void()>(35, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hpfModeLabelsChanged'
        QtMocHelpers::SignalData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hpfModeChanged'
        QtMocHelpers::SignalData<void()>(37, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hpfFrequencyChanged'
        QtMocHelpers::SignalData<void()>(38, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lpfModeLabelsChanged'
        QtMocHelpers::SignalData<void()>(39, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lpfModeChanged'
        QtMocHelpers::SignalData<void()>(40, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lpfFrequencyChanged'
        QtMocHelpers::SignalData<void()>(41, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainInputDeviceChanged'
        QtMocHelpers::SignalData<void()>(42, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputToSidechainChanged'
        QtMocHelpers::SignalData<void()>(43, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputToLinkChanged'
        QtMocHelpers::SignalData<void()>(44, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainToInputChanged'
        QtMocHelpers::SignalData<void()>(45, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainToLinkChanged'
        QtMocHelpers::SignalData<void()>(46, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'linkToSidechainChanged'
        QtMocHelpers::SignalData<void()>(47, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'linkToInputChanged'
        QtMocHelpers::SignalData<void()>(48, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bypass'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isBypassImmutable'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassValue'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputGain'
        QtMocHelpers::PropertyData<double>(52, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isInputGainImmutable'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputGainValue'
        QtMocHelpers::PropertyData<double>(54, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'outputGain'
        QtMocHelpers::PropertyData<double>(55, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isOutputGainImmutable'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOutputGainValue'
        QtMocHelpers::PropertyData<double>(57, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dry'
        QtMocHelpers::PropertyData<double>(58, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isDryImmutable'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDryValue'
        QtMocHelpers::PropertyData<double>(60, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'wet'
        QtMocHelpers::PropertyData<double>(61, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isWetImmutable'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWetValue'
        QtMocHelpers::PropertyData<double>(63, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'modeLabels'
        QtMocHelpers::PropertyData<QStringList>(64, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isModeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultModeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(66, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mode'
        QtMocHelpers::PropertyData<int>(67, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isModeImmutable'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultModeValue'
        QtMocHelpers::PropertyData<int>(69, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'attack'
        QtMocHelpers::PropertyData<double>(70, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isAttackImmutable'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAttackValue'
        QtMocHelpers::PropertyData<double>(72, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'release'
        QtMocHelpers::PropertyData<double>(73, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isReleaseImmutable'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultReleaseValue'
        QtMocHelpers::PropertyData<double>(75, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'releaseThreshold'
        QtMocHelpers::PropertyData<double>(76, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isReleaseThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(77, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultReleaseThresholdValue'
        QtMocHelpers::PropertyData<double>(78, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'threshold'
        QtMocHelpers::PropertyData<double>(79, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(80, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultThresholdValue'
        QtMocHelpers::PropertyData<double>(81, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ratio'
        QtMocHelpers::PropertyData<double>(82, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isRatioImmutable'
        QtMocHelpers::PropertyData<bool>(83, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRatioValue'
        QtMocHelpers::PropertyData<double>(84, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'knee'
        QtMocHelpers::PropertyData<double>(85, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isKneeImmutable'
        QtMocHelpers::PropertyData<bool>(86, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultKneeValue'
        QtMocHelpers::PropertyData<double>(87, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'makeup'
        QtMocHelpers::PropertyData<double>(88, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isMakeupImmutable'
        QtMocHelpers::PropertyData<bool>(89, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMakeupValue'
        QtMocHelpers::PropertyData<double>(90, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'boostAmount'
        QtMocHelpers::PropertyData<double>(91, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isBoostAmountImmutable'
        QtMocHelpers::PropertyData<bool>(92, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBoostAmountValue'
        QtMocHelpers::PropertyData<double>(93, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'boostThreshold'
        QtMocHelpers::PropertyData<double>(94, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isBoostThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(95, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBoostThresholdValue'
        QtMocHelpers::PropertyData<double>(96, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainListen'
        QtMocHelpers::PropertyData<bool>(97, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isSidechainListenImmutable'
        QtMocHelpers::PropertyData<bool>(98, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainListenValue'
        QtMocHelpers::PropertyData<bool>(99, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainTypeLabels'
        QtMocHelpers::PropertyData<QStringList>(100, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'isSidechainTypeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(101, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainTypeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(102, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainType'
        QtMocHelpers::PropertyData<int>(103, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'isSidechainTypeImmutable'
        QtMocHelpers::PropertyData<bool>(104, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainTypeValue'
        QtMocHelpers::PropertyData<int>(105, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainModeLabels'
        QtMocHelpers::PropertyData<QStringList>(106, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'isSidechainModeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(107, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainModeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(108, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainMode'
        QtMocHelpers::PropertyData<int>(109, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'isSidechainModeImmutable'
        QtMocHelpers::PropertyData<bool>(110, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainModeValue'
        QtMocHelpers::PropertyData<int>(111, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stereoSplit'
        QtMocHelpers::PropertyData<bool>(112, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'isStereoSplitImmutable'
        QtMocHelpers::PropertyData<bool>(113, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultStereoSplitValue'
        QtMocHelpers::PropertyData<bool>(114, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainSourceLabels'
        QtMocHelpers::PropertyData<QStringList>(115, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'isSidechainSourceLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(116, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainSourceLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(117, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainSource'
        QtMocHelpers::PropertyData<int>(118, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'isSidechainSourceImmutable'
        QtMocHelpers::PropertyData<bool>(119, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainSourceValue'
        QtMocHelpers::PropertyData<int>(120, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stereoSplitSourceLabels'
        QtMocHelpers::PropertyData<QStringList>(121, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'isStereoSplitSourceLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(122, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultStereoSplitSourceLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(123, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stereoSplitSource'
        QtMocHelpers::PropertyData<int>(124, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 25),
        // property 'isStereoSplitSourceImmutable'
        QtMocHelpers::PropertyData<bool>(125, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultStereoSplitSourceValue'
        QtMocHelpers::PropertyData<int>(126, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainPreamp'
        QtMocHelpers::PropertyData<double>(127, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 26),
        // property 'isSidechainPreampImmutable'
        QtMocHelpers::PropertyData<bool>(128, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainPreampValue'
        QtMocHelpers::PropertyData<double>(129, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainReactivity'
        QtMocHelpers::PropertyData<double>(130, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 27),
        // property 'isSidechainReactivityImmutable'
        QtMocHelpers::PropertyData<bool>(131, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainReactivityValue'
        QtMocHelpers::PropertyData<double>(132, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainLookahead'
        QtMocHelpers::PropertyData<double>(133, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 28),
        // property 'isSidechainLookaheadImmutable'
        QtMocHelpers::PropertyData<bool>(134, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainLookaheadValue'
        QtMocHelpers::PropertyData<double>(135, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hpfModeLabels'
        QtMocHelpers::PropertyData<QStringList>(136, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 29),
        // property 'isHpfModeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(137, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultHpfModeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(138, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hpfMode'
        QtMocHelpers::PropertyData<int>(139, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 30),
        // property 'isHpfModeImmutable'
        QtMocHelpers::PropertyData<bool>(140, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultHpfModeValue'
        QtMocHelpers::PropertyData<int>(141, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hpfFrequency'
        QtMocHelpers::PropertyData<double>(142, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 31),
        // property 'isHpfFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(143, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultHpfFrequencyValue'
        QtMocHelpers::PropertyData<double>(144, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lpfModeLabels'
        QtMocHelpers::PropertyData<QStringList>(145, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 32),
        // property 'isLpfModeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(146, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLpfModeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(147, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lpfMode'
        QtMocHelpers::PropertyData<int>(148, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 33),
        // property 'isLpfModeImmutable'
        QtMocHelpers::PropertyData<bool>(149, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLpfModeValue'
        QtMocHelpers::PropertyData<int>(150, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lpfFrequency'
        QtMocHelpers::PropertyData<double>(151, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 34),
        // property 'isLpfFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(152, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLpfFrequencyValue'
        QtMocHelpers::PropertyData<double>(153, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainInputDevice'
        QtMocHelpers::PropertyData<QString>(154, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 35),
        // property 'isSidechainInputDeviceImmutable'
        QtMocHelpers::PropertyData<bool>(155, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainInputDeviceValue'
        QtMocHelpers::PropertyData<QString>(156, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputToSidechain'
        QtMocHelpers::PropertyData<double>(157, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 36),
        // property 'isInputToSidechainImmutable'
        QtMocHelpers::PropertyData<bool>(158, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputToSidechainValue'
        QtMocHelpers::PropertyData<double>(159, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputToLink'
        QtMocHelpers::PropertyData<double>(160, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 37),
        // property 'isInputToLinkImmutable'
        QtMocHelpers::PropertyData<bool>(161, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputToLinkValue'
        QtMocHelpers::PropertyData<double>(162, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainToInput'
        QtMocHelpers::PropertyData<double>(163, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 38),
        // property 'isSidechainToInputImmutable'
        QtMocHelpers::PropertyData<bool>(164, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainToInputValue'
        QtMocHelpers::PropertyData<double>(165, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainToLink'
        QtMocHelpers::PropertyData<double>(166, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 39),
        // property 'isSidechainToLinkImmutable'
        QtMocHelpers::PropertyData<bool>(167, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainToLinkValue'
        QtMocHelpers::PropertyData<double>(168, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'linkToSidechain'
        QtMocHelpers::PropertyData<double>(169, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 40),
        // property 'isLinkToSidechainImmutable'
        QtMocHelpers::PropertyData<bool>(170, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLinkToSidechainValue'
        QtMocHelpers::PropertyData<double>(171, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'linkToInput'
        QtMocHelpers::PropertyData<double>(172, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 41),
        // property 'isLinkToInputImmutable'
        QtMocHelpers::PropertyData<bool>(173, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLinkToInputValue'
        QtMocHelpers::PropertyData<double>(174, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DbCompressor, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbCompressor::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12DbCompressorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12DbCompressorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12DbCompressorE_t>.metaTypes,
    nullptr
} };

void DbCompressor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbCompressor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bypassChanged(); break;
        case 1: _t->inputGainChanged(); break;
        case 2: _t->outputGainChanged(); break;
        case 3: _t->dryChanged(); break;
        case 4: _t->wetChanged(); break;
        case 5: _t->modeLabelsChanged(); break;
        case 6: _t->modeChanged(); break;
        case 7: _t->attackChanged(); break;
        case 8: _t->releaseChanged(); break;
        case 9: _t->releaseThresholdChanged(); break;
        case 10: _t->thresholdChanged(); break;
        case 11: _t->ratioChanged(); break;
        case 12: _t->kneeChanged(); break;
        case 13: _t->makeupChanged(); break;
        case 14: _t->boostAmountChanged(); break;
        case 15: _t->boostThresholdChanged(); break;
        case 16: _t->sidechainListenChanged(); break;
        case 17: _t->sidechainTypeLabelsChanged(); break;
        case 18: _t->sidechainTypeChanged(); break;
        case 19: _t->sidechainModeLabelsChanged(); break;
        case 20: _t->sidechainModeChanged(); break;
        case 21: _t->stereoSplitChanged(); break;
        case 22: _t->sidechainSourceLabelsChanged(); break;
        case 23: _t->sidechainSourceChanged(); break;
        case 24: _t->stereoSplitSourceLabelsChanged(); break;
        case 25: _t->stereoSplitSourceChanged(); break;
        case 26: _t->sidechainPreampChanged(); break;
        case 27: _t->sidechainReactivityChanged(); break;
        case 28: _t->sidechainLookaheadChanged(); break;
        case 29: _t->hpfModeLabelsChanged(); break;
        case 30: _t->hpfModeChanged(); break;
        case 31: _t->hpfFrequencyChanged(); break;
        case 32: _t->lpfModeLabelsChanged(); break;
        case 33: _t->lpfModeChanged(); break;
        case 34: _t->lpfFrequencyChanged(); break;
        case 35: _t->sidechainInputDeviceChanged(); break;
        case 36: _t->inputToSidechainChanged(); break;
        case 37: _t->inputToLinkChanged(); break;
        case 38: _t->sidechainToInputChanged(); break;
        case 39: _t->sidechainToLinkChanged(); break;
        case 40: _t->linkToSidechainChanged(); break;
        case 41: _t->linkToInputChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::bypassChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::inputGainChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::outputGainChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::dryChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::wetChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::modeLabelsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::modeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::attackChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::releaseChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::releaseThresholdChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::thresholdChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::ratioChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::kneeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::makeupChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::boostAmountChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::boostThresholdChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::sidechainListenChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::sidechainTypeLabelsChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::sidechainTypeChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::sidechainModeLabelsChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::sidechainModeChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::stereoSplitChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::sidechainSourceLabelsChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::sidechainSourceChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::stereoSplitSourceLabelsChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::stereoSplitSourceChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::sidechainPreampChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::sidechainReactivityChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::sidechainLookaheadChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::hpfModeLabelsChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::hpfModeChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::hpfFrequencyChanged, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::lpfModeLabelsChanged, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::lpfModeChanged, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::lpfFrequencyChanged, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::sidechainInputDeviceChanged, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::inputToSidechainChanged, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::inputToLinkChanged, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::sidechainToInputChanged, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::sidechainToLinkChanged, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::linkToSidechainChanged, 40))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbCompressor::*)()>(_a, &DbCompressor::linkToInputChanged, 41))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bypass(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isBypassImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultBypassValue(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->inputGain(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isInputGainImmutable(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->defaultInputGainValue(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->outputGain(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isOutputGainImmutable(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->defaultOutputGainValue(); break;
        case 9: *reinterpret_cast<double*>(_v) = _t->dry(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isDryImmutable(); break;
        case 11: *reinterpret_cast<double*>(_v) = _t->defaultDryValue(); break;
        case 12: *reinterpret_cast<double*>(_v) = _t->wet(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isWetImmutable(); break;
        case 14: *reinterpret_cast<double*>(_v) = _t->defaultWetValue(); break;
        case 15: *reinterpret_cast<QStringList*>(_v) = _t->modeLabels(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isModeLabelsImmutable(); break;
        case 17: *reinterpret_cast<QStringList*>(_v) = _t->defaultModeLabelsValue(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->mode(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isModeImmutable(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->defaultModeValue(); break;
        case 21: *reinterpret_cast<double*>(_v) = _t->attack(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isAttackImmutable(); break;
        case 23: *reinterpret_cast<double*>(_v) = _t->defaultAttackValue(); break;
        case 24: *reinterpret_cast<double*>(_v) = _t->release(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isReleaseImmutable(); break;
        case 26: *reinterpret_cast<double*>(_v) = _t->defaultReleaseValue(); break;
        case 27: *reinterpret_cast<double*>(_v) = _t->releaseThreshold(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isReleaseThresholdImmutable(); break;
        case 29: *reinterpret_cast<double*>(_v) = _t->defaultReleaseThresholdValue(); break;
        case 30: *reinterpret_cast<double*>(_v) = _t->threshold(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isThresholdImmutable(); break;
        case 32: *reinterpret_cast<double*>(_v) = _t->defaultThresholdValue(); break;
        case 33: *reinterpret_cast<double*>(_v) = _t->ratio(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isRatioImmutable(); break;
        case 35: *reinterpret_cast<double*>(_v) = _t->defaultRatioValue(); break;
        case 36: *reinterpret_cast<double*>(_v) = _t->knee(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isKneeImmutable(); break;
        case 38: *reinterpret_cast<double*>(_v) = _t->defaultKneeValue(); break;
        case 39: *reinterpret_cast<double*>(_v) = _t->makeup(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->isMakeupImmutable(); break;
        case 41: *reinterpret_cast<double*>(_v) = _t->defaultMakeupValue(); break;
        case 42: *reinterpret_cast<double*>(_v) = _t->boostAmount(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->isBoostAmountImmutable(); break;
        case 44: *reinterpret_cast<double*>(_v) = _t->defaultBoostAmountValue(); break;
        case 45: *reinterpret_cast<double*>(_v) = _t->boostThreshold(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->isBoostThresholdImmutable(); break;
        case 47: *reinterpret_cast<double*>(_v) = _t->defaultBoostThresholdValue(); break;
        case 48: *reinterpret_cast<bool*>(_v) = _t->sidechainListen(); break;
        case 49: *reinterpret_cast<bool*>(_v) = _t->isSidechainListenImmutable(); break;
        case 50: *reinterpret_cast<bool*>(_v) = _t->defaultSidechainListenValue(); break;
        case 51: *reinterpret_cast<QStringList*>(_v) = _t->sidechainTypeLabels(); break;
        case 52: *reinterpret_cast<bool*>(_v) = _t->isSidechainTypeLabelsImmutable(); break;
        case 53: *reinterpret_cast<QStringList*>(_v) = _t->defaultSidechainTypeLabelsValue(); break;
        case 54: *reinterpret_cast<int*>(_v) = _t->sidechainType(); break;
        case 55: *reinterpret_cast<bool*>(_v) = _t->isSidechainTypeImmutable(); break;
        case 56: *reinterpret_cast<int*>(_v) = _t->defaultSidechainTypeValue(); break;
        case 57: *reinterpret_cast<QStringList*>(_v) = _t->sidechainModeLabels(); break;
        case 58: *reinterpret_cast<bool*>(_v) = _t->isSidechainModeLabelsImmutable(); break;
        case 59: *reinterpret_cast<QStringList*>(_v) = _t->defaultSidechainModeLabelsValue(); break;
        case 60: *reinterpret_cast<int*>(_v) = _t->sidechainMode(); break;
        case 61: *reinterpret_cast<bool*>(_v) = _t->isSidechainModeImmutable(); break;
        case 62: *reinterpret_cast<int*>(_v) = _t->defaultSidechainModeValue(); break;
        case 63: *reinterpret_cast<bool*>(_v) = _t->stereoSplit(); break;
        case 64: *reinterpret_cast<bool*>(_v) = _t->isStereoSplitImmutable(); break;
        case 65: *reinterpret_cast<bool*>(_v) = _t->defaultStereoSplitValue(); break;
        case 66: *reinterpret_cast<QStringList*>(_v) = _t->sidechainSourceLabels(); break;
        case 67: *reinterpret_cast<bool*>(_v) = _t->isSidechainSourceLabelsImmutable(); break;
        case 68: *reinterpret_cast<QStringList*>(_v) = _t->defaultSidechainSourceLabelsValue(); break;
        case 69: *reinterpret_cast<int*>(_v) = _t->sidechainSource(); break;
        case 70: *reinterpret_cast<bool*>(_v) = _t->isSidechainSourceImmutable(); break;
        case 71: *reinterpret_cast<int*>(_v) = _t->defaultSidechainSourceValue(); break;
        case 72: *reinterpret_cast<QStringList*>(_v) = _t->stereoSplitSourceLabels(); break;
        case 73: *reinterpret_cast<bool*>(_v) = _t->isStereoSplitSourceLabelsImmutable(); break;
        case 74: *reinterpret_cast<QStringList*>(_v) = _t->defaultStereoSplitSourceLabelsValue(); break;
        case 75: *reinterpret_cast<int*>(_v) = _t->stereoSplitSource(); break;
        case 76: *reinterpret_cast<bool*>(_v) = _t->isStereoSplitSourceImmutable(); break;
        case 77: *reinterpret_cast<int*>(_v) = _t->defaultStereoSplitSourceValue(); break;
        case 78: *reinterpret_cast<double*>(_v) = _t->sidechainPreamp(); break;
        case 79: *reinterpret_cast<bool*>(_v) = _t->isSidechainPreampImmutable(); break;
        case 80: *reinterpret_cast<double*>(_v) = _t->defaultSidechainPreampValue(); break;
        case 81: *reinterpret_cast<double*>(_v) = _t->sidechainReactivity(); break;
        case 82: *reinterpret_cast<bool*>(_v) = _t->isSidechainReactivityImmutable(); break;
        case 83: *reinterpret_cast<double*>(_v) = _t->defaultSidechainReactivityValue(); break;
        case 84: *reinterpret_cast<double*>(_v) = _t->sidechainLookahead(); break;
        case 85: *reinterpret_cast<bool*>(_v) = _t->isSidechainLookaheadImmutable(); break;
        case 86: *reinterpret_cast<double*>(_v) = _t->defaultSidechainLookaheadValue(); break;
        case 87: *reinterpret_cast<QStringList*>(_v) = _t->hpfModeLabels(); break;
        case 88: *reinterpret_cast<bool*>(_v) = _t->isHpfModeLabelsImmutable(); break;
        case 89: *reinterpret_cast<QStringList*>(_v) = _t->defaultHpfModeLabelsValue(); break;
        case 90: *reinterpret_cast<int*>(_v) = _t->hpfMode(); break;
        case 91: *reinterpret_cast<bool*>(_v) = _t->isHpfModeImmutable(); break;
        case 92: *reinterpret_cast<int*>(_v) = _t->defaultHpfModeValue(); break;
        case 93: *reinterpret_cast<double*>(_v) = _t->hpfFrequency(); break;
        case 94: *reinterpret_cast<bool*>(_v) = _t->isHpfFrequencyImmutable(); break;
        case 95: *reinterpret_cast<double*>(_v) = _t->defaultHpfFrequencyValue(); break;
        case 96: *reinterpret_cast<QStringList*>(_v) = _t->lpfModeLabels(); break;
        case 97: *reinterpret_cast<bool*>(_v) = _t->isLpfModeLabelsImmutable(); break;
        case 98: *reinterpret_cast<QStringList*>(_v) = _t->defaultLpfModeLabelsValue(); break;
        case 99: *reinterpret_cast<int*>(_v) = _t->lpfMode(); break;
        case 100: *reinterpret_cast<bool*>(_v) = _t->isLpfModeImmutable(); break;
        case 101: *reinterpret_cast<int*>(_v) = _t->defaultLpfModeValue(); break;
        case 102: *reinterpret_cast<double*>(_v) = _t->lpfFrequency(); break;
        case 103: *reinterpret_cast<bool*>(_v) = _t->isLpfFrequencyImmutable(); break;
        case 104: *reinterpret_cast<double*>(_v) = _t->defaultLpfFrequencyValue(); break;
        case 105: *reinterpret_cast<QString*>(_v) = _t->sidechainInputDevice(); break;
        case 106: *reinterpret_cast<bool*>(_v) = _t->isSidechainInputDeviceImmutable(); break;
        case 107: *reinterpret_cast<QString*>(_v) = _t->defaultSidechainInputDeviceValue(); break;
        case 108: *reinterpret_cast<double*>(_v) = _t->inputToSidechain(); break;
        case 109: *reinterpret_cast<bool*>(_v) = _t->isInputToSidechainImmutable(); break;
        case 110: *reinterpret_cast<double*>(_v) = _t->defaultInputToSidechainValue(); break;
        case 111: *reinterpret_cast<double*>(_v) = _t->inputToLink(); break;
        case 112: *reinterpret_cast<bool*>(_v) = _t->isInputToLinkImmutable(); break;
        case 113: *reinterpret_cast<double*>(_v) = _t->defaultInputToLinkValue(); break;
        case 114: *reinterpret_cast<double*>(_v) = _t->sidechainToInput(); break;
        case 115: *reinterpret_cast<bool*>(_v) = _t->isSidechainToInputImmutable(); break;
        case 116: *reinterpret_cast<double*>(_v) = _t->defaultSidechainToInputValue(); break;
        case 117: *reinterpret_cast<double*>(_v) = _t->sidechainToLink(); break;
        case 118: *reinterpret_cast<bool*>(_v) = _t->isSidechainToLinkImmutable(); break;
        case 119: *reinterpret_cast<double*>(_v) = _t->defaultSidechainToLinkValue(); break;
        case 120: *reinterpret_cast<double*>(_v) = _t->linkToSidechain(); break;
        case 121: *reinterpret_cast<bool*>(_v) = _t->isLinkToSidechainImmutable(); break;
        case 122: *reinterpret_cast<double*>(_v) = _t->defaultLinkToSidechainValue(); break;
        case 123: *reinterpret_cast<double*>(_v) = _t->linkToInput(); break;
        case 124: *reinterpret_cast<bool*>(_v) = _t->isLinkToInputImmutable(); break;
        case 125: *reinterpret_cast<double*>(_v) = _t->defaultLinkToInputValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBypass(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setInputGain(*reinterpret_cast<double*>(_v)); break;
        case 6: _t->setOutputGain(*reinterpret_cast<double*>(_v)); break;
        case 9: _t->setDry(*reinterpret_cast<double*>(_v)); break;
        case 12: _t->setWet(*reinterpret_cast<double*>(_v)); break;
        case 15: _t->setModeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 18: _t->setMode(*reinterpret_cast<int*>(_v)); break;
        case 21: _t->setAttack(*reinterpret_cast<double*>(_v)); break;
        case 24: _t->setRelease(*reinterpret_cast<double*>(_v)); break;
        case 27: _t->setReleaseThreshold(*reinterpret_cast<double*>(_v)); break;
        case 30: _t->setThreshold(*reinterpret_cast<double*>(_v)); break;
        case 33: _t->setRatio(*reinterpret_cast<double*>(_v)); break;
        case 36: _t->setKnee(*reinterpret_cast<double*>(_v)); break;
        case 39: _t->setMakeup(*reinterpret_cast<double*>(_v)); break;
        case 42: _t->setBoostAmount(*reinterpret_cast<double*>(_v)); break;
        case 45: _t->setBoostThreshold(*reinterpret_cast<double*>(_v)); break;
        case 48: _t->setSidechainListen(*reinterpret_cast<bool*>(_v)); break;
        case 51: _t->setSidechainTypeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 54: _t->setSidechainType(*reinterpret_cast<int*>(_v)); break;
        case 57: _t->setSidechainModeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 60: _t->setSidechainMode(*reinterpret_cast<int*>(_v)); break;
        case 63: _t->setStereoSplit(*reinterpret_cast<bool*>(_v)); break;
        case 66: _t->setSidechainSourceLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 69: _t->setSidechainSource(*reinterpret_cast<int*>(_v)); break;
        case 72: _t->setStereoSplitSourceLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 75: _t->setStereoSplitSource(*reinterpret_cast<int*>(_v)); break;
        case 78: _t->setSidechainPreamp(*reinterpret_cast<double*>(_v)); break;
        case 81: _t->setSidechainReactivity(*reinterpret_cast<double*>(_v)); break;
        case 84: _t->setSidechainLookahead(*reinterpret_cast<double*>(_v)); break;
        case 87: _t->setHpfModeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 90: _t->setHpfMode(*reinterpret_cast<int*>(_v)); break;
        case 93: _t->setHpfFrequency(*reinterpret_cast<double*>(_v)); break;
        case 96: _t->setLpfModeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 99: _t->setLpfMode(*reinterpret_cast<int*>(_v)); break;
        case 102: _t->setLpfFrequency(*reinterpret_cast<double*>(_v)); break;
        case 105: _t->setSidechainInputDevice(*reinterpret_cast<QString*>(_v)); break;
        case 108: _t->setInputToSidechain(*reinterpret_cast<double*>(_v)); break;
        case 111: _t->setInputToLink(*reinterpret_cast<double*>(_v)); break;
        case 114: _t->setSidechainToInput(*reinterpret_cast<double*>(_v)); break;
        case 117: _t->setSidechainToLink(*reinterpret_cast<double*>(_v)); break;
        case 120: _t->setLinkToSidechain(*reinterpret_cast<double*>(_v)); break;
        case 123: _t->setLinkToInput(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbCompressor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbCompressor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12DbCompressorE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbCompressor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 42)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 42;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 42)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 42;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 126;
    }
    return _id;
}

// SIGNAL 0
void DbCompressor::bypassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbCompressor::inputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbCompressor::outputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbCompressor::dryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DbCompressor::wetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DbCompressor::modeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DbCompressor::modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DbCompressor::attackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DbCompressor::releaseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DbCompressor::releaseThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DbCompressor::thresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DbCompressor::ratioChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void DbCompressor::kneeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void DbCompressor::makeupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void DbCompressor::boostAmountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void DbCompressor::boostThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void DbCompressor::sidechainListenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void DbCompressor::sidechainTypeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void DbCompressor::sidechainTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void DbCompressor::sidechainModeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void DbCompressor::sidechainModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void DbCompressor::stereoSplitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void DbCompressor::sidechainSourceLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void DbCompressor::sidechainSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void DbCompressor::stereoSplitSourceLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void DbCompressor::stereoSplitSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void DbCompressor::sidechainPreampChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void DbCompressor::sidechainReactivityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void DbCompressor::sidechainLookaheadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void DbCompressor::hpfModeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void DbCompressor::hpfModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void DbCompressor::hpfFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void DbCompressor::lpfModeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}

// SIGNAL 33
void DbCompressor::lpfModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 33, nullptr);
}

// SIGNAL 34
void DbCompressor::lpfFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 34, nullptr);
}

// SIGNAL 35
void DbCompressor::sidechainInputDeviceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 35, nullptr);
}

// SIGNAL 36
void DbCompressor::inputToSidechainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 36, nullptr);
}

// SIGNAL 37
void DbCompressor::inputToLinkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 37, nullptr);
}

// SIGNAL 38
void DbCompressor::sidechainToInputChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 38, nullptr);
}

// SIGNAL 39
void DbCompressor::sidechainToLinkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 39, nullptr);
}

// SIGNAL 40
void DbCompressor::linkToSidechainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 40, nullptr);
}

// SIGNAL 41
void DbCompressor::linkToInputChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 41, nullptr);
}
QT_WARNING_POP
