// This file is generated by kconfig_compiler_kf6 from easyeffects_db_equalizer_channel.kcfg.
// All changes you do to this file will be lost.
#ifndef DBEQUALIZERCHANNEL_H
#define DBEQUALIZERCHANNEL_H

#include "kconfig_base_ee.hpp"

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>
#include <qqmlintegration.h>

class DbEqualizerChannel : public KConfigBaseEE
{
  Q_OBJECT
  QML_ELEMENT
  QML_UNCREATABLE("")
  public:

    DbEqualizerChannel( const QString & masterGroup, const QString & instanceIndex, const QString & channel );
    ~DbEqualizerChannel() override;

    /**
      Set bandModeLabels
    */
    void setBandModeLabels( const QStringList & v )
    {
      if (v != mBandModeLabels && !isBandModeLabelsImmutable()) {
        mBandModeLabels = v;
        Q_EMIT bandModeLabelsChanged();
      }
    }

    Q_PROPERTY(QStringList bandModeLabels READ bandModeLabels WRITE setBandModeLabels NOTIFY bandModeLabelsChanged)
    Q_PROPERTY(bool isBandModeLabelsImmutable READ isBandModeLabelsImmutable CONSTANT)
    Q_PROPERTY(QStringList defaultBandModeLabelsValue READ defaultBandModeLabelsValue CONSTANT)
    /**
      Get bandModeLabels
    */
    QStringList bandModeLabels() const
    {
      return mBandModeLabels;
    }

    /**
      Is bandModeLabels Immutable
    */
    bool isBandModeLabelsImmutable() const
    {
      return isImmutable( QStringLiteral( "bandModeLabels" ) );
    }

    /**
      Get bandModeLabels default value
    */
    QStringList defaultBandModeLabelsValue() const
    {
        return defaultBandModeLabelsValue_helper();
    }

    /**
      Set bandTypeLabels
    */
    void setBandTypeLabels( const QStringList & v )
    {
      if (v != mBandTypeLabels && !isBandTypeLabelsImmutable()) {
        mBandTypeLabels = v;
        Q_EMIT bandTypeLabelsChanged();
      }
    }

    Q_PROPERTY(QStringList bandTypeLabels READ bandTypeLabels WRITE setBandTypeLabels NOTIFY bandTypeLabelsChanged)
    Q_PROPERTY(bool isBandTypeLabelsImmutable READ isBandTypeLabelsImmutable CONSTANT)
    Q_PROPERTY(QStringList defaultBandTypeLabelsValue READ defaultBandTypeLabelsValue CONSTANT)
    /**
      Get bandTypeLabels
    */
    QStringList bandTypeLabels() const
    {
      return mBandTypeLabels;
    }

    /**
      Is bandTypeLabels Immutable
    */
    bool isBandTypeLabelsImmutable() const
    {
      return isImmutable( QStringLiteral( "bandTypeLabels" ) );
    }

    /**
      Get bandTypeLabels default value
    */
    QStringList defaultBandTypeLabelsValue() const
    {
        return defaultBandTypeLabelsValue_helper();
    }

    /**
      Set bandSlopeLabels
    */
    void setBandSlopeLabels( const QStringList & v )
    {
      if (v != mBandSlopeLabels && !isBandSlopeLabelsImmutable()) {
        mBandSlopeLabels = v;
        Q_EMIT bandSlopeLabelsChanged();
      }
    }

    Q_PROPERTY(QStringList bandSlopeLabels READ bandSlopeLabels WRITE setBandSlopeLabels NOTIFY bandSlopeLabelsChanged)
    Q_PROPERTY(bool isBandSlopeLabelsImmutable READ isBandSlopeLabelsImmutable CONSTANT)
    Q_PROPERTY(QStringList defaultBandSlopeLabelsValue READ defaultBandSlopeLabelsValue CONSTANT)
    /**
      Get bandSlopeLabels
    */
    QStringList bandSlopeLabels() const
    {
      return mBandSlopeLabels;
    }

    /**
      Is bandSlopeLabels Immutable
    */
    bool isBandSlopeLabelsImmutable() const
    {
      return isImmutable( QStringLiteral( "bandSlopeLabels" ) );
    }

    /**
      Get bandSlopeLabels default value
    */
    QStringList defaultBandSlopeLabelsValue() const
    {
        return defaultBandSlopeLabelsValue_helper();
    }

    /**
      Set band0Gain
    */
    void setBand0Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand0Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand0Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand0Gain && !isBand0GainImmutable()) {
        mBand0Gain = v;
        Q_EMIT band0GainChanged();
      }
    }

    Q_PROPERTY(double band0Gain READ band0Gain WRITE setBand0Gain NOTIFY band0GainChanged)
    Q_PROPERTY(bool isBand0GainImmutable READ isBand0GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand0GainValue READ defaultBand0GainValue CONSTANT)
    /**
      Get band0Gain
    */
    double band0Gain() const
    {
      return mBand0Gain;
    }

    /**
      Is band0Gain Immutable
    */
    bool isBand0GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band0Gain" ) );
    }

    /**
      Get band0Gain default value
    */
    double defaultBand0GainValue() const
    {
        return defaultBand0GainValue_helper();
    }

    /**
      Set band1Gain
    */
    void setBand1Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand1Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand1Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand1Gain && !isBand1GainImmutable()) {
        mBand1Gain = v;
        Q_EMIT band1GainChanged();
      }
    }

    Q_PROPERTY(double band1Gain READ band1Gain WRITE setBand1Gain NOTIFY band1GainChanged)
    Q_PROPERTY(bool isBand1GainImmutable READ isBand1GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand1GainValue READ defaultBand1GainValue CONSTANT)
    /**
      Get band1Gain
    */
    double band1Gain() const
    {
      return mBand1Gain;
    }

    /**
      Is band1Gain Immutable
    */
    bool isBand1GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band1Gain" ) );
    }

    /**
      Get band1Gain default value
    */
    double defaultBand1GainValue() const
    {
        return defaultBand1GainValue_helper();
    }

    /**
      Set band2Gain
    */
    void setBand2Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand2Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand2Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand2Gain && !isBand2GainImmutable()) {
        mBand2Gain = v;
        Q_EMIT band2GainChanged();
      }
    }

    Q_PROPERTY(double band2Gain READ band2Gain WRITE setBand2Gain NOTIFY band2GainChanged)
    Q_PROPERTY(bool isBand2GainImmutable READ isBand2GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand2GainValue READ defaultBand2GainValue CONSTANT)
    /**
      Get band2Gain
    */
    double band2Gain() const
    {
      return mBand2Gain;
    }

    /**
      Is band2Gain Immutable
    */
    bool isBand2GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band2Gain" ) );
    }

    /**
      Get band2Gain default value
    */
    double defaultBand2GainValue() const
    {
        return defaultBand2GainValue_helper();
    }

    /**
      Set band3Gain
    */
    void setBand3Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand3Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand3Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand3Gain && !isBand3GainImmutable()) {
        mBand3Gain = v;
        Q_EMIT band3GainChanged();
      }
    }

    Q_PROPERTY(double band3Gain READ band3Gain WRITE setBand3Gain NOTIFY band3GainChanged)
    Q_PROPERTY(bool isBand3GainImmutable READ isBand3GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand3GainValue READ defaultBand3GainValue CONSTANT)
    /**
      Get band3Gain
    */
    double band3Gain() const
    {
      return mBand3Gain;
    }

    /**
      Is band3Gain Immutable
    */
    bool isBand3GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band3Gain" ) );
    }

    /**
      Get band3Gain default value
    */
    double defaultBand3GainValue() const
    {
        return defaultBand3GainValue_helper();
    }

    /**
      Set band4Gain
    */
    void setBand4Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand4Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand4Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand4Gain && !isBand4GainImmutable()) {
        mBand4Gain = v;
        Q_EMIT band4GainChanged();
      }
    }

    Q_PROPERTY(double band4Gain READ band4Gain WRITE setBand4Gain NOTIFY band4GainChanged)
    Q_PROPERTY(bool isBand4GainImmutable READ isBand4GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand4GainValue READ defaultBand4GainValue CONSTANT)
    /**
      Get band4Gain
    */
    double band4Gain() const
    {
      return mBand4Gain;
    }

    /**
      Is band4Gain Immutable
    */
    bool isBand4GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band4Gain" ) );
    }

    /**
      Get band4Gain default value
    */
    double defaultBand4GainValue() const
    {
        return defaultBand4GainValue_helper();
    }

    /**
      Set band5Gain
    */
    void setBand5Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand5Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand5Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand5Gain && !isBand5GainImmutable()) {
        mBand5Gain = v;
        Q_EMIT band5GainChanged();
      }
    }

    Q_PROPERTY(double band5Gain READ band5Gain WRITE setBand5Gain NOTIFY band5GainChanged)
    Q_PROPERTY(bool isBand5GainImmutable READ isBand5GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand5GainValue READ defaultBand5GainValue CONSTANT)
    /**
      Get band5Gain
    */
    double band5Gain() const
    {
      return mBand5Gain;
    }

    /**
      Is band5Gain Immutable
    */
    bool isBand5GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band5Gain" ) );
    }

    /**
      Get band5Gain default value
    */
    double defaultBand5GainValue() const
    {
        return defaultBand5GainValue_helper();
    }

    /**
      Set band6Gain
    */
    void setBand6Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand6Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand6Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand6Gain && !isBand6GainImmutable()) {
        mBand6Gain = v;
        Q_EMIT band6GainChanged();
      }
    }

    Q_PROPERTY(double band6Gain READ band6Gain WRITE setBand6Gain NOTIFY band6GainChanged)
    Q_PROPERTY(bool isBand6GainImmutable READ isBand6GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand6GainValue READ defaultBand6GainValue CONSTANT)
    /**
      Get band6Gain
    */
    double band6Gain() const
    {
      return mBand6Gain;
    }

    /**
      Is band6Gain Immutable
    */
    bool isBand6GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band6Gain" ) );
    }

    /**
      Get band6Gain default value
    */
    double defaultBand6GainValue() const
    {
        return defaultBand6GainValue_helper();
    }

    /**
      Set band7Gain
    */
    void setBand7Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand7Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand7Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand7Gain && !isBand7GainImmutable()) {
        mBand7Gain = v;
        Q_EMIT band7GainChanged();
      }
    }

    Q_PROPERTY(double band7Gain READ band7Gain WRITE setBand7Gain NOTIFY band7GainChanged)
    Q_PROPERTY(bool isBand7GainImmutable READ isBand7GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand7GainValue READ defaultBand7GainValue CONSTANT)
    /**
      Get band7Gain
    */
    double band7Gain() const
    {
      return mBand7Gain;
    }

    /**
      Is band7Gain Immutable
    */
    bool isBand7GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band7Gain" ) );
    }

    /**
      Get band7Gain default value
    */
    double defaultBand7GainValue() const
    {
        return defaultBand7GainValue_helper();
    }

    /**
      Set band8Gain
    */
    void setBand8Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand8Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand8Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand8Gain && !isBand8GainImmutable()) {
        mBand8Gain = v;
        Q_EMIT band8GainChanged();
      }
    }

    Q_PROPERTY(double band8Gain READ band8Gain WRITE setBand8Gain NOTIFY band8GainChanged)
    Q_PROPERTY(bool isBand8GainImmutable READ isBand8GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand8GainValue READ defaultBand8GainValue CONSTANT)
    /**
      Get band8Gain
    */
    double band8Gain() const
    {
      return mBand8Gain;
    }

    /**
      Is band8Gain Immutable
    */
    bool isBand8GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band8Gain" ) );
    }

    /**
      Get band8Gain default value
    */
    double defaultBand8GainValue() const
    {
        return defaultBand8GainValue_helper();
    }

    /**
      Set band9Gain
    */
    void setBand9Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand9Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand9Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand9Gain && !isBand9GainImmutable()) {
        mBand9Gain = v;
        Q_EMIT band9GainChanged();
      }
    }

    Q_PROPERTY(double band9Gain READ band9Gain WRITE setBand9Gain NOTIFY band9GainChanged)
    Q_PROPERTY(bool isBand9GainImmutable READ isBand9GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand9GainValue READ defaultBand9GainValue CONSTANT)
    /**
      Get band9Gain
    */
    double band9Gain() const
    {
      return mBand9Gain;
    }

    /**
      Is band9Gain Immutable
    */
    bool isBand9GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band9Gain" ) );
    }

    /**
      Get band9Gain default value
    */
    double defaultBand9GainValue() const
    {
        return defaultBand9GainValue_helper();
    }

    /**
      Set band10Gain
    */
    void setBand10Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand10Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand10Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand10Gain && !isBand10GainImmutable()) {
        mBand10Gain = v;
        Q_EMIT band10GainChanged();
      }
    }

    Q_PROPERTY(double band10Gain READ band10Gain WRITE setBand10Gain NOTIFY band10GainChanged)
    Q_PROPERTY(bool isBand10GainImmutable READ isBand10GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand10GainValue READ defaultBand10GainValue CONSTANT)
    /**
      Get band10Gain
    */
    double band10Gain() const
    {
      return mBand10Gain;
    }

    /**
      Is band10Gain Immutable
    */
    bool isBand10GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band10Gain" ) );
    }

    /**
      Get band10Gain default value
    */
    double defaultBand10GainValue() const
    {
        return defaultBand10GainValue_helper();
    }

    /**
      Set band11Gain
    */
    void setBand11Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand11Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand11Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand11Gain && !isBand11GainImmutable()) {
        mBand11Gain = v;
        Q_EMIT band11GainChanged();
      }
    }

    Q_PROPERTY(double band11Gain READ band11Gain WRITE setBand11Gain NOTIFY band11GainChanged)
    Q_PROPERTY(bool isBand11GainImmutable READ isBand11GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand11GainValue READ defaultBand11GainValue CONSTANT)
    /**
      Get band11Gain
    */
    double band11Gain() const
    {
      return mBand11Gain;
    }

    /**
      Is band11Gain Immutable
    */
    bool isBand11GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band11Gain" ) );
    }

    /**
      Get band11Gain default value
    */
    double defaultBand11GainValue() const
    {
        return defaultBand11GainValue_helper();
    }

    /**
      Set band12Gain
    */
    void setBand12Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand12Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand12Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand12Gain && !isBand12GainImmutable()) {
        mBand12Gain = v;
        Q_EMIT band12GainChanged();
      }
    }

    Q_PROPERTY(double band12Gain READ band12Gain WRITE setBand12Gain NOTIFY band12GainChanged)
    Q_PROPERTY(bool isBand12GainImmutable READ isBand12GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand12GainValue READ defaultBand12GainValue CONSTANT)
    /**
      Get band12Gain
    */
    double band12Gain() const
    {
      return mBand12Gain;
    }

    /**
      Is band12Gain Immutable
    */
    bool isBand12GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band12Gain" ) );
    }

    /**
      Get band12Gain default value
    */
    double defaultBand12GainValue() const
    {
        return defaultBand12GainValue_helper();
    }

    /**
      Set band13Gain
    */
    void setBand13Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand13Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand13Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand13Gain && !isBand13GainImmutable()) {
        mBand13Gain = v;
        Q_EMIT band13GainChanged();
      }
    }

    Q_PROPERTY(double band13Gain READ band13Gain WRITE setBand13Gain NOTIFY band13GainChanged)
    Q_PROPERTY(bool isBand13GainImmutable READ isBand13GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand13GainValue READ defaultBand13GainValue CONSTANT)
    /**
      Get band13Gain
    */
    double band13Gain() const
    {
      return mBand13Gain;
    }

    /**
      Is band13Gain Immutable
    */
    bool isBand13GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band13Gain" ) );
    }

    /**
      Get band13Gain default value
    */
    double defaultBand13GainValue() const
    {
        return defaultBand13GainValue_helper();
    }

    /**
      Set band14Gain
    */
    void setBand14Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand14Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand14Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand14Gain && !isBand14GainImmutable()) {
        mBand14Gain = v;
        Q_EMIT band14GainChanged();
      }
    }

    Q_PROPERTY(double band14Gain READ band14Gain WRITE setBand14Gain NOTIFY band14GainChanged)
    Q_PROPERTY(bool isBand14GainImmutable READ isBand14GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand14GainValue READ defaultBand14GainValue CONSTANT)
    /**
      Get band14Gain
    */
    double band14Gain() const
    {
      return mBand14Gain;
    }

    /**
      Is band14Gain Immutable
    */
    bool isBand14GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band14Gain" ) );
    }

    /**
      Get band14Gain default value
    */
    double defaultBand14GainValue() const
    {
        return defaultBand14GainValue_helper();
    }

    /**
      Set band15Gain
    */
    void setBand15Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand15Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand15Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand15Gain && !isBand15GainImmutable()) {
        mBand15Gain = v;
        Q_EMIT band15GainChanged();
      }
    }

    Q_PROPERTY(double band15Gain READ band15Gain WRITE setBand15Gain NOTIFY band15GainChanged)
    Q_PROPERTY(bool isBand15GainImmutable READ isBand15GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand15GainValue READ defaultBand15GainValue CONSTANT)
    /**
      Get band15Gain
    */
    double band15Gain() const
    {
      return mBand15Gain;
    }

    /**
      Is band15Gain Immutable
    */
    bool isBand15GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band15Gain" ) );
    }

    /**
      Get band15Gain default value
    */
    double defaultBand15GainValue() const
    {
        return defaultBand15GainValue_helper();
    }

    /**
      Set band16Gain
    */
    void setBand16Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand16Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand16Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand16Gain && !isBand16GainImmutable()) {
        mBand16Gain = v;
        Q_EMIT band16GainChanged();
      }
    }

    Q_PROPERTY(double band16Gain READ band16Gain WRITE setBand16Gain NOTIFY band16GainChanged)
    Q_PROPERTY(bool isBand16GainImmutable READ isBand16GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand16GainValue READ defaultBand16GainValue CONSTANT)
    /**
      Get band16Gain
    */
    double band16Gain() const
    {
      return mBand16Gain;
    }

    /**
      Is band16Gain Immutable
    */
    bool isBand16GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band16Gain" ) );
    }

    /**
      Get band16Gain default value
    */
    double defaultBand16GainValue() const
    {
        return defaultBand16GainValue_helper();
    }

    /**
      Set band17Gain
    */
    void setBand17Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand17Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand17Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand17Gain && !isBand17GainImmutable()) {
        mBand17Gain = v;
        Q_EMIT band17GainChanged();
      }
    }

    Q_PROPERTY(double band17Gain READ band17Gain WRITE setBand17Gain NOTIFY band17GainChanged)
    Q_PROPERTY(bool isBand17GainImmutable READ isBand17GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand17GainValue READ defaultBand17GainValue CONSTANT)
    /**
      Get band17Gain
    */
    double band17Gain() const
    {
      return mBand17Gain;
    }

    /**
      Is band17Gain Immutable
    */
    bool isBand17GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band17Gain" ) );
    }

    /**
      Get band17Gain default value
    */
    double defaultBand17GainValue() const
    {
        return defaultBand17GainValue_helper();
    }

    /**
      Set band18Gain
    */
    void setBand18Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand18Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand18Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand18Gain && !isBand18GainImmutable()) {
        mBand18Gain = v;
        Q_EMIT band18GainChanged();
      }
    }

    Q_PROPERTY(double band18Gain READ band18Gain WRITE setBand18Gain NOTIFY band18GainChanged)
    Q_PROPERTY(bool isBand18GainImmutable READ isBand18GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand18GainValue READ defaultBand18GainValue CONSTANT)
    /**
      Get band18Gain
    */
    double band18Gain() const
    {
      return mBand18Gain;
    }

    /**
      Is band18Gain Immutable
    */
    bool isBand18GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band18Gain" ) );
    }

    /**
      Get band18Gain default value
    */
    double defaultBand18GainValue() const
    {
        return defaultBand18GainValue_helper();
    }

    /**
      Set band19Gain
    */
    void setBand19Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand19Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand19Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand19Gain && !isBand19GainImmutable()) {
        mBand19Gain = v;
        Q_EMIT band19GainChanged();
      }
    }

    Q_PROPERTY(double band19Gain READ band19Gain WRITE setBand19Gain NOTIFY band19GainChanged)
    Q_PROPERTY(bool isBand19GainImmutable READ isBand19GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand19GainValue READ defaultBand19GainValue CONSTANT)
    /**
      Get band19Gain
    */
    double band19Gain() const
    {
      return mBand19Gain;
    }

    /**
      Is band19Gain Immutable
    */
    bool isBand19GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band19Gain" ) );
    }

    /**
      Get band19Gain default value
    */
    double defaultBand19GainValue() const
    {
        return defaultBand19GainValue_helper();
    }

    /**
      Set band20Gain
    */
    void setBand20Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand20Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand20Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand20Gain && !isBand20GainImmutable()) {
        mBand20Gain = v;
        Q_EMIT band20GainChanged();
      }
    }

    Q_PROPERTY(double band20Gain READ band20Gain WRITE setBand20Gain NOTIFY band20GainChanged)
    Q_PROPERTY(bool isBand20GainImmutable READ isBand20GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand20GainValue READ defaultBand20GainValue CONSTANT)
    /**
      Get band20Gain
    */
    double band20Gain() const
    {
      return mBand20Gain;
    }

    /**
      Is band20Gain Immutable
    */
    bool isBand20GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band20Gain" ) );
    }

    /**
      Get band20Gain default value
    */
    double defaultBand20GainValue() const
    {
        return defaultBand20GainValue_helper();
    }

    /**
      Set band21Gain
    */
    void setBand21Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand21Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand21Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand21Gain && !isBand21GainImmutable()) {
        mBand21Gain = v;
        Q_EMIT band21GainChanged();
      }
    }

    Q_PROPERTY(double band21Gain READ band21Gain WRITE setBand21Gain NOTIFY band21GainChanged)
    Q_PROPERTY(bool isBand21GainImmutable READ isBand21GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand21GainValue READ defaultBand21GainValue CONSTANT)
    /**
      Get band21Gain
    */
    double band21Gain() const
    {
      return mBand21Gain;
    }

    /**
      Is band21Gain Immutable
    */
    bool isBand21GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band21Gain" ) );
    }

    /**
      Get band21Gain default value
    */
    double defaultBand21GainValue() const
    {
        return defaultBand21GainValue_helper();
    }

    /**
      Set band22Gain
    */
    void setBand22Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand22Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand22Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand22Gain && !isBand22GainImmutable()) {
        mBand22Gain = v;
        Q_EMIT band22GainChanged();
      }
    }

    Q_PROPERTY(double band22Gain READ band22Gain WRITE setBand22Gain NOTIFY band22GainChanged)
    Q_PROPERTY(bool isBand22GainImmutable READ isBand22GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand22GainValue READ defaultBand22GainValue CONSTANT)
    /**
      Get band22Gain
    */
    double band22Gain() const
    {
      return mBand22Gain;
    }

    /**
      Is band22Gain Immutable
    */
    bool isBand22GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band22Gain" ) );
    }

    /**
      Get band22Gain default value
    */
    double defaultBand22GainValue() const
    {
        return defaultBand22GainValue_helper();
    }

    /**
      Set band23Gain
    */
    void setBand23Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand23Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand23Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand23Gain && !isBand23GainImmutable()) {
        mBand23Gain = v;
        Q_EMIT band23GainChanged();
      }
    }

    Q_PROPERTY(double band23Gain READ band23Gain WRITE setBand23Gain NOTIFY band23GainChanged)
    Q_PROPERTY(bool isBand23GainImmutable READ isBand23GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand23GainValue READ defaultBand23GainValue CONSTANT)
    /**
      Get band23Gain
    */
    double band23Gain() const
    {
      return mBand23Gain;
    }

    /**
      Is band23Gain Immutable
    */
    bool isBand23GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band23Gain" ) );
    }

    /**
      Get band23Gain default value
    */
    double defaultBand23GainValue() const
    {
        return defaultBand23GainValue_helper();
    }

    /**
      Set band24Gain
    */
    void setBand24Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand24Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand24Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand24Gain && !isBand24GainImmutable()) {
        mBand24Gain = v;
        Q_EMIT band24GainChanged();
      }
    }

    Q_PROPERTY(double band24Gain READ band24Gain WRITE setBand24Gain NOTIFY band24GainChanged)
    Q_PROPERTY(bool isBand24GainImmutable READ isBand24GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand24GainValue READ defaultBand24GainValue CONSTANT)
    /**
      Get band24Gain
    */
    double band24Gain() const
    {
      return mBand24Gain;
    }

    /**
      Is band24Gain Immutable
    */
    bool isBand24GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band24Gain" ) );
    }

    /**
      Get band24Gain default value
    */
    double defaultBand24GainValue() const
    {
        return defaultBand24GainValue_helper();
    }

    /**
      Set band25Gain
    */
    void setBand25Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand25Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand25Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand25Gain && !isBand25GainImmutable()) {
        mBand25Gain = v;
        Q_EMIT band25GainChanged();
      }
    }

    Q_PROPERTY(double band25Gain READ band25Gain WRITE setBand25Gain NOTIFY band25GainChanged)
    Q_PROPERTY(bool isBand25GainImmutable READ isBand25GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand25GainValue READ defaultBand25GainValue CONSTANT)
    /**
      Get band25Gain
    */
    double band25Gain() const
    {
      return mBand25Gain;
    }

    /**
      Is band25Gain Immutable
    */
    bool isBand25GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band25Gain" ) );
    }

    /**
      Get band25Gain default value
    */
    double defaultBand25GainValue() const
    {
        return defaultBand25GainValue_helper();
    }

    /**
      Set band26Gain
    */
    void setBand26Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand26Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand26Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand26Gain && !isBand26GainImmutable()) {
        mBand26Gain = v;
        Q_EMIT band26GainChanged();
      }
    }

    Q_PROPERTY(double band26Gain READ band26Gain WRITE setBand26Gain NOTIFY band26GainChanged)
    Q_PROPERTY(bool isBand26GainImmutable READ isBand26GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand26GainValue READ defaultBand26GainValue CONSTANT)
    /**
      Get band26Gain
    */
    double band26Gain() const
    {
      return mBand26Gain;
    }

    /**
      Is band26Gain Immutable
    */
    bool isBand26GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band26Gain" ) );
    }

    /**
      Get band26Gain default value
    */
    double defaultBand26GainValue() const
    {
        return defaultBand26GainValue_helper();
    }

    /**
      Set band27Gain
    */
    void setBand27Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand27Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand27Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand27Gain && !isBand27GainImmutable()) {
        mBand27Gain = v;
        Q_EMIT band27GainChanged();
      }
    }

    Q_PROPERTY(double band27Gain READ band27Gain WRITE setBand27Gain NOTIFY band27GainChanged)
    Q_PROPERTY(bool isBand27GainImmutable READ isBand27GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand27GainValue READ defaultBand27GainValue CONSTANT)
    /**
      Get band27Gain
    */
    double band27Gain() const
    {
      return mBand27Gain;
    }

    /**
      Is band27Gain Immutable
    */
    bool isBand27GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band27Gain" ) );
    }

    /**
      Get band27Gain default value
    */
    double defaultBand27GainValue() const
    {
        return defaultBand27GainValue_helper();
    }

    /**
      Set band28Gain
    */
    void setBand28Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand28Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand28Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand28Gain && !isBand28GainImmutable()) {
        mBand28Gain = v;
        Q_EMIT band28GainChanged();
      }
    }

    Q_PROPERTY(double band28Gain READ band28Gain WRITE setBand28Gain NOTIFY band28GainChanged)
    Q_PROPERTY(bool isBand28GainImmutable READ isBand28GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand28GainValue READ defaultBand28GainValue CONSTANT)
    /**
      Get band28Gain
    */
    double band28Gain() const
    {
      return mBand28Gain;
    }

    /**
      Is band28Gain Immutable
    */
    bool isBand28GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band28Gain" ) );
    }

    /**
      Get band28Gain default value
    */
    double defaultBand28GainValue() const
    {
        return defaultBand28GainValue_helper();
    }

    /**
      Set band29Gain
    */
    void setBand29Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand29Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand29Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand29Gain && !isBand29GainImmutable()) {
        mBand29Gain = v;
        Q_EMIT band29GainChanged();
      }
    }

    Q_PROPERTY(double band29Gain READ band29Gain WRITE setBand29Gain NOTIFY band29GainChanged)
    Q_PROPERTY(bool isBand29GainImmutable READ isBand29GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand29GainValue READ defaultBand29GainValue CONSTANT)
    /**
      Get band29Gain
    */
    double band29Gain() const
    {
      return mBand29Gain;
    }

    /**
      Is band29Gain Immutable
    */
    bool isBand29GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band29Gain" ) );
    }

    /**
      Get band29Gain default value
    */
    double defaultBand29GainValue() const
    {
        return defaultBand29GainValue_helper();
    }

    /**
      Set band30Gain
    */
    void setBand30Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand30Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand30Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand30Gain && !isBand30GainImmutable()) {
        mBand30Gain = v;
        Q_EMIT band30GainChanged();
      }
    }

    Q_PROPERTY(double band30Gain READ band30Gain WRITE setBand30Gain NOTIFY band30GainChanged)
    Q_PROPERTY(bool isBand30GainImmutable READ isBand30GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand30GainValue READ defaultBand30GainValue CONSTANT)
    /**
      Get band30Gain
    */
    double band30Gain() const
    {
      return mBand30Gain;
    }

    /**
      Is band30Gain Immutable
    */
    bool isBand30GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band30Gain" ) );
    }

    /**
      Get band30Gain default value
    */
    double defaultBand30GainValue() const
    {
        return defaultBand30GainValue_helper();
    }

    /**
      Set band31Gain
    */
    void setBand31Gain( double v )
    {
      if (v < -36)
      {
        qDebug() << "setBand31Gain: value " << v << " is less than the minimum value of -36";
        v = -36;
      }

      if (v > 36)
      {
        qDebug() << "setBand31Gain: value " << v << " is greater than the maximum value of 36";
        v = 36;
      }

      if (v != mBand31Gain && !isBand31GainImmutable()) {
        mBand31Gain = v;
        Q_EMIT band31GainChanged();
      }
    }

    Q_PROPERTY(double band31Gain READ band31Gain WRITE setBand31Gain NOTIFY band31GainChanged)
    Q_PROPERTY(bool isBand31GainImmutable READ isBand31GainImmutable CONSTANT)
    Q_PROPERTY(double defaultBand31GainValue READ defaultBand31GainValue CONSTANT)
    /**
      Get band31Gain
    */
    double band31Gain() const
    {
      return mBand31Gain;
    }

    /**
      Is band31Gain Immutable
    */
    bool isBand31GainImmutable() const
    {
      return isImmutable( QStringLiteral( "band31Gain" ) );
    }

    /**
      Get band31Gain default value
    */
    double defaultBand31GainValue() const
    {
        return defaultBand31GainValue_helper();
    }

    /**
      Set band0Frequency
    */
    void setBand0Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand0Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand0Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand0Frequency && !isBand0FrequencyImmutable()) {
        mBand0Frequency = v;
        Q_EMIT band0FrequencyChanged();
      }
    }

    Q_PROPERTY(double band0Frequency READ band0Frequency WRITE setBand0Frequency NOTIFY band0FrequencyChanged)
    Q_PROPERTY(bool isBand0FrequencyImmutable READ isBand0FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand0FrequencyValue READ defaultBand0FrequencyValue CONSTANT)
    /**
      Get band0Frequency
    */
    double band0Frequency() const
    {
      return mBand0Frequency;
    }

    /**
      Is band0Frequency Immutable
    */
    bool isBand0FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band0Frequency" ) );
    }

    /**
      Get band0Frequency default value
    */
    double defaultBand0FrequencyValue() const
    {
        return defaultBand0FrequencyValue_helper();
    }

    /**
      Set band1Frequency
    */
    void setBand1Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand1Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand1Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand1Frequency && !isBand1FrequencyImmutable()) {
        mBand1Frequency = v;
        Q_EMIT band1FrequencyChanged();
      }
    }

    Q_PROPERTY(double band1Frequency READ band1Frequency WRITE setBand1Frequency NOTIFY band1FrequencyChanged)
    Q_PROPERTY(bool isBand1FrequencyImmutable READ isBand1FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand1FrequencyValue READ defaultBand1FrequencyValue CONSTANT)
    /**
      Get band1Frequency
    */
    double band1Frequency() const
    {
      return mBand1Frequency;
    }

    /**
      Is band1Frequency Immutable
    */
    bool isBand1FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band1Frequency" ) );
    }

    /**
      Get band1Frequency default value
    */
    double defaultBand1FrequencyValue() const
    {
        return defaultBand1FrequencyValue_helper();
    }

    /**
      Set band2Frequency
    */
    void setBand2Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand2Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand2Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand2Frequency && !isBand2FrequencyImmutable()) {
        mBand2Frequency = v;
        Q_EMIT band2FrequencyChanged();
      }
    }

    Q_PROPERTY(double band2Frequency READ band2Frequency WRITE setBand2Frequency NOTIFY band2FrequencyChanged)
    Q_PROPERTY(bool isBand2FrequencyImmutable READ isBand2FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand2FrequencyValue READ defaultBand2FrequencyValue CONSTANT)
    /**
      Get band2Frequency
    */
    double band2Frequency() const
    {
      return mBand2Frequency;
    }

    /**
      Is band2Frequency Immutable
    */
    bool isBand2FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band2Frequency" ) );
    }

    /**
      Get band2Frequency default value
    */
    double defaultBand2FrequencyValue() const
    {
        return defaultBand2FrequencyValue_helper();
    }

    /**
      Set band3Frequency
    */
    void setBand3Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand3Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand3Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand3Frequency && !isBand3FrequencyImmutable()) {
        mBand3Frequency = v;
        Q_EMIT band3FrequencyChanged();
      }
    }

    Q_PROPERTY(double band3Frequency READ band3Frequency WRITE setBand3Frequency NOTIFY band3FrequencyChanged)
    Q_PROPERTY(bool isBand3FrequencyImmutable READ isBand3FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand3FrequencyValue READ defaultBand3FrequencyValue CONSTANT)
    /**
      Get band3Frequency
    */
    double band3Frequency() const
    {
      return mBand3Frequency;
    }

    /**
      Is band3Frequency Immutable
    */
    bool isBand3FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band3Frequency" ) );
    }

    /**
      Get band3Frequency default value
    */
    double defaultBand3FrequencyValue() const
    {
        return defaultBand3FrequencyValue_helper();
    }

    /**
      Set band4Frequency
    */
    void setBand4Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand4Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand4Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand4Frequency && !isBand4FrequencyImmutable()) {
        mBand4Frequency = v;
        Q_EMIT band4FrequencyChanged();
      }
    }

    Q_PROPERTY(double band4Frequency READ band4Frequency WRITE setBand4Frequency NOTIFY band4FrequencyChanged)
    Q_PROPERTY(bool isBand4FrequencyImmutable READ isBand4FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand4FrequencyValue READ defaultBand4FrequencyValue CONSTANT)
    /**
      Get band4Frequency
    */
    double band4Frequency() const
    {
      return mBand4Frequency;
    }

    /**
      Is band4Frequency Immutable
    */
    bool isBand4FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band4Frequency" ) );
    }

    /**
      Get band4Frequency default value
    */
    double defaultBand4FrequencyValue() const
    {
        return defaultBand4FrequencyValue_helper();
    }

    /**
      Set band5Frequency
    */
    void setBand5Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand5Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand5Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand5Frequency && !isBand5FrequencyImmutable()) {
        mBand5Frequency = v;
        Q_EMIT band5FrequencyChanged();
      }
    }

    Q_PROPERTY(double band5Frequency READ band5Frequency WRITE setBand5Frequency NOTIFY band5FrequencyChanged)
    Q_PROPERTY(bool isBand5FrequencyImmutable READ isBand5FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand5FrequencyValue READ defaultBand5FrequencyValue CONSTANT)
    /**
      Get band5Frequency
    */
    double band5Frequency() const
    {
      return mBand5Frequency;
    }

    /**
      Is band5Frequency Immutable
    */
    bool isBand5FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band5Frequency" ) );
    }

    /**
      Get band5Frequency default value
    */
    double defaultBand5FrequencyValue() const
    {
        return defaultBand5FrequencyValue_helper();
    }

    /**
      Set band6Frequency
    */
    void setBand6Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand6Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand6Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand6Frequency && !isBand6FrequencyImmutable()) {
        mBand6Frequency = v;
        Q_EMIT band6FrequencyChanged();
      }
    }

    Q_PROPERTY(double band6Frequency READ band6Frequency WRITE setBand6Frequency NOTIFY band6FrequencyChanged)
    Q_PROPERTY(bool isBand6FrequencyImmutable READ isBand6FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand6FrequencyValue READ defaultBand6FrequencyValue CONSTANT)
    /**
      Get band6Frequency
    */
    double band6Frequency() const
    {
      return mBand6Frequency;
    }

    /**
      Is band6Frequency Immutable
    */
    bool isBand6FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band6Frequency" ) );
    }

    /**
      Get band6Frequency default value
    */
    double defaultBand6FrequencyValue() const
    {
        return defaultBand6FrequencyValue_helper();
    }

    /**
      Set band7Frequency
    */
    void setBand7Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand7Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand7Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand7Frequency && !isBand7FrequencyImmutable()) {
        mBand7Frequency = v;
        Q_EMIT band7FrequencyChanged();
      }
    }

    Q_PROPERTY(double band7Frequency READ band7Frequency WRITE setBand7Frequency NOTIFY band7FrequencyChanged)
    Q_PROPERTY(bool isBand7FrequencyImmutable READ isBand7FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand7FrequencyValue READ defaultBand7FrequencyValue CONSTANT)
    /**
      Get band7Frequency
    */
    double band7Frequency() const
    {
      return mBand7Frequency;
    }

    /**
      Is band7Frequency Immutable
    */
    bool isBand7FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band7Frequency" ) );
    }

    /**
      Get band7Frequency default value
    */
    double defaultBand7FrequencyValue() const
    {
        return defaultBand7FrequencyValue_helper();
    }

    /**
      Set band8Frequency
    */
    void setBand8Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand8Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand8Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand8Frequency && !isBand8FrequencyImmutable()) {
        mBand8Frequency = v;
        Q_EMIT band8FrequencyChanged();
      }
    }

    Q_PROPERTY(double band8Frequency READ band8Frequency WRITE setBand8Frequency NOTIFY band8FrequencyChanged)
    Q_PROPERTY(bool isBand8FrequencyImmutable READ isBand8FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand8FrequencyValue READ defaultBand8FrequencyValue CONSTANT)
    /**
      Get band8Frequency
    */
    double band8Frequency() const
    {
      return mBand8Frequency;
    }

    /**
      Is band8Frequency Immutable
    */
    bool isBand8FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band8Frequency" ) );
    }

    /**
      Get band8Frequency default value
    */
    double defaultBand8FrequencyValue() const
    {
        return defaultBand8FrequencyValue_helper();
    }

    /**
      Set band9Frequency
    */
    void setBand9Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand9Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand9Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand9Frequency && !isBand9FrequencyImmutable()) {
        mBand9Frequency = v;
        Q_EMIT band9FrequencyChanged();
      }
    }

    Q_PROPERTY(double band9Frequency READ band9Frequency WRITE setBand9Frequency NOTIFY band9FrequencyChanged)
    Q_PROPERTY(bool isBand9FrequencyImmutable READ isBand9FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand9FrequencyValue READ defaultBand9FrequencyValue CONSTANT)
    /**
      Get band9Frequency
    */
    double band9Frequency() const
    {
      return mBand9Frequency;
    }

    /**
      Is band9Frequency Immutable
    */
    bool isBand9FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band9Frequency" ) );
    }

    /**
      Get band9Frequency default value
    */
    double defaultBand9FrequencyValue() const
    {
        return defaultBand9FrequencyValue_helper();
    }

    /**
      Set band10Frequency
    */
    void setBand10Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand10Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand10Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand10Frequency && !isBand10FrequencyImmutable()) {
        mBand10Frequency = v;
        Q_EMIT band10FrequencyChanged();
      }
    }

    Q_PROPERTY(double band10Frequency READ band10Frequency WRITE setBand10Frequency NOTIFY band10FrequencyChanged)
    Q_PROPERTY(bool isBand10FrequencyImmutable READ isBand10FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand10FrequencyValue READ defaultBand10FrequencyValue CONSTANT)
    /**
      Get band10Frequency
    */
    double band10Frequency() const
    {
      return mBand10Frequency;
    }

    /**
      Is band10Frequency Immutable
    */
    bool isBand10FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band10Frequency" ) );
    }

    /**
      Get band10Frequency default value
    */
    double defaultBand10FrequencyValue() const
    {
        return defaultBand10FrequencyValue_helper();
    }

    /**
      Set band11Frequency
    */
    void setBand11Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand11Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand11Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand11Frequency && !isBand11FrequencyImmutable()) {
        mBand11Frequency = v;
        Q_EMIT band11FrequencyChanged();
      }
    }

    Q_PROPERTY(double band11Frequency READ band11Frequency WRITE setBand11Frequency NOTIFY band11FrequencyChanged)
    Q_PROPERTY(bool isBand11FrequencyImmutable READ isBand11FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand11FrequencyValue READ defaultBand11FrequencyValue CONSTANT)
    /**
      Get band11Frequency
    */
    double band11Frequency() const
    {
      return mBand11Frequency;
    }

    /**
      Is band11Frequency Immutable
    */
    bool isBand11FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band11Frequency" ) );
    }

    /**
      Get band11Frequency default value
    */
    double defaultBand11FrequencyValue() const
    {
        return defaultBand11FrequencyValue_helper();
    }

    /**
      Set band12Frequency
    */
    void setBand12Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand12Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand12Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand12Frequency && !isBand12FrequencyImmutable()) {
        mBand12Frequency = v;
        Q_EMIT band12FrequencyChanged();
      }
    }

    Q_PROPERTY(double band12Frequency READ band12Frequency WRITE setBand12Frequency NOTIFY band12FrequencyChanged)
    Q_PROPERTY(bool isBand12FrequencyImmutable READ isBand12FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand12FrequencyValue READ defaultBand12FrequencyValue CONSTANT)
    /**
      Get band12Frequency
    */
    double band12Frequency() const
    {
      return mBand12Frequency;
    }

    /**
      Is band12Frequency Immutable
    */
    bool isBand12FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band12Frequency" ) );
    }

    /**
      Get band12Frequency default value
    */
    double defaultBand12FrequencyValue() const
    {
        return defaultBand12FrequencyValue_helper();
    }

    /**
      Set band13Frequency
    */
    void setBand13Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand13Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand13Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand13Frequency && !isBand13FrequencyImmutable()) {
        mBand13Frequency = v;
        Q_EMIT band13FrequencyChanged();
      }
    }

    Q_PROPERTY(double band13Frequency READ band13Frequency WRITE setBand13Frequency NOTIFY band13FrequencyChanged)
    Q_PROPERTY(bool isBand13FrequencyImmutable READ isBand13FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand13FrequencyValue READ defaultBand13FrequencyValue CONSTANT)
    /**
      Get band13Frequency
    */
    double band13Frequency() const
    {
      return mBand13Frequency;
    }

    /**
      Is band13Frequency Immutable
    */
    bool isBand13FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band13Frequency" ) );
    }

    /**
      Get band13Frequency default value
    */
    double defaultBand13FrequencyValue() const
    {
        return defaultBand13FrequencyValue_helper();
    }

    /**
      Set band14Frequency
    */
    void setBand14Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand14Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand14Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand14Frequency && !isBand14FrequencyImmutable()) {
        mBand14Frequency = v;
        Q_EMIT band14FrequencyChanged();
      }
    }

    Q_PROPERTY(double band14Frequency READ band14Frequency WRITE setBand14Frequency NOTIFY band14FrequencyChanged)
    Q_PROPERTY(bool isBand14FrequencyImmutable READ isBand14FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand14FrequencyValue READ defaultBand14FrequencyValue CONSTANT)
    /**
      Get band14Frequency
    */
    double band14Frequency() const
    {
      return mBand14Frequency;
    }

    /**
      Is band14Frequency Immutable
    */
    bool isBand14FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band14Frequency" ) );
    }

    /**
      Get band14Frequency default value
    */
    double defaultBand14FrequencyValue() const
    {
        return defaultBand14FrequencyValue_helper();
    }

    /**
      Set band15Frequency
    */
    void setBand15Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand15Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand15Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand15Frequency && !isBand15FrequencyImmutable()) {
        mBand15Frequency = v;
        Q_EMIT band15FrequencyChanged();
      }
    }

    Q_PROPERTY(double band15Frequency READ band15Frequency WRITE setBand15Frequency NOTIFY band15FrequencyChanged)
    Q_PROPERTY(bool isBand15FrequencyImmutable READ isBand15FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand15FrequencyValue READ defaultBand15FrequencyValue CONSTANT)
    /**
      Get band15Frequency
    */
    double band15Frequency() const
    {
      return mBand15Frequency;
    }

    /**
      Is band15Frequency Immutable
    */
    bool isBand15FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band15Frequency" ) );
    }

    /**
      Get band15Frequency default value
    */
    double defaultBand15FrequencyValue() const
    {
        return defaultBand15FrequencyValue_helper();
    }

    /**
      Set band16Frequency
    */
    void setBand16Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand16Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand16Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand16Frequency && !isBand16FrequencyImmutable()) {
        mBand16Frequency = v;
        Q_EMIT band16FrequencyChanged();
      }
    }

    Q_PROPERTY(double band16Frequency READ band16Frequency WRITE setBand16Frequency NOTIFY band16FrequencyChanged)
    Q_PROPERTY(bool isBand16FrequencyImmutable READ isBand16FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand16FrequencyValue READ defaultBand16FrequencyValue CONSTANT)
    /**
      Get band16Frequency
    */
    double band16Frequency() const
    {
      return mBand16Frequency;
    }

    /**
      Is band16Frequency Immutable
    */
    bool isBand16FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band16Frequency" ) );
    }

    /**
      Get band16Frequency default value
    */
    double defaultBand16FrequencyValue() const
    {
        return defaultBand16FrequencyValue_helper();
    }

    /**
      Set band17Frequency
    */
    void setBand17Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand17Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand17Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand17Frequency && !isBand17FrequencyImmutable()) {
        mBand17Frequency = v;
        Q_EMIT band17FrequencyChanged();
      }
    }

    Q_PROPERTY(double band17Frequency READ band17Frequency WRITE setBand17Frequency NOTIFY band17FrequencyChanged)
    Q_PROPERTY(bool isBand17FrequencyImmutable READ isBand17FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand17FrequencyValue READ defaultBand17FrequencyValue CONSTANT)
    /**
      Get band17Frequency
    */
    double band17Frequency() const
    {
      return mBand17Frequency;
    }

    /**
      Is band17Frequency Immutable
    */
    bool isBand17FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band17Frequency" ) );
    }

    /**
      Get band17Frequency default value
    */
    double defaultBand17FrequencyValue() const
    {
        return defaultBand17FrequencyValue_helper();
    }

    /**
      Set band18Frequency
    */
    void setBand18Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand18Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand18Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand18Frequency && !isBand18FrequencyImmutable()) {
        mBand18Frequency = v;
        Q_EMIT band18FrequencyChanged();
      }
    }

    Q_PROPERTY(double band18Frequency READ band18Frequency WRITE setBand18Frequency NOTIFY band18FrequencyChanged)
    Q_PROPERTY(bool isBand18FrequencyImmutable READ isBand18FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand18FrequencyValue READ defaultBand18FrequencyValue CONSTANT)
    /**
      Get band18Frequency
    */
    double band18Frequency() const
    {
      return mBand18Frequency;
    }

    /**
      Is band18Frequency Immutable
    */
    bool isBand18FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band18Frequency" ) );
    }

    /**
      Get band18Frequency default value
    */
    double defaultBand18FrequencyValue() const
    {
        return defaultBand18FrequencyValue_helper();
    }

    /**
      Set band19Frequency
    */
    void setBand19Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand19Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand19Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand19Frequency && !isBand19FrequencyImmutable()) {
        mBand19Frequency = v;
        Q_EMIT band19FrequencyChanged();
      }
    }

    Q_PROPERTY(double band19Frequency READ band19Frequency WRITE setBand19Frequency NOTIFY band19FrequencyChanged)
    Q_PROPERTY(bool isBand19FrequencyImmutable READ isBand19FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand19FrequencyValue READ defaultBand19FrequencyValue CONSTANT)
    /**
      Get band19Frequency
    */
    double band19Frequency() const
    {
      return mBand19Frequency;
    }

    /**
      Is band19Frequency Immutable
    */
    bool isBand19FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band19Frequency" ) );
    }

    /**
      Get band19Frequency default value
    */
    double defaultBand19FrequencyValue() const
    {
        return defaultBand19FrequencyValue_helper();
    }

    /**
      Set band20Frequency
    */
    void setBand20Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand20Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand20Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand20Frequency && !isBand20FrequencyImmutable()) {
        mBand20Frequency = v;
        Q_EMIT band20FrequencyChanged();
      }
    }

    Q_PROPERTY(double band20Frequency READ band20Frequency WRITE setBand20Frequency NOTIFY band20FrequencyChanged)
    Q_PROPERTY(bool isBand20FrequencyImmutable READ isBand20FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand20FrequencyValue READ defaultBand20FrequencyValue CONSTANT)
    /**
      Get band20Frequency
    */
    double band20Frequency() const
    {
      return mBand20Frequency;
    }

    /**
      Is band20Frequency Immutable
    */
    bool isBand20FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band20Frequency" ) );
    }

    /**
      Get band20Frequency default value
    */
    double defaultBand20FrequencyValue() const
    {
        return defaultBand20FrequencyValue_helper();
    }

    /**
      Set band21Frequency
    */
    void setBand21Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand21Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand21Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand21Frequency && !isBand21FrequencyImmutable()) {
        mBand21Frequency = v;
        Q_EMIT band21FrequencyChanged();
      }
    }

    Q_PROPERTY(double band21Frequency READ band21Frequency WRITE setBand21Frequency NOTIFY band21FrequencyChanged)
    Q_PROPERTY(bool isBand21FrequencyImmutable READ isBand21FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand21FrequencyValue READ defaultBand21FrequencyValue CONSTANT)
    /**
      Get band21Frequency
    */
    double band21Frequency() const
    {
      return mBand21Frequency;
    }

    /**
      Is band21Frequency Immutable
    */
    bool isBand21FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band21Frequency" ) );
    }

    /**
      Get band21Frequency default value
    */
    double defaultBand21FrequencyValue() const
    {
        return defaultBand21FrequencyValue_helper();
    }

    /**
      Set band22Frequency
    */
    void setBand22Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand22Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand22Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand22Frequency && !isBand22FrequencyImmutable()) {
        mBand22Frequency = v;
        Q_EMIT band22FrequencyChanged();
      }
    }

    Q_PROPERTY(double band22Frequency READ band22Frequency WRITE setBand22Frequency NOTIFY band22FrequencyChanged)
    Q_PROPERTY(bool isBand22FrequencyImmutable READ isBand22FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand22FrequencyValue READ defaultBand22FrequencyValue CONSTANT)
    /**
      Get band22Frequency
    */
    double band22Frequency() const
    {
      return mBand22Frequency;
    }

    /**
      Is band22Frequency Immutable
    */
    bool isBand22FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band22Frequency" ) );
    }

    /**
      Get band22Frequency default value
    */
    double defaultBand22FrequencyValue() const
    {
        return defaultBand22FrequencyValue_helper();
    }

    /**
      Set band23Frequency
    */
    void setBand23Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand23Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand23Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand23Frequency && !isBand23FrequencyImmutable()) {
        mBand23Frequency = v;
        Q_EMIT band23FrequencyChanged();
      }
    }

    Q_PROPERTY(double band23Frequency READ band23Frequency WRITE setBand23Frequency NOTIFY band23FrequencyChanged)
    Q_PROPERTY(bool isBand23FrequencyImmutable READ isBand23FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand23FrequencyValue READ defaultBand23FrequencyValue CONSTANT)
    /**
      Get band23Frequency
    */
    double band23Frequency() const
    {
      return mBand23Frequency;
    }

    /**
      Is band23Frequency Immutable
    */
    bool isBand23FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band23Frequency" ) );
    }

    /**
      Get band23Frequency default value
    */
    double defaultBand23FrequencyValue() const
    {
        return defaultBand23FrequencyValue_helper();
    }

    /**
      Set band24Frequency
    */
    void setBand24Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand24Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand24Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand24Frequency && !isBand24FrequencyImmutable()) {
        mBand24Frequency = v;
        Q_EMIT band24FrequencyChanged();
      }
    }

    Q_PROPERTY(double band24Frequency READ band24Frequency WRITE setBand24Frequency NOTIFY band24FrequencyChanged)
    Q_PROPERTY(bool isBand24FrequencyImmutable READ isBand24FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand24FrequencyValue READ defaultBand24FrequencyValue CONSTANT)
    /**
      Get band24Frequency
    */
    double band24Frequency() const
    {
      return mBand24Frequency;
    }

    /**
      Is band24Frequency Immutable
    */
    bool isBand24FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band24Frequency" ) );
    }

    /**
      Get band24Frequency default value
    */
    double defaultBand24FrequencyValue() const
    {
        return defaultBand24FrequencyValue_helper();
    }

    /**
      Set band25Frequency
    */
    void setBand25Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand25Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand25Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand25Frequency && !isBand25FrequencyImmutable()) {
        mBand25Frequency = v;
        Q_EMIT band25FrequencyChanged();
      }
    }

    Q_PROPERTY(double band25Frequency READ band25Frequency WRITE setBand25Frequency NOTIFY band25FrequencyChanged)
    Q_PROPERTY(bool isBand25FrequencyImmutable READ isBand25FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand25FrequencyValue READ defaultBand25FrequencyValue CONSTANT)
    /**
      Get band25Frequency
    */
    double band25Frequency() const
    {
      return mBand25Frequency;
    }

    /**
      Is band25Frequency Immutable
    */
    bool isBand25FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band25Frequency" ) );
    }

    /**
      Get band25Frequency default value
    */
    double defaultBand25FrequencyValue() const
    {
        return defaultBand25FrequencyValue_helper();
    }

    /**
      Set band26Frequency
    */
    void setBand26Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand26Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand26Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand26Frequency && !isBand26FrequencyImmutable()) {
        mBand26Frequency = v;
        Q_EMIT band26FrequencyChanged();
      }
    }

    Q_PROPERTY(double band26Frequency READ band26Frequency WRITE setBand26Frequency NOTIFY band26FrequencyChanged)
    Q_PROPERTY(bool isBand26FrequencyImmutable READ isBand26FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand26FrequencyValue READ defaultBand26FrequencyValue CONSTANT)
    /**
      Get band26Frequency
    */
    double band26Frequency() const
    {
      return mBand26Frequency;
    }

    /**
      Is band26Frequency Immutable
    */
    bool isBand26FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band26Frequency" ) );
    }

    /**
      Get band26Frequency default value
    */
    double defaultBand26FrequencyValue() const
    {
        return defaultBand26FrequencyValue_helper();
    }

    /**
      Set band27Frequency
    */
    void setBand27Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand27Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand27Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand27Frequency && !isBand27FrequencyImmutable()) {
        mBand27Frequency = v;
        Q_EMIT band27FrequencyChanged();
      }
    }

    Q_PROPERTY(double band27Frequency READ band27Frequency WRITE setBand27Frequency NOTIFY band27FrequencyChanged)
    Q_PROPERTY(bool isBand27FrequencyImmutable READ isBand27FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand27FrequencyValue READ defaultBand27FrequencyValue CONSTANT)
    /**
      Get band27Frequency
    */
    double band27Frequency() const
    {
      return mBand27Frequency;
    }

    /**
      Is band27Frequency Immutable
    */
    bool isBand27FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band27Frequency" ) );
    }

    /**
      Get band27Frequency default value
    */
    double defaultBand27FrequencyValue() const
    {
        return defaultBand27FrequencyValue_helper();
    }

    /**
      Set band28Frequency
    */
    void setBand28Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand28Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand28Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand28Frequency && !isBand28FrequencyImmutable()) {
        mBand28Frequency = v;
        Q_EMIT band28FrequencyChanged();
      }
    }

    Q_PROPERTY(double band28Frequency READ band28Frequency WRITE setBand28Frequency NOTIFY band28FrequencyChanged)
    Q_PROPERTY(bool isBand28FrequencyImmutable READ isBand28FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand28FrequencyValue READ defaultBand28FrequencyValue CONSTANT)
    /**
      Get band28Frequency
    */
    double band28Frequency() const
    {
      return mBand28Frequency;
    }

    /**
      Is band28Frequency Immutable
    */
    bool isBand28FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band28Frequency" ) );
    }

    /**
      Get band28Frequency default value
    */
    double defaultBand28FrequencyValue() const
    {
        return defaultBand28FrequencyValue_helper();
    }

    /**
      Set band29Frequency
    */
    void setBand29Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand29Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand29Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand29Frequency && !isBand29FrequencyImmutable()) {
        mBand29Frequency = v;
        Q_EMIT band29FrequencyChanged();
      }
    }

    Q_PROPERTY(double band29Frequency READ band29Frequency WRITE setBand29Frequency NOTIFY band29FrequencyChanged)
    Q_PROPERTY(bool isBand29FrequencyImmutable READ isBand29FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand29FrequencyValue READ defaultBand29FrequencyValue CONSTANT)
    /**
      Get band29Frequency
    */
    double band29Frequency() const
    {
      return mBand29Frequency;
    }

    /**
      Is band29Frequency Immutable
    */
    bool isBand29FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band29Frequency" ) );
    }

    /**
      Get band29Frequency default value
    */
    double defaultBand29FrequencyValue() const
    {
        return defaultBand29FrequencyValue_helper();
    }

    /**
      Set band30Frequency
    */
    void setBand30Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand30Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand30Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand30Frequency && !isBand30FrequencyImmutable()) {
        mBand30Frequency = v;
        Q_EMIT band30FrequencyChanged();
      }
    }

    Q_PROPERTY(double band30Frequency READ band30Frequency WRITE setBand30Frequency NOTIFY band30FrequencyChanged)
    Q_PROPERTY(bool isBand30FrequencyImmutable READ isBand30FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand30FrequencyValue READ defaultBand30FrequencyValue CONSTANT)
    /**
      Get band30Frequency
    */
    double band30Frequency() const
    {
      return mBand30Frequency;
    }

    /**
      Is band30Frequency Immutable
    */
    bool isBand30FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band30Frequency" ) );
    }

    /**
      Get band30Frequency default value
    */
    double defaultBand30FrequencyValue() const
    {
        return defaultBand30FrequencyValue_helper();
    }

    /**
      Set band31Frequency
    */
    void setBand31Frequency( double v )
    {
      if (v < 10)
      {
        qDebug() << "setBand31Frequency: value " << v << " is less than the minimum value of 10";
        v = 10;
      }

      if (v > 24000)
      {
        qDebug() << "setBand31Frequency: value " << v << " is greater than the maximum value of 24000";
        v = 24000;
      }

      if (v != mBand31Frequency && !isBand31FrequencyImmutable()) {
        mBand31Frequency = v;
        Q_EMIT band31FrequencyChanged();
      }
    }

    Q_PROPERTY(double band31Frequency READ band31Frequency WRITE setBand31Frequency NOTIFY band31FrequencyChanged)
    Q_PROPERTY(bool isBand31FrequencyImmutable READ isBand31FrequencyImmutable CONSTANT)
    Q_PROPERTY(double defaultBand31FrequencyValue READ defaultBand31FrequencyValue CONSTANT)
    /**
      Get band31Frequency
    */
    double band31Frequency() const
    {
      return mBand31Frequency;
    }

    /**
      Is band31Frequency Immutable
    */
    bool isBand31FrequencyImmutable() const
    {
      return isImmutable( QStringLiteral( "band31Frequency" ) );
    }

    /**
      Get band31Frequency default value
    */
    double defaultBand31FrequencyValue() const
    {
        return defaultBand31FrequencyValue_helper();
    }

    /**
      Set band0Q
    */
    void setBand0Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand0Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand0Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand0Q && !isBand0QImmutable()) {
        mBand0Q = v;
        Q_EMIT band0QChanged();
      }
    }

    Q_PROPERTY(double band0Q READ band0Q WRITE setBand0Q NOTIFY band0QChanged)
    Q_PROPERTY(bool isBand0QImmutable READ isBand0QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand0QValue READ defaultBand0QValue CONSTANT)
    /**
      Get band0Q
    */
    double band0Q() const
    {
      return mBand0Q;
    }

    /**
      Is band0Q Immutable
    */
    bool isBand0QImmutable() const
    {
      return isImmutable( QStringLiteral( "band0Q" ) );
    }

    /**
      Get band0Q default value
    */
    double defaultBand0QValue() const
    {
        return defaultBand0QValue_helper();
    }

    /**
      Set band1Q
    */
    void setBand1Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand1Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand1Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand1Q && !isBand1QImmutable()) {
        mBand1Q = v;
        Q_EMIT band1QChanged();
      }
    }

    Q_PROPERTY(double band1Q READ band1Q WRITE setBand1Q NOTIFY band1QChanged)
    Q_PROPERTY(bool isBand1QImmutable READ isBand1QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand1QValue READ defaultBand1QValue CONSTANT)
    /**
      Get band1Q
    */
    double band1Q() const
    {
      return mBand1Q;
    }

    /**
      Is band1Q Immutable
    */
    bool isBand1QImmutable() const
    {
      return isImmutable( QStringLiteral( "band1Q" ) );
    }

    /**
      Get band1Q default value
    */
    double defaultBand1QValue() const
    {
        return defaultBand1QValue_helper();
    }

    /**
      Set band2Q
    */
    void setBand2Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand2Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand2Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand2Q && !isBand2QImmutable()) {
        mBand2Q = v;
        Q_EMIT band2QChanged();
      }
    }

    Q_PROPERTY(double band2Q READ band2Q WRITE setBand2Q NOTIFY band2QChanged)
    Q_PROPERTY(bool isBand2QImmutable READ isBand2QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand2QValue READ defaultBand2QValue CONSTANT)
    /**
      Get band2Q
    */
    double band2Q() const
    {
      return mBand2Q;
    }

    /**
      Is band2Q Immutable
    */
    bool isBand2QImmutable() const
    {
      return isImmutable( QStringLiteral( "band2Q" ) );
    }

    /**
      Get band2Q default value
    */
    double defaultBand2QValue() const
    {
        return defaultBand2QValue_helper();
    }

    /**
      Set band3Q
    */
    void setBand3Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand3Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand3Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand3Q && !isBand3QImmutable()) {
        mBand3Q = v;
        Q_EMIT band3QChanged();
      }
    }

    Q_PROPERTY(double band3Q READ band3Q WRITE setBand3Q NOTIFY band3QChanged)
    Q_PROPERTY(bool isBand3QImmutable READ isBand3QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand3QValue READ defaultBand3QValue CONSTANT)
    /**
      Get band3Q
    */
    double band3Q() const
    {
      return mBand3Q;
    }

    /**
      Is band3Q Immutable
    */
    bool isBand3QImmutable() const
    {
      return isImmutable( QStringLiteral( "band3Q" ) );
    }

    /**
      Get band3Q default value
    */
    double defaultBand3QValue() const
    {
        return defaultBand3QValue_helper();
    }

    /**
      Set band4Q
    */
    void setBand4Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand4Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand4Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand4Q && !isBand4QImmutable()) {
        mBand4Q = v;
        Q_EMIT band4QChanged();
      }
    }

    Q_PROPERTY(double band4Q READ band4Q WRITE setBand4Q NOTIFY band4QChanged)
    Q_PROPERTY(bool isBand4QImmutable READ isBand4QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand4QValue READ defaultBand4QValue CONSTANT)
    /**
      Get band4Q
    */
    double band4Q() const
    {
      return mBand4Q;
    }

    /**
      Is band4Q Immutable
    */
    bool isBand4QImmutable() const
    {
      return isImmutable( QStringLiteral( "band4Q" ) );
    }

    /**
      Get band4Q default value
    */
    double defaultBand4QValue() const
    {
        return defaultBand4QValue_helper();
    }

    /**
      Set band5Q
    */
    void setBand5Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand5Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand5Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand5Q && !isBand5QImmutable()) {
        mBand5Q = v;
        Q_EMIT band5QChanged();
      }
    }

    Q_PROPERTY(double band5Q READ band5Q WRITE setBand5Q NOTIFY band5QChanged)
    Q_PROPERTY(bool isBand5QImmutable READ isBand5QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand5QValue READ defaultBand5QValue CONSTANT)
    /**
      Get band5Q
    */
    double band5Q() const
    {
      return mBand5Q;
    }

    /**
      Is band5Q Immutable
    */
    bool isBand5QImmutable() const
    {
      return isImmutable( QStringLiteral( "band5Q" ) );
    }

    /**
      Get band5Q default value
    */
    double defaultBand5QValue() const
    {
        return defaultBand5QValue_helper();
    }

    /**
      Set band6Q
    */
    void setBand6Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand6Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand6Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand6Q && !isBand6QImmutable()) {
        mBand6Q = v;
        Q_EMIT band6QChanged();
      }
    }

    Q_PROPERTY(double band6Q READ band6Q WRITE setBand6Q NOTIFY band6QChanged)
    Q_PROPERTY(bool isBand6QImmutable READ isBand6QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand6QValue READ defaultBand6QValue CONSTANT)
    /**
      Get band6Q
    */
    double band6Q() const
    {
      return mBand6Q;
    }

    /**
      Is band6Q Immutable
    */
    bool isBand6QImmutable() const
    {
      return isImmutable( QStringLiteral( "band6Q" ) );
    }

    /**
      Get band6Q default value
    */
    double defaultBand6QValue() const
    {
        return defaultBand6QValue_helper();
    }

    /**
      Set band7Q
    */
    void setBand7Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand7Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand7Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand7Q && !isBand7QImmutable()) {
        mBand7Q = v;
        Q_EMIT band7QChanged();
      }
    }

    Q_PROPERTY(double band7Q READ band7Q WRITE setBand7Q NOTIFY band7QChanged)
    Q_PROPERTY(bool isBand7QImmutable READ isBand7QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand7QValue READ defaultBand7QValue CONSTANT)
    /**
      Get band7Q
    */
    double band7Q() const
    {
      return mBand7Q;
    }

    /**
      Is band7Q Immutable
    */
    bool isBand7QImmutable() const
    {
      return isImmutable( QStringLiteral( "band7Q" ) );
    }

    /**
      Get band7Q default value
    */
    double defaultBand7QValue() const
    {
        return defaultBand7QValue_helper();
    }

    /**
      Set band8Q
    */
    void setBand8Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand8Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand8Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand8Q && !isBand8QImmutable()) {
        mBand8Q = v;
        Q_EMIT band8QChanged();
      }
    }

    Q_PROPERTY(double band8Q READ band8Q WRITE setBand8Q NOTIFY band8QChanged)
    Q_PROPERTY(bool isBand8QImmutable READ isBand8QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand8QValue READ defaultBand8QValue CONSTANT)
    /**
      Get band8Q
    */
    double band8Q() const
    {
      return mBand8Q;
    }

    /**
      Is band8Q Immutable
    */
    bool isBand8QImmutable() const
    {
      return isImmutable( QStringLiteral( "band8Q" ) );
    }

    /**
      Get band8Q default value
    */
    double defaultBand8QValue() const
    {
        return defaultBand8QValue_helper();
    }

    /**
      Set band9Q
    */
    void setBand9Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand9Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand9Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand9Q && !isBand9QImmutable()) {
        mBand9Q = v;
        Q_EMIT band9QChanged();
      }
    }

    Q_PROPERTY(double band9Q READ band9Q WRITE setBand9Q NOTIFY band9QChanged)
    Q_PROPERTY(bool isBand9QImmutable READ isBand9QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand9QValue READ defaultBand9QValue CONSTANT)
    /**
      Get band9Q
    */
    double band9Q() const
    {
      return mBand9Q;
    }

    /**
      Is band9Q Immutable
    */
    bool isBand9QImmutable() const
    {
      return isImmutable( QStringLiteral( "band9Q" ) );
    }

    /**
      Get band9Q default value
    */
    double defaultBand9QValue() const
    {
        return defaultBand9QValue_helper();
    }

    /**
      Set band10Q
    */
    void setBand10Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand10Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand10Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand10Q && !isBand10QImmutable()) {
        mBand10Q = v;
        Q_EMIT band10QChanged();
      }
    }

    Q_PROPERTY(double band10Q READ band10Q WRITE setBand10Q NOTIFY band10QChanged)
    Q_PROPERTY(bool isBand10QImmutable READ isBand10QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand10QValue READ defaultBand10QValue CONSTANT)
    /**
      Get band10Q
    */
    double band10Q() const
    {
      return mBand10Q;
    }

    /**
      Is band10Q Immutable
    */
    bool isBand10QImmutable() const
    {
      return isImmutable( QStringLiteral( "band10Q" ) );
    }

    /**
      Get band10Q default value
    */
    double defaultBand10QValue() const
    {
        return defaultBand10QValue_helper();
    }

    /**
      Set band11Q
    */
    void setBand11Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand11Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand11Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand11Q && !isBand11QImmutable()) {
        mBand11Q = v;
        Q_EMIT band11QChanged();
      }
    }

    Q_PROPERTY(double band11Q READ band11Q WRITE setBand11Q NOTIFY band11QChanged)
    Q_PROPERTY(bool isBand11QImmutable READ isBand11QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand11QValue READ defaultBand11QValue CONSTANT)
    /**
      Get band11Q
    */
    double band11Q() const
    {
      return mBand11Q;
    }

    /**
      Is band11Q Immutable
    */
    bool isBand11QImmutable() const
    {
      return isImmutable( QStringLiteral( "band11Q" ) );
    }

    /**
      Get band11Q default value
    */
    double defaultBand11QValue() const
    {
        return defaultBand11QValue_helper();
    }

    /**
      Set band12Q
    */
    void setBand12Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand12Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand12Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand12Q && !isBand12QImmutable()) {
        mBand12Q = v;
        Q_EMIT band12QChanged();
      }
    }

    Q_PROPERTY(double band12Q READ band12Q WRITE setBand12Q NOTIFY band12QChanged)
    Q_PROPERTY(bool isBand12QImmutable READ isBand12QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand12QValue READ defaultBand12QValue CONSTANT)
    /**
      Get band12Q
    */
    double band12Q() const
    {
      return mBand12Q;
    }

    /**
      Is band12Q Immutable
    */
    bool isBand12QImmutable() const
    {
      return isImmutable( QStringLiteral( "band12Q" ) );
    }

    /**
      Get band12Q default value
    */
    double defaultBand12QValue() const
    {
        return defaultBand12QValue_helper();
    }

    /**
      Set band13Q
    */
    void setBand13Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand13Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand13Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand13Q && !isBand13QImmutable()) {
        mBand13Q = v;
        Q_EMIT band13QChanged();
      }
    }

    Q_PROPERTY(double band13Q READ band13Q WRITE setBand13Q NOTIFY band13QChanged)
    Q_PROPERTY(bool isBand13QImmutable READ isBand13QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand13QValue READ defaultBand13QValue CONSTANT)
    /**
      Get band13Q
    */
    double band13Q() const
    {
      return mBand13Q;
    }

    /**
      Is band13Q Immutable
    */
    bool isBand13QImmutable() const
    {
      return isImmutable( QStringLiteral( "band13Q" ) );
    }

    /**
      Get band13Q default value
    */
    double defaultBand13QValue() const
    {
        return defaultBand13QValue_helper();
    }

    /**
      Set band14Q
    */
    void setBand14Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand14Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand14Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand14Q && !isBand14QImmutable()) {
        mBand14Q = v;
        Q_EMIT band14QChanged();
      }
    }

    Q_PROPERTY(double band14Q READ band14Q WRITE setBand14Q NOTIFY band14QChanged)
    Q_PROPERTY(bool isBand14QImmutable READ isBand14QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand14QValue READ defaultBand14QValue CONSTANT)
    /**
      Get band14Q
    */
    double band14Q() const
    {
      return mBand14Q;
    }

    /**
      Is band14Q Immutable
    */
    bool isBand14QImmutable() const
    {
      return isImmutable( QStringLiteral( "band14Q" ) );
    }

    /**
      Get band14Q default value
    */
    double defaultBand14QValue() const
    {
        return defaultBand14QValue_helper();
    }

    /**
      Set band15Q
    */
    void setBand15Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand15Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand15Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand15Q && !isBand15QImmutable()) {
        mBand15Q = v;
        Q_EMIT band15QChanged();
      }
    }

    Q_PROPERTY(double band15Q READ band15Q WRITE setBand15Q NOTIFY band15QChanged)
    Q_PROPERTY(bool isBand15QImmutable READ isBand15QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand15QValue READ defaultBand15QValue CONSTANT)
    /**
      Get band15Q
    */
    double band15Q() const
    {
      return mBand15Q;
    }

    /**
      Is band15Q Immutable
    */
    bool isBand15QImmutable() const
    {
      return isImmutable( QStringLiteral( "band15Q" ) );
    }

    /**
      Get band15Q default value
    */
    double defaultBand15QValue() const
    {
        return defaultBand15QValue_helper();
    }

    /**
      Set band16Q
    */
    void setBand16Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand16Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand16Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand16Q && !isBand16QImmutable()) {
        mBand16Q = v;
        Q_EMIT band16QChanged();
      }
    }

    Q_PROPERTY(double band16Q READ band16Q WRITE setBand16Q NOTIFY band16QChanged)
    Q_PROPERTY(bool isBand16QImmutable READ isBand16QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand16QValue READ defaultBand16QValue CONSTANT)
    /**
      Get band16Q
    */
    double band16Q() const
    {
      return mBand16Q;
    }

    /**
      Is band16Q Immutable
    */
    bool isBand16QImmutable() const
    {
      return isImmutable( QStringLiteral( "band16Q" ) );
    }

    /**
      Get band16Q default value
    */
    double defaultBand16QValue() const
    {
        return defaultBand16QValue_helper();
    }

    /**
      Set band17Q
    */
    void setBand17Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand17Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand17Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand17Q && !isBand17QImmutable()) {
        mBand17Q = v;
        Q_EMIT band17QChanged();
      }
    }

    Q_PROPERTY(double band17Q READ band17Q WRITE setBand17Q NOTIFY band17QChanged)
    Q_PROPERTY(bool isBand17QImmutable READ isBand17QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand17QValue READ defaultBand17QValue CONSTANT)
    /**
      Get band17Q
    */
    double band17Q() const
    {
      return mBand17Q;
    }

    /**
      Is band17Q Immutable
    */
    bool isBand17QImmutable() const
    {
      return isImmutable( QStringLiteral( "band17Q" ) );
    }

    /**
      Get band17Q default value
    */
    double defaultBand17QValue() const
    {
        return defaultBand17QValue_helper();
    }

    /**
      Set band18Q
    */
    void setBand18Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand18Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand18Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand18Q && !isBand18QImmutable()) {
        mBand18Q = v;
        Q_EMIT band18QChanged();
      }
    }

    Q_PROPERTY(double band18Q READ band18Q WRITE setBand18Q NOTIFY band18QChanged)
    Q_PROPERTY(bool isBand18QImmutable READ isBand18QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand18QValue READ defaultBand18QValue CONSTANT)
    /**
      Get band18Q
    */
    double band18Q() const
    {
      return mBand18Q;
    }

    /**
      Is band18Q Immutable
    */
    bool isBand18QImmutable() const
    {
      return isImmutable( QStringLiteral( "band18Q" ) );
    }

    /**
      Get band18Q default value
    */
    double defaultBand18QValue() const
    {
        return defaultBand18QValue_helper();
    }

    /**
      Set band19Q
    */
    void setBand19Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand19Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand19Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand19Q && !isBand19QImmutable()) {
        mBand19Q = v;
        Q_EMIT band19QChanged();
      }
    }

    Q_PROPERTY(double band19Q READ band19Q WRITE setBand19Q NOTIFY band19QChanged)
    Q_PROPERTY(bool isBand19QImmutable READ isBand19QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand19QValue READ defaultBand19QValue CONSTANT)
    /**
      Get band19Q
    */
    double band19Q() const
    {
      return mBand19Q;
    }

    /**
      Is band19Q Immutable
    */
    bool isBand19QImmutable() const
    {
      return isImmutable( QStringLiteral( "band19Q" ) );
    }

    /**
      Get band19Q default value
    */
    double defaultBand19QValue() const
    {
        return defaultBand19QValue_helper();
    }

    /**
      Set band20Q
    */
    void setBand20Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand20Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand20Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand20Q && !isBand20QImmutable()) {
        mBand20Q = v;
        Q_EMIT band20QChanged();
      }
    }

    Q_PROPERTY(double band20Q READ band20Q WRITE setBand20Q NOTIFY band20QChanged)
    Q_PROPERTY(bool isBand20QImmutable READ isBand20QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand20QValue READ defaultBand20QValue CONSTANT)
    /**
      Get band20Q
    */
    double band20Q() const
    {
      return mBand20Q;
    }

    /**
      Is band20Q Immutable
    */
    bool isBand20QImmutable() const
    {
      return isImmutable( QStringLiteral( "band20Q" ) );
    }

    /**
      Get band20Q default value
    */
    double defaultBand20QValue() const
    {
        return defaultBand20QValue_helper();
    }

    /**
      Set band21Q
    */
    void setBand21Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand21Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand21Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand21Q && !isBand21QImmutable()) {
        mBand21Q = v;
        Q_EMIT band21QChanged();
      }
    }

    Q_PROPERTY(double band21Q READ band21Q WRITE setBand21Q NOTIFY band21QChanged)
    Q_PROPERTY(bool isBand21QImmutable READ isBand21QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand21QValue READ defaultBand21QValue CONSTANT)
    /**
      Get band21Q
    */
    double band21Q() const
    {
      return mBand21Q;
    }

    /**
      Is band21Q Immutable
    */
    bool isBand21QImmutable() const
    {
      return isImmutable( QStringLiteral( "band21Q" ) );
    }

    /**
      Get band21Q default value
    */
    double defaultBand21QValue() const
    {
        return defaultBand21QValue_helper();
    }

    /**
      Set band22Q
    */
    void setBand22Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand22Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand22Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand22Q && !isBand22QImmutable()) {
        mBand22Q = v;
        Q_EMIT band22QChanged();
      }
    }

    Q_PROPERTY(double band22Q READ band22Q WRITE setBand22Q NOTIFY band22QChanged)
    Q_PROPERTY(bool isBand22QImmutable READ isBand22QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand22QValue READ defaultBand22QValue CONSTANT)
    /**
      Get band22Q
    */
    double band22Q() const
    {
      return mBand22Q;
    }

    /**
      Is band22Q Immutable
    */
    bool isBand22QImmutable() const
    {
      return isImmutable( QStringLiteral( "band22Q" ) );
    }

    /**
      Get band22Q default value
    */
    double defaultBand22QValue() const
    {
        return defaultBand22QValue_helper();
    }

    /**
      Set band23Q
    */
    void setBand23Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand23Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand23Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand23Q && !isBand23QImmutable()) {
        mBand23Q = v;
        Q_EMIT band23QChanged();
      }
    }

    Q_PROPERTY(double band23Q READ band23Q WRITE setBand23Q NOTIFY band23QChanged)
    Q_PROPERTY(bool isBand23QImmutable READ isBand23QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand23QValue READ defaultBand23QValue CONSTANT)
    /**
      Get band23Q
    */
    double band23Q() const
    {
      return mBand23Q;
    }

    /**
      Is band23Q Immutable
    */
    bool isBand23QImmutable() const
    {
      return isImmutable( QStringLiteral( "band23Q" ) );
    }

    /**
      Get band23Q default value
    */
    double defaultBand23QValue() const
    {
        return defaultBand23QValue_helper();
    }

    /**
      Set band24Q
    */
    void setBand24Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand24Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand24Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand24Q && !isBand24QImmutable()) {
        mBand24Q = v;
        Q_EMIT band24QChanged();
      }
    }

    Q_PROPERTY(double band24Q READ band24Q WRITE setBand24Q NOTIFY band24QChanged)
    Q_PROPERTY(bool isBand24QImmutable READ isBand24QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand24QValue READ defaultBand24QValue CONSTANT)
    /**
      Get band24Q
    */
    double band24Q() const
    {
      return mBand24Q;
    }

    /**
      Is band24Q Immutable
    */
    bool isBand24QImmutable() const
    {
      return isImmutable( QStringLiteral( "band24Q" ) );
    }

    /**
      Get band24Q default value
    */
    double defaultBand24QValue() const
    {
        return defaultBand24QValue_helper();
    }

    /**
      Set band25Q
    */
    void setBand25Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand25Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand25Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand25Q && !isBand25QImmutable()) {
        mBand25Q = v;
        Q_EMIT band25QChanged();
      }
    }

    Q_PROPERTY(double band25Q READ band25Q WRITE setBand25Q NOTIFY band25QChanged)
    Q_PROPERTY(bool isBand25QImmutable READ isBand25QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand25QValue READ defaultBand25QValue CONSTANT)
    /**
      Get band25Q
    */
    double band25Q() const
    {
      return mBand25Q;
    }

    /**
      Is band25Q Immutable
    */
    bool isBand25QImmutable() const
    {
      return isImmutable( QStringLiteral( "band25Q" ) );
    }

    /**
      Get band25Q default value
    */
    double defaultBand25QValue() const
    {
        return defaultBand25QValue_helper();
    }

    /**
      Set band26Q
    */
    void setBand26Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand26Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand26Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand26Q && !isBand26QImmutable()) {
        mBand26Q = v;
        Q_EMIT band26QChanged();
      }
    }

    Q_PROPERTY(double band26Q READ band26Q WRITE setBand26Q NOTIFY band26QChanged)
    Q_PROPERTY(bool isBand26QImmutable READ isBand26QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand26QValue READ defaultBand26QValue CONSTANT)
    /**
      Get band26Q
    */
    double band26Q() const
    {
      return mBand26Q;
    }

    /**
      Is band26Q Immutable
    */
    bool isBand26QImmutable() const
    {
      return isImmutable( QStringLiteral( "band26Q" ) );
    }

    /**
      Get band26Q default value
    */
    double defaultBand26QValue() const
    {
        return defaultBand26QValue_helper();
    }

    /**
      Set band27Q
    */
    void setBand27Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand27Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand27Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand27Q && !isBand27QImmutable()) {
        mBand27Q = v;
        Q_EMIT band27QChanged();
      }
    }

    Q_PROPERTY(double band27Q READ band27Q WRITE setBand27Q NOTIFY band27QChanged)
    Q_PROPERTY(bool isBand27QImmutable READ isBand27QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand27QValue READ defaultBand27QValue CONSTANT)
    /**
      Get band27Q
    */
    double band27Q() const
    {
      return mBand27Q;
    }

    /**
      Is band27Q Immutable
    */
    bool isBand27QImmutable() const
    {
      return isImmutable( QStringLiteral( "band27Q" ) );
    }

    /**
      Get band27Q default value
    */
    double defaultBand27QValue() const
    {
        return defaultBand27QValue_helper();
    }

    /**
      Set band28Q
    */
    void setBand28Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand28Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand28Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand28Q && !isBand28QImmutable()) {
        mBand28Q = v;
        Q_EMIT band28QChanged();
      }
    }

    Q_PROPERTY(double band28Q READ band28Q WRITE setBand28Q NOTIFY band28QChanged)
    Q_PROPERTY(bool isBand28QImmutable READ isBand28QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand28QValue READ defaultBand28QValue CONSTANT)
    /**
      Get band28Q
    */
    double band28Q() const
    {
      return mBand28Q;
    }

    /**
      Is band28Q Immutable
    */
    bool isBand28QImmutable() const
    {
      return isImmutable( QStringLiteral( "band28Q" ) );
    }

    /**
      Get band28Q default value
    */
    double defaultBand28QValue() const
    {
        return defaultBand28QValue_helper();
    }

    /**
      Set band29Q
    */
    void setBand29Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand29Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand29Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand29Q && !isBand29QImmutable()) {
        mBand29Q = v;
        Q_EMIT band29QChanged();
      }
    }

    Q_PROPERTY(double band29Q READ band29Q WRITE setBand29Q NOTIFY band29QChanged)
    Q_PROPERTY(bool isBand29QImmutable READ isBand29QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand29QValue READ defaultBand29QValue CONSTANT)
    /**
      Get band29Q
    */
    double band29Q() const
    {
      return mBand29Q;
    }

    /**
      Is band29Q Immutable
    */
    bool isBand29QImmutable() const
    {
      return isImmutable( QStringLiteral( "band29Q" ) );
    }

    /**
      Get band29Q default value
    */
    double defaultBand29QValue() const
    {
        return defaultBand29QValue_helper();
    }

    /**
      Set band30Q
    */
    void setBand30Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand30Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand30Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand30Q && !isBand30QImmutable()) {
        mBand30Q = v;
        Q_EMIT band30QChanged();
      }
    }

    Q_PROPERTY(double band30Q READ band30Q WRITE setBand30Q NOTIFY band30QChanged)
    Q_PROPERTY(bool isBand30QImmutable READ isBand30QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand30QValue READ defaultBand30QValue CONSTANT)
    /**
      Get band30Q
    */
    double band30Q() const
    {
      return mBand30Q;
    }

    /**
      Is band30Q Immutable
    */
    bool isBand30QImmutable() const
    {
      return isImmutable( QStringLiteral( "band30Q" ) );
    }

    /**
      Get band30Q default value
    */
    double defaultBand30QValue() const
    {
        return defaultBand30QValue_helper();
    }

    /**
      Set band31Q
    */
    void setBand31Q( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand31Q: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 100)
      {
        qDebug() << "setBand31Q: value " << v << " is greater than the maximum value of 100";
        v = 100;
      }

      if (v != mBand31Q && !isBand31QImmutable()) {
        mBand31Q = v;
        Q_EMIT band31QChanged();
      }
    }

    Q_PROPERTY(double band31Q READ band31Q WRITE setBand31Q NOTIFY band31QChanged)
    Q_PROPERTY(bool isBand31QImmutable READ isBand31QImmutable CONSTANT)
    Q_PROPERTY(double defaultBand31QValue READ defaultBand31QValue CONSTANT)
    /**
      Get band31Q
    */
    double band31Q() const
    {
      return mBand31Q;
    }

    /**
      Is band31Q Immutable
    */
    bool isBand31QImmutable() const
    {
      return isImmutable( QStringLiteral( "band31Q" ) );
    }

    /**
      Get band31Q default value
    */
    double defaultBand31QValue() const
    {
        return defaultBand31QValue_helper();
    }

    /**
      Set band0Width
    */
    void setBand0Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand0Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand0Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand0Width && !isBand0WidthImmutable()) {
        mBand0Width = v;
        Q_EMIT band0WidthChanged();
      }
    }

    Q_PROPERTY(double band0Width READ band0Width WRITE setBand0Width NOTIFY band0WidthChanged)
    Q_PROPERTY(bool isBand0WidthImmutable READ isBand0WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand0WidthValue READ defaultBand0WidthValue CONSTANT)
    /**
      Get band0Width
    */
    double band0Width() const
    {
      return mBand0Width;
    }

    /**
      Is band0Width Immutable
    */
    bool isBand0WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band0Width" ) );
    }

    /**
      Get band0Width default value
    */
    double defaultBand0WidthValue() const
    {
        return defaultBand0WidthValue_helper();
    }

    /**
      Set band1Width
    */
    void setBand1Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand1Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand1Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand1Width && !isBand1WidthImmutable()) {
        mBand1Width = v;
        Q_EMIT band1WidthChanged();
      }
    }

    Q_PROPERTY(double band1Width READ band1Width WRITE setBand1Width NOTIFY band1WidthChanged)
    Q_PROPERTY(bool isBand1WidthImmutable READ isBand1WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand1WidthValue READ defaultBand1WidthValue CONSTANT)
    /**
      Get band1Width
    */
    double band1Width() const
    {
      return mBand1Width;
    }

    /**
      Is band1Width Immutable
    */
    bool isBand1WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band1Width" ) );
    }

    /**
      Get band1Width default value
    */
    double defaultBand1WidthValue() const
    {
        return defaultBand1WidthValue_helper();
    }

    /**
      Set band2Width
    */
    void setBand2Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand2Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand2Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand2Width && !isBand2WidthImmutable()) {
        mBand2Width = v;
        Q_EMIT band2WidthChanged();
      }
    }

    Q_PROPERTY(double band2Width READ band2Width WRITE setBand2Width NOTIFY band2WidthChanged)
    Q_PROPERTY(bool isBand2WidthImmutable READ isBand2WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand2WidthValue READ defaultBand2WidthValue CONSTANT)
    /**
      Get band2Width
    */
    double band2Width() const
    {
      return mBand2Width;
    }

    /**
      Is band2Width Immutable
    */
    bool isBand2WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band2Width" ) );
    }

    /**
      Get band2Width default value
    */
    double defaultBand2WidthValue() const
    {
        return defaultBand2WidthValue_helper();
    }

    /**
      Set band3Width
    */
    void setBand3Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand3Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand3Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand3Width && !isBand3WidthImmutable()) {
        mBand3Width = v;
        Q_EMIT band3WidthChanged();
      }
    }

    Q_PROPERTY(double band3Width READ band3Width WRITE setBand3Width NOTIFY band3WidthChanged)
    Q_PROPERTY(bool isBand3WidthImmutable READ isBand3WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand3WidthValue READ defaultBand3WidthValue CONSTANT)
    /**
      Get band3Width
    */
    double band3Width() const
    {
      return mBand3Width;
    }

    /**
      Is band3Width Immutable
    */
    bool isBand3WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band3Width" ) );
    }

    /**
      Get band3Width default value
    */
    double defaultBand3WidthValue() const
    {
        return defaultBand3WidthValue_helper();
    }

    /**
      Set band4Width
    */
    void setBand4Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand4Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand4Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand4Width && !isBand4WidthImmutable()) {
        mBand4Width = v;
        Q_EMIT band4WidthChanged();
      }
    }

    Q_PROPERTY(double band4Width READ band4Width WRITE setBand4Width NOTIFY band4WidthChanged)
    Q_PROPERTY(bool isBand4WidthImmutable READ isBand4WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand4WidthValue READ defaultBand4WidthValue CONSTANT)
    /**
      Get band4Width
    */
    double band4Width() const
    {
      return mBand4Width;
    }

    /**
      Is band4Width Immutable
    */
    bool isBand4WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band4Width" ) );
    }

    /**
      Get band4Width default value
    */
    double defaultBand4WidthValue() const
    {
        return defaultBand4WidthValue_helper();
    }

    /**
      Set band5Width
    */
    void setBand5Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand5Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand5Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand5Width && !isBand5WidthImmutable()) {
        mBand5Width = v;
        Q_EMIT band5WidthChanged();
      }
    }

    Q_PROPERTY(double band5Width READ band5Width WRITE setBand5Width NOTIFY band5WidthChanged)
    Q_PROPERTY(bool isBand5WidthImmutable READ isBand5WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand5WidthValue READ defaultBand5WidthValue CONSTANT)
    /**
      Get band5Width
    */
    double band5Width() const
    {
      return mBand5Width;
    }

    /**
      Is band5Width Immutable
    */
    bool isBand5WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band5Width" ) );
    }

    /**
      Get band5Width default value
    */
    double defaultBand5WidthValue() const
    {
        return defaultBand5WidthValue_helper();
    }

    /**
      Set band6Width
    */
    void setBand6Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand6Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand6Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand6Width && !isBand6WidthImmutable()) {
        mBand6Width = v;
        Q_EMIT band6WidthChanged();
      }
    }

    Q_PROPERTY(double band6Width READ band6Width WRITE setBand6Width NOTIFY band6WidthChanged)
    Q_PROPERTY(bool isBand6WidthImmutable READ isBand6WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand6WidthValue READ defaultBand6WidthValue CONSTANT)
    /**
      Get band6Width
    */
    double band6Width() const
    {
      return mBand6Width;
    }

    /**
      Is band6Width Immutable
    */
    bool isBand6WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band6Width" ) );
    }

    /**
      Get band6Width default value
    */
    double defaultBand6WidthValue() const
    {
        return defaultBand6WidthValue_helper();
    }

    /**
      Set band7Width
    */
    void setBand7Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand7Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand7Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand7Width && !isBand7WidthImmutable()) {
        mBand7Width = v;
        Q_EMIT band7WidthChanged();
      }
    }

    Q_PROPERTY(double band7Width READ band7Width WRITE setBand7Width NOTIFY band7WidthChanged)
    Q_PROPERTY(bool isBand7WidthImmutable READ isBand7WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand7WidthValue READ defaultBand7WidthValue CONSTANT)
    /**
      Get band7Width
    */
    double band7Width() const
    {
      return mBand7Width;
    }

    /**
      Is band7Width Immutable
    */
    bool isBand7WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band7Width" ) );
    }

    /**
      Get band7Width default value
    */
    double defaultBand7WidthValue() const
    {
        return defaultBand7WidthValue_helper();
    }

    /**
      Set band8Width
    */
    void setBand8Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand8Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand8Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand8Width && !isBand8WidthImmutable()) {
        mBand8Width = v;
        Q_EMIT band8WidthChanged();
      }
    }

    Q_PROPERTY(double band8Width READ band8Width WRITE setBand8Width NOTIFY band8WidthChanged)
    Q_PROPERTY(bool isBand8WidthImmutable READ isBand8WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand8WidthValue READ defaultBand8WidthValue CONSTANT)
    /**
      Get band8Width
    */
    double band8Width() const
    {
      return mBand8Width;
    }

    /**
      Is band8Width Immutable
    */
    bool isBand8WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band8Width" ) );
    }

    /**
      Get band8Width default value
    */
    double defaultBand8WidthValue() const
    {
        return defaultBand8WidthValue_helper();
    }

    /**
      Set band9Width
    */
    void setBand9Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand9Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand9Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand9Width && !isBand9WidthImmutable()) {
        mBand9Width = v;
        Q_EMIT band9WidthChanged();
      }
    }

    Q_PROPERTY(double band9Width READ band9Width WRITE setBand9Width NOTIFY band9WidthChanged)
    Q_PROPERTY(bool isBand9WidthImmutable READ isBand9WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand9WidthValue READ defaultBand9WidthValue CONSTANT)
    /**
      Get band9Width
    */
    double band9Width() const
    {
      return mBand9Width;
    }

    /**
      Is band9Width Immutable
    */
    bool isBand9WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band9Width" ) );
    }

    /**
      Get band9Width default value
    */
    double defaultBand9WidthValue() const
    {
        return defaultBand9WidthValue_helper();
    }

    /**
      Set band10Width
    */
    void setBand10Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand10Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand10Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand10Width && !isBand10WidthImmutable()) {
        mBand10Width = v;
        Q_EMIT band10WidthChanged();
      }
    }

    Q_PROPERTY(double band10Width READ band10Width WRITE setBand10Width NOTIFY band10WidthChanged)
    Q_PROPERTY(bool isBand10WidthImmutable READ isBand10WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand10WidthValue READ defaultBand10WidthValue CONSTANT)
    /**
      Get band10Width
    */
    double band10Width() const
    {
      return mBand10Width;
    }

    /**
      Is band10Width Immutable
    */
    bool isBand10WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band10Width" ) );
    }

    /**
      Get band10Width default value
    */
    double defaultBand10WidthValue() const
    {
        return defaultBand10WidthValue_helper();
    }

    /**
      Set band11Width
    */
    void setBand11Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand11Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand11Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand11Width && !isBand11WidthImmutable()) {
        mBand11Width = v;
        Q_EMIT band11WidthChanged();
      }
    }

    Q_PROPERTY(double band11Width READ band11Width WRITE setBand11Width NOTIFY band11WidthChanged)
    Q_PROPERTY(bool isBand11WidthImmutable READ isBand11WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand11WidthValue READ defaultBand11WidthValue CONSTANT)
    /**
      Get band11Width
    */
    double band11Width() const
    {
      return mBand11Width;
    }

    /**
      Is band11Width Immutable
    */
    bool isBand11WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band11Width" ) );
    }

    /**
      Get band11Width default value
    */
    double defaultBand11WidthValue() const
    {
        return defaultBand11WidthValue_helper();
    }

    /**
      Set band12Width
    */
    void setBand12Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand12Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand12Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand12Width && !isBand12WidthImmutable()) {
        mBand12Width = v;
        Q_EMIT band12WidthChanged();
      }
    }

    Q_PROPERTY(double band12Width READ band12Width WRITE setBand12Width NOTIFY band12WidthChanged)
    Q_PROPERTY(bool isBand12WidthImmutable READ isBand12WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand12WidthValue READ defaultBand12WidthValue CONSTANT)
    /**
      Get band12Width
    */
    double band12Width() const
    {
      return mBand12Width;
    }

    /**
      Is band12Width Immutable
    */
    bool isBand12WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band12Width" ) );
    }

    /**
      Get band12Width default value
    */
    double defaultBand12WidthValue() const
    {
        return defaultBand12WidthValue_helper();
    }

    /**
      Set band13Width
    */
    void setBand13Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand13Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand13Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand13Width && !isBand13WidthImmutable()) {
        mBand13Width = v;
        Q_EMIT band13WidthChanged();
      }
    }

    Q_PROPERTY(double band13Width READ band13Width WRITE setBand13Width NOTIFY band13WidthChanged)
    Q_PROPERTY(bool isBand13WidthImmutable READ isBand13WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand13WidthValue READ defaultBand13WidthValue CONSTANT)
    /**
      Get band13Width
    */
    double band13Width() const
    {
      return mBand13Width;
    }

    /**
      Is band13Width Immutable
    */
    bool isBand13WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band13Width" ) );
    }

    /**
      Get band13Width default value
    */
    double defaultBand13WidthValue() const
    {
        return defaultBand13WidthValue_helper();
    }

    /**
      Set band14Width
    */
    void setBand14Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand14Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand14Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand14Width && !isBand14WidthImmutable()) {
        mBand14Width = v;
        Q_EMIT band14WidthChanged();
      }
    }

    Q_PROPERTY(double band14Width READ band14Width WRITE setBand14Width NOTIFY band14WidthChanged)
    Q_PROPERTY(bool isBand14WidthImmutable READ isBand14WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand14WidthValue READ defaultBand14WidthValue CONSTANT)
    /**
      Get band14Width
    */
    double band14Width() const
    {
      return mBand14Width;
    }

    /**
      Is band14Width Immutable
    */
    bool isBand14WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band14Width" ) );
    }

    /**
      Get band14Width default value
    */
    double defaultBand14WidthValue() const
    {
        return defaultBand14WidthValue_helper();
    }

    /**
      Set band15Width
    */
    void setBand15Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand15Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand15Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand15Width && !isBand15WidthImmutable()) {
        mBand15Width = v;
        Q_EMIT band15WidthChanged();
      }
    }

    Q_PROPERTY(double band15Width READ band15Width WRITE setBand15Width NOTIFY band15WidthChanged)
    Q_PROPERTY(bool isBand15WidthImmutable READ isBand15WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand15WidthValue READ defaultBand15WidthValue CONSTANT)
    /**
      Get band15Width
    */
    double band15Width() const
    {
      return mBand15Width;
    }

    /**
      Is band15Width Immutable
    */
    bool isBand15WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band15Width" ) );
    }

    /**
      Get band15Width default value
    */
    double defaultBand15WidthValue() const
    {
        return defaultBand15WidthValue_helper();
    }

    /**
      Set band16Width
    */
    void setBand16Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand16Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand16Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand16Width && !isBand16WidthImmutable()) {
        mBand16Width = v;
        Q_EMIT band16WidthChanged();
      }
    }

    Q_PROPERTY(double band16Width READ band16Width WRITE setBand16Width NOTIFY band16WidthChanged)
    Q_PROPERTY(bool isBand16WidthImmutable READ isBand16WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand16WidthValue READ defaultBand16WidthValue CONSTANT)
    /**
      Get band16Width
    */
    double band16Width() const
    {
      return mBand16Width;
    }

    /**
      Is band16Width Immutable
    */
    bool isBand16WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band16Width" ) );
    }

    /**
      Get band16Width default value
    */
    double defaultBand16WidthValue() const
    {
        return defaultBand16WidthValue_helper();
    }

    /**
      Set band17Width
    */
    void setBand17Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand17Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand17Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand17Width && !isBand17WidthImmutable()) {
        mBand17Width = v;
        Q_EMIT band17WidthChanged();
      }
    }

    Q_PROPERTY(double band17Width READ band17Width WRITE setBand17Width NOTIFY band17WidthChanged)
    Q_PROPERTY(bool isBand17WidthImmutable READ isBand17WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand17WidthValue READ defaultBand17WidthValue CONSTANT)
    /**
      Get band17Width
    */
    double band17Width() const
    {
      return mBand17Width;
    }

    /**
      Is band17Width Immutable
    */
    bool isBand17WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band17Width" ) );
    }

    /**
      Get band17Width default value
    */
    double defaultBand17WidthValue() const
    {
        return defaultBand17WidthValue_helper();
    }

    /**
      Set band18Width
    */
    void setBand18Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand18Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand18Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand18Width && !isBand18WidthImmutable()) {
        mBand18Width = v;
        Q_EMIT band18WidthChanged();
      }
    }

    Q_PROPERTY(double band18Width READ band18Width WRITE setBand18Width NOTIFY band18WidthChanged)
    Q_PROPERTY(bool isBand18WidthImmutable READ isBand18WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand18WidthValue READ defaultBand18WidthValue CONSTANT)
    /**
      Get band18Width
    */
    double band18Width() const
    {
      return mBand18Width;
    }

    /**
      Is band18Width Immutable
    */
    bool isBand18WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band18Width" ) );
    }

    /**
      Get band18Width default value
    */
    double defaultBand18WidthValue() const
    {
        return defaultBand18WidthValue_helper();
    }

    /**
      Set band19Width
    */
    void setBand19Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand19Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand19Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand19Width && !isBand19WidthImmutable()) {
        mBand19Width = v;
        Q_EMIT band19WidthChanged();
      }
    }

    Q_PROPERTY(double band19Width READ band19Width WRITE setBand19Width NOTIFY band19WidthChanged)
    Q_PROPERTY(bool isBand19WidthImmutable READ isBand19WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand19WidthValue READ defaultBand19WidthValue CONSTANT)
    /**
      Get band19Width
    */
    double band19Width() const
    {
      return mBand19Width;
    }

    /**
      Is band19Width Immutable
    */
    bool isBand19WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band19Width" ) );
    }

    /**
      Get band19Width default value
    */
    double defaultBand19WidthValue() const
    {
        return defaultBand19WidthValue_helper();
    }

    /**
      Set band20Width
    */
    void setBand20Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand20Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand20Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand20Width && !isBand20WidthImmutable()) {
        mBand20Width = v;
        Q_EMIT band20WidthChanged();
      }
    }

    Q_PROPERTY(double band20Width READ band20Width WRITE setBand20Width NOTIFY band20WidthChanged)
    Q_PROPERTY(bool isBand20WidthImmutable READ isBand20WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand20WidthValue READ defaultBand20WidthValue CONSTANT)
    /**
      Get band20Width
    */
    double band20Width() const
    {
      return mBand20Width;
    }

    /**
      Is band20Width Immutable
    */
    bool isBand20WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band20Width" ) );
    }

    /**
      Get band20Width default value
    */
    double defaultBand20WidthValue() const
    {
        return defaultBand20WidthValue_helper();
    }

    /**
      Set band21Width
    */
    void setBand21Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand21Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand21Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand21Width && !isBand21WidthImmutable()) {
        mBand21Width = v;
        Q_EMIT band21WidthChanged();
      }
    }

    Q_PROPERTY(double band21Width READ band21Width WRITE setBand21Width NOTIFY band21WidthChanged)
    Q_PROPERTY(bool isBand21WidthImmutable READ isBand21WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand21WidthValue READ defaultBand21WidthValue CONSTANT)
    /**
      Get band21Width
    */
    double band21Width() const
    {
      return mBand21Width;
    }

    /**
      Is band21Width Immutable
    */
    bool isBand21WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band21Width" ) );
    }

    /**
      Get band21Width default value
    */
    double defaultBand21WidthValue() const
    {
        return defaultBand21WidthValue_helper();
    }

    /**
      Set band22Width
    */
    void setBand22Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand22Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand22Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand22Width && !isBand22WidthImmutable()) {
        mBand22Width = v;
        Q_EMIT band22WidthChanged();
      }
    }

    Q_PROPERTY(double band22Width READ band22Width WRITE setBand22Width NOTIFY band22WidthChanged)
    Q_PROPERTY(bool isBand22WidthImmutable READ isBand22WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand22WidthValue READ defaultBand22WidthValue CONSTANT)
    /**
      Get band22Width
    */
    double band22Width() const
    {
      return mBand22Width;
    }

    /**
      Is band22Width Immutable
    */
    bool isBand22WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band22Width" ) );
    }

    /**
      Get band22Width default value
    */
    double defaultBand22WidthValue() const
    {
        return defaultBand22WidthValue_helper();
    }

    /**
      Set band23Width
    */
    void setBand23Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand23Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand23Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand23Width && !isBand23WidthImmutable()) {
        mBand23Width = v;
        Q_EMIT band23WidthChanged();
      }
    }

    Q_PROPERTY(double band23Width READ band23Width WRITE setBand23Width NOTIFY band23WidthChanged)
    Q_PROPERTY(bool isBand23WidthImmutable READ isBand23WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand23WidthValue READ defaultBand23WidthValue CONSTANT)
    /**
      Get band23Width
    */
    double band23Width() const
    {
      return mBand23Width;
    }

    /**
      Is band23Width Immutable
    */
    bool isBand23WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band23Width" ) );
    }

    /**
      Get band23Width default value
    */
    double defaultBand23WidthValue() const
    {
        return defaultBand23WidthValue_helper();
    }

    /**
      Set band24Width
    */
    void setBand24Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand24Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand24Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand24Width && !isBand24WidthImmutable()) {
        mBand24Width = v;
        Q_EMIT band24WidthChanged();
      }
    }

    Q_PROPERTY(double band24Width READ band24Width WRITE setBand24Width NOTIFY band24WidthChanged)
    Q_PROPERTY(bool isBand24WidthImmutable READ isBand24WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand24WidthValue READ defaultBand24WidthValue CONSTANT)
    /**
      Get band24Width
    */
    double band24Width() const
    {
      return mBand24Width;
    }

    /**
      Is band24Width Immutable
    */
    bool isBand24WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band24Width" ) );
    }

    /**
      Get band24Width default value
    */
    double defaultBand24WidthValue() const
    {
        return defaultBand24WidthValue_helper();
    }

    /**
      Set band25Width
    */
    void setBand25Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand25Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand25Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand25Width && !isBand25WidthImmutable()) {
        mBand25Width = v;
        Q_EMIT band25WidthChanged();
      }
    }

    Q_PROPERTY(double band25Width READ band25Width WRITE setBand25Width NOTIFY band25WidthChanged)
    Q_PROPERTY(bool isBand25WidthImmutable READ isBand25WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand25WidthValue READ defaultBand25WidthValue CONSTANT)
    /**
      Get band25Width
    */
    double band25Width() const
    {
      return mBand25Width;
    }

    /**
      Is band25Width Immutable
    */
    bool isBand25WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band25Width" ) );
    }

    /**
      Get band25Width default value
    */
    double defaultBand25WidthValue() const
    {
        return defaultBand25WidthValue_helper();
    }

    /**
      Set band26Width
    */
    void setBand26Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand26Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand26Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand26Width && !isBand26WidthImmutable()) {
        mBand26Width = v;
        Q_EMIT band26WidthChanged();
      }
    }

    Q_PROPERTY(double band26Width READ band26Width WRITE setBand26Width NOTIFY band26WidthChanged)
    Q_PROPERTY(bool isBand26WidthImmutable READ isBand26WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand26WidthValue READ defaultBand26WidthValue CONSTANT)
    /**
      Get band26Width
    */
    double band26Width() const
    {
      return mBand26Width;
    }

    /**
      Is band26Width Immutable
    */
    bool isBand26WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band26Width" ) );
    }

    /**
      Get band26Width default value
    */
    double defaultBand26WidthValue() const
    {
        return defaultBand26WidthValue_helper();
    }

    /**
      Set band27Width
    */
    void setBand27Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand27Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand27Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand27Width && !isBand27WidthImmutable()) {
        mBand27Width = v;
        Q_EMIT band27WidthChanged();
      }
    }

    Q_PROPERTY(double band27Width READ band27Width WRITE setBand27Width NOTIFY band27WidthChanged)
    Q_PROPERTY(bool isBand27WidthImmutable READ isBand27WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand27WidthValue READ defaultBand27WidthValue CONSTANT)
    /**
      Get band27Width
    */
    double band27Width() const
    {
      return mBand27Width;
    }

    /**
      Is band27Width Immutable
    */
    bool isBand27WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band27Width" ) );
    }

    /**
      Get band27Width default value
    */
    double defaultBand27WidthValue() const
    {
        return defaultBand27WidthValue_helper();
    }

    /**
      Set band28Width
    */
    void setBand28Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand28Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand28Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand28Width && !isBand28WidthImmutable()) {
        mBand28Width = v;
        Q_EMIT band28WidthChanged();
      }
    }

    Q_PROPERTY(double band28Width READ band28Width WRITE setBand28Width NOTIFY band28WidthChanged)
    Q_PROPERTY(bool isBand28WidthImmutable READ isBand28WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand28WidthValue READ defaultBand28WidthValue CONSTANT)
    /**
      Get band28Width
    */
    double band28Width() const
    {
      return mBand28Width;
    }

    /**
      Is band28Width Immutable
    */
    bool isBand28WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band28Width" ) );
    }

    /**
      Get band28Width default value
    */
    double defaultBand28WidthValue() const
    {
        return defaultBand28WidthValue_helper();
    }

    /**
      Set band29Width
    */
    void setBand29Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand29Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand29Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand29Width && !isBand29WidthImmutable()) {
        mBand29Width = v;
        Q_EMIT band29WidthChanged();
      }
    }

    Q_PROPERTY(double band29Width READ band29Width WRITE setBand29Width NOTIFY band29WidthChanged)
    Q_PROPERTY(bool isBand29WidthImmutable READ isBand29WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand29WidthValue READ defaultBand29WidthValue CONSTANT)
    /**
      Get band29Width
    */
    double band29Width() const
    {
      return mBand29Width;
    }

    /**
      Is band29Width Immutable
    */
    bool isBand29WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band29Width" ) );
    }

    /**
      Get band29Width default value
    */
    double defaultBand29WidthValue() const
    {
        return defaultBand29WidthValue_helper();
    }

    /**
      Set band30Width
    */
    void setBand30Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand30Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand30Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand30Width && !isBand30WidthImmutable()) {
        mBand30Width = v;
        Q_EMIT band30WidthChanged();
      }
    }

    Q_PROPERTY(double band30Width READ band30Width WRITE setBand30Width NOTIFY band30WidthChanged)
    Q_PROPERTY(bool isBand30WidthImmutable READ isBand30WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand30WidthValue READ defaultBand30WidthValue CONSTANT)
    /**
      Get band30Width
    */
    double band30Width() const
    {
      return mBand30Width;
    }

    /**
      Is band30Width Immutable
    */
    bool isBand30WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band30Width" ) );
    }

    /**
      Get band30Width default value
    */
    double defaultBand30WidthValue() const
    {
        return defaultBand30WidthValue_helper();
    }

    /**
      Set band31Width
    */
    void setBand31Width( double v )
    {
      if (v < 0)
      {
        qDebug() << "setBand31Width: value " << v << " is less than the minimum value of 0";
        v = 0;
      }

      if (v > 12)
      {
        qDebug() << "setBand31Width: value " << v << " is greater than the maximum value of 12";
        v = 12;
      }

      if (v != mBand31Width && !isBand31WidthImmutable()) {
        mBand31Width = v;
        Q_EMIT band31WidthChanged();
      }
    }

    Q_PROPERTY(double band31Width READ band31Width WRITE setBand31Width NOTIFY band31WidthChanged)
    Q_PROPERTY(bool isBand31WidthImmutable READ isBand31WidthImmutable CONSTANT)
    Q_PROPERTY(double defaultBand31WidthValue READ defaultBand31WidthValue CONSTANT)
    /**
      Get band31Width
    */
    double band31Width() const
    {
      return mBand31Width;
    }

    /**
      Is band31Width Immutable
    */
    bool isBand31WidthImmutable() const
    {
      return isImmutable( QStringLiteral( "band31Width" ) );
    }

    /**
      Get band31Width default value
    */
    double defaultBand31WidthValue() const
    {
        return defaultBand31WidthValue_helper();
    }

    /**
      Set band0Type
    */
    void setBand0Type( int v )
    {
      if (v != mBand0Type && !isBand0TypeImmutable()) {
        mBand0Type = v;
        Q_EMIT band0TypeChanged();
      }
    }

    Q_PROPERTY(int band0Type READ band0Type WRITE setBand0Type NOTIFY band0TypeChanged)
    Q_PROPERTY(bool isBand0TypeImmutable READ isBand0TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand0TypeValue READ defaultBand0TypeValue CONSTANT)
    /**
      Get band0Type
    */
    int band0Type() const
    {
      return mBand0Type;
    }

    /**
      Is band0Type Immutable
    */
    bool isBand0TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band0Type" ) );
    }

    /**
      Get band0Type default value
    */
    int defaultBand0TypeValue() const
    {
        return defaultBand0TypeValue_helper();
    }

    /**
      Set band1Type
    */
    void setBand1Type( int v )
    {
      if (v != mBand1Type && !isBand1TypeImmutable()) {
        mBand1Type = v;
        Q_EMIT band1TypeChanged();
      }
    }

    Q_PROPERTY(int band1Type READ band1Type WRITE setBand1Type NOTIFY band1TypeChanged)
    Q_PROPERTY(bool isBand1TypeImmutable READ isBand1TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand1TypeValue READ defaultBand1TypeValue CONSTANT)
    /**
      Get band1Type
    */
    int band1Type() const
    {
      return mBand1Type;
    }

    /**
      Is band1Type Immutable
    */
    bool isBand1TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band1Type" ) );
    }

    /**
      Get band1Type default value
    */
    int defaultBand1TypeValue() const
    {
        return defaultBand1TypeValue_helper();
    }

    /**
      Set band2Type
    */
    void setBand2Type( int v )
    {
      if (v != mBand2Type && !isBand2TypeImmutable()) {
        mBand2Type = v;
        Q_EMIT band2TypeChanged();
      }
    }

    Q_PROPERTY(int band2Type READ band2Type WRITE setBand2Type NOTIFY band2TypeChanged)
    Q_PROPERTY(bool isBand2TypeImmutable READ isBand2TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand2TypeValue READ defaultBand2TypeValue CONSTANT)
    /**
      Get band2Type
    */
    int band2Type() const
    {
      return mBand2Type;
    }

    /**
      Is band2Type Immutable
    */
    bool isBand2TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band2Type" ) );
    }

    /**
      Get band2Type default value
    */
    int defaultBand2TypeValue() const
    {
        return defaultBand2TypeValue_helper();
    }

    /**
      Set band3Type
    */
    void setBand3Type( int v )
    {
      if (v != mBand3Type && !isBand3TypeImmutable()) {
        mBand3Type = v;
        Q_EMIT band3TypeChanged();
      }
    }

    Q_PROPERTY(int band3Type READ band3Type WRITE setBand3Type NOTIFY band3TypeChanged)
    Q_PROPERTY(bool isBand3TypeImmutable READ isBand3TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand3TypeValue READ defaultBand3TypeValue CONSTANT)
    /**
      Get band3Type
    */
    int band3Type() const
    {
      return mBand3Type;
    }

    /**
      Is band3Type Immutable
    */
    bool isBand3TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band3Type" ) );
    }

    /**
      Get band3Type default value
    */
    int defaultBand3TypeValue() const
    {
        return defaultBand3TypeValue_helper();
    }

    /**
      Set band4Type
    */
    void setBand4Type( int v )
    {
      if (v != mBand4Type && !isBand4TypeImmutable()) {
        mBand4Type = v;
        Q_EMIT band4TypeChanged();
      }
    }

    Q_PROPERTY(int band4Type READ band4Type WRITE setBand4Type NOTIFY band4TypeChanged)
    Q_PROPERTY(bool isBand4TypeImmutable READ isBand4TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand4TypeValue READ defaultBand4TypeValue CONSTANT)
    /**
      Get band4Type
    */
    int band4Type() const
    {
      return mBand4Type;
    }

    /**
      Is band4Type Immutable
    */
    bool isBand4TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band4Type" ) );
    }

    /**
      Get band4Type default value
    */
    int defaultBand4TypeValue() const
    {
        return defaultBand4TypeValue_helper();
    }

    /**
      Set band5Type
    */
    void setBand5Type( int v )
    {
      if (v != mBand5Type && !isBand5TypeImmutable()) {
        mBand5Type = v;
        Q_EMIT band5TypeChanged();
      }
    }

    Q_PROPERTY(int band5Type READ band5Type WRITE setBand5Type NOTIFY band5TypeChanged)
    Q_PROPERTY(bool isBand5TypeImmutable READ isBand5TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand5TypeValue READ defaultBand5TypeValue CONSTANT)
    /**
      Get band5Type
    */
    int band5Type() const
    {
      return mBand5Type;
    }

    /**
      Is band5Type Immutable
    */
    bool isBand5TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band5Type" ) );
    }

    /**
      Get band5Type default value
    */
    int defaultBand5TypeValue() const
    {
        return defaultBand5TypeValue_helper();
    }

    /**
      Set band6Type
    */
    void setBand6Type( int v )
    {
      if (v != mBand6Type && !isBand6TypeImmutable()) {
        mBand6Type = v;
        Q_EMIT band6TypeChanged();
      }
    }

    Q_PROPERTY(int band6Type READ band6Type WRITE setBand6Type NOTIFY band6TypeChanged)
    Q_PROPERTY(bool isBand6TypeImmutable READ isBand6TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand6TypeValue READ defaultBand6TypeValue CONSTANT)
    /**
      Get band6Type
    */
    int band6Type() const
    {
      return mBand6Type;
    }

    /**
      Is band6Type Immutable
    */
    bool isBand6TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band6Type" ) );
    }

    /**
      Get band6Type default value
    */
    int defaultBand6TypeValue() const
    {
        return defaultBand6TypeValue_helper();
    }

    /**
      Set band7Type
    */
    void setBand7Type( int v )
    {
      if (v != mBand7Type && !isBand7TypeImmutable()) {
        mBand7Type = v;
        Q_EMIT band7TypeChanged();
      }
    }

    Q_PROPERTY(int band7Type READ band7Type WRITE setBand7Type NOTIFY band7TypeChanged)
    Q_PROPERTY(bool isBand7TypeImmutable READ isBand7TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand7TypeValue READ defaultBand7TypeValue CONSTANT)
    /**
      Get band7Type
    */
    int band7Type() const
    {
      return mBand7Type;
    }

    /**
      Is band7Type Immutable
    */
    bool isBand7TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band7Type" ) );
    }

    /**
      Get band7Type default value
    */
    int defaultBand7TypeValue() const
    {
        return defaultBand7TypeValue_helper();
    }

    /**
      Set band8Type
    */
    void setBand8Type( int v )
    {
      if (v != mBand8Type && !isBand8TypeImmutable()) {
        mBand8Type = v;
        Q_EMIT band8TypeChanged();
      }
    }

    Q_PROPERTY(int band8Type READ band8Type WRITE setBand8Type NOTIFY band8TypeChanged)
    Q_PROPERTY(bool isBand8TypeImmutable READ isBand8TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand8TypeValue READ defaultBand8TypeValue CONSTANT)
    /**
      Get band8Type
    */
    int band8Type() const
    {
      return mBand8Type;
    }

    /**
      Is band8Type Immutable
    */
    bool isBand8TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band8Type" ) );
    }

    /**
      Get band8Type default value
    */
    int defaultBand8TypeValue() const
    {
        return defaultBand8TypeValue_helper();
    }

    /**
      Set band9Type
    */
    void setBand9Type( int v )
    {
      if (v != mBand9Type && !isBand9TypeImmutable()) {
        mBand9Type = v;
        Q_EMIT band9TypeChanged();
      }
    }

    Q_PROPERTY(int band9Type READ band9Type WRITE setBand9Type NOTIFY band9TypeChanged)
    Q_PROPERTY(bool isBand9TypeImmutable READ isBand9TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand9TypeValue READ defaultBand9TypeValue CONSTANT)
    /**
      Get band9Type
    */
    int band9Type() const
    {
      return mBand9Type;
    }

    /**
      Is band9Type Immutable
    */
    bool isBand9TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band9Type" ) );
    }

    /**
      Get band9Type default value
    */
    int defaultBand9TypeValue() const
    {
        return defaultBand9TypeValue_helper();
    }

    /**
      Set band10Type
    */
    void setBand10Type( int v )
    {
      if (v != mBand10Type && !isBand10TypeImmutable()) {
        mBand10Type = v;
        Q_EMIT band10TypeChanged();
      }
    }

    Q_PROPERTY(int band10Type READ band10Type WRITE setBand10Type NOTIFY band10TypeChanged)
    Q_PROPERTY(bool isBand10TypeImmutable READ isBand10TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand10TypeValue READ defaultBand10TypeValue CONSTANT)
    /**
      Get band10Type
    */
    int band10Type() const
    {
      return mBand10Type;
    }

    /**
      Is band10Type Immutable
    */
    bool isBand10TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band10Type" ) );
    }

    /**
      Get band10Type default value
    */
    int defaultBand10TypeValue() const
    {
        return defaultBand10TypeValue_helper();
    }

    /**
      Set band11Type
    */
    void setBand11Type( int v )
    {
      if (v != mBand11Type && !isBand11TypeImmutable()) {
        mBand11Type = v;
        Q_EMIT band11TypeChanged();
      }
    }

    Q_PROPERTY(int band11Type READ band11Type WRITE setBand11Type NOTIFY band11TypeChanged)
    Q_PROPERTY(bool isBand11TypeImmutable READ isBand11TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand11TypeValue READ defaultBand11TypeValue CONSTANT)
    /**
      Get band11Type
    */
    int band11Type() const
    {
      return mBand11Type;
    }

    /**
      Is band11Type Immutable
    */
    bool isBand11TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band11Type" ) );
    }

    /**
      Get band11Type default value
    */
    int defaultBand11TypeValue() const
    {
        return defaultBand11TypeValue_helper();
    }

    /**
      Set band12Type
    */
    void setBand12Type( int v )
    {
      if (v != mBand12Type && !isBand12TypeImmutable()) {
        mBand12Type = v;
        Q_EMIT band12TypeChanged();
      }
    }

    Q_PROPERTY(int band12Type READ band12Type WRITE setBand12Type NOTIFY band12TypeChanged)
    Q_PROPERTY(bool isBand12TypeImmutable READ isBand12TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand12TypeValue READ defaultBand12TypeValue CONSTANT)
    /**
      Get band12Type
    */
    int band12Type() const
    {
      return mBand12Type;
    }

    /**
      Is band12Type Immutable
    */
    bool isBand12TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band12Type" ) );
    }

    /**
      Get band12Type default value
    */
    int defaultBand12TypeValue() const
    {
        return defaultBand12TypeValue_helper();
    }

    /**
      Set band13Type
    */
    void setBand13Type( int v )
    {
      if (v != mBand13Type && !isBand13TypeImmutable()) {
        mBand13Type = v;
        Q_EMIT band13TypeChanged();
      }
    }

    Q_PROPERTY(int band13Type READ band13Type WRITE setBand13Type NOTIFY band13TypeChanged)
    Q_PROPERTY(bool isBand13TypeImmutable READ isBand13TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand13TypeValue READ defaultBand13TypeValue CONSTANT)
    /**
      Get band13Type
    */
    int band13Type() const
    {
      return mBand13Type;
    }

    /**
      Is band13Type Immutable
    */
    bool isBand13TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band13Type" ) );
    }

    /**
      Get band13Type default value
    */
    int defaultBand13TypeValue() const
    {
        return defaultBand13TypeValue_helper();
    }

    /**
      Set band14Type
    */
    void setBand14Type( int v )
    {
      if (v != mBand14Type && !isBand14TypeImmutable()) {
        mBand14Type = v;
        Q_EMIT band14TypeChanged();
      }
    }

    Q_PROPERTY(int band14Type READ band14Type WRITE setBand14Type NOTIFY band14TypeChanged)
    Q_PROPERTY(bool isBand14TypeImmutable READ isBand14TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand14TypeValue READ defaultBand14TypeValue CONSTANT)
    /**
      Get band14Type
    */
    int band14Type() const
    {
      return mBand14Type;
    }

    /**
      Is band14Type Immutable
    */
    bool isBand14TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band14Type" ) );
    }

    /**
      Get band14Type default value
    */
    int defaultBand14TypeValue() const
    {
        return defaultBand14TypeValue_helper();
    }

    /**
      Set band15Type
    */
    void setBand15Type( int v )
    {
      if (v != mBand15Type && !isBand15TypeImmutable()) {
        mBand15Type = v;
        Q_EMIT band15TypeChanged();
      }
    }

    Q_PROPERTY(int band15Type READ band15Type WRITE setBand15Type NOTIFY band15TypeChanged)
    Q_PROPERTY(bool isBand15TypeImmutable READ isBand15TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand15TypeValue READ defaultBand15TypeValue CONSTANT)
    /**
      Get band15Type
    */
    int band15Type() const
    {
      return mBand15Type;
    }

    /**
      Is band15Type Immutable
    */
    bool isBand15TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band15Type" ) );
    }

    /**
      Get band15Type default value
    */
    int defaultBand15TypeValue() const
    {
        return defaultBand15TypeValue_helper();
    }

    /**
      Set band16Type
    */
    void setBand16Type( int v )
    {
      if (v != mBand16Type && !isBand16TypeImmutable()) {
        mBand16Type = v;
        Q_EMIT band16TypeChanged();
      }
    }

    Q_PROPERTY(int band16Type READ band16Type WRITE setBand16Type NOTIFY band16TypeChanged)
    Q_PROPERTY(bool isBand16TypeImmutable READ isBand16TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand16TypeValue READ defaultBand16TypeValue CONSTANT)
    /**
      Get band16Type
    */
    int band16Type() const
    {
      return mBand16Type;
    }

    /**
      Is band16Type Immutable
    */
    bool isBand16TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band16Type" ) );
    }

    /**
      Get band16Type default value
    */
    int defaultBand16TypeValue() const
    {
        return defaultBand16TypeValue_helper();
    }

    /**
      Set band17Type
    */
    void setBand17Type( int v )
    {
      if (v != mBand17Type && !isBand17TypeImmutable()) {
        mBand17Type = v;
        Q_EMIT band17TypeChanged();
      }
    }

    Q_PROPERTY(int band17Type READ band17Type WRITE setBand17Type NOTIFY band17TypeChanged)
    Q_PROPERTY(bool isBand17TypeImmutable READ isBand17TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand17TypeValue READ defaultBand17TypeValue CONSTANT)
    /**
      Get band17Type
    */
    int band17Type() const
    {
      return mBand17Type;
    }

    /**
      Is band17Type Immutable
    */
    bool isBand17TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band17Type" ) );
    }

    /**
      Get band17Type default value
    */
    int defaultBand17TypeValue() const
    {
        return defaultBand17TypeValue_helper();
    }

    /**
      Set band18Type
    */
    void setBand18Type( int v )
    {
      if (v != mBand18Type && !isBand18TypeImmutable()) {
        mBand18Type = v;
        Q_EMIT band18TypeChanged();
      }
    }

    Q_PROPERTY(int band18Type READ band18Type WRITE setBand18Type NOTIFY band18TypeChanged)
    Q_PROPERTY(bool isBand18TypeImmutable READ isBand18TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand18TypeValue READ defaultBand18TypeValue CONSTANT)
    /**
      Get band18Type
    */
    int band18Type() const
    {
      return mBand18Type;
    }

    /**
      Is band18Type Immutable
    */
    bool isBand18TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band18Type" ) );
    }

    /**
      Get band18Type default value
    */
    int defaultBand18TypeValue() const
    {
        return defaultBand18TypeValue_helper();
    }

    /**
      Set band19Type
    */
    void setBand19Type( int v )
    {
      if (v != mBand19Type && !isBand19TypeImmutable()) {
        mBand19Type = v;
        Q_EMIT band19TypeChanged();
      }
    }

    Q_PROPERTY(int band19Type READ band19Type WRITE setBand19Type NOTIFY band19TypeChanged)
    Q_PROPERTY(bool isBand19TypeImmutable READ isBand19TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand19TypeValue READ defaultBand19TypeValue CONSTANT)
    /**
      Get band19Type
    */
    int band19Type() const
    {
      return mBand19Type;
    }

    /**
      Is band19Type Immutable
    */
    bool isBand19TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band19Type" ) );
    }

    /**
      Get band19Type default value
    */
    int defaultBand19TypeValue() const
    {
        return defaultBand19TypeValue_helper();
    }

    /**
      Set band20Type
    */
    void setBand20Type( int v )
    {
      if (v != mBand20Type && !isBand20TypeImmutable()) {
        mBand20Type = v;
        Q_EMIT band20TypeChanged();
      }
    }

    Q_PROPERTY(int band20Type READ band20Type WRITE setBand20Type NOTIFY band20TypeChanged)
    Q_PROPERTY(bool isBand20TypeImmutable READ isBand20TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand20TypeValue READ defaultBand20TypeValue CONSTANT)
    /**
      Get band20Type
    */
    int band20Type() const
    {
      return mBand20Type;
    }

    /**
      Is band20Type Immutable
    */
    bool isBand20TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band20Type" ) );
    }

    /**
      Get band20Type default value
    */
    int defaultBand20TypeValue() const
    {
        return defaultBand20TypeValue_helper();
    }

    /**
      Set band21Type
    */
    void setBand21Type( int v )
    {
      if (v != mBand21Type && !isBand21TypeImmutable()) {
        mBand21Type = v;
        Q_EMIT band21TypeChanged();
      }
    }

    Q_PROPERTY(int band21Type READ band21Type WRITE setBand21Type NOTIFY band21TypeChanged)
    Q_PROPERTY(bool isBand21TypeImmutable READ isBand21TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand21TypeValue READ defaultBand21TypeValue CONSTANT)
    /**
      Get band21Type
    */
    int band21Type() const
    {
      return mBand21Type;
    }

    /**
      Is band21Type Immutable
    */
    bool isBand21TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band21Type" ) );
    }

    /**
      Get band21Type default value
    */
    int defaultBand21TypeValue() const
    {
        return defaultBand21TypeValue_helper();
    }

    /**
      Set band22Type
    */
    void setBand22Type( int v )
    {
      if (v != mBand22Type && !isBand22TypeImmutable()) {
        mBand22Type = v;
        Q_EMIT band22TypeChanged();
      }
    }

    Q_PROPERTY(int band22Type READ band22Type WRITE setBand22Type NOTIFY band22TypeChanged)
    Q_PROPERTY(bool isBand22TypeImmutable READ isBand22TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand22TypeValue READ defaultBand22TypeValue CONSTANT)
    /**
      Get band22Type
    */
    int band22Type() const
    {
      return mBand22Type;
    }

    /**
      Is band22Type Immutable
    */
    bool isBand22TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band22Type" ) );
    }

    /**
      Get band22Type default value
    */
    int defaultBand22TypeValue() const
    {
        return defaultBand22TypeValue_helper();
    }

    /**
      Set band23Type
    */
    void setBand23Type( int v )
    {
      if (v != mBand23Type && !isBand23TypeImmutable()) {
        mBand23Type = v;
        Q_EMIT band23TypeChanged();
      }
    }

    Q_PROPERTY(int band23Type READ band23Type WRITE setBand23Type NOTIFY band23TypeChanged)
    Q_PROPERTY(bool isBand23TypeImmutable READ isBand23TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand23TypeValue READ defaultBand23TypeValue CONSTANT)
    /**
      Get band23Type
    */
    int band23Type() const
    {
      return mBand23Type;
    }

    /**
      Is band23Type Immutable
    */
    bool isBand23TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band23Type" ) );
    }

    /**
      Get band23Type default value
    */
    int defaultBand23TypeValue() const
    {
        return defaultBand23TypeValue_helper();
    }

    /**
      Set band24Type
    */
    void setBand24Type( int v )
    {
      if (v != mBand24Type && !isBand24TypeImmutable()) {
        mBand24Type = v;
        Q_EMIT band24TypeChanged();
      }
    }

    Q_PROPERTY(int band24Type READ band24Type WRITE setBand24Type NOTIFY band24TypeChanged)
    Q_PROPERTY(bool isBand24TypeImmutable READ isBand24TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand24TypeValue READ defaultBand24TypeValue CONSTANT)
    /**
      Get band24Type
    */
    int band24Type() const
    {
      return mBand24Type;
    }

    /**
      Is band24Type Immutable
    */
    bool isBand24TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band24Type" ) );
    }

    /**
      Get band24Type default value
    */
    int defaultBand24TypeValue() const
    {
        return defaultBand24TypeValue_helper();
    }

    /**
      Set band25Type
    */
    void setBand25Type( int v )
    {
      if (v != mBand25Type && !isBand25TypeImmutable()) {
        mBand25Type = v;
        Q_EMIT band25TypeChanged();
      }
    }

    Q_PROPERTY(int band25Type READ band25Type WRITE setBand25Type NOTIFY band25TypeChanged)
    Q_PROPERTY(bool isBand25TypeImmutable READ isBand25TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand25TypeValue READ defaultBand25TypeValue CONSTANT)
    /**
      Get band25Type
    */
    int band25Type() const
    {
      return mBand25Type;
    }

    /**
      Is band25Type Immutable
    */
    bool isBand25TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band25Type" ) );
    }

    /**
      Get band25Type default value
    */
    int defaultBand25TypeValue() const
    {
        return defaultBand25TypeValue_helper();
    }

    /**
      Set band26Type
    */
    void setBand26Type( int v )
    {
      if (v != mBand26Type && !isBand26TypeImmutable()) {
        mBand26Type = v;
        Q_EMIT band26TypeChanged();
      }
    }

    Q_PROPERTY(int band26Type READ band26Type WRITE setBand26Type NOTIFY band26TypeChanged)
    Q_PROPERTY(bool isBand26TypeImmutable READ isBand26TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand26TypeValue READ defaultBand26TypeValue CONSTANT)
    /**
      Get band26Type
    */
    int band26Type() const
    {
      return mBand26Type;
    }

    /**
      Is band26Type Immutable
    */
    bool isBand26TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band26Type" ) );
    }

    /**
      Get band26Type default value
    */
    int defaultBand26TypeValue() const
    {
        return defaultBand26TypeValue_helper();
    }

    /**
      Set band27Type
    */
    void setBand27Type( int v )
    {
      if (v != mBand27Type && !isBand27TypeImmutable()) {
        mBand27Type = v;
        Q_EMIT band27TypeChanged();
      }
    }

    Q_PROPERTY(int band27Type READ band27Type WRITE setBand27Type NOTIFY band27TypeChanged)
    Q_PROPERTY(bool isBand27TypeImmutable READ isBand27TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand27TypeValue READ defaultBand27TypeValue CONSTANT)
    /**
      Get band27Type
    */
    int band27Type() const
    {
      return mBand27Type;
    }

    /**
      Is band27Type Immutable
    */
    bool isBand27TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band27Type" ) );
    }

    /**
      Get band27Type default value
    */
    int defaultBand27TypeValue() const
    {
        return defaultBand27TypeValue_helper();
    }

    /**
      Set band28Type
    */
    void setBand28Type( int v )
    {
      if (v != mBand28Type && !isBand28TypeImmutable()) {
        mBand28Type = v;
        Q_EMIT band28TypeChanged();
      }
    }

    Q_PROPERTY(int band28Type READ band28Type WRITE setBand28Type NOTIFY band28TypeChanged)
    Q_PROPERTY(bool isBand28TypeImmutable READ isBand28TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand28TypeValue READ defaultBand28TypeValue CONSTANT)
    /**
      Get band28Type
    */
    int band28Type() const
    {
      return mBand28Type;
    }

    /**
      Is band28Type Immutable
    */
    bool isBand28TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band28Type" ) );
    }

    /**
      Get band28Type default value
    */
    int defaultBand28TypeValue() const
    {
        return defaultBand28TypeValue_helper();
    }

    /**
      Set band29Type
    */
    void setBand29Type( int v )
    {
      if (v != mBand29Type && !isBand29TypeImmutable()) {
        mBand29Type = v;
        Q_EMIT band29TypeChanged();
      }
    }

    Q_PROPERTY(int band29Type READ band29Type WRITE setBand29Type NOTIFY band29TypeChanged)
    Q_PROPERTY(bool isBand29TypeImmutable READ isBand29TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand29TypeValue READ defaultBand29TypeValue CONSTANT)
    /**
      Get band29Type
    */
    int band29Type() const
    {
      return mBand29Type;
    }

    /**
      Is band29Type Immutable
    */
    bool isBand29TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band29Type" ) );
    }

    /**
      Get band29Type default value
    */
    int defaultBand29TypeValue() const
    {
        return defaultBand29TypeValue_helper();
    }

    /**
      Set band30Type
    */
    void setBand30Type( int v )
    {
      if (v != mBand30Type && !isBand30TypeImmutable()) {
        mBand30Type = v;
        Q_EMIT band30TypeChanged();
      }
    }

    Q_PROPERTY(int band30Type READ band30Type WRITE setBand30Type NOTIFY band30TypeChanged)
    Q_PROPERTY(bool isBand30TypeImmutable READ isBand30TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand30TypeValue READ defaultBand30TypeValue CONSTANT)
    /**
      Get band30Type
    */
    int band30Type() const
    {
      return mBand30Type;
    }

    /**
      Is band30Type Immutable
    */
    bool isBand30TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band30Type" ) );
    }

    /**
      Get band30Type default value
    */
    int defaultBand30TypeValue() const
    {
        return defaultBand30TypeValue_helper();
    }

    /**
      Set band31Type
    */
    void setBand31Type( int v )
    {
      if (v != mBand31Type && !isBand31TypeImmutable()) {
        mBand31Type = v;
        Q_EMIT band31TypeChanged();
      }
    }

    Q_PROPERTY(int band31Type READ band31Type WRITE setBand31Type NOTIFY band31TypeChanged)
    Q_PROPERTY(bool isBand31TypeImmutable READ isBand31TypeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand31TypeValue READ defaultBand31TypeValue CONSTANT)
    /**
      Get band31Type
    */
    int band31Type() const
    {
      return mBand31Type;
    }

    /**
      Is band31Type Immutable
    */
    bool isBand31TypeImmutable() const
    {
      return isImmutable( QStringLiteral( "band31Type" ) );
    }

    /**
      Get band31Type default value
    */
    int defaultBand31TypeValue() const
    {
        return defaultBand31TypeValue_helper();
    }

    /**
      Set band0Mode
    */
    void setBand0Mode( int v )
    {
      if (v != mBand0Mode && !isBand0ModeImmutable()) {
        mBand0Mode = v;
        Q_EMIT band0ModeChanged();
      }
    }

    Q_PROPERTY(int band0Mode READ band0Mode WRITE setBand0Mode NOTIFY band0ModeChanged)
    Q_PROPERTY(bool isBand0ModeImmutable READ isBand0ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand0ModeValue READ defaultBand0ModeValue CONSTANT)
    /**
      Get band0Mode
    */
    int band0Mode() const
    {
      return mBand0Mode;
    }

    /**
      Is band0Mode Immutable
    */
    bool isBand0ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band0Mode" ) );
    }

    /**
      Get band0Mode default value
    */
    int defaultBand0ModeValue() const
    {
        return defaultBand0ModeValue_helper();
    }

    /**
      Set band1Mode
    */
    void setBand1Mode( int v )
    {
      if (v != mBand1Mode && !isBand1ModeImmutable()) {
        mBand1Mode = v;
        Q_EMIT band1ModeChanged();
      }
    }

    Q_PROPERTY(int band1Mode READ band1Mode WRITE setBand1Mode NOTIFY band1ModeChanged)
    Q_PROPERTY(bool isBand1ModeImmutable READ isBand1ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand1ModeValue READ defaultBand1ModeValue CONSTANT)
    /**
      Get band1Mode
    */
    int band1Mode() const
    {
      return mBand1Mode;
    }

    /**
      Is band1Mode Immutable
    */
    bool isBand1ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band1Mode" ) );
    }

    /**
      Get band1Mode default value
    */
    int defaultBand1ModeValue() const
    {
        return defaultBand1ModeValue_helper();
    }

    /**
      Set band2Mode
    */
    void setBand2Mode( int v )
    {
      if (v != mBand2Mode && !isBand2ModeImmutable()) {
        mBand2Mode = v;
        Q_EMIT band2ModeChanged();
      }
    }

    Q_PROPERTY(int band2Mode READ band2Mode WRITE setBand2Mode NOTIFY band2ModeChanged)
    Q_PROPERTY(bool isBand2ModeImmutable READ isBand2ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand2ModeValue READ defaultBand2ModeValue CONSTANT)
    /**
      Get band2Mode
    */
    int band2Mode() const
    {
      return mBand2Mode;
    }

    /**
      Is band2Mode Immutable
    */
    bool isBand2ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band2Mode" ) );
    }

    /**
      Get band2Mode default value
    */
    int defaultBand2ModeValue() const
    {
        return defaultBand2ModeValue_helper();
    }

    /**
      Set band3Mode
    */
    void setBand3Mode( int v )
    {
      if (v != mBand3Mode && !isBand3ModeImmutable()) {
        mBand3Mode = v;
        Q_EMIT band3ModeChanged();
      }
    }

    Q_PROPERTY(int band3Mode READ band3Mode WRITE setBand3Mode NOTIFY band3ModeChanged)
    Q_PROPERTY(bool isBand3ModeImmutable READ isBand3ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand3ModeValue READ defaultBand3ModeValue CONSTANT)
    /**
      Get band3Mode
    */
    int band3Mode() const
    {
      return mBand3Mode;
    }

    /**
      Is band3Mode Immutable
    */
    bool isBand3ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band3Mode" ) );
    }

    /**
      Get band3Mode default value
    */
    int defaultBand3ModeValue() const
    {
        return defaultBand3ModeValue_helper();
    }

    /**
      Set band4Mode
    */
    void setBand4Mode( int v )
    {
      if (v != mBand4Mode && !isBand4ModeImmutable()) {
        mBand4Mode = v;
        Q_EMIT band4ModeChanged();
      }
    }

    Q_PROPERTY(int band4Mode READ band4Mode WRITE setBand4Mode NOTIFY band4ModeChanged)
    Q_PROPERTY(bool isBand4ModeImmutable READ isBand4ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand4ModeValue READ defaultBand4ModeValue CONSTANT)
    /**
      Get band4Mode
    */
    int band4Mode() const
    {
      return mBand4Mode;
    }

    /**
      Is band4Mode Immutable
    */
    bool isBand4ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band4Mode" ) );
    }

    /**
      Get band4Mode default value
    */
    int defaultBand4ModeValue() const
    {
        return defaultBand4ModeValue_helper();
    }

    /**
      Set band5Mode
    */
    void setBand5Mode( int v )
    {
      if (v != mBand5Mode && !isBand5ModeImmutable()) {
        mBand5Mode = v;
        Q_EMIT band5ModeChanged();
      }
    }

    Q_PROPERTY(int band5Mode READ band5Mode WRITE setBand5Mode NOTIFY band5ModeChanged)
    Q_PROPERTY(bool isBand5ModeImmutable READ isBand5ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand5ModeValue READ defaultBand5ModeValue CONSTANT)
    /**
      Get band5Mode
    */
    int band5Mode() const
    {
      return mBand5Mode;
    }

    /**
      Is band5Mode Immutable
    */
    bool isBand5ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band5Mode" ) );
    }

    /**
      Get band5Mode default value
    */
    int defaultBand5ModeValue() const
    {
        return defaultBand5ModeValue_helper();
    }

    /**
      Set band6Mode
    */
    void setBand6Mode( int v )
    {
      if (v != mBand6Mode && !isBand6ModeImmutable()) {
        mBand6Mode = v;
        Q_EMIT band6ModeChanged();
      }
    }

    Q_PROPERTY(int band6Mode READ band6Mode WRITE setBand6Mode NOTIFY band6ModeChanged)
    Q_PROPERTY(bool isBand6ModeImmutable READ isBand6ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand6ModeValue READ defaultBand6ModeValue CONSTANT)
    /**
      Get band6Mode
    */
    int band6Mode() const
    {
      return mBand6Mode;
    }

    /**
      Is band6Mode Immutable
    */
    bool isBand6ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band6Mode" ) );
    }

    /**
      Get band6Mode default value
    */
    int defaultBand6ModeValue() const
    {
        return defaultBand6ModeValue_helper();
    }

    /**
      Set band7Mode
    */
    void setBand7Mode( int v )
    {
      if (v != mBand7Mode && !isBand7ModeImmutable()) {
        mBand7Mode = v;
        Q_EMIT band7ModeChanged();
      }
    }

    Q_PROPERTY(int band7Mode READ band7Mode WRITE setBand7Mode NOTIFY band7ModeChanged)
    Q_PROPERTY(bool isBand7ModeImmutable READ isBand7ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand7ModeValue READ defaultBand7ModeValue CONSTANT)
    /**
      Get band7Mode
    */
    int band7Mode() const
    {
      return mBand7Mode;
    }

    /**
      Is band7Mode Immutable
    */
    bool isBand7ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band7Mode" ) );
    }

    /**
      Get band7Mode default value
    */
    int defaultBand7ModeValue() const
    {
        return defaultBand7ModeValue_helper();
    }

    /**
      Set band8Mode
    */
    void setBand8Mode( int v )
    {
      if (v != mBand8Mode && !isBand8ModeImmutable()) {
        mBand8Mode = v;
        Q_EMIT band8ModeChanged();
      }
    }

    Q_PROPERTY(int band8Mode READ band8Mode WRITE setBand8Mode NOTIFY band8ModeChanged)
    Q_PROPERTY(bool isBand8ModeImmutable READ isBand8ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand8ModeValue READ defaultBand8ModeValue CONSTANT)
    /**
      Get band8Mode
    */
    int band8Mode() const
    {
      return mBand8Mode;
    }

    /**
      Is band8Mode Immutable
    */
    bool isBand8ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band8Mode" ) );
    }

    /**
      Get band8Mode default value
    */
    int defaultBand8ModeValue() const
    {
        return defaultBand8ModeValue_helper();
    }

    /**
      Set band9Mode
    */
    void setBand9Mode( int v )
    {
      if (v != mBand9Mode && !isBand9ModeImmutable()) {
        mBand9Mode = v;
        Q_EMIT band9ModeChanged();
      }
    }

    Q_PROPERTY(int band9Mode READ band9Mode WRITE setBand9Mode NOTIFY band9ModeChanged)
    Q_PROPERTY(bool isBand9ModeImmutable READ isBand9ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand9ModeValue READ defaultBand9ModeValue CONSTANT)
    /**
      Get band9Mode
    */
    int band9Mode() const
    {
      return mBand9Mode;
    }

    /**
      Is band9Mode Immutable
    */
    bool isBand9ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band9Mode" ) );
    }

    /**
      Get band9Mode default value
    */
    int defaultBand9ModeValue() const
    {
        return defaultBand9ModeValue_helper();
    }

    /**
      Set band10Mode
    */
    void setBand10Mode( int v )
    {
      if (v != mBand10Mode && !isBand10ModeImmutable()) {
        mBand10Mode = v;
        Q_EMIT band10ModeChanged();
      }
    }

    Q_PROPERTY(int band10Mode READ band10Mode WRITE setBand10Mode NOTIFY band10ModeChanged)
    Q_PROPERTY(bool isBand10ModeImmutable READ isBand10ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand10ModeValue READ defaultBand10ModeValue CONSTANT)
    /**
      Get band10Mode
    */
    int band10Mode() const
    {
      return mBand10Mode;
    }

    /**
      Is band10Mode Immutable
    */
    bool isBand10ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band10Mode" ) );
    }

    /**
      Get band10Mode default value
    */
    int defaultBand10ModeValue() const
    {
        return defaultBand10ModeValue_helper();
    }

    /**
      Set band11Mode
    */
    void setBand11Mode( int v )
    {
      if (v != mBand11Mode && !isBand11ModeImmutable()) {
        mBand11Mode = v;
        Q_EMIT band11ModeChanged();
      }
    }

    Q_PROPERTY(int band11Mode READ band11Mode WRITE setBand11Mode NOTIFY band11ModeChanged)
    Q_PROPERTY(bool isBand11ModeImmutable READ isBand11ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand11ModeValue READ defaultBand11ModeValue CONSTANT)
    /**
      Get band11Mode
    */
    int band11Mode() const
    {
      return mBand11Mode;
    }

    /**
      Is band11Mode Immutable
    */
    bool isBand11ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band11Mode" ) );
    }

    /**
      Get band11Mode default value
    */
    int defaultBand11ModeValue() const
    {
        return defaultBand11ModeValue_helper();
    }

    /**
      Set band12Mode
    */
    void setBand12Mode( int v )
    {
      if (v != mBand12Mode && !isBand12ModeImmutable()) {
        mBand12Mode = v;
        Q_EMIT band12ModeChanged();
      }
    }

    Q_PROPERTY(int band12Mode READ band12Mode WRITE setBand12Mode NOTIFY band12ModeChanged)
    Q_PROPERTY(bool isBand12ModeImmutable READ isBand12ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand12ModeValue READ defaultBand12ModeValue CONSTANT)
    /**
      Get band12Mode
    */
    int band12Mode() const
    {
      return mBand12Mode;
    }

    /**
      Is band12Mode Immutable
    */
    bool isBand12ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band12Mode" ) );
    }

    /**
      Get band12Mode default value
    */
    int defaultBand12ModeValue() const
    {
        return defaultBand12ModeValue_helper();
    }

    /**
      Set band13Mode
    */
    void setBand13Mode( int v )
    {
      if (v != mBand13Mode && !isBand13ModeImmutable()) {
        mBand13Mode = v;
        Q_EMIT band13ModeChanged();
      }
    }

    Q_PROPERTY(int band13Mode READ band13Mode WRITE setBand13Mode NOTIFY band13ModeChanged)
    Q_PROPERTY(bool isBand13ModeImmutable READ isBand13ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand13ModeValue READ defaultBand13ModeValue CONSTANT)
    /**
      Get band13Mode
    */
    int band13Mode() const
    {
      return mBand13Mode;
    }

    /**
      Is band13Mode Immutable
    */
    bool isBand13ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band13Mode" ) );
    }

    /**
      Get band13Mode default value
    */
    int defaultBand13ModeValue() const
    {
        return defaultBand13ModeValue_helper();
    }

    /**
      Set band14Mode
    */
    void setBand14Mode( int v )
    {
      if (v != mBand14Mode && !isBand14ModeImmutable()) {
        mBand14Mode = v;
        Q_EMIT band14ModeChanged();
      }
    }

    Q_PROPERTY(int band14Mode READ band14Mode WRITE setBand14Mode NOTIFY band14ModeChanged)
    Q_PROPERTY(bool isBand14ModeImmutable READ isBand14ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand14ModeValue READ defaultBand14ModeValue CONSTANT)
    /**
      Get band14Mode
    */
    int band14Mode() const
    {
      return mBand14Mode;
    }

    /**
      Is band14Mode Immutable
    */
    bool isBand14ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band14Mode" ) );
    }

    /**
      Get band14Mode default value
    */
    int defaultBand14ModeValue() const
    {
        return defaultBand14ModeValue_helper();
    }

    /**
      Set band15Mode
    */
    void setBand15Mode( int v )
    {
      if (v != mBand15Mode && !isBand15ModeImmutable()) {
        mBand15Mode = v;
        Q_EMIT band15ModeChanged();
      }
    }

    Q_PROPERTY(int band15Mode READ band15Mode WRITE setBand15Mode NOTIFY band15ModeChanged)
    Q_PROPERTY(bool isBand15ModeImmutable READ isBand15ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand15ModeValue READ defaultBand15ModeValue CONSTANT)
    /**
      Get band15Mode
    */
    int band15Mode() const
    {
      return mBand15Mode;
    }

    /**
      Is band15Mode Immutable
    */
    bool isBand15ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band15Mode" ) );
    }

    /**
      Get band15Mode default value
    */
    int defaultBand15ModeValue() const
    {
        return defaultBand15ModeValue_helper();
    }

    /**
      Set band16Mode
    */
    void setBand16Mode( int v )
    {
      if (v != mBand16Mode && !isBand16ModeImmutable()) {
        mBand16Mode = v;
        Q_EMIT band16ModeChanged();
      }
    }

    Q_PROPERTY(int band16Mode READ band16Mode WRITE setBand16Mode NOTIFY band16ModeChanged)
    Q_PROPERTY(bool isBand16ModeImmutable READ isBand16ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand16ModeValue READ defaultBand16ModeValue CONSTANT)
    /**
      Get band16Mode
    */
    int band16Mode() const
    {
      return mBand16Mode;
    }

    /**
      Is band16Mode Immutable
    */
    bool isBand16ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band16Mode" ) );
    }

    /**
      Get band16Mode default value
    */
    int defaultBand16ModeValue() const
    {
        return defaultBand16ModeValue_helper();
    }

    /**
      Set band17Mode
    */
    void setBand17Mode( int v )
    {
      if (v != mBand17Mode && !isBand17ModeImmutable()) {
        mBand17Mode = v;
        Q_EMIT band17ModeChanged();
      }
    }

    Q_PROPERTY(int band17Mode READ band17Mode WRITE setBand17Mode NOTIFY band17ModeChanged)
    Q_PROPERTY(bool isBand17ModeImmutable READ isBand17ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand17ModeValue READ defaultBand17ModeValue CONSTANT)
    /**
      Get band17Mode
    */
    int band17Mode() const
    {
      return mBand17Mode;
    }

    /**
      Is band17Mode Immutable
    */
    bool isBand17ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band17Mode" ) );
    }

    /**
      Get band17Mode default value
    */
    int defaultBand17ModeValue() const
    {
        return defaultBand17ModeValue_helper();
    }

    /**
      Set band18Mode
    */
    void setBand18Mode( int v )
    {
      if (v != mBand18Mode && !isBand18ModeImmutable()) {
        mBand18Mode = v;
        Q_EMIT band18ModeChanged();
      }
    }

    Q_PROPERTY(int band18Mode READ band18Mode WRITE setBand18Mode NOTIFY band18ModeChanged)
    Q_PROPERTY(bool isBand18ModeImmutable READ isBand18ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand18ModeValue READ defaultBand18ModeValue CONSTANT)
    /**
      Get band18Mode
    */
    int band18Mode() const
    {
      return mBand18Mode;
    }

    /**
      Is band18Mode Immutable
    */
    bool isBand18ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band18Mode" ) );
    }

    /**
      Get band18Mode default value
    */
    int defaultBand18ModeValue() const
    {
        return defaultBand18ModeValue_helper();
    }

    /**
      Set band19Mode
    */
    void setBand19Mode( int v )
    {
      if (v != mBand19Mode && !isBand19ModeImmutable()) {
        mBand19Mode = v;
        Q_EMIT band19ModeChanged();
      }
    }

    Q_PROPERTY(int band19Mode READ band19Mode WRITE setBand19Mode NOTIFY band19ModeChanged)
    Q_PROPERTY(bool isBand19ModeImmutable READ isBand19ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand19ModeValue READ defaultBand19ModeValue CONSTANT)
    /**
      Get band19Mode
    */
    int band19Mode() const
    {
      return mBand19Mode;
    }

    /**
      Is band19Mode Immutable
    */
    bool isBand19ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band19Mode" ) );
    }

    /**
      Get band19Mode default value
    */
    int defaultBand19ModeValue() const
    {
        return defaultBand19ModeValue_helper();
    }

    /**
      Set band20Mode
    */
    void setBand20Mode( int v )
    {
      if (v != mBand20Mode && !isBand20ModeImmutable()) {
        mBand20Mode = v;
        Q_EMIT band20ModeChanged();
      }
    }

    Q_PROPERTY(int band20Mode READ band20Mode WRITE setBand20Mode NOTIFY band20ModeChanged)
    Q_PROPERTY(bool isBand20ModeImmutable READ isBand20ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand20ModeValue READ defaultBand20ModeValue CONSTANT)
    /**
      Get band20Mode
    */
    int band20Mode() const
    {
      return mBand20Mode;
    }

    /**
      Is band20Mode Immutable
    */
    bool isBand20ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band20Mode" ) );
    }

    /**
      Get band20Mode default value
    */
    int defaultBand20ModeValue() const
    {
        return defaultBand20ModeValue_helper();
    }

    /**
      Set band21Mode
    */
    void setBand21Mode( int v )
    {
      if (v != mBand21Mode && !isBand21ModeImmutable()) {
        mBand21Mode = v;
        Q_EMIT band21ModeChanged();
      }
    }

    Q_PROPERTY(int band21Mode READ band21Mode WRITE setBand21Mode NOTIFY band21ModeChanged)
    Q_PROPERTY(bool isBand21ModeImmutable READ isBand21ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand21ModeValue READ defaultBand21ModeValue CONSTANT)
    /**
      Get band21Mode
    */
    int band21Mode() const
    {
      return mBand21Mode;
    }

    /**
      Is band21Mode Immutable
    */
    bool isBand21ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band21Mode" ) );
    }

    /**
      Get band21Mode default value
    */
    int defaultBand21ModeValue() const
    {
        return defaultBand21ModeValue_helper();
    }

    /**
      Set band22Mode
    */
    void setBand22Mode( int v )
    {
      if (v != mBand22Mode && !isBand22ModeImmutable()) {
        mBand22Mode = v;
        Q_EMIT band22ModeChanged();
      }
    }

    Q_PROPERTY(int band22Mode READ band22Mode WRITE setBand22Mode NOTIFY band22ModeChanged)
    Q_PROPERTY(bool isBand22ModeImmutable READ isBand22ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand22ModeValue READ defaultBand22ModeValue CONSTANT)
    /**
      Get band22Mode
    */
    int band22Mode() const
    {
      return mBand22Mode;
    }

    /**
      Is band22Mode Immutable
    */
    bool isBand22ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band22Mode" ) );
    }

    /**
      Get band22Mode default value
    */
    int defaultBand22ModeValue() const
    {
        return defaultBand22ModeValue_helper();
    }

    /**
      Set band23Mode
    */
    void setBand23Mode( int v )
    {
      if (v != mBand23Mode && !isBand23ModeImmutable()) {
        mBand23Mode = v;
        Q_EMIT band23ModeChanged();
      }
    }

    Q_PROPERTY(int band23Mode READ band23Mode WRITE setBand23Mode NOTIFY band23ModeChanged)
    Q_PROPERTY(bool isBand23ModeImmutable READ isBand23ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand23ModeValue READ defaultBand23ModeValue CONSTANT)
    /**
      Get band23Mode
    */
    int band23Mode() const
    {
      return mBand23Mode;
    }

    /**
      Is band23Mode Immutable
    */
    bool isBand23ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band23Mode" ) );
    }

    /**
      Get band23Mode default value
    */
    int defaultBand23ModeValue() const
    {
        return defaultBand23ModeValue_helper();
    }

    /**
      Set band24Mode
    */
    void setBand24Mode( int v )
    {
      if (v != mBand24Mode && !isBand24ModeImmutable()) {
        mBand24Mode = v;
        Q_EMIT band24ModeChanged();
      }
    }

    Q_PROPERTY(int band24Mode READ band24Mode WRITE setBand24Mode NOTIFY band24ModeChanged)
    Q_PROPERTY(bool isBand24ModeImmutable READ isBand24ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand24ModeValue READ defaultBand24ModeValue CONSTANT)
    /**
      Get band24Mode
    */
    int band24Mode() const
    {
      return mBand24Mode;
    }

    /**
      Is band24Mode Immutable
    */
    bool isBand24ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band24Mode" ) );
    }

    /**
      Get band24Mode default value
    */
    int defaultBand24ModeValue() const
    {
        return defaultBand24ModeValue_helper();
    }

    /**
      Set band25Mode
    */
    void setBand25Mode( int v )
    {
      if (v != mBand25Mode && !isBand25ModeImmutable()) {
        mBand25Mode = v;
        Q_EMIT band25ModeChanged();
      }
    }

    Q_PROPERTY(int band25Mode READ band25Mode WRITE setBand25Mode NOTIFY band25ModeChanged)
    Q_PROPERTY(bool isBand25ModeImmutable READ isBand25ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand25ModeValue READ defaultBand25ModeValue CONSTANT)
    /**
      Get band25Mode
    */
    int band25Mode() const
    {
      return mBand25Mode;
    }

    /**
      Is band25Mode Immutable
    */
    bool isBand25ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band25Mode" ) );
    }

    /**
      Get band25Mode default value
    */
    int defaultBand25ModeValue() const
    {
        return defaultBand25ModeValue_helper();
    }

    /**
      Set band26Mode
    */
    void setBand26Mode( int v )
    {
      if (v != mBand26Mode && !isBand26ModeImmutable()) {
        mBand26Mode = v;
        Q_EMIT band26ModeChanged();
      }
    }

    Q_PROPERTY(int band26Mode READ band26Mode WRITE setBand26Mode NOTIFY band26ModeChanged)
    Q_PROPERTY(bool isBand26ModeImmutable READ isBand26ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand26ModeValue READ defaultBand26ModeValue CONSTANT)
    /**
      Get band26Mode
    */
    int band26Mode() const
    {
      return mBand26Mode;
    }

    /**
      Is band26Mode Immutable
    */
    bool isBand26ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band26Mode" ) );
    }

    /**
      Get band26Mode default value
    */
    int defaultBand26ModeValue() const
    {
        return defaultBand26ModeValue_helper();
    }

    /**
      Set band27Mode
    */
    void setBand27Mode( int v )
    {
      if (v != mBand27Mode && !isBand27ModeImmutable()) {
        mBand27Mode = v;
        Q_EMIT band27ModeChanged();
      }
    }

    Q_PROPERTY(int band27Mode READ band27Mode WRITE setBand27Mode NOTIFY band27ModeChanged)
    Q_PROPERTY(bool isBand27ModeImmutable READ isBand27ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand27ModeValue READ defaultBand27ModeValue CONSTANT)
    /**
      Get band27Mode
    */
    int band27Mode() const
    {
      return mBand27Mode;
    }

    /**
      Is band27Mode Immutable
    */
    bool isBand27ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band27Mode" ) );
    }

    /**
      Get band27Mode default value
    */
    int defaultBand27ModeValue() const
    {
        return defaultBand27ModeValue_helper();
    }

    /**
      Set band28Mode
    */
    void setBand28Mode( int v )
    {
      if (v != mBand28Mode && !isBand28ModeImmutable()) {
        mBand28Mode = v;
        Q_EMIT band28ModeChanged();
      }
    }

    Q_PROPERTY(int band28Mode READ band28Mode WRITE setBand28Mode NOTIFY band28ModeChanged)
    Q_PROPERTY(bool isBand28ModeImmutable READ isBand28ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand28ModeValue READ defaultBand28ModeValue CONSTANT)
    /**
      Get band28Mode
    */
    int band28Mode() const
    {
      return mBand28Mode;
    }

    /**
      Is band28Mode Immutable
    */
    bool isBand28ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band28Mode" ) );
    }

    /**
      Get band28Mode default value
    */
    int defaultBand28ModeValue() const
    {
        return defaultBand28ModeValue_helper();
    }

    /**
      Set band29Mode
    */
    void setBand29Mode( int v )
    {
      if (v != mBand29Mode && !isBand29ModeImmutable()) {
        mBand29Mode = v;
        Q_EMIT band29ModeChanged();
      }
    }

    Q_PROPERTY(int band29Mode READ band29Mode WRITE setBand29Mode NOTIFY band29ModeChanged)
    Q_PROPERTY(bool isBand29ModeImmutable READ isBand29ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand29ModeValue READ defaultBand29ModeValue CONSTANT)
    /**
      Get band29Mode
    */
    int band29Mode() const
    {
      return mBand29Mode;
    }

    /**
      Is band29Mode Immutable
    */
    bool isBand29ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band29Mode" ) );
    }

    /**
      Get band29Mode default value
    */
    int defaultBand29ModeValue() const
    {
        return defaultBand29ModeValue_helper();
    }

    /**
      Set band30Mode
    */
    void setBand30Mode( int v )
    {
      if (v != mBand30Mode && !isBand30ModeImmutable()) {
        mBand30Mode = v;
        Q_EMIT band30ModeChanged();
      }
    }

    Q_PROPERTY(int band30Mode READ band30Mode WRITE setBand30Mode NOTIFY band30ModeChanged)
    Q_PROPERTY(bool isBand30ModeImmutable READ isBand30ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand30ModeValue READ defaultBand30ModeValue CONSTANT)
    /**
      Get band30Mode
    */
    int band30Mode() const
    {
      return mBand30Mode;
    }

    /**
      Is band30Mode Immutable
    */
    bool isBand30ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band30Mode" ) );
    }

    /**
      Get band30Mode default value
    */
    int defaultBand30ModeValue() const
    {
        return defaultBand30ModeValue_helper();
    }

    /**
      Set band31Mode
    */
    void setBand31Mode( int v )
    {
      if (v != mBand31Mode && !isBand31ModeImmutable()) {
        mBand31Mode = v;
        Q_EMIT band31ModeChanged();
      }
    }

    Q_PROPERTY(int band31Mode READ band31Mode WRITE setBand31Mode NOTIFY band31ModeChanged)
    Q_PROPERTY(bool isBand31ModeImmutable READ isBand31ModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand31ModeValue READ defaultBand31ModeValue CONSTANT)
    /**
      Get band31Mode
    */
    int band31Mode() const
    {
      return mBand31Mode;
    }

    /**
      Is band31Mode Immutable
    */
    bool isBand31ModeImmutable() const
    {
      return isImmutable( QStringLiteral( "band31Mode" ) );
    }

    /**
      Get band31Mode default value
    */
    int defaultBand31ModeValue() const
    {
        return defaultBand31ModeValue_helper();
    }

    /**
      Set band0Slope
    */
    void setBand0Slope( int v )
    {
      if (v != mBand0Slope && !isBand0SlopeImmutable()) {
        mBand0Slope = v;
        Q_EMIT band0SlopeChanged();
      }
    }

    Q_PROPERTY(int band0Slope READ band0Slope WRITE setBand0Slope NOTIFY band0SlopeChanged)
    Q_PROPERTY(bool isBand0SlopeImmutable READ isBand0SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand0SlopeValue READ defaultBand0SlopeValue CONSTANT)
    /**
      Get band0Slope
    */
    int band0Slope() const
    {
      return mBand0Slope;
    }

    /**
      Is band0Slope Immutable
    */
    bool isBand0SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band0Slope" ) );
    }

    /**
      Get band0Slope default value
    */
    int defaultBand0SlopeValue() const
    {
        return defaultBand0SlopeValue_helper();
    }

    /**
      Set band1Slope
    */
    void setBand1Slope( int v )
    {
      if (v != mBand1Slope && !isBand1SlopeImmutable()) {
        mBand1Slope = v;
        Q_EMIT band1SlopeChanged();
      }
    }

    Q_PROPERTY(int band1Slope READ band1Slope WRITE setBand1Slope NOTIFY band1SlopeChanged)
    Q_PROPERTY(bool isBand1SlopeImmutable READ isBand1SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand1SlopeValue READ defaultBand1SlopeValue CONSTANT)
    /**
      Get band1Slope
    */
    int band1Slope() const
    {
      return mBand1Slope;
    }

    /**
      Is band1Slope Immutable
    */
    bool isBand1SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band1Slope" ) );
    }

    /**
      Get band1Slope default value
    */
    int defaultBand1SlopeValue() const
    {
        return defaultBand1SlopeValue_helper();
    }

    /**
      Set band2Slope
    */
    void setBand2Slope( int v )
    {
      if (v != mBand2Slope && !isBand2SlopeImmutable()) {
        mBand2Slope = v;
        Q_EMIT band2SlopeChanged();
      }
    }

    Q_PROPERTY(int band2Slope READ band2Slope WRITE setBand2Slope NOTIFY band2SlopeChanged)
    Q_PROPERTY(bool isBand2SlopeImmutable READ isBand2SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand2SlopeValue READ defaultBand2SlopeValue CONSTANT)
    /**
      Get band2Slope
    */
    int band2Slope() const
    {
      return mBand2Slope;
    }

    /**
      Is band2Slope Immutable
    */
    bool isBand2SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band2Slope" ) );
    }

    /**
      Get band2Slope default value
    */
    int defaultBand2SlopeValue() const
    {
        return defaultBand2SlopeValue_helper();
    }

    /**
      Set band3Slope
    */
    void setBand3Slope( int v )
    {
      if (v != mBand3Slope && !isBand3SlopeImmutable()) {
        mBand3Slope = v;
        Q_EMIT band3SlopeChanged();
      }
    }

    Q_PROPERTY(int band3Slope READ band3Slope WRITE setBand3Slope NOTIFY band3SlopeChanged)
    Q_PROPERTY(bool isBand3SlopeImmutable READ isBand3SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand3SlopeValue READ defaultBand3SlopeValue CONSTANT)
    /**
      Get band3Slope
    */
    int band3Slope() const
    {
      return mBand3Slope;
    }

    /**
      Is band3Slope Immutable
    */
    bool isBand3SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band3Slope" ) );
    }

    /**
      Get band3Slope default value
    */
    int defaultBand3SlopeValue() const
    {
        return defaultBand3SlopeValue_helper();
    }

    /**
      Set band4Slope
    */
    void setBand4Slope( int v )
    {
      if (v != mBand4Slope && !isBand4SlopeImmutable()) {
        mBand4Slope = v;
        Q_EMIT band4SlopeChanged();
      }
    }

    Q_PROPERTY(int band4Slope READ band4Slope WRITE setBand4Slope NOTIFY band4SlopeChanged)
    Q_PROPERTY(bool isBand4SlopeImmutable READ isBand4SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand4SlopeValue READ defaultBand4SlopeValue CONSTANT)
    /**
      Get band4Slope
    */
    int band4Slope() const
    {
      return mBand4Slope;
    }

    /**
      Is band4Slope Immutable
    */
    bool isBand4SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band4Slope" ) );
    }

    /**
      Get band4Slope default value
    */
    int defaultBand4SlopeValue() const
    {
        return defaultBand4SlopeValue_helper();
    }

    /**
      Set band5Slope
    */
    void setBand5Slope( int v )
    {
      if (v != mBand5Slope && !isBand5SlopeImmutable()) {
        mBand5Slope = v;
        Q_EMIT band5SlopeChanged();
      }
    }

    Q_PROPERTY(int band5Slope READ band5Slope WRITE setBand5Slope NOTIFY band5SlopeChanged)
    Q_PROPERTY(bool isBand5SlopeImmutable READ isBand5SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand5SlopeValue READ defaultBand5SlopeValue CONSTANT)
    /**
      Get band5Slope
    */
    int band5Slope() const
    {
      return mBand5Slope;
    }

    /**
      Is band5Slope Immutable
    */
    bool isBand5SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band5Slope" ) );
    }

    /**
      Get band5Slope default value
    */
    int defaultBand5SlopeValue() const
    {
        return defaultBand5SlopeValue_helper();
    }

    /**
      Set band6Slope
    */
    void setBand6Slope( int v )
    {
      if (v != mBand6Slope && !isBand6SlopeImmutable()) {
        mBand6Slope = v;
        Q_EMIT band6SlopeChanged();
      }
    }

    Q_PROPERTY(int band6Slope READ band6Slope WRITE setBand6Slope NOTIFY band6SlopeChanged)
    Q_PROPERTY(bool isBand6SlopeImmutable READ isBand6SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand6SlopeValue READ defaultBand6SlopeValue CONSTANT)
    /**
      Get band6Slope
    */
    int band6Slope() const
    {
      return mBand6Slope;
    }

    /**
      Is band6Slope Immutable
    */
    bool isBand6SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band6Slope" ) );
    }

    /**
      Get band6Slope default value
    */
    int defaultBand6SlopeValue() const
    {
        return defaultBand6SlopeValue_helper();
    }

    /**
      Set band7Slope
    */
    void setBand7Slope( int v )
    {
      if (v != mBand7Slope && !isBand7SlopeImmutable()) {
        mBand7Slope = v;
        Q_EMIT band7SlopeChanged();
      }
    }

    Q_PROPERTY(int band7Slope READ band7Slope WRITE setBand7Slope NOTIFY band7SlopeChanged)
    Q_PROPERTY(bool isBand7SlopeImmutable READ isBand7SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand7SlopeValue READ defaultBand7SlopeValue CONSTANT)
    /**
      Get band7Slope
    */
    int band7Slope() const
    {
      return mBand7Slope;
    }

    /**
      Is band7Slope Immutable
    */
    bool isBand7SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band7Slope" ) );
    }

    /**
      Get band7Slope default value
    */
    int defaultBand7SlopeValue() const
    {
        return defaultBand7SlopeValue_helper();
    }

    /**
      Set band8Slope
    */
    void setBand8Slope( int v )
    {
      if (v != mBand8Slope && !isBand8SlopeImmutable()) {
        mBand8Slope = v;
        Q_EMIT band8SlopeChanged();
      }
    }

    Q_PROPERTY(int band8Slope READ band8Slope WRITE setBand8Slope NOTIFY band8SlopeChanged)
    Q_PROPERTY(bool isBand8SlopeImmutable READ isBand8SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand8SlopeValue READ defaultBand8SlopeValue CONSTANT)
    /**
      Get band8Slope
    */
    int band8Slope() const
    {
      return mBand8Slope;
    }

    /**
      Is band8Slope Immutable
    */
    bool isBand8SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band8Slope" ) );
    }

    /**
      Get band8Slope default value
    */
    int defaultBand8SlopeValue() const
    {
        return defaultBand8SlopeValue_helper();
    }

    /**
      Set band9Slope
    */
    void setBand9Slope( int v )
    {
      if (v != mBand9Slope && !isBand9SlopeImmutable()) {
        mBand9Slope = v;
        Q_EMIT band9SlopeChanged();
      }
    }

    Q_PROPERTY(int band9Slope READ band9Slope WRITE setBand9Slope NOTIFY band9SlopeChanged)
    Q_PROPERTY(bool isBand9SlopeImmutable READ isBand9SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand9SlopeValue READ defaultBand9SlopeValue CONSTANT)
    /**
      Get band9Slope
    */
    int band9Slope() const
    {
      return mBand9Slope;
    }

    /**
      Is band9Slope Immutable
    */
    bool isBand9SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band9Slope" ) );
    }

    /**
      Get band9Slope default value
    */
    int defaultBand9SlopeValue() const
    {
        return defaultBand9SlopeValue_helper();
    }

    /**
      Set band10Slope
    */
    void setBand10Slope( int v )
    {
      if (v != mBand10Slope && !isBand10SlopeImmutable()) {
        mBand10Slope = v;
        Q_EMIT band10SlopeChanged();
      }
    }

    Q_PROPERTY(int band10Slope READ band10Slope WRITE setBand10Slope NOTIFY band10SlopeChanged)
    Q_PROPERTY(bool isBand10SlopeImmutable READ isBand10SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand10SlopeValue READ defaultBand10SlopeValue CONSTANT)
    /**
      Get band10Slope
    */
    int band10Slope() const
    {
      return mBand10Slope;
    }

    /**
      Is band10Slope Immutable
    */
    bool isBand10SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band10Slope" ) );
    }

    /**
      Get band10Slope default value
    */
    int defaultBand10SlopeValue() const
    {
        return defaultBand10SlopeValue_helper();
    }

    /**
      Set band11Slope
    */
    void setBand11Slope( int v )
    {
      if (v != mBand11Slope && !isBand11SlopeImmutable()) {
        mBand11Slope = v;
        Q_EMIT band11SlopeChanged();
      }
    }

    Q_PROPERTY(int band11Slope READ band11Slope WRITE setBand11Slope NOTIFY band11SlopeChanged)
    Q_PROPERTY(bool isBand11SlopeImmutable READ isBand11SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand11SlopeValue READ defaultBand11SlopeValue CONSTANT)
    /**
      Get band11Slope
    */
    int band11Slope() const
    {
      return mBand11Slope;
    }

    /**
      Is band11Slope Immutable
    */
    bool isBand11SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band11Slope" ) );
    }

    /**
      Get band11Slope default value
    */
    int defaultBand11SlopeValue() const
    {
        return defaultBand11SlopeValue_helper();
    }

    /**
      Set band12Slope
    */
    void setBand12Slope( int v )
    {
      if (v != mBand12Slope && !isBand12SlopeImmutable()) {
        mBand12Slope = v;
        Q_EMIT band12SlopeChanged();
      }
    }

    Q_PROPERTY(int band12Slope READ band12Slope WRITE setBand12Slope NOTIFY band12SlopeChanged)
    Q_PROPERTY(bool isBand12SlopeImmutable READ isBand12SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand12SlopeValue READ defaultBand12SlopeValue CONSTANT)
    /**
      Get band12Slope
    */
    int band12Slope() const
    {
      return mBand12Slope;
    }

    /**
      Is band12Slope Immutable
    */
    bool isBand12SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band12Slope" ) );
    }

    /**
      Get band12Slope default value
    */
    int defaultBand12SlopeValue() const
    {
        return defaultBand12SlopeValue_helper();
    }

    /**
      Set band13Slope
    */
    void setBand13Slope( int v )
    {
      if (v != mBand13Slope && !isBand13SlopeImmutable()) {
        mBand13Slope = v;
        Q_EMIT band13SlopeChanged();
      }
    }

    Q_PROPERTY(int band13Slope READ band13Slope WRITE setBand13Slope NOTIFY band13SlopeChanged)
    Q_PROPERTY(bool isBand13SlopeImmutable READ isBand13SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand13SlopeValue READ defaultBand13SlopeValue CONSTANT)
    /**
      Get band13Slope
    */
    int band13Slope() const
    {
      return mBand13Slope;
    }

    /**
      Is band13Slope Immutable
    */
    bool isBand13SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band13Slope" ) );
    }

    /**
      Get band13Slope default value
    */
    int defaultBand13SlopeValue() const
    {
        return defaultBand13SlopeValue_helper();
    }

    /**
      Set band14Slope
    */
    void setBand14Slope( int v )
    {
      if (v != mBand14Slope && !isBand14SlopeImmutable()) {
        mBand14Slope = v;
        Q_EMIT band14SlopeChanged();
      }
    }

    Q_PROPERTY(int band14Slope READ band14Slope WRITE setBand14Slope NOTIFY band14SlopeChanged)
    Q_PROPERTY(bool isBand14SlopeImmutable READ isBand14SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand14SlopeValue READ defaultBand14SlopeValue CONSTANT)
    /**
      Get band14Slope
    */
    int band14Slope() const
    {
      return mBand14Slope;
    }

    /**
      Is band14Slope Immutable
    */
    bool isBand14SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band14Slope" ) );
    }

    /**
      Get band14Slope default value
    */
    int defaultBand14SlopeValue() const
    {
        return defaultBand14SlopeValue_helper();
    }

    /**
      Set band15Slope
    */
    void setBand15Slope( int v )
    {
      if (v != mBand15Slope && !isBand15SlopeImmutable()) {
        mBand15Slope = v;
        Q_EMIT band15SlopeChanged();
      }
    }

    Q_PROPERTY(int band15Slope READ band15Slope WRITE setBand15Slope NOTIFY band15SlopeChanged)
    Q_PROPERTY(bool isBand15SlopeImmutable READ isBand15SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand15SlopeValue READ defaultBand15SlopeValue CONSTANT)
    /**
      Get band15Slope
    */
    int band15Slope() const
    {
      return mBand15Slope;
    }

    /**
      Is band15Slope Immutable
    */
    bool isBand15SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band15Slope" ) );
    }

    /**
      Get band15Slope default value
    */
    int defaultBand15SlopeValue() const
    {
        return defaultBand15SlopeValue_helper();
    }

    /**
      Set band16Slope
    */
    void setBand16Slope( int v )
    {
      if (v != mBand16Slope && !isBand16SlopeImmutable()) {
        mBand16Slope = v;
        Q_EMIT band16SlopeChanged();
      }
    }

    Q_PROPERTY(int band16Slope READ band16Slope WRITE setBand16Slope NOTIFY band16SlopeChanged)
    Q_PROPERTY(bool isBand16SlopeImmutable READ isBand16SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand16SlopeValue READ defaultBand16SlopeValue CONSTANT)
    /**
      Get band16Slope
    */
    int band16Slope() const
    {
      return mBand16Slope;
    }

    /**
      Is band16Slope Immutable
    */
    bool isBand16SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band16Slope" ) );
    }

    /**
      Get band16Slope default value
    */
    int defaultBand16SlopeValue() const
    {
        return defaultBand16SlopeValue_helper();
    }

    /**
      Set band17Slope
    */
    void setBand17Slope( int v )
    {
      if (v != mBand17Slope && !isBand17SlopeImmutable()) {
        mBand17Slope = v;
        Q_EMIT band17SlopeChanged();
      }
    }

    Q_PROPERTY(int band17Slope READ band17Slope WRITE setBand17Slope NOTIFY band17SlopeChanged)
    Q_PROPERTY(bool isBand17SlopeImmutable READ isBand17SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand17SlopeValue READ defaultBand17SlopeValue CONSTANT)
    /**
      Get band17Slope
    */
    int band17Slope() const
    {
      return mBand17Slope;
    }

    /**
      Is band17Slope Immutable
    */
    bool isBand17SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band17Slope" ) );
    }

    /**
      Get band17Slope default value
    */
    int defaultBand17SlopeValue() const
    {
        return defaultBand17SlopeValue_helper();
    }

    /**
      Set band18Slope
    */
    void setBand18Slope( int v )
    {
      if (v != mBand18Slope && !isBand18SlopeImmutable()) {
        mBand18Slope = v;
        Q_EMIT band18SlopeChanged();
      }
    }

    Q_PROPERTY(int band18Slope READ band18Slope WRITE setBand18Slope NOTIFY band18SlopeChanged)
    Q_PROPERTY(bool isBand18SlopeImmutable READ isBand18SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand18SlopeValue READ defaultBand18SlopeValue CONSTANT)
    /**
      Get band18Slope
    */
    int band18Slope() const
    {
      return mBand18Slope;
    }

    /**
      Is band18Slope Immutable
    */
    bool isBand18SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band18Slope" ) );
    }

    /**
      Get band18Slope default value
    */
    int defaultBand18SlopeValue() const
    {
        return defaultBand18SlopeValue_helper();
    }

    /**
      Set band19Slope
    */
    void setBand19Slope( int v )
    {
      if (v != mBand19Slope && !isBand19SlopeImmutable()) {
        mBand19Slope = v;
        Q_EMIT band19SlopeChanged();
      }
    }

    Q_PROPERTY(int band19Slope READ band19Slope WRITE setBand19Slope NOTIFY band19SlopeChanged)
    Q_PROPERTY(bool isBand19SlopeImmutable READ isBand19SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand19SlopeValue READ defaultBand19SlopeValue CONSTANT)
    /**
      Get band19Slope
    */
    int band19Slope() const
    {
      return mBand19Slope;
    }

    /**
      Is band19Slope Immutable
    */
    bool isBand19SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band19Slope" ) );
    }

    /**
      Get band19Slope default value
    */
    int defaultBand19SlopeValue() const
    {
        return defaultBand19SlopeValue_helper();
    }

    /**
      Set band20Slope
    */
    void setBand20Slope( int v )
    {
      if (v != mBand20Slope && !isBand20SlopeImmutable()) {
        mBand20Slope = v;
        Q_EMIT band20SlopeChanged();
      }
    }

    Q_PROPERTY(int band20Slope READ band20Slope WRITE setBand20Slope NOTIFY band20SlopeChanged)
    Q_PROPERTY(bool isBand20SlopeImmutable READ isBand20SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand20SlopeValue READ defaultBand20SlopeValue CONSTANT)
    /**
      Get band20Slope
    */
    int band20Slope() const
    {
      return mBand20Slope;
    }

    /**
      Is band20Slope Immutable
    */
    bool isBand20SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band20Slope" ) );
    }

    /**
      Get band20Slope default value
    */
    int defaultBand20SlopeValue() const
    {
        return defaultBand20SlopeValue_helper();
    }

    /**
      Set band21Slope
    */
    void setBand21Slope( int v )
    {
      if (v != mBand21Slope && !isBand21SlopeImmutable()) {
        mBand21Slope = v;
        Q_EMIT band21SlopeChanged();
      }
    }

    Q_PROPERTY(int band21Slope READ band21Slope WRITE setBand21Slope NOTIFY band21SlopeChanged)
    Q_PROPERTY(bool isBand21SlopeImmutable READ isBand21SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand21SlopeValue READ defaultBand21SlopeValue CONSTANT)
    /**
      Get band21Slope
    */
    int band21Slope() const
    {
      return mBand21Slope;
    }

    /**
      Is band21Slope Immutable
    */
    bool isBand21SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band21Slope" ) );
    }

    /**
      Get band21Slope default value
    */
    int defaultBand21SlopeValue() const
    {
        return defaultBand21SlopeValue_helper();
    }

    /**
      Set band22Slope
    */
    void setBand22Slope( int v )
    {
      if (v != mBand22Slope && !isBand22SlopeImmutable()) {
        mBand22Slope = v;
        Q_EMIT band22SlopeChanged();
      }
    }

    Q_PROPERTY(int band22Slope READ band22Slope WRITE setBand22Slope NOTIFY band22SlopeChanged)
    Q_PROPERTY(bool isBand22SlopeImmutable READ isBand22SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand22SlopeValue READ defaultBand22SlopeValue CONSTANT)
    /**
      Get band22Slope
    */
    int band22Slope() const
    {
      return mBand22Slope;
    }

    /**
      Is band22Slope Immutable
    */
    bool isBand22SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band22Slope" ) );
    }

    /**
      Get band22Slope default value
    */
    int defaultBand22SlopeValue() const
    {
        return defaultBand22SlopeValue_helper();
    }

    /**
      Set band23Slope
    */
    void setBand23Slope( int v )
    {
      if (v != mBand23Slope && !isBand23SlopeImmutable()) {
        mBand23Slope = v;
        Q_EMIT band23SlopeChanged();
      }
    }

    Q_PROPERTY(int band23Slope READ band23Slope WRITE setBand23Slope NOTIFY band23SlopeChanged)
    Q_PROPERTY(bool isBand23SlopeImmutable READ isBand23SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand23SlopeValue READ defaultBand23SlopeValue CONSTANT)
    /**
      Get band23Slope
    */
    int band23Slope() const
    {
      return mBand23Slope;
    }

    /**
      Is band23Slope Immutable
    */
    bool isBand23SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band23Slope" ) );
    }

    /**
      Get band23Slope default value
    */
    int defaultBand23SlopeValue() const
    {
        return defaultBand23SlopeValue_helper();
    }

    /**
      Set band24Slope
    */
    void setBand24Slope( int v )
    {
      if (v != mBand24Slope && !isBand24SlopeImmutable()) {
        mBand24Slope = v;
        Q_EMIT band24SlopeChanged();
      }
    }

    Q_PROPERTY(int band24Slope READ band24Slope WRITE setBand24Slope NOTIFY band24SlopeChanged)
    Q_PROPERTY(bool isBand24SlopeImmutable READ isBand24SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand24SlopeValue READ defaultBand24SlopeValue CONSTANT)
    /**
      Get band24Slope
    */
    int band24Slope() const
    {
      return mBand24Slope;
    }

    /**
      Is band24Slope Immutable
    */
    bool isBand24SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band24Slope" ) );
    }

    /**
      Get band24Slope default value
    */
    int defaultBand24SlopeValue() const
    {
        return defaultBand24SlopeValue_helper();
    }

    /**
      Set band25Slope
    */
    void setBand25Slope( int v )
    {
      if (v != mBand25Slope && !isBand25SlopeImmutable()) {
        mBand25Slope = v;
        Q_EMIT band25SlopeChanged();
      }
    }

    Q_PROPERTY(int band25Slope READ band25Slope WRITE setBand25Slope NOTIFY band25SlopeChanged)
    Q_PROPERTY(bool isBand25SlopeImmutable READ isBand25SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand25SlopeValue READ defaultBand25SlopeValue CONSTANT)
    /**
      Get band25Slope
    */
    int band25Slope() const
    {
      return mBand25Slope;
    }

    /**
      Is band25Slope Immutable
    */
    bool isBand25SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band25Slope" ) );
    }

    /**
      Get band25Slope default value
    */
    int defaultBand25SlopeValue() const
    {
        return defaultBand25SlopeValue_helper();
    }

    /**
      Set band26Slope
    */
    void setBand26Slope( int v )
    {
      if (v != mBand26Slope && !isBand26SlopeImmutable()) {
        mBand26Slope = v;
        Q_EMIT band26SlopeChanged();
      }
    }

    Q_PROPERTY(int band26Slope READ band26Slope WRITE setBand26Slope NOTIFY band26SlopeChanged)
    Q_PROPERTY(bool isBand26SlopeImmutable READ isBand26SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand26SlopeValue READ defaultBand26SlopeValue CONSTANT)
    /**
      Get band26Slope
    */
    int band26Slope() const
    {
      return mBand26Slope;
    }

    /**
      Is band26Slope Immutable
    */
    bool isBand26SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band26Slope" ) );
    }

    /**
      Get band26Slope default value
    */
    int defaultBand26SlopeValue() const
    {
        return defaultBand26SlopeValue_helper();
    }

    /**
      Set band27Slope
    */
    void setBand27Slope( int v )
    {
      if (v != mBand27Slope && !isBand27SlopeImmutable()) {
        mBand27Slope = v;
        Q_EMIT band27SlopeChanged();
      }
    }

    Q_PROPERTY(int band27Slope READ band27Slope WRITE setBand27Slope NOTIFY band27SlopeChanged)
    Q_PROPERTY(bool isBand27SlopeImmutable READ isBand27SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand27SlopeValue READ defaultBand27SlopeValue CONSTANT)
    /**
      Get band27Slope
    */
    int band27Slope() const
    {
      return mBand27Slope;
    }

    /**
      Is band27Slope Immutable
    */
    bool isBand27SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band27Slope" ) );
    }

    /**
      Get band27Slope default value
    */
    int defaultBand27SlopeValue() const
    {
        return defaultBand27SlopeValue_helper();
    }

    /**
      Set band28Slope
    */
    void setBand28Slope( int v )
    {
      if (v != mBand28Slope && !isBand28SlopeImmutable()) {
        mBand28Slope = v;
        Q_EMIT band28SlopeChanged();
      }
    }

    Q_PROPERTY(int band28Slope READ band28Slope WRITE setBand28Slope NOTIFY band28SlopeChanged)
    Q_PROPERTY(bool isBand28SlopeImmutable READ isBand28SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand28SlopeValue READ defaultBand28SlopeValue CONSTANT)
    /**
      Get band28Slope
    */
    int band28Slope() const
    {
      return mBand28Slope;
    }

    /**
      Is band28Slope Immutable
    */
    bool isBand28SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band28Slope" ) );
    }

    /**
      Get band28Slope default value
    */
    int defaultBand28SlopeValue() const
    {
        return defaultBand28SlopeValue_helper();
    }

    /**
      Set band29Slope
    */
    void setBand29Slope( int v )
    {
      if (v != mBand29Slope && !isBand29SlopeImmutable()) {
        mBand29Slope = v;
        Q_EMIT band29SlopeChanged();
      }
    }

    Q_PROPERTY(int band29Slope READ band29Slope WRITE setBand29Slope NOTIFY band29SlopeChanged)
    Q_PROPERTY(bool isBand29SlopeImmutable READ isBand29SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand29SlopeValue READ defaultBand29SlopeValue CONSTANT)
    /**
      Get band29Slope
    */
    int band29Slope() const
    {
      return mBand29Slope;
    }

    /**
      Is band29Slope Immutable
    */
    bool isBand29SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band29Slope" ) );
    }

    /**
      Get band29Slope default value
    */
    int defaultBand29SlopeValue() const
    {
        return defaultBand29SlopeValue_helper();
    }

    /**
      Set band30Slope
    */
    void setBand30Slope( int v )
    {
      if (v != mBand30Slope && !isBand30SlopeImmutable()) {
        mBand30Slope = v;
        Q_EMIT band30SlopeChanged();
      }
    }

    Q_PROPERTY(int band30Slope READ band30Slope WRITE setBand30Slope NOTIFY band30SlopeChanged)
    Q_PROPERTY(bool isBand30SlopeImmutable READ isBand30SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand30SlopeValue READ defaultBand30SlopeValue CONSTANT)
    /**
      Get band30Slope
    */
    int band30Slope() const
    {
      return mBand30Slope;
    }

    /**
      Is band30Slope Immutable
    */
    bool isBand30SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band30Slope" ) );
    }

    /**
      Get band30Slope default value
    */
    int defaultBand30SlopeValue() const
    {
        return defaultBand30SlopeValue_helper();
    }

    /**
      Set band31Slope
    */
    void setBand31Slope( int v )
    {
      if (v != mBand31Slope && !isBand31SlopeImmutable()) {
        mBand31Slope = v;
        Q_EMIT band31SlopeChanged();
      }
    }

    Q_PROPERTY(int band31Slope READ band31Slope WRITE setBand31Slope NOTIFY band31SlopeChanged)
    Q_PROPERTY(bool isBand31SlopeImmutable READ isBand31SlopeImmutable CONSTANT)
    Q_PROPERTY(int defaultBand31SlopeValue READ defaultBand31SlopeValue CONSTANT)
    /**
      Get band31Slope
    */
    int band31Slope() const
    {
      return mBand31Slope;
    }

    /**
      Is band31Slope Immutable
    */
    bool isBand31SlopeImmutable() const
    {
      return isImmutable( QStringLiteral( "band31Slope" ) );
    }

    /**
      Get band31Slope default value
    */
    int defaultBand31SlopeValue() const
    {
        return defaultBand31SlopeValue_helper();
    }

    /**
      Set band0Solo
    */
    void setBand0Solo( bool v )
    {
      if (v != mBand0Solo && !isBand0SoloImmutable()) {
        mBand0Solo = v;
        Q_EMIT band0SoloChanged();
      }
    }

    Q_PROPERTY(bool band0Solo READ band0Solo WRITE setBand0Solo NOTIFY band0SoloChanged)
    Q_PROPERTY(bool isBand0SoloImmutable READ isBand0SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand0SoloValue READ defaultBand0SoloValue CONSTANT)
    /**
      Get band0Solo
    */
    bool band0Solo() const
    {
      return mBand0Solo;
    }

    /**
      Is band0Solo Immutable
    */
    bool isBand0SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band0Solo" ) );
    }

    /**
      Get band0Solo default value
    */
    bool defaultBand0SoloValue() const
    {
        return defaultBand0SoloValue_helper();
    }

    /**
      Set band1Solo
    */
    void setBand1Solo( bool v )
    {
      if (v != mBand1Solo && !isBand1SoloImmutable()) {
        mBand1Solo = v;
        Q_EMIT band1SoloChanged();
      }
    }

    Q_PROPERTY(bool band1Solo READ band1Solo WRITE setBand1Solo NOTIFY band1SoloChanged)
    Q_PROPERTY(bool isBand1SoloImmutable READ isBand1SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand1SoloValue READ defaultBand1SoloValue CONSTANT)
    /**
      Get band1Solo
    */
    bool band1Solo() const
    {
      return mBand1Solo;
    }

    /**
      Is band1Solo Immutable
    */
    bool isBand1SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band1Solo" ) );
    }

    /**
      Get band1Solo default value
    */
    bool defaultBand1SoloValue() const
    {
        return defaultBand1SoloValue_helper();
    }

    /**
      Set band2Solo
    */
    void setBand2Solo( bool v )
    {
      if (v != mBand2Solo && !isBand2SoloImmutable()) {
        mBand2Solo = v;
        Q_EMIT band2SoloChanged();
      }
    }

    Q_PROPERTY(bool band2Solo READ band2Solo WRITE setBand2Solo NOTIFY band2SoloChanged)
    Q_PROPERTY(bool isBand2SoloImmutable READ isBand2SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand2SoloValue READ defaultBand2SoloValue CONSTANT)
    /**
      Get band2Solo
    */
    bool band2Solo() const
    {
      return mBand2Solo;
    }

    /**
      Is band2Solo Immutable
    */
    bool isBand2SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band2Solo" ) );
    }

    /**
      Get band2Solo default value
    */
    bool defaultBand2SoloValue() const
    {
        return defaultBand2SoloValue_helper();
    }

    /**
      Set band3Solo
    */
    void setBand3Solo( bool v )
    {
      if (v != mBand3Solo && !isBand3SoloImmutable()) {
        mBand3Solo = v;
        Q_EMIT band3SoloChanged();
      }
    }

    Q_PROPERTY(bool band3Solo READ band3Solo WRITE setBand3Solo NOTIFY band3SoloChanged)
    Q_PROPERTY(bool isBand3SoloImmutable READ isBand3SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand3SoloValue READ defaultBand3SoloValue CONSTANT)
    /**
      Get band3Solo
    */
    bool band3Solo() const
    {
      return mBand3Solo;
    }

    /**
      Is band3Solo Immutable
    */
    bool isBand3SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band3Solo" ) );
    }

    /**
      Get band3Solo default value
    */
    bool defaultBand3SoloValue() const
    {
        return defaultBand3SoloValue_helper();
    }

    /**
      Set band4Solo
    */
    void setBand4Solo( bool v )
    {
      if (v != mBand4Solo && !isBand4SoloImmutable()) {
        mBand4Solo = v;
        Q_EMIT band4SoloChanged();
      }
    }

    Q_PROPERTY(bool band4Solo READ band4Solo WRITE setBand4Solo NOTIFY band4SoloChanged)
    Q_PROPERTY(bool isBand4SoloImmutable READ isBand4SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand4SoloValue READ defaultBand4SoloValue CONSTANT)
    /**
      Get band4Solo
    */
    bool band4Solo() const
    {
      return mBand4Solo;
    }

    /**
      Is band4Solo Immutable
    */
    bool isBand4SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band4Solo" ) );
    }

    /**
      Get band4Solo default value
    */
    bool defaultBand4SoloValue() const
    {
        return defaultBand4SoloValue_helper();
    }

    /**
      Set band5Solo
    */
    void setBand5Solo( bool v )
    {
      if (v != mBand5Solo && !isBand5SoloImmutable()) {
        mBand5Solo = v;
        Q_EMIT band5SoloChanged();
      }
    }

    Q_PROPERTY(bool band5Solo READ band5Solo WRITE setBand5Solo NOTIFY band5SoloChanged)
    Q_PROPERTY(bool isBand5SoloImmutable READ isBand5SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand5SoloValue READ defaultBand5SoloValue CONSTANT)
    /**
      Get band5Solo
    */
    bool band5Solo() const
    {
      return mBand5Solo;
    }

    /**
      Is band5Solo Immutable
    */
    bool isBand5SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band5Solo" ) );
    }

    /**
      Get band5Solo default value
    */
    bool defaultBand5SoloValue() const
    {
        return defaultBand5SoloValue_helper();
    }

    /**
      Set band6Solo
    */
    void setBand6Solo( bool v )
    {
      if (v != mBand6Solo && !isBand6SoloImmutable()) {
        mBand6Solo = v;
        Q_EMIT band6SoloChanged();
      }
    }

    Q_PROPERTY(bool band6Solo READ band6Solo WRITE setBand6Solo NOTIFY band6SoloChanged)
    Q_PROPERTY(bool isBand6SoloImmutable READ isBand6SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand6SoloValue READ defaultBand6SoloValue CONSTANT)
    /**
      Get band6Solo
    */
    bool band6Solo() const
    {
      return mBand6Solo;
    }

    /**
      Is band6Solo Immutable
    */
    bool isBand6SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band6Solo" ) );
    }

    /**
      Get band6Solo default value
    */
    bool defaultBand6SoloValue() const
    {
        return defaultBand6SoloValue_helper();
    }

    /**
      Set band7Solo
    */
    void setBand7Solo( bool v )
    {
      if (v != mBand7Solo && !isBand7SoloImmutable()) {
        mBand7Solo = v;
        Q_EMIT band7SoloChanged();
      }
    }

    Q_PROPERTY(bool band7Solo READ band7Solo WRITE setBand7Solo NOTIFY band7SoloChanged)
    Q_PROPERTY(bool isBand7SoloImmutable READ isBand7SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand7SoloValue READ defaultBand7SoloValue CONSTANT)
    /**
      Get band7Solo
    */
    bool band7Solo() const
    {
      return mBand7Solo;
    }

    /**
      Is band7Solo Immutable
    */
    bool isBand7SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band7Solo" ) );
    }

    /**
      Get band7Solo default value
    */
    bool defaultBand7SoloValue() const
    {
        return defaultBand7SoloValue_helper();
    }

    /**
      Set band8Solo
    */
    void setBand8Solo( bool v )
    {
      if (v != mBand8Solo && !isBand8SoloImmutable()) {
        mBand8Solo = v;
        Q_EMIT band8SoloChanged();
      }
    }

    Q_PROPERTY(bool band8Solo READ band8Solo WRITE setBand8Solo NOTIFY band8SoloChanged)
    Q_PROPERTY(bool isBand8SoloImmutable READ isBand8SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand8SoloValue READ defaultBand8SoloValue CONSTANT)
    /**
      Get band8Solo
    */
    bool band8Solo() const
    {
      return mBand8Solo;
    }

    /**
      Is band8Solo Immutable
    */
    bool isBand8SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band8Solo" ) );
    }

    /**
      Get band8Solo default value
    */
    bool defaultBand8SoloValue() const
    {
        return defaultBand8SoloValue_helper();
    }

    /**
      Set band9Solo
    */
    void setBand9Solo( bool v )
    {
      if (v != mBand9Solo && !isBand9SoloImmutable()) {
        mBand9Solo = v;
        Q_EMIT band9SoloChanged();
      }
    }

    Q_PROPERTY(bool band9Solo READ band9Solo WRITE setBand9Solo NOTIFY band9SoloChanged)
    Q_PROPERTY(bool isBand9SoloImmutable READ isBand9SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand9SoloValue READ defaultBand9SoloValue CONSTANT)
    /**
      Get band9Solo
    */
    bool band9Solo() const
    {
      return mBand9Solo;
    }

    /**
      Is band9Solo Immutable
    */
    bool isBand9SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band9Solo" ) );
    }

    /**
      Get band9Solo default value
    */
    bool defaultBand9SoloValue() const
    {
        return defaultBand9SoloValue_helper();
    }

    /**
      Set band10Solo
    */
    void setBand10Solo( bool v )
    {
      if (v != mBand10Solo && !isBand10SoloImmutable()) {
        mBand10Solo = v;
        Q_EMIT band10SoloChanged();
      }
    }

    Q_PROPERTY(bool band10Solo READ band10Solo WRITE setBand10Solo NOTIFY band10SoloChanged)
    Q_PROPERTY(bool isBand10SoloImmutable READ isBand10SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand10SoloValue READ defaultBand10SoloValue CONSTANT)
    /**
      Get band10Solo
    */
    bool band10Solo() const
    {
      return mBand10Solo;
    }

    /**
      Is band10Solo Immutable
    */
    bool isBand10SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band10Solo" ) );
    }

    /**
      Get band10Solo default value
    */
    bool defaultBand10SoloValue() const
    {
        return defaultBand10SoloValue_helper();
    }

    /**
      Set band11Solo
    */
    void setBand11Solo( bool v )
    {
      if (v != mBand11Solo && !isBand11SoloImmutable()) {
        mBand11Solo = v;
        Q_EMIT band11SoloChanged();
      }
    }

    Q_PROPERTY(bool band11Solo READ band11Solo WRITE setBand11Solo NOTIFY band11SoloChanged)
    Q_PROPERTY(bool isBand11SoloImmutable READ isBand11SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand11SoloValue READ defaultBand11SoloValue CONSTANT)
    /**
      Get band11Solo
    */
    bool band11Solo() const
    {
      return mBand11Solo;
    }

    /**
      Is band11Solo Immutable
    */
    bool isBand11SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band11Solo" ) );
    }

    /**
      Get band11Solo default value
    */
    bool defaultBand11SoloValue() const
    {
        return defaultBand11SoloValue_helper();
    }

    /**
      Set band12Solo
    */
    void setBand12Solo( bool v )
    {
      if (v != mBand12Solo && !isBand12SoloImmutable()) {
        mBand12Solo = v;
        Q_EMIT band12SoloChanged();
      }
    }

    Q_PROPERTY(bool band12Solo READ band12Solo WRITE setBand12Solo NOTIFY band12SoloChanged)
    Q_PROPERTY(bool isBand12SoloImmutable READ isBand12SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand12SoloValue READ defaultBand12SoloValue CONSTANT)
    /**
      Get band12Solo
    */
    bool band12Solo() const
    {
      return mBand12Solo;
    }

    /**
      Is band12Solo Immutable
    */
    bool isBand12SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band12Solo" ) );
    }

    /**
      Get band12Solo default value
    */
    bool defaultBand12SoloValue() const
    {
        return defaultBand12SoloValue_helper();
    }

    /**
      Set band13Solo
    */
    void setBand13Solo( bool v )
    {
      if (v != mBand13Solo && !isBand13SoloImmutable()) {
        mBand13Solo = v;
        Q_EMIT band13SoloChanged();
      }
    }

    Q_PROPERTY(bool band13Solo READ band13Solo WRITE setBand13Solo NOTIFY band13SoloChanged)
    Q_PROPERTY(bool isBand13SoloImmutable READ isBand13SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand13SoloValue READ defaultBand13SoloValue CONSTANT)
    /**
      Get band13Solo
    */
    bool band13Solo() const
    {
      return mBand13Solo;
    }

    /**
      Is band13Solo Immutable
    */
    bool isBand13SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band13Solo" ) );
    }

    /**
      Get band13Solo default value
    */
    bool defaultBand13SoloValue() const
    {
        return defaultBand13SoloValue_helper();
    }

    /**
      Set band14Solo
    */
    void setBand14Solo( bool v )
    {
      if (v != mBand14Solo && !isBand14SoloImmutable()) {
        mBand14Solo = v;
        Q_EMIT band14SoloChanged();
      }
    }

    Q_PROPERTY(bool band14Solo READ band14Solo WRITE setBand14Solo NOTIFY band14SoloChanged)
    Q_PROPERTY(bool isBand14SoloImmutable READ isBand14SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand14SoloValue READ defaultBand14SoloValue CONSTANT)
    /**
      Get band14Solo
    */
    bool band14Solo() const
    {
      return mBand14Solo;
    }

    /**
      Is band14Solo Immutable
    */
    bool isBand14SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band14Solo" ) );
    }

    /**
      Get band14Solo default value
    */
    bool defaultBand14SoloValue() const
    {
        return defaultBand14SoloValue_helper();
    }

    /**
      Set band15Solo
    */
    void setBand15Solo( bool v )
    {
      if (v != mBand15Solo && !isBand15SoloImmutable()) {
        mBand15Solo = v;
        Q_EMIT band15SoloChanged();
      }
    }

    Q_PROPERTY(bool band15Solo READ band15Solo WRITE setBand15Solo NOTIFY band15SoloChanged)
    Q_PROPERTY(bool isBand15SoloImmutable READ isBand15SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand15SoloValue READ defaultBand15SoloValue CONSTANT)
    /**
      Get band15Solo
    */
    bool band15Solo() const
    {
      return mBand15Solo;
    }

    /**
      Is band15Solo Immutable
    */
    bool isBand15SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band15Solo" ) );
    }

    /**
      Get band15Solo default value
    */
    bool defaultBand15SoloValue() const
    {
        return defaultBand15SoloValue_helper();
    }

    /**
      Set band16Solo
    */
    void setBand16Solo( bool v )
    {
      if (v != mBand16Solo && !isBand16SoloImmutable()) {
        mBand16Solo = v;
        Q_EMIT band16SoloChanged();
      }
    }

    Q_PROPERTY(bool band16Solo READ band16Solo WRITE setBand16Solo NOTIFY band16SoloChanged)
    Q_PROPERTY(bool isBand16SoloImmutable READ isBand16SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand16SoloValue READ defaultBand16SoloValue CONSTANT)
    /**
      Get band16Solo
    */
    bool band16Solo() const
    {
      return mBand16Solo;
    }

    /**
      Is band16Solo Immutable
    */
    bool isBand16SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band16Solo" ) );
    }

    /**
      Get band16Solo default value
    */
    bool defaultBand16SoloValue() const
    {
        return defaultBand16SoloValue_helper();
    }

    /**
      Set band17Solo
    */
    void setBand17Solo( bool v )
    {
      if (v != mBand17Solo && !isBand17SoloImmutable()) {
        mBand17Solo = v;
        Q_EMIT band17SoloChanged();
      }
    }

    Q_PROPERTY(bool band17Solo READ band17Solo WRITE setBand17Solo NOTIFY band17SoloChanged)
    Q_PROPERTY(bool isBand17SoloImmutable READ isBand17SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand17SoloValue READ defaultBand17SoloValue CONSTANT)
    /**
      Get band17Solo
    */
    bool band17Solo() const
    {
      return mBand17Solo;
    }

    /**
      Is band17Solo Immutable
    */
    bool isBand17SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band17Solo" ) );
    }

    /**
      Get band17Solo default value
    */
    bool defaultBand17SoloValue() const
    {
        return defaultBand17SoloValue_helper();
    }

    /**
      Set band18Solo
    */
    void setBand18Solo( bool v )
    {
      if (v != mBand18Solo && !isBand18SoloImmutable()) {
        mBand18Solo = v;
        Q_EMIT band18SoloChanged();
      }
    }

    Q_PROPERTY(bool band18Solo READ band18Solo WRITE setBand18Solo NOTIFY band18SoloChanged)
    Q_PROPERTY(bool isBand18SoloImmutable READ isBand18SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand18SoloValue READ defaultBand18SoloValue CONSTANT)
    /**
      Get band18Solo
    */
    bool band18Solo() const
    {
      return mBand18Solo;
    }

    /**
      Is band18Solo Immutable
    */
    bool isBand18SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band18Solo" ) );
    }

    /**
      Get band18Solo default value
    */
    bool defaultBand18SoloValue() const
    {
        return defaultBand18SoloValue_helper();
    }

    /**
      Set band19Solo
    */
    void setBand19Solo( bool v )
    {
      if (v != mBand19Solo && !isBand19SoloImmutable()) {
        mBand19Solo = v;
        Q_EMIT band19SoloChanged();
      }
    }

    Q_PROPERTY(bool band19Solo READ band19Solo WRITE setBand19Solo NOTIFY band19SoloChanged)
    Q_PROPERTY(bool isBand19SoloImmutable READ isBand19SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand19SoloValue READ defaultBand19SoloValue CONSTANT)
    /**
      Get band19Solo
    */
    bool band19Solo() const
    {
      return mBand19Solo;
    }

    /**
      Is band19Solo Immutable
    */
    bool isBand19SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band19Solo" ) );
    }

    /**
      Get band19Solo default value
    */
    bool defaultBand19SoloValue() const
    {
        return defaultBand19SoloValue_helper();
    }

    /**
      Set band20Solo
    */
    void setBand20Solo( bool v )
    {
      if (v != mBand20Solo && !isBand20SoloImmutable()) {
        mBand20Solo = v;
        Q_EMIT band20SoloChanged();
      }
    }

    Q_PROPERTY(bool band20Solo READ band20Solo WRITE setBand20Solo NOTIFY band20SoloChanged)
    Q_PROPERTY(bool isBand20SoloImmutable READ isBand20SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand20SoloValue READ defaultBand20SoloValue CONSTANT)
    /**
      Get band20Solo
    */
    bool band20Solo() const
    {
      return mBand20Solo;
    }

    /**
      Is band20Solo Immutable
    */
    bool isBand20SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band20Solo" ) );
    }

    /**
      Get band20Solo default value
    */
    bool defaultBand20SoloValue() const
    {
        return defaultBand20SoloValue_helper();
    }

    /**
      Set band21Solo
    */
    void setBand21Solo( bool v )
    {
      if (v != mBand21Solo && !isBand21SoloImmutable()) {
        mBand21Solo = v;
        Q_EMIT band21SoloChanged();
      }
    }

    Q_PROPERTY(bool band21Solo READ band21Solo WRITE setBand21Solo NOTIFY band21SoloChanged)
    Q_PROPERTY(bool isBand21SoloImmutable READ isBand21SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand21SoloValue READ defaultBand21SoloValue CONSTANT)
    /**
      Get band21Solo
    */
    bool band21Solo() const
    {
      return mBand21Solo;
    }

    /**
      Is band21Solo Immutable
    */
    bool isBand21SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band21Solo" ) );
    }

    /**
      Get band21Solo default value
    */
    bool defaultBand21SoloValue() const
    {
        return defaultBand21SoloValue_helper();
    }

    /**
      Set band22Solo
    */
    void setBand22Solo( bool v )
    {
      if (v != mBand22Solo && !isBand22SoloImmutable()) {
        mBand22Solo = v;
        Q_EMIT band22SoloChanged();
      }
    }

    Q_PROPERTY(bool band22Solo READ band22Solo WRITE setBand22Solo NOTIFY band22SoloChanged)
    Q_PROPERTY(bool isBand22SoloImmutable READ isBand22SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand22SoloValue READ defaultBand22SoloValue CONSTANT)
    /**
      Get band22Solo
    */
    bool band22Solo() const
    {
      return mBand22Solo;
    }

    /**
      Is band22Solo Immutable
    */
    bool isBand22SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band22Solo" ) );
    }

    /**
      Get band22Solo default value
    */
    bool defaultBand22SoloValue() const
    {
        return defaultBand22SoloValue_helper();
    }

    /**
      Set band23Solo
    */
    void setBand23Solo( bool v )
    {
      if (v != mBand23Solo && !isBand23SoloImmutable()) {
        mBand23Solo = v;
        Q_EMIT band23SoloChanged();
      }
    }

    Q_PROPERTY(bool band23Solo READ band23Solo WRITE setBand23Solo NOTIFY band23SoloChanged)
    Q_PROPERTY(bool isBand23SoloImmutable READ isBand23SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand23SoloValue READ defaultBand23SoloValue CONSTANT)
    /**
      Get band23Solo
    */
    bool band23Solo() const
    {
      return mBand23Solo;
    }

    /**
      Is band23Solo Immutable
    */
    bool isBand23SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band23Solo" ) );
    }

    /**
      Get band23Solo default value
    */
    bool defaultBand23SoloValue() const
    {
        return defaultBand23SoloValue_helper();
    }

    /**
      Set band24Solo
    */
    void setBand24Solo( bool v )
    {
      if (v != mBand24Solo && !isBand24SoloImmutable()) {
        mBand24Solo = v;
        Q_EMIT band24SoloChanged();
      }
    }

    Q_PROPERTY(bool band24Solo READ band24Solo WRITE setBand24Solo NOTIFY band24SoloChanged)
    Q_PROPERTY(bool isBand24SoloImmutable READ isBand24SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand24SoloValue READ defaultBand24SoloValue CONSTANT)
    /**
      Get band24Solo
    */
    bool band24Solo() const
    {
      return mBand24Solo;
    }

    /**
      Is band24Solo Immutable
    */
    bool isBand24SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band24Solo" ) );
    }

    /**
      Get band24Solo default value
    */
    bool defaultBand24SoloValue() const
    {
        return defaultBand24SoloValue_helper();
    }

    /**
      Set band25Solo
    */
    void setBand25Solo( bool v )
    {
      if (v != mBand25Solo && !isBand25SoloImmutable()) {
        mBand25Solo = v;
        Q_EMIT band25SoloChanged();
      }
    }

    Q_PROPERTY(bool band25Solo READ band25Solo WRITE setBand25Solo NOTIFY band25SoloChanged)
    Q_PROPERTY(bool isBand25SoloImmutable READ isBand25SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand25SoloValue READ defaultBand25SoloValue CONSTANT)
    /**
      Get band25Solo
    */
    bool band25Solo() const
    {
      return mBand25Solo;
    }

    /**
      Is band25Solo Immutable
    */
    bool isBand25SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band25Solo" ) );
    }

    /**
      Get band25Solo default value
    */
    bool defaultBand25SoloValue() const
    {
        return defaultBand25SoloValue_helper();
    }

    /**
      Set band26Solo
    */
    void setBand26Solo( bool v )
    {
      if (v != mBand26Solo && !isBand26SoloImmutable()) {
        mBand26Solo = v;
        Q_EMIT band26SoloChanged();
      }
    }

    Q_PROPERTY(bool band26Solo READ band26Solo WRITE setBand26Solo NOTIFY band26SoloChanged)
    Q_PROPERTY(bool isBand26SoloImmutable READ isBand26SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand26SoloValue READ defaultBand26SoloValue CONSTANT)
    /**
      Get band26Solo
    */
    bool band26Solo() const
    {
      return mBand26Solo;
    }

    /**
      Is band26Solo Immutable
    */
    bool isBand26SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band26Solo" ) );
    }

    /**
      Get band26Solo default value
    */
    bool defaultBand26SoloValue() const
    {
        return defaultBand26SoloValue_helper();
    }

    /**
      Set band27Solo
    */
    void setBand27Solo( bool v )
    {
      if (v != mBand27Solo && !isBand27SoloImmutable()) {
        mBand27Solo = v;
        Q_EMIT band27SoloChanged();
      }
    }

    Q_PROPERTY(bool band27Solo READ band27Solo WRITE setBand27Solo NOTIFY band27SoloChanged)
    Q_PROPERTY(bool isBand27SoloImmutable READ isBand27SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand27SoloValue READ defaultBand27SoloValue CONSTANT)
    /**
      Get band27Solo
    */
    bool band27Solo() const
    {
      return mBand27Solo;
    }

    /**
      Is band27Solo Immutable
    */
    bool isBand27SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band27Solo" ) );
    }

    /**
      Get band27Solo default value
    */
    bool defaultBand27SoloValue() const
    {
        return defaultBand27SoloValue_helper();
    }

    /**
      Set band28Solo
    */
    void setBand28Solo( bool v )
    {
      if (v != mBand28Solo && !isBand28SoloImmutable()) {
        mBand28Solo = v;
        Q_EMIT band28SoloChanged();
      }
    }

    Q_PROPERTY(bool band28Solo READ band28Solo WRITE setBand28Solo NOTIFY band28SoloChanged)
    Q_PROPERTY(bool isBand28SoloImmutable READ isBand28SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand28SoloValue READ defaultBand28SoloValue CONSTANT)
    /**
      Get band28Solo
    */
    bool band28Solo() const
    {
      return mBand28Solo;
    }

    /**
      Is band28Solo Immutable
    */
    bool isBand28SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band28Solo" ) );
    }

    /**
      Get band28Solo default value
    */
    bool defaultBand28SoloValue() const
    {
        return defaultBand28SoloValue_helper();
    }

    /**
      Set band29Solo
    */
    void setBand29Solo( bool v )
    {
      if (v != mBand29Solo && !isBand29SoloImmutable()) {
        mBand29Solo = v;
        Q_EMIT band29SoloChanged();
      }
    }

    Q_PROPERTY(bool band29Solo READ band29Solo WRITE setBand29Solo NOTIFY band29SoloChanged)
    Q_PROPERTY(bool isBand29SoloImmutable READ isBand29SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand29SoloValue READ defaultBand29SoloValue CONSTANT)
    /**
      Get band29Solo
    */
    bool band29Solo() const
    {
      return mBand29Solo;
    }

    /**
      Is band29Solo Immutable
    */
    bool isBand29SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band29Solo" ) );
    }

    /**
      Get band29Solo default value
    */
    bool defaultBand29SoloValue() const
    {
        return defaultBand29SoloValue_helper();
    }

    /**
      Set band30Solo
    */
    void setBand30Solo( bool v )
    {
      if (v != mBand30Solo && !isBand30SoloImmutable()) {
        mBand30Solo = v;
        Q_EMIT band30SoloChanged();
      }
    }

    Q_PROPERTY(bool band30Solo READ band30Solo WRITE setBand30Solo NOTIFY band30SoloChanged)
    Q_PROPERTY(bool isBand30SoloImmutable READ isBand30SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand30SoloValue READ defaultBand30SoloValue CONSTANT)
    /**
      Get band30Solo
    */
    bool band30Solo() const
    {
      return mBand30Solo;
    }

    /**
      Is band30Solo Immutable
    */
    bool isBand30SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band30Solo" ) );
    }

    /**
      Get band30Solo default value
    */
    bool defaultBand30SoloValue() const
    {
        return defaultBand30SoloValue_helper();
    }

    /**
      Set band31Solo
    */
    void setBand31Solo( bool v )
    {
      if (v != mBand31Solo && !isBand31SoloImmutable()) {
        mBand31Solo = v;
        Q_EMIT band31SoloChanged();
      }
    }

    Q_PROPERTY(bool band31Solo READ band31Solo WRITE setBand31Solo NOTIFY band31SoloChanged)
    Q_PROPERTY(bool isBand31SoloImmutable READ isBand31SoloImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand31SoloValue READ defaultBand31SoloValue CONSTANT)
    /**
      Get band31Solo
    */
    bool band31Solo() const
    {
      return mBand31Solo;
    }

    /**
      Is band31Solo Immutable
    */
    bool isBand31SoloImmutable() const
    {
      return isImmutable( QStringLiteral( "band31Solo" ) );
    }

    /**
      Get band31Solo default value
    */
    bool defaultBand31SoloValue() const
    {
        return defaultBand31SoloValue_helper();
    }

    /**
      Set band0Mute
    */
    void setBand0Mute( bool v )
    {
      if (v != mBand0Mute && !isBand0MuteImmutable()) {
        mBand0Mute = v;
        Q_EMIT band0MuteChanged();
      }
    }

    Q_PROPERTY(bool band0Mute READ band0Mute WRITE setBand0Mute NOTIFY band0MuteChanged)
    Q_PROPERTY(bool isBand0MuteImmutable READ isBand0MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand0MuteValue READ defaultBand0MuteValue CONSTANT)
    /**
      Get band0Mute
    */
    bool band0Mute() const
    {
      return mBand0Mute;
    }

    /**
      Is band0Mute Immutable
    */
    bool isBand0MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band0Mute" ) );
    }

    /**
      Get band0Mute default value
    */
    bool defaultBand0MuteValue() const
    {
        return defaultBand0MuteValue_helper();
    }

    /**
      Set band1Mute
    */
    void setBand1Mute( bool v )
    {
      if (v != mBand1Mute && !isBand1MuteImmutable()) {
        mBand1Mute = v;
        Q_EMIT band1MuteChanged();
      }
    }

    Q_PROPERTY(bool band1Mute READ band1Mute WRITE setBand1Mute NOTIFY band1MuteChanged)
    Q_PROPERTY(bool isBand1MuteImmutable READ isBand1MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand1MuteValue READ defaultBand1MuteValue CONSTANT)
    /**
      Get band1Mute
    */
    bool band1Mute() const
    {
      return mBand1Mute;
    }

    /**
      Is band1Mute Immutable
    */
    bool isBand1MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band1Mute" ) );
    }

    /**
      Get band1Mute default value
    */
    bool defaultBand1MuteValue() const
    {
        return defaultBand1MuteValue_helper();
    }

    /**
      Set band2Mute
    */
    void setBand2Mute( bool v )
    {
      if (v != mBand2Mute && !isBand2MuteImmutable()) {
        mBand2Mute = v;
        Q_EMIT band2MuteChanged();
      }
    }

    Q_PROPERTY(bool band2Mute READ band2Mute WRITE setBand2Mute NOTIFY band2MuteChanged)
    Q_PROPERTY(bool isBand2MuteImmutable READ isBand2MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand2MuteValue READ defaultBand2MuteValue CONSTANT)
    /**
      Get band2Mute
    */
    bool band2Mute() const
    {
      return mBand2Mute;
    }

    /**
      Is band2Mute Immutable
    */
    bool isBand2MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band2Mute" ) );
    }

    /**
      Get band2Mute default value
    */
    bool defaultBand2MuteValue() const
    {
        return defaultBand2MuteValue_helper();
    }

    /**
      Set band3Mute
    */
    void setBand3Mute( bool v )
    {
      if (v != mBand3Mute && !isBand3MuteImmutable()) {
        mBand3Mute = v;
        Q_EMIT band3MuteChanged();
      }
    }

    Q_PROPERTY(bool band3Mute READ band3Mute WRITE setBand3Mute NOTIFY band3MuteChanged)
    Q_PROPERTY(bool isBand3MuteImmutable READ isBand3MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand3MuteValue READ defaultBand3MuteValue CONSTANT)
    /**
      Get band3Mute
    */
    bool band3Mute() const
    {
      return mBand3Mute;
    }

    /**
      Is band3Mute Immutable
    */
    bool isBand3MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band3Mute" ) );
    }

    /**
      Get band3Mute default value
    */
    bool defaultBand3MuteValue() const
    {
        return defaultBand3MuteValue_helper();
    }

    /**
      Set band4Mute
    */
    void setBand4Mute( bool v )
    {
      if (v != mBand4Mute && !isBand4MuteImmutable()) {
        mBand4Mute = v;
        Q_EMIT band4MuteChanged();
      }
    }

    Q_PROPERTY(bool band4Mute READ band4Mute WRITE setBand4Mute NOTIFY band4MuteChanged)
    Q_PROPERTY(bool isBand4MuteImmutable READ isBand4MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand4MuteValue READ defaultBand4MuteValue CONSTANT)
    /**
      Get band4Mute
    */
    bool band4Mute() const
    {
      return mBand4Mute;
    }

    /**
      Is band4Mute Immutable
    */
    bool isBand4MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band4Mute" ) );
    }

    /**
      Get band4Mute default value
    */
    bool defaultBand4MuteValue() const
    {
        return defaultBand4MuteValue_helper();
    }

    /**
      Set band5Mute
    */
    void setBand5Mute( bool v )
    {
      if (v != mBand5Mute && !isBand5MuteImmutable()) {
        mBand5Mute = v;
        Q_EMIT band5MuteChanged();
      }
    }

    Q_PROPERTY(bool band5Mute READ band5Mute WRITE setBand5Mute NOTIFY band5MuteChanged)
    Q_PROPERTY(bool isBand5MuteImmutable READ isBand5MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand5MuteValue READ defaultBand5MuteValue CONSTANT)
    /**
      Get band5Mute
    */
    bool band5Mute() const
    {
      return mBand5Mute;
    }

    /**
      Is band5Mute Immutable
    */
    bool isBand5MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band5Mute" ) );
    }

    /**
      Get band5Mute default value
    */
    bool defaultBand5MuteValue() const
    {
        return defaultBand5MuteValue_helper();
    }

    /**
      Set band6Mute
    */
    void setBand6Mute( bool v )
    {
      if (v != mBand6Mute && !isBand6MuteImmutable()) {
        mBand6Mute = v;
        Q_EMIT band6MuteChanged();
      }
    }

    Q_PROPERTY(bool band6Mute READ band6Mute WRITE setBand6Mute NOTIFY band6MuteChanged)
    Q_PROPERTY(bool isBand6MuteImmutable READ isBand6MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand6MuteValue READ defaultBand6MuteValue CONSTANT)
    /**
      Get band6Mute
    */
    bool band6Mute() const
    {
      return mBand6Mute;
    }

    /**
      Is band6Mute Immutable
    */
    bool isBand6MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band6Mute" ) );
    }

    /**
      Get band6Mute default value
    */
    bool defaultBand6MuteValue() const
    {
        return defaultBand6MuteValue_helper();
    }

    /**
      Set band7Mute
    */
    void setBand7Mute( bool v )
    {
      if (v != mBand7Mute && !isBand7MuteImmutable()) {
        mBand7Mute = v;
        Q_EMIT band7MuteChanged();
      }
    }

    Q_PROPERTY(bool band7Mute READ band7Mute WRITE setBand7Mute NOTIFY band7MuteChanged)
    Q_PROPERTY(bool isBand7MuteImmutable READ isBand7MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand7MuteValue READ defaultBand7MuteValue CONSTANT)
    /**
      Get band7Mute
    */
    bool band7Mute() const
    {
      return mBand7Mute;
    }

    /**
      Is band7Mute Immutable
    */
    bool isBand7MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band7Mute" ) );
    }

    /**
      Get band7Mute default value
    */
    bool defaultBand7MuteValue() const
    {
        return defaultBand7MuteValue_helper();
    }

    /**
      Set band8Mute
    */
    void setBand8Mute( bool v )
    {
      if (v != mBand8Mute && !isBand8MuteImmutable()) {
        mBand8Mute = v;
        Q_EMIT band8MuteChanged();
      }
    }

    Q_PROPERTY(bool band8Mute READ band8Mute WRITE setBand8Mute NOTIFY band8MuteChanged)
    Q_PROPERTY(bool isBand8MuteImmutable READ isBand8MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand8MuteValue READ defaultBand8MuteValue CONSTANT)
    /**
      Get band8Mute
    */
    bool band8Mute() const
    {
      return mBand8Mute;
    }

    /**
      Is band8Mute Immutable
    */
    bool isBand8MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band8Mute" ) );
    }

    /**
      Get band8Mute default value
    */
    bool defaultBand8MuteValue() const
    {
        return defaultBand8MuteValue_helper();
    }

    /**
      Set band9Mute
    */
    void setBand9Mute( bool v )
    {
      if (v != mBand9Mute && !isBand9MuteImmutable()) {
        mBand9Mute = v;
        Q_EMIT band9MuteChanged();
      }
    }

    Q_PROPERTY(bool band9Mute READ band9Mute WRITE setBand9Mute NOTIFY band9MuteChanged)
    Q_PROPERTY(bool isBand9MuteImmutable READ isBand9MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand9MuteValue READ defaultBand9MuteValue CONSTANT)
    /**
      Get band9Mute
    */
    bool band9Mute() const
    {
      return mBand9Mute;
    }

    /**
      Is band9Mute Immutable
    */
    bool isBand9MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band9Mute" ) );
    }

    /**
      Get band9Mute default value
    */
    bool defaultBand9MuteValue() const
    {
        return defaultBand9MuteValue_helper();
    }

    /**
      Set band10Mute
    */
    void setBand10Mute( bool v )
    {
      if (v != mBand10Mute && !isBand10MuteImmutable()) {
        mBand10Mute = v;
        Q_EMIT band10MuteChanged();
      }
    }

    Q_PROPERTY(bool band10Mute READ band10Mute WRITE setBand10Mute NOTIFY band10MuteChanged)
    Q_PROPERTY(bool isBand10MuteImmutable READ isBand10MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand10MuteValue READ defaultBand10MuteValue CONSTANT)
    /**
      Get band10Mute
    */
    bool band10Mute() const
    {
      return mBand10Mute;
    }

    /**
      Is band10Mute Immutable
    */
    bool isBand10MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band10Mute" ) );
    }

    /**
      Get band10Mute default value
    */
    bool defaultBand10MuteValue() const
    {
        return defaultBand10MuteValue_helper();
    }

    /**
      Set band11Mute
    */
    void setBand11Mute( bool v )
    {
      if (v != mBand11Mute && !isBand11MuteImmutable()) {
        mBand11Mute = v;
        Q_EMIT band11MuteChanged();
      }
    }

    Q_PROPERTY(bool band11Mute READ band11Mute WRITE setBand11Mute NOTIFY band11MuteChanged)
    Q_PROPERTY(bool isBand11MuteImmutable READ isBand11MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand11MuteValue READ defaultBand11MuteValue CONSTANT)
    /**
      Get band11Mute
    */
    bool band11Mute() const
    {
      return mBand11Mute;
    }

    /**
      Is band11Mute Immutable
    */
    bool isBand11MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band11Mute" ) );
    }

    /**
      Get band11Mute default value
    */
    bool defaultBand11MuteValue() const
    {
        return defaultBand11MuteValue_helper();
    }

    /**
      Set band12Mute
    */
    void setBand12Mute( bool v )
    {
      if (v != mBand12Mute && !isBand12MuteImmutable()) {
        mBand12Mute = v;
        Q_EMIT band12MuteChanged();
      }
    }

    Q_PROPERTY(bool band12Mute READ band12Mute WRITE setBand12Mute NOTIFY band12MuteChanged)
    Q_PROPERTY(bool isBand12MuteImmutable READ isBand12MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand12MuteValue READ defaultBand12MuteValue CONSTANT)
    /**
      Get band12Mute
    */
    bool band12Mute() const
    {
      return mBand12Mute;
    }

    /**
      Is band12Mute Immutable
    */
    bool isBand12MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band12Mute" ) );
    }

    /**
      Get band12Mute default value
    */
    bool defaultBand12MuteValue() const
    {
        return defaultBand12MuteValue_helper();
    }

    /**
      Set band13Mute
    */
    void setBand13Mute( bool v )
    {
      if (v != mBand13Mute && !isBand13MuteImmutable()) {
        mBand13Mute = v;
        Q_EMIT band13MuteChanged();
      }
    }

    Q_PROPERTY(bool band13Mute READ band13Mute WRITE setBand13Mute NOTIFY band13MuteChanged)
    Q_PROPERTY(bool isBand13MuteImmutable READ isBand13MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand13MuteValue READ defaultBand13MuteValue CONSTANT)
    /**
      Get band13Mute
    */
    bool band13Mute() const
    {
      return mBand13Mute;
    }

    /**
      Is band13Mute Immutable
    */
    bool isBand13MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band13Mute" ) );
    }

    /**
      Get band13Mute default value
    */
    bool defaultBand13MuteValue() const
    {
        return defaultBand13MuteValue_helper();
    }

    /**
      Set band14Mute
    */
    void setBand14Mute( bool v )
    {
      if (v != mBand14Mute && !isBand14MuteImmutable()) {
        mBand14Mute = v;
        Q_EMIT band14MuteChanged();
      }
    }

    Q_PROPERTY(bool band14Mute READ band14Mute WRITE setBand14Mute NOTIFY band14MuteChanged)
    Q_PROPERTY(bool isBand14MuteImmutable READ isBand14MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand14MuteValue READ defaultBand14MuteValue CONSTANT)
    /**
      Get band14Mute
    */
    bool band14Mute() const
    {
      return mBand14Mute;
    }

    /**
      Is band14Mute Immutable
    */
    bool isBand14MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band14Mute" ) );
    }

    /**
      Get band14Mute default value
    */
    bool defaultBand14MuteValue() const
    {
        return defaultBand14MuteValue_helper();
    }

    /**
      Set band15Mute
    */
    void setBand15Mute( bool v )
    {
      if (v != mBand15Mute && !isBand15MuteImmutable()) {
        mBand15Mute = v;
        Q_EMIT band15MuteChanged();
      }
    }

    Q_PROPERTY(bool band15Mute READ band15Mute WRITE setBand15Mute NOTIFY band15MuteChanged)
    Q_PROPERTY(bool isBand15MuteImmutable READ isBand15MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand15MuteValue READ defaultBand15MuteValue CONSTANT)
    /**
      Get band15Mute
    */
    bool band15Mute() const
    {
      return mBand15Mute;
    }

    /**
      Is band15Mute Immutable
    */
    bool isBand15MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band15Mute" ) );
    }

    /**
      Get band15Mute default value
    */
    bool defaultBand15MuteValue() const
    {
        return defaultBand15MuteValue_helper();
    }

    /**
      Set band16Mute
    */
    void setBand16Mute( bool v )
    {
      if (v != mBand16Mute && !isBand16MuteImmutable()) {
        mBand16Mute = v;
        Q_EMIT band16MuteChanged();
      }
    }

    Q_PROPERTY(bool band16Mute READ band16Mute WRITE setBand16Mute NOTIFY band16MuteChanged)
    Q_PROPERTY(bool isBand16MuteImmutable READ isBand16MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand16MuteValue READ defaultBand16MuteValue CONSTANT)
    /**
      Get band16Mute
    */
    bool band16Mute() const
    {
      return mBand16Mute;
    }

    /**
      Is band16Mute Immutable
    */
    bool isBand16MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band16Mute" ) );
    }

    /**
      Get band16Mute default value
    */
    bool defaultBand16MuteValue() const
    {
        return defaultBand16MuteValue_helper();
    }

    /**
      Set band17Mute
    */
    void setBand17Mute( bool v )
    {
      if (v != mBand17Mute && !isBand17MuteImmutable()) {
        mBand17Mute = v;
        Q_EMIT band17MuteChanged();
      }
    }

    Q_PROPERTY(bool band17Mute READ band17Mute WRITE setBand17Mute NOTIFY band17MuteChanged)
    Q_PROPERTY(bool isBand17MuteImmutable READ isBand17MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand17MuteValue READ defaultBand17MuteValue CONSTANT)
    /**
      Get band17Mute
    */
    bool band17Mute() const
    {
      return mBand17Mute;
    }

    /**
      Is band17Mute Immutable
    */
    bool isBand17MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band17Mute" ) );
    }

    /**
      Get band17Mute default value
    */
    bool defaultBand17MuteValue() const
    {
        return defaultBand17MuteValue_helper();
    }

    /**
      Set band18Mute
    */
    void setBand18Mute( bool v )
    {
      if (v != mBand18Mute && !isBand18MuteImmutable()) {
        mBand18Mute = v;
        Q_EMIT band18MuteChanged();
      }
    }

    Q_PROPERTY(bool band18Mute READ band18Mute WRITE setBand18Mute NOTIFY band18MuteChanged)
    Q_PROPERTY(bool isBand18MuteImmutable READ isBand18MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand18MuteValue READ defaultBand18MuteValue CONSTANT)
    /**
      Get band18Mute
    */
    bool band18Mute() const
    {
      return mBand18Mute;
    }

    /**
      Is band18Mute Immutable
    */
    bool isBand18MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band18Mute" ) );
    }

    /**
      Get band18Mute default value
    */
    bool defaultBand18MuteValue() const
    {
        return defaultBand18MuteValue_helper();
    }

    /**
      Set band19Mute
    */
    void setBand19Mute( bool v )
    {
      if (v != mBand19Mute && !isBand19MuteImmutable()) {
        mBand19Mute = v;
        Q_EMIT band19MuteChanged();
      }
    }

    Q_PROPERTY(bool band19Mute READ band19Mute WRITE setBand19Mute NOTIFY band19MuteChanged)
    Q_PROPERTY(bool isBand19MuteImmutable READ isBand19MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand19MuteValue READ defaultBand19MuteValue CONSTANT)
    /**
      Get band19Mute
    */
    bool band19Mute() const
    {
      return mBand19Mute;
    }

    /**
      Is band19Mute Immutable
    */
    bool isBand19MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band19Mute" ) );
    }

    /**
      Get band19Mute default value
    */
    bool defaultBand19MuteValue() const
    {
        return defaultBand19MuteValue_helper();
    }

    /**
      Set band20Mute
    */
    void setBand20Mute( bool v )
    {
      if (v != mBand20Mute && !isBand20MuteImmutable()) {
        mBand20Mute = v;
        Q_EMIT band20MuteChanged();
      }
    }

    Q_PROPERTY(bool band20Mute READ band20Mute WRITE setBand20Mute NOTIFY band20MuteChanged)
    Q_PROPERTY(bool isBand20MuteImmutable READ isBand20MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand20MuteValue READ defaultBand20MuteValue CONSTANT)
    /**
      Get band20Mute
    */
    bool band20Mute() const
    {
      return mBand20Mute;
    }

    /**
      Is band20Mute Immutable
    */
    bool isBand20MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band20Mute" ) );
    }

    /**
      Get band20Mute default value
    */
    bool defaultBand20MuteValue() const
    {
        return defaultBand20MuteValue_helper();
    }

    /**
      Set band21Mute
    */
    void setBand21Mute( bool v )
    {
      if (v != mBand21Mute && !isBand21MuteImmutable()) {
        mBand21Mute = v;
        Q_EMIT band21MuteChanged();
      }
    }

    Q_PROPERTY(bool band21Mute READ band21Mute WRITE setBand21Mute NOTIFY band21MuteChanged)
    Q_PROPERTY(bool isBand21MuteImmutable READ isBand21MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand21MuteValue READ defaultBand21MuteValue CONSTANT)
    /**
      Get band21Mute
    */
    bool band21Mute() const
    {
      return mBand21Mute;
    }

    /**
      Is band21Mute Immutable
    */
    bool isBand21MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band21Mute" ) );
    }

    /**
      Get band21Mute default value
    */
    bool defaultBand21MuteValue() const
    {
        return defaultBand21MuteValue_helper();
    }

    /**
      Set band22Mute
    */
    void setBand22Mute( bool v )
    {
      if (v != mBand22Mute && !isBand22MuteImmutable()) {
        mBand22Mute = v;
        Q_EMIT band22MuteChanged();
      }
    }

    Q_PROPERTY(bool band22Mute READ band22Mute WRITE setBand22Mute NOTIFY band22MuteChanged)
    Q_PROPERTY(bool isBand22MuteImmutable READ isBand22MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand22MuteValue READ defaultBand22MuteValue CONSTANT)
    /**
      Get band22Mute
    */
    bool band22Mute() const
    {
      return mBand22Mute;
    }

    /**
      Is band22Mute Immutable
    */
    bool isBand22MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band22Mute" ) );
    }

    /**
      Get band22Mute default value
    */
    bool defaultBand22MuteValue() const
    {
        return defaultBand22MuteValue_helper();
    }

    /**
      Set band23Mute
    */
    void setBand23Mute( bool v )
    {
      if (v != mBand23Mute && !isBand23MuteImmutable()) {
        mBand23Mute = v;
        Q_EMIT band23MuteChanged();
      }
    }

    Q_PROPERTY(bool band23Mute READ band23Mute WRITE setBand23Mute NOTIFY band23MuteChanged)
    Q_PROPERTY(bool isBand23MuteImmutable READ isBand23MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand23MuteValue READ defaultBand23MuteValue CONSTANT)
    /**
      Get band23Mute
    */
    bool band23Mute() const
    {
      return mBand23Mute;
    }

    /**
      Is band23Mute Immutable
    */
    bool isBand23MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band23Mute" ) );
    }

    /**
      Get band23Mute default value
    */
    bool defaultBand23MuteValue() const
    {
        return defaultBand23MuteValue_helper();
    }

    /**
      Set band24Mute
    */
    void setBand24Mute( bool v )
    {
      if (v != mBand24Mute && !isBand24MuteImmutable()) {
        mBand24Mute = v;
        Q_EMIT band24MuteChanged();
      }
    }

    Q_PROPERTY(bool band24Mute READ band24Mute WRITE setBand24Mute NOTIFY band24MuteChanged)
    Q_PROPERTY(bool isBand24MuteImmutable READ isBand24MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand24MuteValue READ defaultBand24MuteValue CONSTANT)
    /**
      Get band24Mute
    */
    bool band24Mute() const
    {
      return mBand24Mute;
    }

    /**
      Is band24Mute Immutable
    */
    bool isBand24MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band24Mute" ) );
    }

    /**
      Get band24Mute default value
    */
    bool defaultBand24MuteValue() const
    {
        return defaultBand24MuteValue_helper();
    }

    /**
      Set band25Mute
    */
    void setBand25Mute( bool v )
    {
      if (v != mBand25Mute && !isBand25MuteImmutable()) {
        mBand25Mute = v;
        Q_EMIT band25MuteChanged();
      }
    }

    Q_PROPERTY(bool band25Mute READ band25Mute WRITE setBand25Mute NOTIFY band25MuteChanged)
    Q_PROPERTY(bool isBand25MuteImmutable READ isBand25MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand25MuteValue READ defaultBand25MuteValue CONSTANT)
    /**
      Get band25Mute
    */
    bool band25Mute() const
    {
      return mBand25Mute;
    }

    /**
      Is band25Mute Immutable
    */
    bool isBand25MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band25Mute" ) );
    }

    /**
      Get band25Mute default value
    */
    bool defaultBand25MuteValue() const
    {
        return defaultBand25MuteValue_helper();
    }

    /**
      Set band26Mute
    */
    void setBand26Mute( bool v )
    {
      if (v != mBand26Mute && !isBand26MuteImmutable()) {
        mBand26Mute = v;
        Q_EMIT band26MuteChanged();
      }
    }

    Q_PROPERTY(bool band26Mute READ band26Mute WRITE setBand26Mute NOTIFY band26MuteChanged)
    Q_PROPERTY(bool isBand26MuteImmutable READ isBand26MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand26MuteValue READ defaultBand26MuteValue CONSTANT)
    /**
      Get band26Mute
    */
    bool band26Mute() const
    {
      return mBand26Mute;
    }

    /**
      Is band26Mute Immutable
    */
    bool isBand26MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band26Mute" ) );
    }

    /**
      Get band26Mute default value
    */
    bool defaultBand26MuteValue() const
    {
        return defaultBand26MuteValue_helper();
    }

    /**
      Set band27Mute
    */
    void setBand27Mute( bool v )
    {
      if (v != mBand27Mute && !isBand27MuteImmutable()) {
        mBand27Mute = v;
        Q_EMIT band27MuteChanged();
      }
    }

    Q_PROPERTY(bool band27Mute READ band27Mute WRITE setBand27Mute NOTIFY band27MuteChanged)
    Q_PROPERTY(bool isBand27MuteImmutable READ isBand27MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand27MuteValue READ defaultBand27MuteValue CONSTANT)
    /**
      Get band27Mute
    */
    bool band27Mute() const
    {
      return mBand27Mute;
    }

    /**
      Is band27Mute Immutable
    */
    bool isBand27MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band27Mute" ) );
    }

    /**
      Get band27Mute default value
    */
    bool defaultBand27MuteValue() const
    {
        return defaultBand27MuteValue_helper();
    }

    /**
      Set band28Mute
    */
    void setBand28Mute( bool v )
    {
      if (v != mBand28Mute && !isBand28MuteImmutable()) {
        mBand28Mute = v;
        Q_EMIT band28MuteChanged();
      }
    }

    Q_PROPERTY(bool band28Mute READ band28Mute WRITE setBand28Mute NOTIFY band28MuteChanged)
    Q_PROPERTY(bool isBand28MuteImmutable READ isBand28MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand28MuteValue READ defaultBand28MuteValue CONSTANT)
    /**
      Get band28Mute
    */
    bool band28Mute() const
    {
      return mBand28Mute;
    }

    /**
      Is band28Mute Immutable
    */
    bool isBand28MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band28Mute" ) );
    }

    /**
      Get band28Mute default value
    */
    bool defaultBand28MuteValue() const
    {
        return defaultBand28MuteValue_helper();
    }

    /**
      Set band29Mute
    */
    void setBand29Mute( bool v )
    {
      if (v != mBand29Mute && !isBand29MuteImmutable()) {
        mBand29Mute = v;
        Q_EMIT band29MuteChanged();
      }
    }

    Q_PROPERTY(bool band29Mute READ band29Mute WRITE setBand29Mute NOTIFY band29MuteChanged)
    Q_PROPERTY(bool isBand29MuteImmutable READ isBand29MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand29MuteValue READ defaultBand29MuteValue CONSTANT)
    /**
      Get band29Mute
    */
    bool band29Mute() const
    {
      return mBand29Mute;
    }

    /**
      Is band29Mute Immutable
    */
    bool isBand29MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band29Mute" ) );
    }

    /**
      Get band29Mute default value
    */
    bool defaultBand29MuteValue() const
    {
        return defaultBand29MuteValue_helper();
    }

    /**
      Set band30Mute
    */
    void setBand30Mute( bool v )
    {
      if (v != mBand30Mute && !isBand30MuteImmutable()) {
        mBand30Mute = v;
        Q_EMIT band30MuteChanged();
      }
    }

    Q_PROPERTY(bool band30Mute READ band30Mute WRITE setBand30Mute NOTIFY band30MuteChanged)
    Q_PROPERTY(bool isBand30MuteImmutable READ isBand30MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand30MuteValue READ defaultBand30MuteValue CONSTANT)
    /**
      Get band30Mute
    */
    bool band30Mute() const
    {
      return mBand30Mute;
    }

    /**
      Is band30Mute Immutable
    */
    bool isBand30MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band30Mute" ) );
    }

    /**
      Get band30Mute default value
    */
    bool defaultBand30MuteValue() const
    {
        return defaultBand30MuteValue_helper();
    }

    /**
      Set band31Mute
    */
    void setBand31Mute( bool v )
    {
      if (v != mBand31Mute && !isBand31MuteImmutable()) {
        mBand31Mute = v;
        Q_EMIT band31MuteChanged();
      }
    }

    Q_PROPERTY(bool band31Mute READ band31Mute WRITE setBand31Mute NOTIFY band31MuteChanged)
    Q_PROPERTY(bool isBand31MuteImmutable READ isBand31MuteImmutable CONSTANT)
    Q_PROPERTY(bool defaultBand31MuteValue READ defaultBand31MuteValue CONSTANT)
    /**
      Get band31Mute
    */
    bool band31Mute() const
    {
      return mBand31Mute;
    }

    /**
      Is band31Mute Immutable
    */
    bool isBand31MuteImmutable() const
    {
      return isImmutable( QStringLiteral( "band31Mute" ) );
    }

    /**
      Get band31Mute default value
    */
    bool defaultBand31MuteValue() const
    {
        return defaultBand31MuteValue_helper();
    }


    enum {
      signalBandModeLabelsChanged = 1,
      signalBandTypeLabelsChanged = 2,
      signalBandSlopeLabelsChanged = 3,
      signalBand0GainChanged = 4,
      signalBand1GainChanged = 5,
      signalBand2GainChanged = 6,
      signalBand3GainChanged = 7,
      signalBand4GainChanged = 8,
      signalBand5GainChanged = 9,
      signalBand6GainChanged = 10,
      signalBand7GainChanged = 11,
      signalBand8GainChanged = 12,
      signalBand9GainChanged = 13,
      signalBand10GainChanged = 14,
      signalBand11GainChanged = 15,
      signalBand12GainChanged = 16,
      signalBand13GainChanged = 17,
      signalBand14GainChanged = 18,
      signalBand15GainChanged = 19,
      signalBand16GainChanged = 20,
      signalBand17GainChanged = 21,
      signalBand18GainChanged = 22,
      signalBand19GainChanged = 23,
      signalBand20GainChanged = 24,
      signalBand21GainChanged = 25,
      signalBand22GainChanged = 26,
      signalBand23GainChanged = 27,
      signalBand24GainChanged = 28,
      signalBand25GainChanged = 29,
      signalBand26GainChanged = 30,
      signalBand27GainChanged = 31,
      signalBand28GainChanged = 32,
      signalBand29GainChanged = 33,
      signalBand30GainChanged = 34,
      signalBand31GainChanged = 35,
      signalBand0FrequencyChanged = 36,
      signalBand1FrequencyChanged = 37,
      signalBand2FrequencyChanged = 38,
      signalBand3FrequencyChanged = 39,
      signalBand4FrequencyChanged = 40,
      signalBand5FrequencyChanged = 41,
      signalBand6FrequencyChanged = 42,
      signalBand7FrequencyChanged = 43,
      signalBand8FrequencyChanged = 44,
      signalBand9FrequencyChanged = 45,
      signalBand10FrequencyChanged = 46,
      signalBand11FrequencyChanged = 47,
      signalBand12FrequencyChanged = 48,
      signalBand13FrequencyChanged = 49,
      signalBand14FrequencyChanged = 50,
      signalBand15FrequencyChanged = 51,
      signalBand16FrequencyChanged = 52,
      signalBand17FrequencyChanged = 53,
      signalBand18FrequencyChanged = 54,
      signalBand19FrequencyChanged = 55,
      signalBand20FrequencyChanged = 56,
      signalBand21FrequencyChanged = 57,
      signalBand22FrequencyChanged = 58,
      signalBand23FrequencyChanged = 59,
      signalBand24FrequencyChanged = 60,
      signalBand25FrequencyChanged = 61,
      signalBand26FrequencyChanged = 62,
      signalBand27FrequencyChanged = 63,
      signalBand28FrequencyChanged = 64,
      signalBand29FrequencyChanged = 65,
      signalBand30FrequencyChanged = 66,
      signalBand31FrequencyChanged = 67,
      signalBand0QChanged = 68,
      signalBand1QChanged = 69,
      signalBand2QChanged = 70,
      signalBand3QChanged = 71,
      signalBand4QChanged = 72,
      signalBand5QChanged = 73,
      signalBand6QChanged = 74,
      signalBand7QChanged = 75,
      signalBand8QChanged = 76,
      signalBand9QChanged = 77,
      signalBand10QChanged = 78,
      signalBand11QChanged = 79,
      signalBand12QChanged = 80,
      signalBand13QChanged = 81,
      signalBand14QChanged = 82,
      signalBand15QChanged = 83,
      signalBand16QChanged = 84,
      signalBand17QChanged = 85,
      signalBand18QChanged = 86,
      signalBand19QChanged = 87,
      signalBand20QChanged = 88,
      signalBand21QChanged = 89,
      signalBand22QChanged = 90,
      signalBand23QChanged = 91,
      signalBand24QChanged = 92,
      signalBand25QChanged = 93,
      signalBand26QChanged = 94,
      signalBand27QChanged = 95,
      signalBand28QChanged = 96,
      signalBand29QChanged = 97,
      signalBand30QChanged = 98,
      signalBand31QChanged = 99,
      signalBand0WidthChanged = 100,
      signalBand1WidthChanged = 101,
      signalBand2WidthChanged = 102,
      signalBand3WidthChanged = 103,
      signalBand4WidthChanged = 104,
      signalBand5WidthChanged = 105,
      signalBand6WidthChanged = 106,
      signalBand7WidthChanged = 107,
      signalBand8WidthChanged = 108,
      signalBand9WidthChanged = 109,
      signalBand10WidthChanged = 110,
      signalBand11WidthChanged = 111,
      signalBand12WidthChanged = 112,
      signalBand13WidthChanged = 113,
      signalBand14WidthChanged = 114,
      signalBand15WidthChanged = 115,
      signalBand16WidthChanged = 116,
      signalBand17WidthChanged = 117,
      signalBand18WidthChanged = 118,
      signalBand19WidthChanged = 119,
      signalBand20WidthChanged = 120,
      signalBand21WidthChanged = 121,
      signalBand22WidthChanged = 122,
      signalBand23WidthChanged = 123,
      signalBand24WidthChanged = 124,
      signalBand25WidthChanged = 125,
      signalBand26WidthChanged = 126,
      signalBand27WidthChanged = 127,
      signalBand28WidthChanged = 128,
      signalBand29WidthChanged = 129,
      signalBand30WidthChanged = 130,
      signalBand31WidthChanged = 131,
      signalBand0TypeChanged = 132,
      signalBand1TypeChanged = 133,
      signalBand2TypeChanged = 134,
      signalBand3TypeChanged = 135,
      signalBand4TypeChanged = 136,
      signalBand5TypeChanged = 137,
      signalBand6TypeChanged = 138,
      signalBand7TypeChanged = 139,
      signalBand8TypeChanged = 140,
      signalBand9TypeChanged = 141,
      signalBand10TypeChanged = 142,
      signalBand11TypeChanged = 143,
      signalBand12TypeChanged = 144,
      signalBand13TypeChanged = 145,
      signalBand14TypeChanged = 146,
      signalBand15TypeChanged = 147,
      signalBand16TypeChanged = 148,
      signalBand17TypeChanged = 149,
      signalBand18TypeChanged = 150,
      signalBand19TypeChanged = 151,
      signalBand20TypeChanged = 152,
      signalBand21TypeChanged = 153,
      signalBand22TypeChanged = 154,
      signalBand23TypeChanged = 155,
      signalBand24TypeChanged = 156,
      signalBand25TypeChanged = 157,
      signalBand26TypeChanged = 158,
      signalBand27TypeChanged = 159,
      signalBand28TypeChanged = 160,
      signalBand29TypeChanged = 161,
      signalBand30TypeChanged = 162,
      signalBand31TypeChanged = 163,
      signalBand0ModeChanged = 164,
      signalBand1ModeChanged = 165,
      signalBand2ModeChanged = 166,
      signalBand3ModeChanged = 167,
      signalBand4ModeChanged = 168,
      signalBand5ModeChanged = 169,
      signalBand6ModeChanged = 170,
      signalBand7ModeChanged = 171,
      signalBand8ModeChanged = 172,
      signalBand9ModeChanged = 173,
      signalBand10ModeChanged = 174,
      signalBand11ModeChanged = 175,
      signalBand12ModeChanged = 176,
      signalBand13ModeChanged = 177,
      signalBand14ModeChanged = 178,
      signalBand15ModeChanged = 179,
      signalBand16ModeChanged = 180,
      signalBand17ModeChanged = 181,
      signalBand18ModeChanged = 182,
      signalBand19ModeChanged = 183,
      signalBand20ModeChanged = 184,
      signalBand21ModeChanged = 185,
      signalBand22ModeChanged = 186,
      signalBand23ModeChanged = 187,
      signalBand24ModeChanged = 188,
      signalBand25ModeChanged = 189,
      signalBand26ModeChanged = 190,
      signalBand27ModeChanged = 191,
      signalBand28ModeChanged = 192,
      signalBand29ModeChanged = 193,
      signalBand30ModeChanged = 194,
      signalBand31ModeChanged = 195,
      signalBand0SlopeChanged = 196,
      signalBand1SlopeChanged = 197,
      signalBand2SlopeChanged = 198,
      signalBand3SlopeChanged = 199,
      signalBand4SlopeChanged = 200,
      signalBand5SlopeChanged = 201,
      signalBand6SlopeChanged = 202,
      signalBand7SlopeChanged = 203,
      signalBand8SlopeChanged = 204,
      signalBand9SlopeChanged = 205,
      signalBand10SlopeChanged = 206,
      signalBand11SlopeChanged = 207,
      signalBand12SlopeChanged = 208,
      signalBand13SlopeChanged = 209,
      signalBand14SlopeChanged = 210,
      signalBand15SlopeChanged = 211,
      signalBand16SlopeChanged = 212,
      signalBand17SlopeChanged = 213,
      signalBand18SlopeChanged = 214,
      signalBand19SlopeChanged = 215,
      signalBand20SlopeChanged = 216,
      signalBand21SlopeChanged = 217,
      signalBand22SlopeChanged = 218,
      signalBand23SlopeChanged = 219,
      signalBand24SlopeChanged = 220,
      signalBand25SlopeChanged = 221,
      signalBand26SlopeChanged = 222,
      signalBand27SlopeChanged = 223,
      signalBand28SlopeChanged = 224,
      signalBand29SlopeChanged = 225,
      signalBand30SlopeChanged = 226,
      signalBand31SlopeChanged = 227,
      signalBand0SoloChanged = 228,
      signalBand1SoloChanged = 229,
      signalBand2SoloChanged = 230,
      signalBand3SoloChanged = 231,
      signalBand4SoloChanged = 232,
      signalBand5SoloChanged = 233,
      signalBand6SoloChanged = 234,
      signalBand7SoloChanged = 235,
      signalBand8SoloChanged = 236,
      signalBand9SoloChanged = 237,
      signalBand10SoloChanged = 238,
      signalBand11SoloChanged = 239,
      signalBand12SoloChanged = 240,
      signalBand13SoloChanged = 241,
      signalBand14SoloChanged = 242,
      signalBand15SoloChanged = 243,
      signalBand16SoloChanged = 244,
      signalBand17SoloChanged = 245,
      signalBand18SoloChanged = 246,
      signalBand19SoloChanged = 247,
      signalBand20SoloChanged = 248,
      signalBand21SoloChanged = 249,
      signalBand22SoloChanged = 250,
      signalBand23SoloChanged = 251,
      signalBand24SoloChanged = 252,
      signalBand25SoloChanged = 253,
      signalBand26SoloChanged = 254,
      signalBand27SoloChanged = 255,
      signalBand28SoloChanged = 256,
      signalBand29SoloChanged = 257,
      signalBand30SoloChanged = 258,
      signalBand31SoloChanged = 259,
      signalBand0MuteChanged = 260,
      signalBand1MuteChanged = 261,
      signalBand2MuteChanged = 262,
      signalBand3MuteChanged = 263,
      signalBand4MuteChanged = 264,
      signalBand5MuteChanged = 265,
      signalBand6MuteChanged = 266,
      signalBand7MuteChanged = 267,
      signalBand8MuteChanged = 268,
      signalBand9MuteChanged = 269,
      signalBand10MuteChanged = 270,
      signalBand11MuteChanged = 271,
      signalBand12MuteChanged = 272,
      signalBand13MuteChanged = 273,
      signalBand14MuteChanged = 274,
      signalBand15MuteChanged = 275,
      signalBand16MuteChanged = 276,
      signalBand17MuteChanged = 277,
      signalBand18MuteChanged = 278,
      signalBand19MuteChanged = 279,
      signalBand20MuteChanged = 280,
      signalBand21MuteChanged = 281,
      signalBand22MuteChanged = 282,
      signalBand23MuteChanged = 283,
      signalBand24MuteChanged = 284,
      signalBand25MuteChanged = 285,
      signalBand26MuteChanged = 286,
      signalBand27MuteChanged = 287,
      signalBand28MuteChanged = 288,
      signalBand29MuteChanged = 289,
      signalBand30MuteChanged = 290,
      signalBand31MuteChanged = 291
    };

  Q_SIGNALS:
    void bandModeLabelsChanged();

    void bandTypeLabelsChanged();

    void bandSlopeLabelsChanged();

    void band0GainChanged();

    void band1GainChanged();

    void band2GainChanged();

    void band3GainChanged();

    void band4GainChanged();

    void band5GainChanged();

    void band6GainChanged();

    void band7GainChanged();

    void band8GainChanged();

    void band9GainChanged();

    void band10GainChanged();

    void band11GainChanged();

    void band12GainChanged();

    void band13GainChanged();

    void band14GainChanged();

    void band15GainChanged();

    void band16GainChanged();

    void band17GainChanged();

    void band18GainChanged();

    void band19GainChanged();

    void band20GainChanged();

    void band21GainChanged();

    void band22GainChanged();

    void band23GainChanged();

    void band24GainChanged();

    void band25GainChanged();

    void band26GainChanged();

    void band27GainChanged();

    void band28GainChanged();

    void band29GainChanged();

    void band30GainChanged();

    void band31GainChanged();

    void band0FrequencyChanged();

    void band1FrequencyChanged();

    void band2FrequencyChanged();

    void band3FrequencyChanged();

    void band4FrequencyChanged();

    void band5FrequencyChanged();

    void band6FrequencyChanged();

    void band7FrequencyChanged();

    void band8FrequencyChanged();

    void band9FrequencyChanged();

    void band10FrequencyChanged();

    void band11FrequencyChanged();

    void band12FrequencyChanged();

    void band13FrequencyChanged();

    void band14FrequencyChanged();

    void band15FrequencyChanged();

    void band16FrequencyChanged();

    void band17FrequencyChanged();

    void band18FrequencyChanged();

    void band19FrequencyChanged();

    void band20FrequencyChanged();

    void band21FrequencyChanged();

    void band22FrequencyChanged();

    void band23FrequencyChanged();

    void band24FrequencyChanged();

    void band25FrequencyChanged();

    void band26FrequencyChanged();

    void band27FrequencyChanged();

    void band28FrequencyChanged();

    void band29FrequencyChanged();

    void band30FrequencyChanged();

    void band31FrequencyChanged();

    void band0QChanged();

    void band1QChanged();

    void band2QChanged();

    void band3QChanged();

    void band4QChanged();

    void band5QChanged();

    void band6QChanged();

    void band7QChanged();

    void band8QChanged();

    void band9QChanged();

    void band10QChanged();

    void band11QChanged();

    void band12QChanged();

    void band13QChanged();

    void band14QChanged();

    void band15QChanged();

    void band16QChanged();

    void band17QChanged();

    void band18QChanged();

    void band19QChanged();

    void band20QChanged();

    void band21QChanged();

    void band22QChanged();

    void band23QChanged();

    void band24QChanged();

    void band25QChanged();

    void band26QChanged();

    void band27QChanged();

    void band28QChanged();

    void band29QChanged();

    void band30QChanged();

    void band31QChanged();

    void band0WidthChanged();

    void band1WidthChanged();

    void band2WidthChanged();

    void band3WidthChanged();

    void band4WidthChanged();

    void band5WidthChanged();

    void band6WidthChanged();

    void band7WidthChanged();

    void band8WidthChanged();

    void band9WidthChanged();

    void band10WidthChanged();

    void band11WidthChanged();

    void band12WidthChanged();

    void band13WidthChanged();

    void band14WidthChanged();

    void band15WidthChanged();

    void band16WidthChanged();

    void band17WidthChanged();

    void band18WidthChanged();

    void band19WidthChanged();

    void band20WidthChanged();

    void band21WidthChanged();

    void band22WidthChanged();

    void band23WidthChanged();

    void band24WidthChanged();

    void band25WidthChanged();

    void band26WidthChanged();

    void band27WidthChanged();

    void band28WidthChanged();

    void band29WidthChanged();

    void band30WidthChanged();

    void band31WidthChanged();

    void band0TypeChanged();

    void band1TypeChanged();

    void band2TypeChanged();

    void band3TypeChanged();

    void band4TypeChanged();

    void band5TypeChanged();

    void band6TypeChanged();

    void band7TypeChanged();

    void band8TypeChanged();

    void band9TypeChanged();

    void band10TypeChanged();

    void band11TypeChanged();

    void band12TypeChanged();

    void band13TypeChanged();

    void band14TypeChanged();

    void band15TypeChanged();

    void band16TypeChanged();

    void band17TypeChanged();

    void band18TypeChanged();

    void band19TypeChanged();

    void band20TypeChanged();

    void band21TypeChanged();

    void band22TypeChanged();

    void band23TypeChanged();

    void band24TypeChanged();

    void band25TypeChanged();

    void band26TypeChanged();

    void band27TypeChanged();

    void band28TypeChanged();

    void band29TypeChanged();

    void band30TypeChanged();

    void band31TypeChanged();

    void band0ModeChanged();

    void band1ModeChanged();

    void band2ModeChanged();

    void band3ModeChanged();

    void band4ModeChanged();

    void band5ModeChanged();

    void band6ModeChanged();

    void band7ModeChanged();

    void band8ModeChanged();

    void band9ModeChanged();

    void band10ModeChanged();

    void band11ModeChanged();

    void band12ModeChanged();

    void band13ModeChanged();

    void band14ModeChanged();

    void band15ModeChanged();

    void band16ModeChanged();

    void band17ModeChanged();

    void band18ModeChanged();

    void band19ModeChanged();

    void band20ModeChanged();

    void band21ModeChanged();

    void band22ModeChanged();

    void band23ModeChanged();

    void band24ModeChanged();

    void band25ModeChanged();

    void band26ModeChanged();

    void band27ModeChanged();

    void band28ModeChanged();

    void band29ModeChanged();

    void band30ModeChanged();

    void band31ModeChanged();

    void band0SlopeChanged();

    void band1SlopeChanged();

    void band2SlopeChanged();

    void band3SlopeChanged();

    void band4SlopeChanged();

    void band5SlopeChanged();

    void band6SlopeChanged();

    void band7SlopeChanged();

    void band8SlopeChanged();

    void band9SlopeChanged();

    void band10SlopeChanged();

    void band11SlopeChanged();

    void band12SlopeChanged();

    void band13SlopeChanged();

    void band14SlopeChanged();

    void band15SlopeChanged();

    void band16SlopeChanged();

    void band17SlopeChanged();

    void band18SlopeChanged();

    void band19SlopeChanged();

    void band20SlopeChanged();

    void band21SlopeChanged();

    void band22SlopeChanged();

    void band23SlopeChanged();

    void band24SlopeChanged();

    void band25SlopeChanged();

    void band26SlopeChanged();

    void band27SlopeChanged();

    void band28SlopeChanged();

    void band29SlopeChanged();

    void band30SlopeChanged();

    void band31SlopeChanged();

    void band0SoloChanged();

    void band1SoloChanged();

    void band2SoloChanged();

    void band3SoloChanged();

    void band4SoloChanged();

    void band5SoloChanged();

    void band6SoloChanged();

    void band7SoloChanged();

    void band8SoloChanged();

    void band9SoloChanged();

    void band10SoloChanged();

    void band11SoloChanged();

    void band12SoloChanged();

    void band13SoloChanged();

    void band14SoloChanged();

    void band15SoloChanged();

    void band16SoloChanged();

    void band17SoloChanged();

    void band18SoloChanged();

    void band19SoloChanged();

    void band20SoloChanged();

    void band21SoloChanged();

    void band22SoloChanged();

    void band23SoloChanged();

    void band24SoloChanged();

    void band25SoloChanged();

    void band26SoloChanged();

    void band27SoloChanged();

    void band28SoloChanged();

    void band29SoloChanged();

    void band30SoloChanged();

    void band31SoloChanged();

    void band0MuteChanged();

    void band1MuteChanged();

    void band2MuteChanged();

    void band3MuteChanged();

    void band4MuteChanged();

    void band5MuteChanged();

    void band6MuteChanged();

    void band7MuteChanged();

    void band8MuteChanged();

    void band9MuteChanged();

    void band10MuteChanged();

    void band11MuteChanged();

    void band12MuteChanged();

    void band13MuteChanged();

    void band14MuteChanged();

    void band15MuteChanged();

    void band16MuteChanged();

    void band17MuteChanged();

    void band18MuteChanged();

    void band19MuteChanged();

    void band20MuteChanged();

    void band21MuteChanged();

    void band22MuteChanged();

    void band23MuteChanged();

    void band24MuteChanged();

    void band25MuteChanged();

    void band26MuteChanged();

    void band27MuteChanged();

    void band28MuteChanged();

    void band29MuteChanged();

    void band30MuteChanged();

    void band31MuteChanged();

  private:
    void itemChanged(quint64 signalFlag);

  protected:
    QString mParammasterGroup;
    QString mParaminstanceIndex;
    QString mParamchannel;

    // Equalizer#$(instanceIndex)#$(channel)
    QStringList mBandModeLabels;
    QStringList defaultBandModeLabelsValue_helper() const;
    QStringList mBandTypeLabels;
    QStringList defaultBandTypeLabelsValue_helper() const;
    QStringList mBandSlopeLabels;
    QStringList defaultBandSlopeLabelsValue_helper() const;
    double mBand0Gain;
    double defaultBand0GainValue_helper() const;
    double mBand1Gain;
    double defaultBand1GainValue_helper() const;
    double mBand2Gain;
    double defaultBand2GainValue_helper() const;
    double mBand3Gain;
    double defaultBand3GainValue_helper() const;
    double mBand4Gain;
    double defaultBand4GainValue_helper() const;
    double mBand5Gain;
    double defaultBand5GainValue_helper() const;
    double mBand6Gain;
    double defaultBand6GainValue_helper() const;
    double mBand7Gain;
    double defaultBand7GainValue_helper() const;
    double mBand8Gain;
    double defaultBand8GainValue_helper() const;
    double mBand9Gain;
    double defaultBand9GainValue_helper() const;
    double mBand10Gain;
    double defaultBand10GainValue_helper() const;
    double mBand11Gain;
    double defaultBand11GainValue_helper() const;
    double mBand12Gain;
    double defaultBand12GainValue_helper() const;
    double mBand13Gain;
    double defaultBand13GainValue_helper() const;
    double mBand14Gain;
    double defaultBand14GainValue_helper() const;
    double mBand15Gain;
    double defaultBand15GainValue_helper() const;
    double mBand16Gain;
    double defaultBand16GainValue_helper() const;
    double mBand17Gain;
    double defaultBand17GainValue_helper() const;
    double mBand18Gain;
    double defaultBand18GainValue_helper() const;
    double mBand19Gain;
    double defaultBand19GainValue_helper() const;
    double mBand20Gain;
    double defaultBand20GainValue_helper() const;
    double mBand21Gain;
    double defaultBand21GainValue_helper() const;
    double mBand22Gain;
    double defaultBand22GainValue_helper() const;
    double mBand23Gain;
    double defaultBand23GainValue_helper() const;
    double mBand24Gain;
    double defaultBand24GainValue_helper() const;
    double mBand25Gain;
    double defaultBand25GainValue_helper() const;
    double mBand26Gain;
    double defaultBand26GainValue_helper() const;
    double mBand27Gain;
    double defaultBand27GainValue_helper() const;
    double mBand28Gain;
    double defaultBand28GainValue_helper() const;
    double mBand29Gain;
    double defaultBand29GainValue_helper() const;
    double mBand30Gain;
    double defaultBand30GainValue_helper() const;
    double mBand31Gain;
    double defaultBand31GainValue_helper() const;
    double mBand0Frequency;
    double defaultBand0FrequencyValue_helper() const;
    double mBand1Frequency;
    double defaultBand1FrequencyValue_helper() const;
    double mBand2Frequency;
    double defaultBand2FrequencyValue_helper() const;
    double mBand3Frequency;
    double defaultBand3FrequencyValue_helper() const;
    double mBand4Frequency;
    double defaultBand4FrequencyValue_helper() const;
    double mBand5Frequency;
    double defaultBand5FrequencyValue_helper() const;
    double mBand6Frequency;
    double defaultBand6FrequencyValue_helper() const;
    double mBand7Frequency;
    double defaultBand7FrequencyValue_helper() const;
    double mBand8Frequency;
    double defaultBand8FrequencyValue_helper() const;
    double mBand9Frequency;
    double defaultBand9FrequencyValue_helper() const;
    double mBand10Frequency;
    double defaultBand10FrequencyValue_helper() const;
    double mBand11Frequency;
    double defaultBand11FrequencyValue_helper() const;
    double mBand12Frequency;
    double defaultBand12FrequencyValue_helper() const;
    double mBand13Frequency;
    double defaultBand13FrequencyValue_helper() const;
    double mBand14Frequency;
    double defaultBand14FrequencyValue_helper() const;
    double mBand15Frequency;
    double defaultBand15FrequencyValue_helper() const;
    double mBand16Frequency;
    double defaultBand16FrequencyValue_helper() const;
    double mBand17Frequency;
    double defaultBand17FrequencyValue_helper() const;
    double mBand18Frequency;
    double defaultBand18FrequencyValue_helper() const;
    double mBand19Frequency;
    double defaultBand19FrequencyValue_helper() const;
    double mBand20Frequency;
    double defaultBand20FrequencyValue_helper() const;
    double mBand21Frequency;
    double defaultBand21FrequencyValue_helper() const;
    double mBand22Frequency;
    double defaultBand22FrequencyValue_helper() const;
    double mBand23Frequency;
    double defaultBand23FrequencyValue_helper() const;
    double mBand24Frequency;
    double defaultBand24FrequencyValue_helper() const;
    double mBand25Frequency;
    double defaultBand25FrequencyValue_helper() const;
    double mBand26Frequency;
    double defaultBand26FrequencyValue_helper() const;
    double mBand27Frequency;
    double defaultBand27FrequencyValue_helper() const;
    double mBand28Frequency;
    double defaultBand28FrequencyValue_helper() const;
    double mBand29Frequency;
    double defaultBand29FrequencyValue_helper() const;
    double mBand30Frequency;
    double defaultBand30FrequencyValue_helper() const;
    double mBand31Frequency;
    double defaultBand31FrequencyValue_helper() const;
    double mBand0Q;
    double defaultBand0QValue_helper() const;
    double mBand1Q;
    double defaultBand1QValue_helper() const;
    double mBand2Q;
    double defaultBand2QValue_helper() const;
    double mBand3Q;
    double defaultBand3QValue_helper() const;
    double mBand4Q;
    double defaultBand4QValue_helper() const;
    double mBand5Q;
    double defaultBand5QValue_helper() const;
    double mBand6Q;
    double defaultBand6QValue_helper() const;
    double mBand7Q;
    double defaultBand7QValue_helper() const;
    double mBand8Q;
    double defaultBand8QValue_helper() const;
    double mBand9Q;
    double defaultBand9QValue_helper() const;
    double mBand10Q;
    double defaultBand10QValue_helper() const;
    double mBand11Q;
    double defaultBand11QValue_helper() const;
    double mBand12Q;
    double defaultBand12QValue_helper() const;
    double mBand13Q;
    double defaultBand13QValue_helper() const;
    double mBand14Q;
    double defaultBand14QValue_helper() const;
    double mBand15Q;
    double defaultBand15QValue_helper() const;
    double mBand16Q;
    double defaultBand16QValue_helper() const;
    double mBand17Q;
    double defaultBand17QValue_helper() const;
    double mBand18Q;
    double defaultBand18QValue_helper() const;
    double mBand19Q;
    double defaultBand19QValue_helper() const;
    double mBand20Q;
    double defaultBand20QValue_helper() const;
    double mBand21Q;
    double defaultBand21QValue_helper() const;
    double mBand22Q;
    double defaultBand22QValue_helper() const;
    double mBand23Q;
    double defaultBand23QValue_helper() const;
    double mBand24Q;
    double defaultBand24QValue_helper() const;
    double mBand25Q;
    double defaultBand25QValue_helper() const;
    double mBand26Q;
    double defaultBand26QValue_helper() const;
    double mBand27Q;
    double defaultBand27QValue_helper() const;
    double mBand28Q;
    double defaultBand28QValue_helper() const;
    double mBand29Q;
    double defaultBand29QValue_helper() const;
    double mBand30Q;
    double defaultBand30QValue_helper() const;
    double mBand31Q;
    double defaultBand31QValue_helper() const;
    double mBand0Width;
    double defaultBand0WidthValue_helper() const;
    double mBand1Width;
    double defaultBand1WidthValue_helper() const;
    double mBand2Width;
    double defaultBand2WidthValue_helper() const;
    double mBand3Width;
    double defaultBand3WidthValue_helper() const;
    double mBand4Width;
    double defaultBand4WidthValue_helper() const;
    double mBand5Width;
    double defaultBand5WidthValue_helper() const;
    double mBand6Width;
    double defaultBand6WidthValue_helper() const;
    double mBand7Width;
    double defaultBand7WidthValue_helper() const;
    double mBand8Width;
    double defaultBand8WidthValue_helper() const;
    double mBand9Width;
    double defaultBand9WidthValue_helper() const;
    double mBand10Width;
    double defaultBand10WidthValue_helper() const;
    double mBand11Width;
    double defaultBand11WidthValue_helper() const;
    double mBand12Width;
    double defaultBand12WidthValue_helper() const;
    double mBand13Width;
    double defaultBand13WidthValue_helper() const;
    double mBand14Width;
    double defaultBand14WidthValue_helper() const;
    double mBand15Width;
    double defaultBand15WidthValue_helper() const;
    double mBand16Width;
    double defaultBand16WidthValue_helper() const;
    double mBand17Width;
    double defaultBand17WidthValue_helper() const;
    double mBand18Width;
    double defaultBand18WidthValue_helper() const;
    double mBand19Width;
    double defaultBand19WidthValue_helper() const;
    double mBand20Width;
    double defaultBand20WidthValue_helper() const;
    double mBand21Width;
    double defaultBand21WidthValue_helper() const;
    double mBand22Width;
    double defaultBand22WidthValue_helper() const;
    double mBand23Width;
    double defaultBand23WidthValue_helper() const;
    double mBand24Width;
    double defaultBand24WidthValue_helper() const;
    double mBand25Width;
    double defaultBand25WidthValue_helper() const;
    double mBand26Width;
    double defaultBand26WidthValue_helper() const;
    double mBand27Width;
    double defaultBand27WidthValue_helper() const;
    double mBand28Width;
    double defaultBand28WidthValue_helper() const;
    double mBand29Width;
    double defaultBand29WidthValue_helper() const;
    double mBand30Width;
    double defaultBand30WidthValue_helper() const;
    double mBand31Width;
    double defaultBand31WidthValue_helper() const;
    int mBand0Type;
    int defaultBand0TypeValue_helper() const;
    int mBand1Type;
    int defaultBand1TypeValue_helper() const;
    int mBand2Type;
    int defaultBand2TypeValue_helper() const;
    int mBand3Type;
    int defaultBand3TypeValue_helper() const;
    int mBand4Type;
    int defaultBand4TypeValue_helper() const;
    int mBand5Type;
    int defaultBand5TypeValue_helper() const;
    int mBand6Type;
    int defaultBand6TypeValue_helper() const;
    int mBand7Type;
    int defaultBand7TypeValue_helper() const;
    int mBand8Type;
    int defaultBand8TypeValue_helper() const;
    int mBand9Type;
    int defaultBand9TypeValue_helper() const;
    int mBand10Type;
    int defaultBand10TypeValue_helper() const;
    int mBand11Type;
    int defaultBand11TypeValue_helper() const;
    int mBand12Type;
    int defaultBand12TypeValue_helper() const;
    int mBand13Type;
    int defaultBand13TypeValue_helper() const;
    int mBand14Type;
    int defaultBand14TypeValue_helper() const;
    int mBand15Type;
    int defaultBand15TypeValue_helper() const;
    int mBand16Type;
    int defaultBand16TypeValue_helper() const;
    int mBand17Type;
    int defaultBand17TypeValue_helper() const;
    int mBand18Type;
    int defaultBand18TypeValue_helper() const;
    int mBand19Type;
    int defaultBand19TypeValue_helper() const;
    int mBand20Type;
    int defaultBand20TypeValue_helper() const;
    int mBand21Type;
    int defaultBand21TypeValue_helper() const;
    int mBand22Type;
    int defaultBand22TypeValue_helper() const;
    int mBand23Type;
    int defaultBand23TypeValue_helper() const;
    int mBand24Type;
    int defaultBand24TypeValue_helper() const;
    int mBand25Type;
    int defaultBand25TypeValue_helper() const;
    int mBand26Type;
    int defaultBand26TypeValue_helper() const;
    int mBand27Type;
    int defaultBand27TypeValue_helper() const;
    int mBand28Type;
    int defaultBand28TypeValue_helper() const;
    int mBand29Type;
    int defaultBand29TypeValue_helper() const;
    int mBand30Type;
    int defaultBand30TypeValue_helper() const;
    int mBand31Type;
    int defaultBand31TypeValue_helper() const;
    int mBand0Mode;
    int defaultBand0ModeValue_helper() const;
    int mBand1Mode;
    int defaultBand1ModeValue_helper() const;
    int mBand2Mode;
    int defaultBand2ModeValue_helper() const;
    int mBand3Mode;
    int defaultBand3ModeValue_helper() const;
    int mBand4Mode;
    int defaultBand4ModeValue_helper() const;
    int mBand5Mode;
    int defaultBand5ModeValue_helper() const;
    int mBand6Mode;
    int defaultBand6ModeValue_helper() const;
    int mBand7Mode;
    int defaultBand7ModeValue_helper() const;
    int mBand8Mode;
    int defaultBand8ModeValue_helper() const;
    int mBand9Mode;
    int defaultBand9ModeValue_helper() const;
    int mBand10Mode;
    int defaultBand10ModeValue_helper() const;
    int mBand11Mode;
    int defaultBand11ModeValue_helper() const;
    int mBand12Mode;
    int defaultBand12ModeValue_helper() const;
    int mBand13Mode;
    int defaultBand13ModeValue_helper() const;
    int mBand14Mode;
    int defaultBand14ModeValue_helper() const;
    int mBand15Mode;
    int defaultBand15ModeValue_helper() const;
    int mBand16Mode;
    int defaultBand16ModeValue_helper() const;
    int mBand17Mode;
    int defaultBand17ModeValue_helper() const;
    int mBand18Mode;
    int defaultBand18ModeValue_helper() const;
    int mBand19Mode;
    int defaultBand19ModeValue_helper() const;
    int mBand20Mode;
    int defaultBand20ModeValue_helper() const;
    int mBand21Mode;
    int defaultBand21ModeValue_helper() const;
    int mBand22Mode;
    int defaultBand22ModeValue_helper() const;
    int mBand23Mode;
    int defaultBand23ModeValue_helper() const;
    int mBand24Mode;
    int defaultBand24ModeValue_helper() const;
    int mBand25Mode;
    int defaultBand25ModeValue_helper() const;
    int mBand26Mode;
    int defaultBand26ModeValue_helper() const;
    int mBand27Mode;
    int defaultBand27ModeValue_helper() const;
    int mBand28Mode;
    int defaultBand28ModeValue_helper() const;
    int mBand29Mode;
    int defaultBand29ModeValue_helper() const;
    int mBand30Mode;
    int defaultBand30ModeValue_helper() const;
    int mBand31Mode;
    int defaultBand31ModeValue_helper() const;
    int mBand0Slope;
    int defaultBand0SlopeValue_helper() const;
    int mBand1Slope;
    int defaultBand1SlopeValue_helper() const;
    int mBand2Slope;
    int defaultBand2SlopeValue_helper() const;
    int mBand3Slope;
    int defaultBand3SlopeValue_helper() const;
    int mBand4Slope;
    int defaultBand4SlopeValue_helper() const;
    int mBand5Slope;
    int defaultBand5SlopeValue_helper() const;
    int mBand6Slope;
    int defaultBand6SlopeValue_helper() const;
    int mBand7Slope;
    int defaultBand7SlopeValue_helper() const;
    int mBand8Slope;
    int defaultBand8SlopeValue_helper() const;
    int mBand9Slope;
    int defaultBand9SlopeValue_helper() const;
    int mBand10Slope;
    int defaultBand10SlopeValue_helper() const;
    int mBand11Slope;
    int defaultBand11SlopeValue_helper() const;
    int mBand12Slope;
    int defaultBand12SlopeValue_helper() const;
    int mBand13Slope;
    int defaultBand13SlopeValue_helper() const;
    int mBand14Slope;
    int defaultBand14SlopeValue_helper() const;
    int mBand15Slope;
    int defaultBand15SlopeValue_helper() const;
    int mBand16Slope;
    int defaultBand16SlopeValue_helper() const;
    int mBand17Slope;
    int defaultBand17SlopeValue_helper() const;
    int mBand18Slope;
    int defaultBand18SlopeValue_helper() const;
    int mBand19Slope;
    int defaultBand19SlopeValue_helper() const;
    int mBand20Slope;
    int defaultBand20SlopeValue_helper() const;
    int mBand21Slope;
    int defaultBand21SlopeValue_helper() const;
    int mBand22Slope;
    int defaultBand22SlopeValue_helper() const;
    int mBand23Slope;
    int defaultBand23SlopeValue_helper() const;
    int mBand24Slope;
    int defaultBand24SlopeValue_helper() const;
    int mBand25Slope;
    int defaultBand25SlopeValue_helper() const;
    int mBand26Slope;
    int defaultBand26SlopeValue_helper() const;
    int mBand27Slope;
    int defaultBand27SlopeValue_helper() const;
    int mBand28Slope;
    int defaultBand28SlopeValue_helper() const;
    int mBand29Slope;
    int defaultBand29SlopeValue_helper() const;
    int mBand30Slope;
    int defaultBand30SlopeValue_helper() const;
    int mBand31Slope;
    int defaultBand31SlopeValue_helper() const;
    bool mBand0Solo;
    bool defaultBand0SoloValue_helper() const;
    bool mBand1Solo;
    bool defaultBand1SoloValue_helper() const;
    bool mBand2Solo;
    bool defaultBand2SoloValue_helper() const;
    bool mBand3Solo;
    bool defaultBand3SoloValue_helper() const;
    bool mBand4Solo;
    bool defaultBand4SoloValue_helper() const;
    bool mBand5Solo;
    bool defaultBand5SoloValue_helper() const;
    bool mBand6Solo;
    bool defaultBand6SoloValue_helper() const;
    bool mBand7Solo;
    bool defaultBand7SoloValue_helper() const;
    bool mBand8Solo;
    bool defaultBand8SoloValue_helper() const;
    bool mBand9Solo;
    bool defaultBand9SoloValue_helper() const;
    bool mBand10Solo;
    bool defaultBand10SoloValue_helper() const;
    bool mBand11Solo;
    bool defaultBand11SoloValue_helper() const;
    bool mBand12Solo;
    bool defaultBand12SoloValue_helper() const;
    bool mBand13Solo;
    bool defaultBand13SoloValue_helper() const;
    bool mBand14Solo;
    bool defaultBand14SoloValue_helper() const;
    bool mBand15Solo;
    bool defaultBand15SoloValue_helper() const;
    bool mBand16Solo;
    bool defaultBand16SoloValue_helper() const;
    bool mBand17Solo;
    bool defaultBand17SoloValue_helper() const;
    bool mBand18Solo;
    bool defaultBand18SoloValue_helper() const;
    bool mBand19Solo;
    bool defaultBand19SoloValue_helper() const;
    bool mBand20Solo;
    bool defaultBand20SoloValue_helper() const;
    bool mBand21Solo;
    bool defaultBand21SoloValue_helper() const;
    bool mBand22Solo;
    bool defaultBand22SoloValue_helper() const;
    bool mBand23Solo;
    bool defaultBand23SoloValue_helper() const;
    bool mBand24Solo;
    bool defaultBand24SoloValue_helper() const;
    bool mBand25Solo;
    bool defaultBand25SoloValue_helper() const;
    bool mBand26Solo;
    bool defaultBand26SoloValue_helper() const;
    bool mBand27Solo;
    bool defaultBand27SoloValue_helper() const;
    bool mBand28Solo;
    bool defaultBand28SoloValue_helper() const;
    bool mBand29Solo;
    bool defaultBand29SoloValue_helper() const;
    bool mBand30Solo;
    bool defaultBand30SoloValue_helper() const;
    bool mBand31Solo;
    bool defaultBand31SoloValue_helper() const;
    bool mBand0Mute;
    bool defaultBand0MuteValue_helper() const;
    bool mBand1Mute;
    bool defaultBand1MuteValue_helper() const;
    bool mBand2Mute;
    bool defaultBand2MuteValue_helper() const;
    bool mBand3Mute;
    bool defaultBand3MuteValue_helper() const;
    bool mBand4Mute;
    bool defaultBand4MuteValue_helper() const;
    bool mBand5Mute;
    bool defaultBand5MuteValue_helper() const;
    bool mBand6Mute;
    bool defaultBand6MuteValue_helper() const;
    bool mBand7Mute;
    bool defaultBand7MuteValue_helper() const;
    bool mBand8Mute;
    bool defaultBand8MuteValue_helper() const;
    bool mBand9Mute;
    bool defaultBand9MuteValue_helper() const;
    bool mBand10Mute;
    bool defaultBand10MuteValue_helper() const;
    bool mBand11Mute;
    bool defaultBand11MuteValue_helper() const;
    bool mBand12Mute;
    bool defaultBand12MuteValue_helper() const;
    bool mBand13Mute;
    bool defaultBand13MuteValue_helper() const;
    bool mBand14Mute;
    bool defaultBand14MuteValue_helper() const;
    bool mBand15Mute;
    bool defaultBand15MuteValue_helper() const;
    bool mBand16Mute;
    bool defaultBand16MuteValue_helper() const;
    bool mBand17Mute;
    bool defaultBand17MuteValue_helper() const;
    bool mBand18Mute;
    bool defaultBand18MuteValue_helper() const;
    bool mBand19Mute;
    bool defaultBand19MuteValue_helper() const;
    bool mBand20Mute;
    bool defaultBand20MuteValue_helper() const;
    bool mBand21Mute;
    bool defaultBand21MuteValue_helper() const;
    bool mBand22Mute;
    bool defaultBand22MuteValue_helper() const;
    bool mBand23Mute;
    bool defaultBand23MuteValue_helper() const;
    bool mBand24Mute;
    bool defaultBand24MuteValue_helper() const;
    bool mBand25Mute;
    bool defaultBand25MuteValue_helper() const;
    bool mBand26Mute;
    bool defaultBand26MuteValue_helper() const;
    bool mBand27Mute;
    bool defaultBand27MuteValue_helper() const;
    bool mBand28Mute;
    bool defaultBand28MuteValue_helper() const;
    bool mBand29Mute;
    bool defaultBand29MuteValue_helper() const;
    bool mBand30Mute;
    bool defaultBand30MuteValue_helper() const;
    bool mBand31Mute;
    bool defaultBand31MuteValue_helper() const;
};

#endif

