/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db_equalizer_channel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db_equalizer_channel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db_equalizer_channel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18DbEqualizerChannelE_t {};
} // unnamed namespace

template <> constexpr inline auto DbEqualizerChannel::qt_create_metaobjectdata<qt_meta_tag_ZN18DbEqualizerChannelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbEqualizerChannel",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "bandModeLabelsChanged",
        "bandTypeLabelsChanged",
        "bandSlopeLabelsChanged",
        "band0GainChanged",
        "band1GainChanged",
        "band2GainChanged",
        "band3GainChanged",
        "band4GainChanged",
        "band5GainChanged",
        "band6GainChanged",
        "band7GainChanged",
        "band8GainChanged",
        "band9GainChanged",
        "band10GainChanged",
        "band11GainChanged",
        "band12GainChanged",
        "band13GainChanged",
        "band14GainChanged",
        "band15GainChanged",
        "band16GainChanged",
        "band17GainChanged",
        "band18GainChanged",
        "band19GainChanged",
        "band20GainChanged",
        "band21GainChanged",
        "band22GainChanged",
        "band23GainChanged",
        "band24GainChanged",
        "band25GainChanged",
        "band26GainChanged",
        "band27GainChanged",
        "band28GainChanged",
        "band29GainChanged",
        "band30GainChanged",
        "band31GainChanged",
        "band0FrequencyChanged",
        "band1FrequencyChanged",
        "band2FrequencyChanged",
        "band3FrequencyChanged",
        "band4FrequencyChanged",
        "band5FrequencyChanged",
        "band6FrequencyChanged",
        "band7FrequencyChanged",
        "band8FrequencyChanged",
        "band9FrequencyChanged",
        "band10FrequencyChanged",
        "band11FrequencyChanged",
        "band12FrequencyChanged",
        "band13FrequencyChanged",
        "band14FrequencyChanged",
        "band15FrequencyChanged",
        "band16FrequencyChanged",
        "band17FrequencyChanged",
        "band18FrequencyChanged",
        "band19FrequencyChanged",
        "band20FrequencyChanged",
        "band21FrequencyChanged",
        "band22FrequencyChanged",
        "band23FrequencyChanged",
        "band24FrequencyChanged",
        "band25FrequencyChanged",
        "band26FrequencyChanged",
        "band27FrequencyChanged",
        "band28FrequencyChanged",
        "band29FrequencyChanged",
        "band30FrequencyChanged",
        "band31FrequencyChanged",
        "band0QChanged",
        "band1QChanged",
        "band2QChanged",
        "band3QChanged",
        "band4QChanged",
        "band5QChanged",
        "band6QChanged",
        "band7QChanged",
        "band8QChanged",
        "band9QChanged",
        "band10QChanged",
        "band11QChanged",
        "band12QChanged",
        "band13QChanged",
        "band14QChanged",
        "band15QChanged",
        "band16QChanged",
        "band17QChanged",
        "band18QChanged",
        "band19QChanged",
        "band20QChanged",
        "band21QChanged",
        "band22QChanged",
        "band23QChanged",
        "band24QChanged",
        "band25QChanged",
        "band26QChanged",
        "band27QChanged",
        "band28QChanged",
        "band29QChanged",
        "band30QChanged",
        "band31QChanged",
        "band0WidthChanged",
        "band1WidthChanged",
        "band2WidthChanged",
        "band3WidthChanged",
        "band4WidthChanged",
        "band5WidthChanged",
        "band6WidthChanged",
        "band7WidthChanged",
        "band8WidthChanged",
        "band9WidthChanged",
        "band10WidthChanged",
        "band11WidthChanged",
        "band12WidthChanged",
        "band13WidthChanged",
        "band14WidthChanged",
        "band15WidthChanged",
        "band16WidthChanged",
        "band17WidthChanged",
        "band18WidthChanged",
        "band19WidthChanged",
        "band20WidthChanged",
        "band21WidthChanged",
        "band22WidthChanged",
        "band23WidthChanged",
        "band24WidthChanged",
        "band25WidthChanged",
        "band26WidthChanged",
        "band27WidthChanged",
        "band28WidthChanged",
        "band29WidthChanged",
        "band30WidthChanged",
        "band31WidthChanged",
        "band0TypeChanged",
        "band1TypeChanged",
        "band2TypeChanged",
        "band3TypeChanged",
        "band4TypeChanged",
        "band5TypeChanged",
        "band6TypeChanged",
        "band7TypeChanged",
        "band8TypeChanged",
        "band9TypeChanged",
        "band10TypeChanged",
        "band11TypeChanged",
        "band12TypeChanged",
        "band13TypeChanged",
        "band14TypeChanged",
        "band15TypeChanged",
        "band16TypeChanged",
        "band17TypeChanged",
        "band18TypeChanged",
        "band19TypeChanged",
        "band20TypeChanged",
        "band21TypeChanged",
        "band22TypeChanged",
        "band23TypeChanged",
        "band24TypeChanged",
        "band25TypeChanged",
        "band26TypeChanged",
        "band27TypeChanged",
        "band28TypeChanged",
        "band29TypeChanged",
        "band30TypeChanged",
        "band31TypeChanged",
        "band0ModeChanged",
        "band1ModeChanged",
        "band2ModeChanged",
        "band3ModeChanged",
        "band4ModeChanged",
        "band5ModeChanged",
        "band6ModeChanged",
        "band7ModeChanged",
        "band8ModeChanged",
        "band9ModeChanged",
        "band10ModeChanged",
        "band11ModeChanged",
        "band12ModeChanged",
        "band13ModeChanged",
        "band14ModeChanged",
        "band15ModeChanged",
        "band16ModeChanged",
        "band17ModeChanged",
        "band18ModeChanged",
        "band19ModeChanged",
        "band20ModeChanged",
        "band21ModeChanged",
        "band22ModeChanged",
        "band23ModeChanged",
        "band24ModeChanged",
        "band25ModeChanged",
        "band26ModeChanged",
        "band27ModeChanged",
        "band28ModeChanged",
        "band29ModeChanged",
        "band30ModeChanged",
        "band31ModeChanged",
        "band0SlopeChanged",
        "band1SlopeChanged",
        "band2SlopeChanged",
        "band3SlopeChanged",
        "band4SlopeChanged",
        "band5SlopeChanged",
        "band6SlopeChanged",
        "band7SlopeChanged",
        "band8SlopeChanged",
        "band9SlopeChanged",
        "band10SlopeChanged",
        "band11SlopeChanged",
        "band12SlopeChanged",
        "band13SlopeChanged",
        "band14SlopeChanged",
        "band15SlopeChanged",
        "band16SlopeChanged",
        "band17SlopeChanged",
        "band18SlopeChanged",
        "band19SlopeChanged",
        "band20SlopeChanged",
        "band21SlopeChanged",
        "band22SlopeChanged",
        "band23SlopeChanged",
        "band24SlopeChanged",
        "band25SlopeChanged",
        "band26SlopeChanged",
        "band27SlopeChanged",
        "band28SlopeChanged",
        "band29SlopeChanged",
        "band30SlopeChanged",
        "band31SlopeChanged",
        "band0SoloChanged",
        "band1SoloChanged",
        "band2SoloChanged",
        "band3SoloChanged",
        "band4SoloChanged",
        "band5SoloChanged",
        "band6SoloChanged",
        "band7SoloChanged",
        "band8SoloChanged",
        "band9SoloChanged",
        "band10SoloChanged",
        "band11SoloChanged",
        "band12SoloChanged",
        "band13SoloChanged",
        "band14SoloChanged",
        "band15SoloChanged",
        "band16SoloChanged",
        "band17SoloChanged",
        "band18SoloChanged",
        "band19SoloChanged",
        "band20SoloChanged",
        "band21SoloChanged",
        "band22SoloChanged",
        "band23SoloChanged",
        "band24SoloChanged",
        "band25SoloChanged",
        "band26SoloChanged",
        "band27SoloChanged",
        "band28SoloChanged",
        "band29SoloChanged",
        "band30SoloChanged",
        "band31SoloChanged",
        "band0MuteChanged",
        "band1MuteChanged",
        "band2MuteChanged",
        "band3MuteChanged",
        "band4MuteChanged",
        "band5MuteChanged",
        "band6MuteChanged",
        "band7MuteChanged",
        "band8MuteChanged",
        "band9MuteChanged",
        "band10MuteChanged",
        "band11MuteChanged",
        "band12MuteChanged",
        "band13MuteChanged",
        "band14MuteChanged",
        "band15MuteChanged",
        "band16MuteChanged",
        "band17MuteChanged",
        "band18MuteChanged",
        "band19MuteChanged",
        "band20MuteChanged",
        "band21MuteChanged",
        "band22MuteChanged",
        "band23MuteChanged",
        "band24MuteChanged",
        "band25MuteChanged",
        "band26MuteChanged",
        "band27MuteChanged",
        "band28MuteChanged",
        "band29MuteChanged",
        "band30MuteChanged",
        "band31MuteChanged",
        "bandModeLabels",
        "isBandModeLabelsImmutable",
        "defaultBandModeLabelsValue",
        "bandTypeLabels",
        "isBandTypeLabelsImmutable",
        "defaultBandTypeLabelsValue",
        "bandSlopeLabels",
        "isBandSlopeLabelsImmutable",
        "defaultBandSlopeLabelsValue",
        "band0Gain",
        "isBand0GainImmutable",
        "defaultBand0GainValue",
        "band1Gain",
        "isBand1GainImmutable",
        "defaultBand1GainValue",
        "band2Gain",
        "isBand2GainImmutable",
        "defaultBand2GainValue",
        "band3Gain",
        "isBand3GainImmutable",
        "defaultBand3GainValue",
        "band4Gain",
        "isBand4GainImmutable",
        "defaultBand4GainValue",
        "band5Gain",
        "isBand5GainImmutable",
        "defaultBand5GainValue",
        "band6Gain",
        "isBand6GainImmutable",
        "defaultBand6GainValue",
        "band7Gain",
        "isBand7GainImmutable",
        "defaultBand7GainValue",
        "band8Gain",
        "isBand8GainImmutable",
        "defaultBand8GainValue",
        "band9Gain",
        "isBand9GainImmutable",
        "defaultBand9GainValue",
        "band10Gain",
        "isBand10GainImmutable",
        "defaultBand10GainValue",
        "band11Gain",
        "isBand11GainImmutable",
        "defaultBand11GainValue",
        "band12Gain",
        "isBand12GainImmutable",
        "defaultBand12GainValue",
        "band13Gain",
        "isBand13GainImmutable",
        "defaultBand13GainValue",
        "band14Gain",
        "isBand14GainImmutable",
        "defaultBand14GainValue",
        "band15Gain",
        "isBand15GainImmutable",
        "defaultBand15GainValue",
        "band16Gain",
        "isBand16GainImmutable",
        "defaultBand16GainValue",
        "band17Gain",
        "isBand17GainImmutable",
        "defaultBand17GainValue",
        "band18Gain",
        "isBand18GainImmutable",
        "defaultBand18GainValue",
        "band19Gain",
        "isBand19GainImmutable",
        "defaultBand19GainValue",
        "band20Gain",
        "isBand20GainImmutable",
        "defaultBand20GainValue",
        "band21Gain",
        "isBand21GainImmutable",
        "defaultBand21GainValue",
        "band22Gain",
        "isBand22GainImmutable",
        "defaultBand22GainValue",
        "band23Gain",
        "isBand23GainImmutable",
        "defaultBand23GainValue",
        "band24Gain",
        "isBand24GainImmutable",
        "defaultBand24GainValue",
        "band25Gain",
        "isBand25GainImmutable",
        "defaultBand25GainValue",
        "band26Gain",
        "isBand26GainImmutable",
        "defaultBand26GainValue",
        "band27Gain",
        "isBand27GainImmutable",
        "defaultBand27GainValue",
        "band28Gain",
        "isBand28GainImmutable",
        "defaultBand28GainValue",
        "band29Gain",
        "isBand29GainImmutable",
        "defaultBand29GainValue",
        "band30Gain",
        "isBand30GainImmutable",
        "defaultBand30GainValue",
        "band31Gain",
        "isBand31GainImmutable",
        "defaultBand31GainValue",
        "band0Frequency",
        "isBand0FrequencyImmutable",
        "defaultBand0FrequencyValue",
        "band1Frequency",
        "isBand1FrequencyImmutable",
        "defaultBand1FrequencyValue",
        "band2Frequency",
        "isBand2FrequencyImmutable",
        "defaultBand2FrequencyValue",
        "band3Frequency",
        "isBand3FrequencyImmutable",
        "defaultBand3FrequencyValue",
        "band4Frequency",
        "isBand4FrequencyImmutable",
        "defaultBand4FrequencyValue",
        "band5Frequency",
        "isBand5FrequencyImmutable",
        "defaultBand5FrequencyValue",
        "band6Frequency",
        "isBand6FrequencyImmutable",
        "defaultBand6FrequencyValue",
        "band7Frequency",
        "isBand7FrequencyImmutable",
        "defaultBand7FrequencyValue",
        "band8Frequency",
        "isBand8FrequencyImmutable",
        "defaultBand8FrequencyValue",
        "band9Frequency",
        "isBand9FrequencyImmutable",
        "defaultBand9FrequencyValue",
        "band10Frequency",
        "isBand10FrequencyImmutable",
        "defaultBand10FrequencyValue",
        "band11Frequency",
        "isBand11FrequencyImmutable",
        "defaultBand11FrequencyValue",
        "band12Frequency",
        "isBand12FrequencyImmutable",
        "defaultBand12FrequencyValue",
        "band13Frequency",
        "isBand13FrequencyImmutable",
        "defaultBand13FrequencyValue",
        "band14Frequency",
        "isBand14FrequencyImmutable",
        "defaultBand14FrequencyValue",
        "band15Frequency",
        "isBand15FrequencyImmutable",
        "defaultBand15FrequencyValue",
        "band16Frequency",
        "isBand16FrequencyImmutable",
        "defaultBand16FrequencyValue",
        "band17Frequency",
        "isBand17FrequencyImmutable",
        "defaultBand17FrequencyValue",
        "band18Frequency",
        "isBand18FrequencyImmutable",
        "defaultBand18FrequencyValue",
        "band19Frequency",
        "isBand19FrequencyImmutable",
        "defaultBand19FrequencyValue",
        "band20Frequency",
        "isBand20FrequencyImmutable",
        "defaultBand20FrequencyValue",
        "band21Frequency",
        "isBand21FrequencyImmutable",
        "defaultBand21FrequencyValue",
        "band22Frequency",
        "isBand22FrequencyImmutable",
        "defaultBand22FrequencyValue",
        "band23Frequency",
        "isBand23FrequencyImmutable",
        "defaultBand23FrequencyValue",
        "band24Frequency",
        "isBand24FrequencyImmutable",
        "defaultBand24FrequencyValue",
        "band25Frequency",
        "isBand25FrequencyImmutable",
        "defaultBand25FrequencyValue",
        "band26Frequency",
        "isBand26FrequencyImmutable",
        "defaultBand26FrequencyValue",
        "band27Frequency",
        "isBand27FrequencyImmutable",
        "defaultBand27FrequencyValue",
        "band28Frequency",
        "isBand28FrequencyImmutable",
        "defaultBand28FrequencyValue",
        "band29Frequency",
        "isBand29FrequencyImmutable",
        "defaultBand29FrequencyValue",
        "band30Frequency",
        "isBand30FrequencyImmutable",
        "defaultBand30FrequencyValue",
        "band31Frequency",
        "isBand31FrequencyImmutable",
        "defaultBand31FrequencyValue",
        "band0Q",
        "isBand0QImmutable",
        "defaultBand0QValue",
        "band1Q",
        "isBand1QImmutable",
        "defaultBand1QValue",
        "band2Q",
        "isBand2QImmutable",
        "defaultBand2QValue",
        "band3Q",
        "isBand3QImmutable",
        "defaultBand3QValue",
        "band4Q",
        "isBand4QImmutable",
        "defaultBand4QValue",
        "band5Q",
        "isBand5QImmutable",
        "defaultBand5QValue",
        "band6Q",
        "isBand6QImmutable",
        "defaultBand6QValue",
        "band7Q",
        "isBand7QImmutable",
        "defaultBand7QValue",
        "band8Q",
        "isBand8QImmutable",
        "defaultBand8QValue",
        "band9Q",
        "isBand9QImmutable",
        "defaultBand9QValue",
        "band10Q",
        "isBand10QImmutable",
        "defaultBand10QValue",
        "band11Q",
        "isBand11QImmutable",
        "defaultBand11QValue",
        "band12Q",
        "isBand12QImmutable",
        "defaultBand12QValue",
        "band13Q",
        "isBand13QImmutable",
        "defaultBand13QValue",
        "band14Q",
        "isBand14QImmutable",
        "defaultBand14QValue",
        "band15Q",
        "isBand15QImmutable",
        "defaultBand15QValue",
        "band16Q",
        "isBand16QImmutable",
        "defaultBand16QValue",
        "band17Q",
        "isBand17QImmutable",
        "defaultBand17QValue",
        "band18Q",
        "isBand18QImmutable",
        "defaultBand18QValue",
        "band19Q",
        "isBand19QImmutable",
        "defaultBand19QValue",
        "band20Q",
        "isBand20QImmutable",
        "defaultBand20QValue",
        "band21Q",
        "isBand21QImmutable",
        "defaultBand21QValue",
        "band22Q",
        "isBand22QImmutable",
        "defaultBand22QValue",
        "band23Q",
        "isBand23QImmutable",
        "defaultBand23QValue",
        "band24Q",
        "isBand24QImmutable",
        "defaultBand24QValue",
        "band25Q",
        "isBand25QImmutable",
        "defaultBand25QValue",
        "band26Q",
        "isBand26QImmutable",
        "defaultBand26QValue",
        "band27Q",
        "isBand27QImmutable",
        "defaultBand27QValue",
        "band28Q",
        "isBand28QImmutable",
        "defaultBand28QValue",
        "band29Q",
        "isBand29QImmutable",
        "defaultBand29QValue",
        "band30Q",
        "isBand30QImmutable",
        "defaultBand30QValue",
        "band31Q",
        "isBand31QImmutable",
        "defaultBand31QValue",
        "band0Width",
        "isBand0WidthImmutable",
        "defaultBand0WidthValue",
        "band1Width",
        "isBand1WidthImmutable",
        "defaultBand1WidthValue",
        "band2Width",
        "isBand2WidthImmutable",
        "defaultBand2WidthValue",
        "band3Width",
        "isBand3WidthImmutable",
        "defaultBand3WidthValue",
        "band4Width",
        "isBand4WidthImmutable",
        "defaultBand4WidthValue",
        "band5Width",
        "isBand5WidthImmutable",
        "defaultBand5WidthValue",
        "band6Width",
        "isBand6WidthImmutable",
        "defaultBand6WidthValue",
        "band7Width",
        "isBand7WidthImmutable",
        "defaultBand7WidthValue",
        "band8Width",
        "isBand8WidthImmutable",
        "defaultBand8WidthValue",
        "band9Width",
        "isBand9WidthImmutable",
        "defaultBand9WidthValue",
        "band10Width",
        "isBand10WidthImmutable",
        "defaultBand10WidthValue",
        "band11Width",
        "isBand11WidthImmutable",
        "defaultBand11WidthValue",
        "band12Width",
        "isBand12WidthImmutable",
        "defaultBand12WidthValue",
        "band13Width",
        "isBand13WidthImmutable",
        "defaultBand13WidthValue",
        "band14Width",
        "isBand14WidthImmutable",
        "defaultBand14WidthValue",
        "band15Width",
        "isBand15WidthImmutable",
        "defaultBand15WidthValue",
        "band16Width",
        "isBand16WidthImmutable",
        "defaultBand16WidthValue",
        "band17Width",
        "isBand17WidthImmutable",
        "defaultBand17WidthValue",
        "band18Width",
        "isBand18WidthImmutable",
        "defaultBand18WidthValue",
        "band19Width",
        "isBand19WidthImmutable",
        "defaultBand19WidthValue",
        "band20Width",
        "isBand20WidthImmutable",
        "defaultBand20WidthValue",
        "band21Width",
        "isBand21WidthImmutable",
        "defaultBand21WidthValue",
        "band22Width",
        "isBand22WidthImmutable",
        "defaultBand22WidthValue",
        "band23Width",
        "isBand23WidthImmutable",
        "defaultBand23WidthValue",
        "band24Width",
        "isBand24WidthImmutable",
        "defaultBand24WidthValue",
        "band25Width",
        "isBand25WidthImmutable",
        "defaultBand25WidthValue",
        "band26Width",
        "isBand26WidthImmutable",
        "defaultBand26WidthValue",
        "band27Width",
        "isBand27WidthImmutable",
        "defaultBand27WidthValue",
        "band28Width",
        "isBand28WidthImmutable",
        "defaultBand28WidthValue",
        "band29Width",
        "isBand29WidthImmutable",
        "defaultBand29WidthValue",
        "band30Width",
        "isBand30WidthImmutable",
        "defaultBand30WidthValue",
        "band31Width",
        "isBand31WidthImmutable",
        "defaultBand31WidthValue",
        "band0Type",
        "isBand0TypeImmutable",
        "defaultBand0TypeValue",
        "band1Type",
        "isBand1TypeImmutable",
        "defaultBand1TypeValue",
        "band2Type",
        "isBand2TypeImmutable",
        "defaultBand2TypeValue",
        "band3Type",
        "isBand3TypeImmutable",
        "defaultBand3TypeValue",
        "band4Type",
        "isBand4TypeImmutable",
        "defaultBand4TypeValue",
        "band5Type",
        "isBand5TypeImmutable",
        "defaultBand5TypeValue",
        "band6Type",
        "isBand6TypeImmutable",
        "defaultBand6TypeValue",
        "band7Type",
        "isBand7TypeImmutable",
        "defaultBand7TypeValue",
        "band8Type",
        "isBand8TypeImmutable",
        "defaultBand8TypeValue",
        "band9Type",
        "isBand9TypeImmutable",
        "defaultBand9TypeValue",
        "band10Type",
        "isBand10TypeImmutable",
        "defaultBand10TypeValue",
        "band11Type",
        "isBand11TypeImmutable",
        "defaultBand11TypeValue",
        "band12Type",
        "isBand12TypeImmutable",
        "defaultBand12TypeValue",
        "band13Type",
        "isBand13TypeImmutable",
        "defaultBand13TypeValue",
        "band14Type",
        "isBand14TypeImmutable",
        "defaultBand14TypeValue",
        "band15Type",
        "isBand15TypeImmutable",
        "defaultBand15TypeValue",
        "band16Type",
        "isBand16TypeImmutable",
        "defaultBand16TypeValue",
        "band17Type",
        "isBand17TypeImmutable",
        "defaultBand17TypeValue",
        "band18Type",
        "isBand18TypeImmutable",
        "defaultBand18TypeValue",
        "band19Type",
        "isBand19TypeImmutable",
        "defaultBand19TypeValue",
        "band20Type",
        "isBand20TypeImmutable",
        "defaultBand20TypeValue",
        "band21Type",
        "isBand21TypeImmutable",
        "defaultBand21TypeValue",
        "band22Type",
        "isBand22TypeImmutable",
        "defaultBand22TypeValue",
        "band23Type",
        "isBand23TypeImmutable",
        "defaultBand23TypeValue",
        "band24Type",
        "isBand24TypeImmutable",
        "defaultBand24TypeValue",
        "band25Type",
        "isBand25TypeImmutable",
        "defaultBand25TypeValue",
        "band26Type",
        "isBand26TypeImmutable",
        "defaultBand26TypeValue",
        "band27Type",
        "isBand27TypeImmutable",
        "defaultBand27TypeValue",
        "band28Type",
        "isBand28TypeImmutable",
        "defaultBand28TypeValue",
        "band29Type",
        "isBand29TypeImmutable",
        "defaultBand29TypeValue",
        "band30Type",
        "isBand30TypeImmutable",
        "defaultBand30TypeValue",
        "band31Type",
        "isBand31TypeImmutable",
        "defaultBand31TypeValue",
        "band0Mode",
        "isBand0ModeImmutable",
        "defaultBand0ModeValue",
        "band1Mode",
        "isBand1ModeImmutable",
        "defaultBand1ModeValue",
        "band2Mode",
        "isBand2ModeImmutable",
        "defaultBand2ModeValue",
        "band3Mode",
        "isBand3ModeImmutable",
        "defaultBand3ModeValue",
        "band4Mode",
        "isBand4ModeImmutable",
        "defaultBand4ModeValue",
        "band5Mode",
        "isBand5ModeImmutable",
        "defaultBand5ModeValue",
        "band6Mode",
        "isBand6ModeImmutable",
        "defaultBand6ModeValue",
        "band7Mode",
        "isBand7ModeImmutable",
        "defaultBand7ModeValue",
        "band8Mode",
        "isBand8ModeImmutable",
        "defaultBand8ModeValue",
        "band9Mode",
        "isBand9ModeImmutable",
        "defaultBand9ModeValue",
        "band10Mode",
        "isBand10ModeImmutable",
        "defaultBand10ModeValue",
        "band11Mode",
        "isBand11ModeImmutable",
        "defaultBand11ModeValue",
        "band12Mode",
        "isBand12ModeImmutable",
        "defaultBand12ModeValue",
        "band13Mode",
        "isBand13ModeImmutable",
        "defaultBand13ModeValue",
        "band14Mode",
        "isBand14ModeImmutable",
        "defaultBand14ModeValue",
        "band15Mode",
        "isBand15ModeImmutable",
        "defaultBand15ModeValue",
        "band16Mode",
        "isBand16ModeImmutable",
        "defaultBand16ModeValue",
        "band17Mode",
        "isBand17ModeImmutable",
        "defaultBand17ModeValue",
        "band18Mode",
        "isBand18ModeImmutable",
        "defaultBand18ModeValue",
        "band19Mode",
        "isBand19ModeImmutable",
        "defaultBand19ModeValue",
        "band20Mode",
        "isBand20ModeImmutable",
        "defaultBand20ModeValue",
        "band21Mode",
        "isBand21ModeImmutable",
        "defaultBand21ModeValue",
        "band22Mode",
        "isBand22ModeImmutable",
        "defaultBand22ModeValue",
        "band23Mode",
        "isBand23ModeImmutable",
        "defaultBand23ModeValue",
        "band24Mode",
        "isBand24ModeImmutable",
        "defaultBand24ModeValue",
        "band25Mode",
        "isBand25ModeImmutable",
        "defaultBand25ModeValue",
        "band26Mode",
        "isBand26ModeImmutable",
        "defaultBand26ModeValue",
        "band27Mode",
        "isBand27ModeImmutable",
        "defaultBand27ModeValue",
        "band28Mode",
        "isBand28ModeImmutable",
        "defaultBand28ModeValue",
        "band29Mode",
        "isBand29ModeImmutable",
        "defaultBand29ModeValue",
        "band30Mode",
        "isBand30ModeImmutable",
        "defaultBand30ModeValue",
        "band31Mode",
        "isBand31ModeImmutable",
        "defaultBand31ModeValue",
        "band0Slope",
        "isBand0SlopeImmutable",
        "defaultBand0SlopeValue",
        "band1Slope",
        "isBand1SlopeImmutable",
        "defaultBand1SlopeValue",
        "band2Slope",
        "isBand2SlopeImmutable",
        "defaultBand2SlopeValue",
        "band3Slope",
        "isBand3SlopeImmutable",
        "defaultBand3SlopeValue",
        "band4Slope",
        "isBand4SlopeImmutable",
        "defaultBand4SlopeValue",
        "band5Slope",
        "isBand5SlopeImmutable",
        "defaultBand5SlopeValue",
        "band6Slope",
        "isBand6SlopeImmutable",
        "defaultBand6SlopeValue",
        "band7Slope",
        "isBand7SlopeImmutable",
        "defaultBand7SlopeValue",
        "band8Slope",
        "isBand8SlopeImmutable",
        "defaultBand8SlopeValue",
        "band9Slope",
        "isBand9SlopeImmutable",
        "defaultBand9SlopeValue",
        "band10Slope",
        "isBand10SlopeImmutable",
        "defaultBand10SlopeValue",
        "band11Slope",
        "isBand11SlopeImmutable",
        "defaultBand11SlopeValue",
        "band12Slope",
        "isBand12SlopeImmutable",
        "defaultBand12SlopeValue",
        "band13Slope",
        "isBand13SlopeImmutable",
        "defaultBand13SlopeValue",
        "band14Slope",
        "isBand14SlopeImmutable",
        "defaultBand14SlopeValue",
        "band15Slope",
        "isBand15SlopeImmutable",
        "defaultBand15SlopeValue",
        "band16Slope",
        "isBand16SlopeImmutable",
        "defaultBand16SlopeValue",
        "band17Slope",
        "isBand17SlopeImmutable",
        "defaultBand17SlopeValue",
        "band18Slope",
        "isBand18SlopeImmutable",
        "defaultBand18SlopeValue",
        "band19Slope",
        "isBand19SlopeImmutable",
        "defaultBand19SlopeValue",
        "band20Slope",
        "isBand20SlopeImmutable",
        "defaultBand20SlopeValue",
        "band21Slope",
        "isBand21SlopeImmutable",
        "defaultBand21SlopeValue",
        "band22Slope",
        "isBand22SlopeImmutable",
        "defaultBand22SlopeValue",
        "band23Slope",
        "isBand23SlopeImmutable",
        "defaultBand23SlopeValue",
        "band24Slope",
        "isBand24SlopeImmutable",
        "defaultBand24SlopeValue",
        "band25Slope",
        "isBand25SlopeImmutable",
        "defaultBand25SlopeValue",
        "band26Slope",
        "isBand26SlopeImmutable",
        "defaultBand26SlopeValue",
        "band27Slope",
        "isBand27SlopeImmutable",
        "defaultBand27SlopeValue",
        "band28Slope",
        "isBand28SlopeImmutable",
        "defaultBand28SlopeValue",
        "band29Slope",
        "isBand29SlopeImmutable",
        "defaultBand29SlopeValue",
        "band30Slope",
        "isBand30SlopeImmutable",
        "defaultBand30SlopeValue",
        "band31Slope",
        "isBand31SlopeImmutable",
        "defaultBand31SlopeValue",
        "band0Solo",
        "isBand0SoloImmutable",
        "defaultBand0SoloValue",
        "band1Solo",
        "isBand1SoloImmutable",
        "defaultBand1SoloValue",
        "band2Solo",
        "isBand2SoloImmutable",
        "defaultBand2SoloValue",
        "band3Solo",
        "isBand3SoloImmutable",
        "defaultBand3SoloValue",
        "band4Solo",
        "isBand4SoloImmutable",
        "defaultBand4SoloValue",
        "band5Solo",
        "isBand5SoloImmutable",
        "defaultBand5SoloValue",
        "band6Solo",
        "isBand6SoloImmutable",
        "defaultBand6SoloValue",
        "band7Solo",
        "isBand7SoloImmutable",
        "defaultBand7SoloValue",
        "band8Solo",
        "isBand8SoloImmutable",
        "defaultBand8SoloValue",
        "band9Solo",
        "isBand9SoloImmutable",
        "defaultBand9SoloValue",
        "band10Solo",
        "isBand10SoloImmutable",
        "defaultBand10SoloValue",
        "band11Solo",
        "isBand11SoloImmutable",
        "defaultBand11SoloValue",
        "band12Solo",
        "isBand12SoloImmutable",
        "defaultBand12SoloValue",
        "band13Solo",
        "isBand13SoloImmutable",
        "defaultBand13SoloValue",
        "band14Solo",
        "isBand14SoloImmutable",
        "defaultBand14SoloValue",
        "band15Solo",
        "isBand15SoloImmutable",
        "defaultBand15SoloValue",
        "band16Solo",
        "isBand16SoloImmutable",
        "defaultBand16SoloValue",
        "band17Solo",
        "isBand17SoloImmutable",
        "defaultBand17SoloValue",
        "band18Solo",
        "isBand18SoloImmutable",
        "defaultBand18SoloValue",
        "band19Solo",
        "isBand19SoloImmutable",
        "defaultBand19SoloValue",
        "band20Solo",
        "isBand20SoloImmutable",
        "defaultBand20SoloValue",
        "band21Solo",
        "isBand21SoloImmutable",
        "defaultBand21SoloValue",
        "band22Solo",
        "isBand22SoloImmutable",
        "defaultBand22SoloValue",
        "band23Solo",
        "isBand23SoloImmutable",
        "defaultBand23SoloValue",
        "band24Solo",
        "isBand24SoloImmutable",
        "defaultBand24SoloValue",
        "band25Solo",
        "isBand25SoloImmutable",
        "defaultBand25SoloValue",
        "band26Solo",
        "isBand26SoloImmutable",
        "defaultBand26SoloValue",
        "band27Solo",
        "isBand27SoloImmutable",
        "defaultBand27SoloValue",
        "band28Solo",
        "isBand28SoloImmutable",
        "defaultBand28SoloValue",
        "band29Solo",
        "isBand29SoloImmutable",
        "defaultBand29SoloValue",
        "band30Solo",
        "isBand30SoloImmutable",
        "defaultBand30SoloValue",
        "band31Solo",
        "isBand31SoloImmutable",
        "defaultBand31SoloValue",
        "band0Mute",
        "isBand0MuteImmutable",
        "defaultBand0MuteValue",
        "band1Mute",
        "isBand1MuteImmutable",
        "defaultBand1MuteValue",
        "band2Mute",
        "isBand2MuteImmutable",
        "defaultBand2MuteValue",
        "band3Mute",
        "isBand3MuteImmutable",
        "defaultBand3MuteValue",
        "band4Mute",
        "isBand4MuteImmutable",
        "defaultBand4MuteValue",
        "band5Mute",
        "isBand5MuteImmutable",
        "defaultBand5MuteValue",
        "band6Mute",
        "isBand6MuteImmutable",
        "defaultBand6MuteValue",
        "band7Mute",
        "isBand7MuteImmutable",
        "defaultBand7MuteValue",
        "band8Mute",
        "isBand8MuteImmutable",
        "defaultBand8MuteValue",
        "band9Mute",
        "isBand9MuteImmutable",
        "defaultBand9MuteValue",
        "band10Mute",
        "isBand10MuteImmutable",
        "defaultBand10MuteValue",
        "band11Mute",
        "isBand11MuteImmutable",
        "defaultBand11MuteValue",
        "band12Mute",
        "isBand12MuteImmutable",
        "defaultBand12MuteValue",
        "band13Mute",
        "isBand13MuteImmutable",
        "defaultBand13MuteValue",
        "band14Mute",
        "isBand14MuteImmutable",
        "defaultBand14MuteValue",
        "band15Mute",
        "isBand15MuteImmutable",
        "defaultBand15MuteValue",
        "band16Mute",
        "isBand16MuteImmutable",
        "defaultBand16MuteValue",
        "band17Mute",
        "isBand17MuteImmutable",
        "defaultBand17MuteValue",
        "band18Mute",
        "isBand18MuteImmutable",
        "defaultBand18MuteValue",
        "band19Mute",
        "isBand19MuteImmutable",
        "defaultBand19MuteValue",
        "band20Mute",
        "isBand20MuteImmutable",
        "defaultBand20MuteValue",
        "band21Mute",
        "isBand21MuteImmutable",
        "defaultBand21MuteValue",
        "band22Mute",
        "isBand22MuteImmutable",
        "defaultBand22MuteValue",
        "band23Mute",
        "isBand23MuteImmutable",
        "defaultBand23MuteValue",
        "band24Mute",
        "isBand24MuteImmutable",
        "defaultBand24MuteValue",
        "band25Mute",
        "isBand25MuteImmutable",
        "defaultBand25MuteValue",
        "band26Mute",
        "isBand26MuteImmutable",
        "defaultBand26MuteValue",
        "band27Mute",
        "isBand27MuteImmutable",
        "defaultBand27MuteValue",
        "band28Mute",
        "isBand28MuteImmutable",
        "defaultBand28MuteValue",
        "band29Mute",
        "isBand29MuteImmutable",
        "defaultBand29MuteValue",
        "band30Mute",
        "isBand30MuteImmutable",
        "defaultBand30MuteValue",
        "band31Mute",
        "isBand31MuteImmutable",
        "defaultBand31MuteValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bandModeLabelsChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bandTypeLabelsChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bandSlopeLabelsChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0GainChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1GainChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2GainChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3GainChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4GainChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5GainChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6GainChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7GainChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band8GainChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band9GainChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band10GainChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band11GainChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band12GainChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band13GainChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band14GainChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band15GainChanged'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band16GainChanged'
        QtMocHelpers::SignalData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band17GainChanged'
        QtMocHelpers::SignalData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band18GainChanged'
        QtMocHelpers::SignalData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band19GainChanged'
        QtMocHelpers::SignalData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band20GainChanged'
        QtMocHelpers::SignalData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band21GainChanged'
        QtMocHelpers::SignalData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band22GainChanged'
        QtMocHelpers::SignalData<void()>(32, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band23GainChanged'
        QtMocHelpers::SignalData<void()>(33, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band24GainChanged'
        QtMocHelpers::SignalData<void()>(34, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band25GainChanged'
        QtMocHelpers::SignalData<void()>(35, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band26GainChanged'
        QtMocHelpers::SignalData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band27GainChanged'
        QtMocHelpers::SignalData<void()>(37, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band28GainChanged'
        QtMocHelpers::SignalData<void()>(38, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band29GainChanged'
        QtMocHelpers::SignalData<void()>(39, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band30GainChanged'
        QtMocHelpers::SignalData<void()>(40, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band31GainChanged'
        QtMocHelpers::SignalData<void()>(41, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0FrequencyChanged'
        QtMocHelpers::SignalData<void()>(42, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1FrequencyChanged'
        QtMocHelpers::SignalData<void()>(43, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2FrequencyChanged'
        QtMocHelpers::SignalData<void()>(44, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3FrequencyChanged'
        QtMocHelpers::SignalData<void()>(45, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4FrequencyChanged'
        QtMocHelpers::SignalData<void()>(46, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5FrequencyChanged'
        QtMocHelpers::SignalData<void()>(47, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6FrequencyChanged'
        QtMocHelpers::SignalData<void()>(48, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7FrequencyChanged'
        QtMocHelpers::SignalData<void()>(49, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band8FrequencyChanged'
        QtMocHelpers::SignalData<void()>(50, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band9FrequencyChanged'
        QtMocHelpers::SignalData<void()>(51, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band10FrequencyChanged'
        QtMocHelpers::SignalData<void()>(52, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band11FrequencyChanged'
        QtMocHelpers::SignalData<void()>(53, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band12FrequencyChanged'
        QtMocHelpers::SignalData<void()>(54, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band13FrequencyChanged'
        QtMocHelpers::SignalData<void()>(55, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band14FrequencyChanged'
        QtMocHelpers::SignalData<void()>(56, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band15FrequencyChanged'
        QtMocHelpers::SignalData<void()>(57, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band16FrequencyChanged'
        QtMocHelpers::SignalData<void()>(58, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band17FrequencyChanged'
        QtMocHelpers::SignalData<void()>(59, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band18FrequencyChanged'
        QtMocHelpers::SignalData<void()>(60, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band19FrequencyChanged'
        QtMocHelpers::SignalData<void()>(61, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band20FrequencyChanged'
        QtMocHelpers::SignalData<void()>(62, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band21FrequencyChanged'
        QtMocHelpers::SignalData<void()>(63, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band22FrequencyChanged'
        QtMocHelpers::SignalData<void()>(64, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band23FrequencyChanged'
        QtMocHelpers::SignalData<void()>(65, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band24FrequencyChanged'
        QtMocHelpers::SignalData<void()>(66, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band25FrequencyChanged'
        QtMocHelpers::SignalData<void()>(67, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band26FrequencyChanged'
        QtMocHelpers::SignalData<void()>(68, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band27FrequencyChanged'
        QtMocHelpers::SignalData<void()>(69, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band28FrequencyChanged'
        QtMocHelpers::SignalData<void()>(70, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band29FrequencyChanged'
        QtMocHelpers::SignalData<void()>(71, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band30FrequencyChanged'
        QtMocHelpers::SignalData<void()>(72, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band31FrequencyChanged'
        QtMocHelpers::SignalData<void()>(73, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0QChanged'
        QtMocHelpers::SignalData<void()>(74, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1QChanged'
        QtMocHelpers::SignalData<void()>(75, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2QChanged'
        QtMocHelpers::SignalData<void()>(76, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3QChanged'
        QtMocHelpers::SignalData<void()>(77, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4QChanged'
        QtMocHelpers::SignalData<void()>(78, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5QChanged'
        QtMocHelpers::SignalData<void()>(79, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6QChanged'
        QtMocHelpers::SignalData<void()>(80, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7QChanged'
        QtMocHelpers::SignalData<void()>(81, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band8QChanged'
        QtMocHelpers::SignalData<void()>(82, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band9QChanged'
        QtMocHelpers::SignalData<void()>(83, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band10QChanged'
        QtMocHelpers::SignalData<void()>(84, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band11QChanged'
        QtMocHelpers::SignalData<void()>(85, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band12QChanged'
        QtMocHelpers::SignalData<void()>(86, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band13QChanged'
        QtMocHelpers::SignalData<void()>(87, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band14QChanged'
        QtMocHelpers::SignalData<void()>(88, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band15QChanged'
        QtMocHelpers::SignalData<void()>(89, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band16QChanged'
        QtMocHelpers::SignalData<void()>(90, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band17QChanged'
        QtMocHelpers::SignalData<void()>(91, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band18QChanged'
        QtMocHelpers::SignalData<void()>(92, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band19QChanged'
        QtMocHelpers::SignalData<void()>(93, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band20QChanged'
        QtMocHelpers::SignalData<void()>(94, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band21QChanged'
        QtMocHelpers::SignalData<void()>(95, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band22QChanged'
        QtMocHelpers::SignalData<void()>(96, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band23QChanged'
        QtMocHelpers::SignalData<void()>(97, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band24QChanged'
        QtMocHelpers::SignalData<void()>(98, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band25QChanged'
        QtMocHelpers::SignalData<void()>(99, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band26QChanged'
        QtMocHelpers::SignalData<void()>(100, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band27QChanged'
        QtMocHelpers::SignalData<void()>(101, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band28QChanged'
        QtMocHelpers::SignalData<void()>(102, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band29QChanged'
        QtMocHelpers::SignalData<void()>(103, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band30QChanged'
        QtMocHelpers::SignalData<void()>(104, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band31QChanged'
        QtMocHelpers::SignalData<void()>(105, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0WidthChanged'
        QtMocHelpers::SignalData<void()>(106, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1WidthChanged'
        QtMocHelpers::SignalData<void()>(107, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2WidthChanged'
        QtMocHelpers::SignalData<void()>(108, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3WidthChanged'
        QtMocHelpers::SignalData<void()>(109, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4WidthChanged'
        QtMocHelpers::SignalData<void()>(110, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5WidthChanged'
        QtMocHelpers::SignalData<void()>(111, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6WidthChanged'
        QtMocHelpers::SignalData<void()>(112, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7WidthChanged'
        QtMocHelpers::SignalData<void()>(113, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band8WidthChanged'
        QtMocHelpers::SignalData<void()>(114, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band9WidthChanged'
        QtMocHelpers::SignalData<void()>(115, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band10WidthChanged'
        QtMocHelpers::SignalData<void()>(116, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band11WidthChanged'
        QtMocHelpers::SignalData<void()>(117, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band12WidthChanged'
        QtMocHelpers::SignalData<void()>(118, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band13WidthChanged'
        QtMocHelpers::SignalData<void()>(119, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band14WidthChanged'
        QtMocHelpers::SignalData<void()>(120, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band15WidthChanged'
        QtMocHelpers::SignalData<void()>(121, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band16WidthChanged'
        QtMocHelpers::SignalData<void()>(122, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band17WidthChanged'
        QtMocHelpers::SignalData<void()>(123, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band18WidthChanged'
        QtMocHelpers::SignalData<void()>(124, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band19WidthChanged'
        QtMocHelpers::SignalData<void()>(125, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band20WidthChanged'
        QtMocHelpers::SignalData<void()>(126, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band21WidthChanged'
        QtMocHelpers::SignalData<void()>(127, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band22WidthChanged'
        QtMocHelpers::SignalData<void()>(128, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band23WidthChanged'
        QtMocHelpers::SignalData<void()>(129, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band24WidthChanged'
        QtMocHelpers::SignalData<void()>(130, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band25WidthChanged'
        QtMocHelpers::SignalData<void()>(131, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band26WidthChanged'
        QtMocHelpers::SignalData<void()>(132, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band27WidthChanged'
        QtMocHelpers::SignalData<void()>(133, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band28WidthChanged'
        QtMocHelpers::SignalData<void()>(134, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band29WidthChanged'
        QtMocHelpers::SignalData<void()>(135, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band30WidthChanged'
        QtMocHelpers::SignalData<void()>(136, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band31WidthChanged'
        QtMocHelpers::SignalData<void()>(137, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0TypeChanged'
        QtMocHelpers::SignalData<void()>(138, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1TypeChanged'
        QtMocHelpers::SignalData<void()>(139, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2TypeChanged'
        QtMocHelpers::SignalData<void()>(140, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3TypeChanged'
        QtMocHelpers::SignalData<void()>(141, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4TypeChanged'
        QtMocHelpers::SignalData<void()>(142, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5TypeChanged'
        QtMocHelpers::SignalData<void()>(143, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6TypeChanged'
        QtMocHelpers::SignalData<void()>(144, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7TypeChanged'
        QtMocHelpers::SignalData<void()>(145, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band8TypeChanged'
        QtMocHelpers::SignalData<void()>(146, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band9TypeChanged'
        QtMocHelpers::SignalData<void()>(147, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band10TypeChanged'
        QtMocHelpers::SignalData<void()>(148, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band11TypeChanged'
        QtMocHelpers::SignalData<void()>(149, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band12TypeChanged'
        QtMocHelpers::SignalData<void()>(150, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band13TypeChanged'
        QtMocHelpers::SignalData<void()>(151, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band14TypeChanged'
        QtMocHelpers::SignalData<void()>(152, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band15TypeChanged'
        QtMocHelpers::SignalData<void()>(153, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band16TypeChanged'
        QtMocHelpers::SignalData<void()>(154, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band17TypeChanged'
        QtMocHelpers::SignalData<void()>(155, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band18TypeChanged'
        QtMocHelpers::SignalData<void()>(156, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band19TypeChanged'
        QtMocHelpers::SignalData<void()>(157, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band20TypeChanged'
        QtMocHelpers::SignalData<void()>(158, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band21TypeChanged'
        QtMocHelpers::SignalData<void()>(159, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band22TypeChanged'
        QtMocHelpers::SignalData<void()>(160, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band23TypeChanged'
        QtMocHelpers::SignalData<void()>(161, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band24TypeChanged'
        QtMocHelpers::SignalData<void()>(162, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band25TypeChanged'
        QtMocHelpers::SignalData<void()>(163, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band26TypeChanged'
        QtMocHelpers::SignalData<void()>(164, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band27TypeChanged'
        QtMocHelpers::SignalData<void()>(165, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band28TypeChanged'
        QtMocHelpers::SignalData<void()>(166, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band29TypeChanged'
        QtMocHelpers::SignalData<void()>(167, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band30TypeChanged'
        QtMocHelpers::SignalData<void()>(168, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band31TypeChanged'
        QtMocHelpers::SignalData<void()>(169, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0ModeChanged'
        QtMocHelpers::SignalData<void()>(170, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1ModeChanged'
        QtMocHelpers::SignalData<void()>(171, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2ModeChanged'
        QtMocHelpers::SignalData<void()>(172, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3ModeChanged'
        QtMocHelpers::SignalData<void()>(173, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4ModeChanged'
        QtMocHelpers::SignalData<void()>(174, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5ModeChanged'
        QtMocHelpers::SignalData<void()>(175, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6ModeChanged'
        QtMocHelpers::SignalData<void()>(176, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7ModeChanged'
        QtMocHelpers::SignalData<void()>(177, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band8ModeChanged'
        QtMocHelpers::SignalData<void()>(178, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band9ModeChanged'
        QtMocHelpers::SignalData<void()>(179, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band10ModeChanged'
        QtMocHelpers::SignalData<void()>(180, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band11ModeChanged'
        QtMocHelpers::SignalData<void()>(181, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band12ModeChanged'
        QtMocHelpers::SignalData<void()>(182, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band13ModeChanged'
        QtMocHelpers::SignalData<void()>(183, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band14ModeChanged'
        QtMocHelpers::SignalData<void()>(184, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band15ModeChanged'
        QtMocHelpers::SignalData<void()>(185, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band16ModeChanged'
        QtMocHelpers::SignalData<void()>(186, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band17ModeChanged'
        QtMocHelpers::SignalData<void()>(187, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band18ModeChanged'
        QtMocHelpers::SignalData<void()>(188, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band19ModeChanged'
        QtMocHelpers::SignalData<void()>(189, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band20ModeChanged'
        QtMocHelpers::SignalData<void()>(190, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band21ModeChanged'
        QtMocHelpers::SignalData<void()>(191, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band22ModeChanged'
        QtMocHelpers::SignalData<void()>(192, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band23ModeChanged'
        QtMocHelpers::SignalData<void()>(193, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band24ModeChanged'
        QtMocHelpers::SignalData<void()>(194, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band25ModeChanged'
        QtMocHelpers::SignalData<void()>(195, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band26ModeChanged'
        QtMocHelpers::SignalData<void()>(196, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band27ModeChanged'
        QtMocHelpers::SignalData<void()>(197, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band28ModeChanged'
        QtMocHelpers::SignalData<void()>(198, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band29ModeChanged'
        QtMocHelpers::SignalData<void()>(199, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band30ModeChanged'
        QtMocHelpers::SignalData<void()>(200, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band31ModeChanged'
        QtMocHelpers::SignalData<void()>(201, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0SlopeChanged'
        QtMocHelpers::SignalData<void()>(202, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1SlopeChanged'
        QtMocHelpers::SignalData<void()>(203, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2SlopeChanged'
        QtMocHelpers::SignalData<void()>(204, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3SlopeChanged'
        QtMocHelpers::SignalData<void()>(205, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4SlopeChanged'
        QtMocHelpers::SignalData<void()>(206, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5SlopeChanged'
        QtMocHelpers::SignalData<void()>(207, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6SlopeChanged'
        QtMocHelpers::SignalData<void()>(208, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7SlopeChanged'
        QtMocHelpers::SignalData<void()>(209, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band8SlopeChanged'
        QtMocHelpers::SignalData<void()>(210, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band9SlopeChanged'
        QtMocHelpers::SignalData<void()>(211, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band10SlopeChanged'
        QtMocHelpers::SignalData<void()>(212, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band11SlopeChanged'
        QtMocHelpers::SignalData<void()>(213, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band12SlopeChanged'
        QtMocHelpers::SignalData<void()>(214, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band13SlopeChanged'
        QtMocHelpers::SignalData<void()>(215, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band14SlopeChanged'
        QtMocHelpers::SignalData<void()>(216, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band15SlopeChanged'
        QtMocHelpers::SignalData<void()>(217, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band16SlopeChanged'
        QtMocHelpers::SignalData<void()>(218, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band17SlopeChanged'
        QtMocHelpers::SignalData<void()>(219, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band18SlopeChanged'
        QtMocHelpers::SignalData<void()>(220, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band19SlopeChanged'
        QtMocHelpers::SignalData<void()>(221, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band20SlopeChanged'
        QtMocHelpers::SignalData<void()>(222, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band21SlopeChanged'
        QtMocHelpers::SignalData<void()>(223, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band22SlopeChanged'
        QtMocHelpers::SignalData<void()>(224, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band23SlopeChanged'
        QtMocHelpers::SignalData<void()>(225, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band24SlopeChanged'
        QtMocHelpers::SignalData<void()>(226, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band25SlopeChanged'
        QtMocHelpers::SignalData<void()>(227, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band26SlopeChanged'
        QtMocHelpers::SignalData<void()>(228, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band27SlopeChanged'
        QtMocHelpers::SignalData<void()>(229, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band28SlopeChanged'
        QtMocHelpers::SignalData<void()>(230, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band29SlopeChanged'
        QtMocHelpers::SignalData<void()>(231, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band30SlopeChanged'
        QtMocHelpers::SignalData<void()>(232, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band31SlopeChanged'
        QtMocHelpers::SignalData<void()>(233, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0SoloChanged'
        QtMocHelpers::SignalData<void()>(234, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1SoloChanged'
        QtMocHelpers::SignalData<void()>(235, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2SoloChanged'
        QtMocHelpers::SignalData<void()>(236, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3SoloChanged'
        QtMocHelpers::SignalData<void()>(237, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4SoloChanged'
        QtMocHelpers::SignalData<void()>(238, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5SoloChanged'
        QtMocHelpers::SignalData<void()>(239, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6SoloChanged'
        QtMocHelpers::SignalData<void()>(240, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7SoloChanged'
        QtMocHelpers::SignalData<void()>(241, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band8SoloChanged'
        QtMocHelpers::SignalData<void()>(242, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band9SoloChanged'
        QtMocHelpers::SignalData<void()>(243, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band10SoloChanged'
        QtMocHelpers::SignalData<void()>(244, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band11SoloChanged'
        QtMocHelpers::SignalData<void()>(245, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band12SoloChanged'
        QtMocHelpers::SignalData<void()>(246, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band13SoloChanged'
        QtMocHelpers::SignalData<void()>(247, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band14SoloChanged'
        QtMocHelpers::SignalData<void()>(248, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band15SoloChanged'
        QtMocHelpers::SignalData<void()>(249, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band16SoloChanged'
        QtMocHelpers::SignalData<void()>(250, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band17SoloChanged'
        QtMocHelpers::SignalData<void()>(251, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band18SoloChanged'
        QtMocHelpers::SignalData<void()>(252, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band19SoloChanged'
        QtMocHelpers::SignalData<void()>(253, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band20SoloChanged'
        QtMocHelpers::SignalData<void()>(254, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band21SoloChanged'
        QtMocHelpers::SignalData<void()>(255, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band22SoloChanged'
        QtMocHelpers::SignalData<void()>(256, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band23SoloChanged'
        QtMocHelpers::SignalData<void()>(257, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band24SoloChanged'
        QtMocHelpers::SignalData<void()>(258, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band25SoloChanged'
        QtMocHelpers::SignalData<void()>(259, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band26SoloChanged'
        QtMocHelpers::SignalData<void()>(260, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band27SoloChanged'
        QtMocHelpers::SignalData<void()>(261, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band28SoloChanged'
        QtMocHelpers::SignalData<void()>(262, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band29SoloChanged'
        QtMocHelpers::SignalData<void()>(263, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band30SoloChanged'
        QtMocHelpers::SignalData<void()>(264, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band31SoloChanged'
        QtMocHelpers::SignalData<void()>(265, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0MuteChanged'
        QtMocHelpers::SignalData<void()>(266, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1MuteChanged'
        QtMocHelpers::SignalData<void()>(267, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2MuteChanged'
        QtMocHelpers::SignalData<void()>(268, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3MuteChanged'
        QtMocHelpers::SignalData<void()>(269, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4MuteChanged'
        QtMocHelpers::SignalData<void()>(270, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5MuteChanged'
        QtMocHelpers::SignalData<void()>(271, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6MuteChanged'
        QtMocHelpers::SignalData<void()>(272, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7MuteChanged'
        QtMocHelpers::SignalData<void()>(273, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band8MuteChanged'
        QtMocHelpers::SignalData<void()>(274, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band9MuteChanged'
        QtMocHelpers::SignalData<void()>(275, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band10MuteChanged'
        QtMocHelpers::SignalData<void()>(276, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band11MuteChanged'
        QtMocHelpers::SignalData<void()>(277, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band12MuteChanged'
        QtMocHelpers::SignalData<void()>(278, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band13MuteChanged'
        QtMocHelpers::SignalData<void()>(279, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band14MuteChanged'
        QtMocHelpers::SignalData<void()>(280, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band15MuteChanged'
        QtMocHelpers::SignalData<void()>(281, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band16MuteChanged'
        QtMocHelpers::SignalData<void()>(282, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band17MuteChanged'
        QtMocHelpers::SignalData<void()>(283, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band18MuteChanged'
        QtMocHelpers::SignalData<void()>(284, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band19MuteChanged'
        QtMocHelpers::SignalData<void()>(285, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band20MuteChanged'
        QtMocHelpers::SignalData<void()>(286, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band21MuteChanged'
        QtMocHelpers::SignalData<void()>(287, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band22MuteChanged'
        QtMocHelpers::SignalData<void()>(288, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band23MuteChanged'
        QtMocHelpers::SignalData<void()>(289, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band24MuteChanged'
        QtMocHelpers::SignalData<void()>(290, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band25MuteChanged'
        QtMocHelpers::SignalData<void()>(291, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band26MuteChanged'
        QtMocHelpers::SignalData<void()>(292, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band27MuteChanged'
        QtMocHelpers::SignalData<void()>(293, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band28MuteChanged'
        QtMocHelpers::SignalData<void()>(294, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band29MuteChanged'
        QtMocHelpers::SignalData<void()>(295, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band30MuteChanged'
        QtMocHelpers::SignalData<void()>(296, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band31MuteChanged'
        QtMocHelpers::SignalData<void()>(297, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bandModeLabels'
        QtMocHelpers::PropertyData<QStringList>(298, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isBandModeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(299, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBandModeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(300, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bandTypeLabels'
        QtMocHelpers::PropertyData<QStringList>(301, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isBandTypeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(302, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBandTypeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(303, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bandSlopeLabels'
        QtMocHelpers::PropertyData<QStringList>(304, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isBandSlopeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(305, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBandSlopeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(306, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0Gain'
        QtMocHelpers::PropertyData<double>(307, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isBand0GainImmutable'
        QtMocHelpers::PropertyData<bool>(308, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0GainValue'
        QtMocHelpers::PropertyData<double>(309, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1Gain'
        QtMocHelpers::PropertyData<double>(310, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isBand1GainImmutable'
        QtMocHelpers::PropertyData<bool>(311, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1GainValue'
        QtMocHelpers::PropertyData<double>(312, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2Gain'
        QtMocHelpers::PropertyData<double>(313, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isBand2GainImmutable'
        QtMocHelpers::PropertyData<bool>(314, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2GainValue'
        QtMocHelpers::PropertyData<double>(315, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3Gain'
        QtMocHelpers::PropertyData<double>(316, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isBand3GainImmutable'
        QtMocHelpers::PropertyData<bool>(317, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3GainValue'
        QtMocHelpers::PropertyData<double>(318, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4Gain'
        QtMocHelpers::PropertyData<double>(319, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isBand4GainImmutable'
        QtMocHelpers::PropertyData<bool>(320, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4GainValue'
        QtMocHelpers::PropertyData<double>(321, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5Gain'
        QtMocHelpers::PropertyData<double>(322, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isBand5GainImmutable'
        QtMocHelpers::PropertyData<bool>(323, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5GainValue'
        QtMocHelpers::PropertyData<double>(324, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6Gain'
        QtMocHelpers::PropertyData<double>(325, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isBand6GainImmutable'
        QtMocHelpers::PropertyData<bool>(326, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6GainValue'
        QtMocHelpers::PropertyData<double>(327, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7Gain'
        QtMocHelpers::PropertyData<double>(328, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isBand7GainImmutable'
        QtMocHelpers::PropertyData<bool>(329, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7GainValue'
        QtMocHelpers::PropertyData<double>(330, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band8Gain'
        QtMocHelpers::PropertyData<double>(331, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isBand8GainImmutable'
        QtMocHelpers::PropertyData<bool>(332, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand8GainValue'
        QtMocHelpers::PropertyData<double>(333, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band9Gain'
        QtMocHelpers::PropertyData<double>(334, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isBand9GainImmutable'
        QtMocHelpers::PropertyData<bool>(335, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand9GainValue'
        QtMocHelpers::PropertyData<double>(336, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band10Gain'
        QtMocHelpers::PropertyData<double>(337, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isBand10GainImmutable'
        QtMocHelpers::PropertyData<bool>(338, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand10GainValue'
        QtMocHelpers::PropertyData<double>(339, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band11Gain'
        QtMocHelpers::PropertyData<double>(340, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isBand11GainImmutable'
        QtMocHelpers::PropertyData<bool>(341, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand11GainValue'
        QtMocHelpers::PropertyData<double>(342, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band12Gain'
        QtMocHelpers::PropertyData<double>(343, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isBand12GainImmutable'
        QtMocHelpers::PropertyData<bool>(344, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand12GainValue'
        QtMocHelpers::PropertyData<double>(345, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band13Gain'
        QtMocHelpers::PropertyData<double>(346, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isBand13GainImmutable'
        QtMocHelpers::PropertyData<bool>(347, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand13GainValue'
        QtMocHelpers::PropertyData<double>(348, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band14Gain'
        QtMocHelpers::PropertyData<double>(349, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'isBand14GainImmutable'
        QtMocHelpers::PropertyData<bool>(350, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand14GainValue'
        QtMocHelpers::PropertyData<double>(351, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band15Gain'
        QtMocHelpers::PropertyData<double>(352, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'isBand15GainImmutable'
        QtMocHelpers::PropertyData<bool>(353, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand15GainValue'
        QtMocHelpers::PropertyData<double>(354, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band16Gain'
        QtMocHelpers::PropertyData<double>(355, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'isBand16GainImmutable'
        QtMocHelpers::PropertyData<bool>(356, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand16GainValue'
        QtMocHelpers::PropertyData<double>(357, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band17Gain'
        QtMocHelpers::PropertyData<double>(358, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'isBand17GainImmutable'
        QtMocHelpers::PropertyData<bool>(359, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand17GainValue'
        QtMocHelpers::PropertyData<double>(360, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band18Gain'
        QtMocHelpers::PropertyData<double>(361, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'isBand18GainImmutable'
        QtMocHelpers::PropertyData<bool>(362, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand18GainValue'
        QtMocHelpers::PropertyData<double>(363, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band19Gain'
        QtMocHelpers::PropertyData<double>(364, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'isBand19GainImmutable'
        QtMocHelpers::PropertyData<bool>(365, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand19GainValue'
        QtMocHelpers::PropertyData<double>(366, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band20Gain'
        QtMocHelpers::PropertyData<double>(367, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'isBand20GainImmutable'
        QtMocHelpers::PropertyData<bool>(368, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand20GainValue'
        QtMocHelpers::PropertyData<double>(369, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band21Gain'
        QtMocHelpers::PropertyData<double>(370, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'isBand21GainImmutable'
        QtMocHelpers::PropertyData<bool>(371, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand21GainValue'
        QtMocHelpers::PropertyData<double>(372, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band22Gain'
        QtMocHelpers::PropertyData<double>(373, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 25),
        // property 'isBand22GainImmutable'
        QtMocHelpers::PropertyData<bool>(374, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand22GainValue'
        QtMocHelpers::PropertyData<double>(375, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band23Gain'
        QtMocHelpers::PropertyData<double>(376, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 26),
        // property 'isBand23GainImmutable'
        QtMocHelpers::PropertyData<bool>(377, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand23GainValue'
        QtMocHelpers::PropertyData<double>(378, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band24Gain'
        QtMocHelpers::PropertyData<double>(379, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 27),
        // property 'isBand24GainImmutable'
        QtMocHelpers::PropertyData<bool>(380, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand24GainValue'
        QtMocHelpers::PropertyData<double>(381, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band25Gain'
        QtMocHelpers::PropertyData<double>(382, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 28),
        // property 'isBand25GainImmutable'
        QtMocHelpers::PropertyData<bool>(383, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand25GainValue'
        QtMocHelpers::PropertyData<double>(384, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band26Gain'
        QtMocHelpers::PropertyData<double>(385, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 29),
        // property 'isBand26GainImmutable'
        QtMocHelpers::PropertyData<bool>(386, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand26GainValue'
        QtMocHelpers::PropertyData<double>(387, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band27Gain'
        QtMocHelpers::PropertyData<double>(388, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 30),
        // property 'isBand27GainImmutable'
        QtMocHelpers::PropertyData<bool>(389, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand27GainValue'
        QtMocHelpers::PropertyData<double>(390, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band28Gain'
        QtMocHelpers::PropertyData<double>(391, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 31),
        // property 'isBand28GainImmutable'
        QtMocHelpers::PropertyData<bool>(392, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand28GainValue'
        QtMocHelpers::PropertyData<double>(393, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band29Gain'
        QtMocHelpers::PropertyData<double>(394, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 32),
        // property 'isBand29GainImmutable'
        QtMocHelpers::PropertyData<bool>(395, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand29GainValue'
        QtMocHelpers::PropertyData<double>(396, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band30Gain'
        QtMocHelpers::PropertyData<double>(397, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 33),
        // property 'isBand30GainImmutable'
        QtMocHelpers::PropertyData<bool>(398, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand30GainValue'
        QtMocHelpers::PropertyData<double>(399, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band31Gain'
        QtMocHelpers::PropertyData<double>(400, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 34),
        // property 'isBand31GainImmutable'
        QtMocHelpers::PropertyData<bool>(401, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand31GainValue'
        QtMocHelpers::PropertyData<double>(402, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0Frequency'
        QtMocHelpers::PropertyData<double>(403, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 35),
        // property 'isBand0FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(404, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0FrequencyValue'
        QtMocHelpers::PropertyData<double>(405, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1Frequency'
        QtMocHelpers::PropertyData<double>(406, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 36),
        // property 'isBand1FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(407, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1FrequencyValue'
        QtMocHelpers::PropertyData<double>(408, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2Frequency'
        QtMocHelpers::PropertyData<double>(409, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 37),
        // property 'isBand2FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(410, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2FrequencyValue'
        QtMocHelpers::PropertyData<double>(411, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3Frequency'
        QtMocHelpers::PropertyData<double>(412, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 38),
        // property 'isBand3FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(413, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3FrequencyValue'
        QtMocHelpers::PropertyData<double>(414, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4Frequency'
        QtMocHelpers::PropertyData<double>(415, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 39),
        // property 'isBand4FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(416, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4FrequencyValue'
        QtMocHelpers::PropertyData<double>(417, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5Frequency'
        QtMocHelpers::PropertyData<double>(418, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 40),
        // property 'isBand5FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(419, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5FrequencyValue'
        QtMocHelpers::PropertyData<double>(420, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6Frequency'
        QtMocHelpers::PropertyData<double>(421, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 41),
        // property 'isBand6FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(422, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6FrequencyValue'
        QtMocHelpers::PropertyData<double>(423, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7Frequency'
        QtMocHelpers::PropertyData<double>(424, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 42),
        // property 'isBand7FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(425, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7FrequencyValue'
        QtMocHelpers::PropertyData<double>(426, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band8Frequency'
        QtMocHelpers::PropertyData<double>(427, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 43),
        // property 'isBand8FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(428, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand8FrequencyValue'
        QtMocHelpers::PropertyData<double>(429, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band9Frequency'
        QtMocHelpers::PropertyData<double>(430, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 44),
        // property 'isBand9FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(431, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand9FrequencyValue'
        QtMocHelpers::PropertyData<double>(432, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band10Frequency'
        QtMocHelpers::PropertyData<double>(433, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 45),
        // property 'isBand10FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(434, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand10FrequencyValue'
        QtMocHelpers::PropertyData<double>(435, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band11Frequency'
        QtMocHelpers::PropertyData<double>(436, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 46),
        // property 'isBand11FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(437, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand11FrequencyValue'
        QtMocHelpers::PropertyData<double>(438, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band12Frequency'
        QtMocHelpers::PropertyData<double>(439, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 47),
        // property 'isBand12FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(440, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand12FrequencyValue'
        QtMocHelpers::PropertyData<double>(441, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band13Frequency'
        QtMocHelpers::PropertyData<double>(442, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 48),
        // property 'isBand13FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(443, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand13FrequencyValue'
        QtMocHelpers::PropertyData<double>(444, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band14Frequency'
        QtMocHelpers::PropertyData<double>(445, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 49),
        // property 'isBand14FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(446, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand14FrequencyValue'
        QtMocHelpers::PropertyData<double>(447, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band15Frequency'
        QtMocHelpers::PropertyData<double>(448, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 50),
        // property 'isBand15FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(449, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand15FrequencyValue'
        QtMocHelpers::PropertyData<double>(450, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band16Frequency'
        QtMocHelpers::PropertyData<double>(451, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 51),
        // property 'isBand16FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(452, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand16FrequencyValue'
        QtMocHelpers::PropertyData<double>(453, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band17Frequency'
        QtMocHelpers::PropertyData<double>(454, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 52),
        // property 'isBand17FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(455, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand17FrequencyValue'
        QtMocHelpers::PropertyData<double>(456, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band18Frequency'
        QtMocHelpers::PropertyData<double>(457, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 53),
        // property 'isBand18FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(458, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand18FrequencyValue'
        QtMocHelpers::PropertyData<double>(459, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band19Frequency'
        QtMocHelpers::PropertyData<double>(460, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 54),
        // property 'isBand19FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(461, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand19FrequencyValue'
        QtMocHelpers::PropertyData<double>(462, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band20Frequency'
        QtMocHelpers::PropertyData<double>(463, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 55),
        // property 'isBand20FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(464, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand20FrequencyValue'
        QtMocHelpers::PropertyData<double>(465, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band21Frequency'
        QtMocHelpers::PropertyData<double>(466, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 56),
        // property 'isBand21FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(467, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand21FrequencyValue'
        QtMocHelpers::PropertyData<double>(468, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band22Frequency'
        QtMocHelpers::PropertyData<double>(469, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 57),
        // property 'isBand22FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(470, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand22FrequencyValue'
        QtMocHelpers::PropertyData<double>(471, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band23Frequency'
        QtMocHelpers::PropertyData<double>(472, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 58),
        // property 'isBand23FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(473, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand23FrequencyValue'
        QtMocHelpers::PropertyData<double>(474, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band24Frequency'
        QtMocHelpers::PropertyData<double>(475, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 59),
        // property 'isBand24FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(476, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand24FrequencyValue'
        QtMocHelpers::PropertyData<double>(477, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band25Frequency'
        QtMocHelpers::PropertyData<double>(478, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 60),
        // property 'isBand25FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(479, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand25FrequencyValue'
        QtMocHelpers::PropertyData<double>(480, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band26Frequency'
        QtMocHelpers::PropertyData<double>(481, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 61),
        // property 'isBand26FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(482, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand26FrequencyValue'
        QtMocHelpers::PropertyData<double>(483, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band27Frequency'
        QtMocHelpers::PropertyData<double>(484, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 62),
        // property 'isBand27FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(485, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand27FrequencyValue'
        QtMocHelpers::PropertyData<double>(486, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band28Frequency'
        QtMocHelpers::PropertyData<double>(487, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 63),
        // property 'isBand28FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(488, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand28FrequencyValue'
        QtMocHelpers::PropertyData<double>(489, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band29Frequency'
        QtMocHelpers::PropertyData<double>(490, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 64),
        // property 'isBand29FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(491, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand29FrequencyValue'
        QtMocHelpers::PropertyData<double>(492, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band30Frequency'
        QtMocHelpers::PropertyData<double>(493, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 65),
        // property 'isBand30FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(494, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand30FrequencyValue'
        QtMocHelpers::PropertyData<double>(495, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band31Frequency'
        QtMocHelpers::PropertyData<double>(496, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 66),
        // property 'isBand31FrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(497, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand31FrequencyValue'
        QtMocHelpers::PropertyData<double>(498, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0Q'
        QtMocHelpers::PropertyData<double>(499, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 67),
        // property 'isBand0QImmutable'
        QtMocHelpers::PropertyData<bool>(500, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0QValue'
        QtMocHelpers::PropertyData<double>(501, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1Q'
        QtMocHelpers::PropertyData<double>(502, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 68),
        // property 'isBand1QImmutable'
        QtMocHelpers::PropertyData<bool>(503, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1QValue'
        QtMocHelpers::PropertyData<double>(504, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2Q'
        QtMocHelpers::PropertyData<double>(505, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 69),
        // property 'isBand2QImmutable'
        QtMocHelpers::PropertyData<bool>(506, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2QValue'
        QtMocHelpers::PropertyData<double>(507, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3Q'
        QtMocHelpers::PropertyData<double>(508, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 70),
        // property 'isBand3QImmutable'
        QtMocHelpers::PropertyData<bool>(509, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3QValue'
        QtMocHelpers::PropertyData<double>(510, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4Q'
        QtMocHelpers::PropertyData<double>(511, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 71),
        // property 'isBand4QImmutable'
        QtMocHelpers::PropertyData<bool>(512, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4QValue'
        QtMocHelpers::PropertyData<double>(513, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5Q'
        QtMocHelpers::PropertyData<double>(514, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 72),
        // property 'isBand5QImmutable'
        QtMocHelpers::PropertyData<bool>(515, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5QValue'
        QtMocHelpers::PropertyData<double>(516, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6Q'
        QtMocHelpers::PropertyData<double>(517, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 73),
        // property 'isBand6QImmutable'
        QtMocHelpers::PropertyData<bool>(518, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6QValue'
        QtMocHelpers::PropertyData<double>(519, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7Q'
        QtMocHelpers::PropertyData<double>(520, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 74),
        // property 'isBand7QImmutable'
        QtMocHelpers::PropertyData<bool>(521, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7QValue'
        QtMocHelpers::PropertyData<double>(522, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band8Q'
        QtMocHelpers::PropertyData<double>(523, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 75),
        // property 'isBand8QImmutable'
        QtMocHelpers::PropertyData<bool>(524, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand8QValue'
        QtMocHelpers::PropertyData<double>(525, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band9Q'
        QtMocHelpers::PropertyData<double>(526, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 76),
        // property 'isBand9QImmutable'
        QtMocHelpers::PropertyData<bool>(527, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand9QValue'
        QtMocHelpers::PropertyData<double>(528, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band10Q'
        QtMocHelpers::PropertyData<double>(529, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 77),
        // property 'isBand10QImmutable'
        QtMocHelpers::PropertyData<bool>(530, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand10QValue'
        QtMocHelpers::PropertyData<double>(531, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band11Q'
        QtMocHelpers::PropertyData<double>(532, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 78),
        // property 'isBand11QImmutable'
        QtMocHelpers::PropertyData<bool>(533, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand11QValue'
        QtMocHelpers::PropertyData<double>(534, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band12Q'
        QtMocHelpers::PropertyData<double>(535, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 79),
        // property 'isBand12QImmutable'
        QtMocHelpers::PropertyData<bool>(536, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand12QValue'
        QtMocHelpers::PropertyData<double>(537, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band13Q'
        QtMocHelpers::PropertyData<double>(538, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 80),
        // property 'isBand13QImmutable'
        QtMocHelpers::PropertyData<bool>(539, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand13QValue'
        QtMocHelpers::PropertyData<double>(540, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band14Q'
        QtMocHelpers::PropertyData<double>(541, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 81),
        // property 'isBand14QImmutable'
        QtMocHelpers::PropertyData<bool>(542, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand14QValue'
        QtMocHelpers::PropertyData<double>(543, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band15Q'
        QtMocHelpers::PropertyData<double>(544, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 82),
        // property 'isBand15QImmutable'
        QtMocHelpers::PropertyData<bool>(545, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand15QValue'
        QtMocHelpers::PropertyData<double>(546, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band16Q'
        QtMocHelpers::PropertyData<double>(547, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 83),
        // property 'isBand16QImmutable'
        QtMocHelpers::PropertyData<bool>(548, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand16QValue'
        QtMocHelpers::PropertyData<double>(549, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band17Q'
        QtMocHelpers::PropertyData<double>(550, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 84),
        // property 'isBand17QImmutable'
        QtMocHelpers::PropertyData<bool>(551, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand17QValue'
        QtMocHelpers::PropertyData<double>(552, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band18Q'
        QtMocHelpers::PropertyData<double>(553, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 85),
        // property 'isBand18QImmutable'
        QtMocHelpers::PropertyData<bool>(554, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand18QValue'
        QtMocHelpers::PropertyData<double>(555, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band19Q'
        QtMocHelpers::PropertyData<double>(556, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 86),
        // property 'isBand19QImmutable'
        QtMocHelpers::PropertyData<bool>(557, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand19QValue'
        QtMocHelpers::PropertyData<double>(558, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band20Q'
        QtMocHelpers::PropertyData<double>(559, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 87),
        // property 'isBand20QImmutable'
        QtMocHelpers::PropertyData<bool>(560, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand20QValue'
        QtMocHelpers::PropertyData<double>(561, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band21Q'
        QtMocHelpers::PropertyData<double>(562, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 88),
        // property 'isBand21QImmutable'
        QtMocHelpers::PropertyData<bool>(563, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand21QValue'
        QtMocHelpers::PropertyData<double>(564, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band22Q'
        QtMocHelpers::PropertyData<double>(565, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 89),
        // property 'isBand22QImmutable'
        QtMocHelpers::PropertyData<bool>(566, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand22QValue'
        QtMocHelpers::PropertyData<double>(567, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band23Q'
        QtMocHelpers::PropertyData<double>(568, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 90),
        // property 'isBand23QImmutable'
        QtMocHelpers::PropertyData<bool>(569, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand23QValue'
        QtMocHelpers::PropertyData<double>(570, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band24Q'
        QtMocHelpers::PropertyData<double>(571, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 91),
        // property 'isBand24QImmutable'
        QtMocHelpers::PropertyData<bool>(572, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand24QValue'
        QtMocHelpers::PropertyData<double>(573, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band25Q'
        QtMocHelpers::PropertyData<double>(574, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 92),
        // property 'isBand25QImmutable'
        QtMocHelpers::PropertyData<bool>(575, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand25QValue'
        QtMocHelpers::PropertyData<double>(576, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band26Q'
        QtMocHelpers::PropertyData<double>(577, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 93),
        // property 'isBand26QImmutable'
        QtMocHelpers::PropertyData<bool>(578, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand26QValue'
        QtMocHelpers::PropertyData<double>(579, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band27Q'
        QtMocHelpers::PropertyData<double>(580, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 94),
        // property 'isBand27QImmutable'
        QtMocHelpers::PropertyData<bool>(581, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand27QValue'
        QtMocHelpers::PropertyData<double>(582, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band28Q'
        QtMocHelpers::PropertyData<double>(583, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 95),
        // property 'isBand28QImmutable'
        QtMocHelpers::PropertyData<bool>(584, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand28QValue'
        QtMocHelpers::PropertyData<double>(585, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band29Q'
        QtMocHelpers::PropertyData<double>(586, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 96),
        // property 'isBand29QImmutable'
        QtMocHelpers::PropertyData<bool>(587, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand29QValue'
        QtMocHelpers::PropertyData<double>(588, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band30Q'
        QtMocHelpers::PropertyData<double>(589, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 97),
        // property 'isBand30QImmutable'
        QtMocHelpers::PropertyData<bool>(590, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand30QValue'
        QtMocHelpers::PropertyData<double>(591, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band31Q'
        QtMocHelpers::PropertyData<double>(592, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 98),
        // property 'isBand31QImmutable'
        QtMocHelpers::PropertyData<bool>(593, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand31QValue'
        QtMocHelpers::PropertyData<double>(594, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0Width'
        QtMocHelpers::PropertyData<double>(595, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 99),
        // property 'isBand0WidthImmutable'
        QtMocHelpers::PropertyData<bool>(596, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0WidthValue'
        QtMocHelpers::PropertyData<double>(597, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1Width'
        QtMocHelpers::PropertyData<double>(598, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 100),
        // property 'isBand1WidthImmutable'
        QtMocHelpers::PropertyData<bool>(599, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1WidthValue'
        QtMocHelpers::PropertyData<double>(600, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2Width'
        QtMocHelpers::PropertyData<double>(601, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 101),
        // property 'isBand2WidthImmutable'
        QtMocHelpers::PropertyData<bool>(602, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2WidthValue'
        QtMocHelpers::PropertyData<double>(603, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3Width'
        QtMocHelpers::PropertyData<double>(604, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 102),
        // property 'isBand3WidthImmutable'
        QtMocHelpers::PropertyData<bool>(605, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3WidthValue'
        QtMocHelpers::PropertyData<double>(606, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4Width'
        QtMocHelpers::PropertyData<double>(607, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 103),
        // property 'isBand4WidthImmutable'
        QtMocHelpers::PropertyData<bool>(608, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4WidthValue'
        QtMocHelpers::PropertyData<double>(609, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5Width'
        QtMocHelpers::PropertyData<double>(610, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 104),
        // property 'isBand5WidthImmutable'
        QtMocHelpers::PropertyData<bool>(611, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5WidthValue'
        QtMocHelpers::PropertyData<double>(612, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6Width'
        QtMocHelpers::PropertyData<double>(613, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 105),
        // property 'isBand6WidthImmutable'
        QtMocHelpers::PropertyData<bool>(614, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6WidthValue'
        QtMocHelpers::PropertyData<double>(615, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7Width'
        QtMocHelpers::PropertyData<double>(616, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 106),
        // property 'isBand7WidthImmutable'
        QtMocHelpers::PropertyData<bool>(617, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7WidthValue'
        QtMocHelpers::PropertyData<double>(618, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band8Width'
        QtMocHelpers::PropertyData<double>(619, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 107),
        // property 'isBand8WidthImmutable'
        QtMocHelpers::PropertyData<bool>(620, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand8WidthValue'
        QtMocHelpers::PropertyData<double>(621, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band9Width'
        QtMocHelpers::PropertyData<double>(622, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 108),
        // property 'isBand9WidthImmutable'
        QtMocHelpers::PropertyData<bool>(623, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand9WidthValue'
        QtMocHelpers::PropertyData<double>(624, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band10Width'
        QtMocHelpers::PropertyData<double>(625, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 109),
        // property 'isBand10WidthImmutable'
        QtMocHelpers::PropertyData<bool>(626, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand10WidthValue'
        QtMocHelpers::PropertyData<double>(627, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band11Width'
        QtMocHelpers::PropertyData<double>(628, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 110),
        // property 'isBand11WidthImmutable'
        QtMocHelpers::PropertyData<bool>(629, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand11WidthValue'
        QtMocHelpers::PropertyData<double>(630, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band12Width'
        QtMocHelpers::PropertyData<double>(631, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 111),
        // property 'isBand12WidthImmutable'
        QtMocHelpers::PropertyData<bool>(632, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand12WidthValue'
        QtMocHelpers::PropertyData<double>(633, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band13Width'
        QtMocHelpers::PropertyData<double>(634, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 112),
        // property 'isBand13WidthImmutable'
        QtMocHelpers::PropertyData<bool>(635, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand13WidthValue'
        QtMocHelpers::PropertyData<double>(636, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band14Width'
        QtMocHelpers::PropertyData<double>(637, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 113),
        // property 'isBand14WidthImmutable'
        QtMocHelpers::PropertyData<bool>(638, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand14WidthValue'
        QtMocHelpers::PropertyData<double>(639, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band15Width'
        QtMocHelpers::PropertyData<double>(640, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 114),
        // property 'isBand15WidthImmutable'
        QtMocHelpers::PropertyData<bool>(641, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand15WidthValue'
        QtMocHelpers::PropertyData<double>(642, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band16Width'
        QtMocHelpers::PropertyData<double>(643, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 115),
        // property 'isBand16WidthImmutable'
        QtMocHelpers::PropertyData<bool>(644, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand16WidthValue'
        QtMocHelpers::PropertyData<double>(645, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band17Width'
        QtMocHelpers::PropertyData<double>(646, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 116),
        // property 'isBand17WidthImmutable'
        QtMocHelpers::PropertyData<bool>(647, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand17WidthValue'
        QtMocHelpers::PropertyData<double>(648, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band18Width'
        QtMocHelpers::PropertyData<double>(649, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 117),
        // property 'isBand18WidthImmutable'
        QtMocHelpers::PropertyData<bool>(650, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand18WidthValue'
        QtMocHelpers::PropertyData<double>(651, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band19Width'
        QtMocHelpers::PropertyData<double>(652, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 118),
        // property 'isBand19WidthImmutable'
        QtMocHelpers::PropertyData<bool>(653, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand19WidthValue'
        QtMocHelpers::PropertyData<double>(654, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band20Width'
        QtMocHelpers::PropertyData<double>(655, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 119),
        // property 'isBand20WidthImmutable'
        QtMocHelpers::PropertyData<bool>(656, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand20WidthValue'
        QtMocHelpers::PropertyData<double>(657, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band21Width'
        QtMocHelpers::PropertyData<double>(658, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 120),
        // property 'isBand21WidthImmutable'
        QtMocHelpers::PropertyData<bool>(659, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand21WidthValue'
        QtMocHelpers::PropertyData<double>(660, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band22Width'
        QtMocHelpers::PropertyData<double>(661, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 121),
        // property 'isBand22WidthImmutable'
        QtMocHelpers::PropertyData<bool>(662, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand22WidthValue'
        QtMocHelpers::PropertyData<double>(663, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band23Width'
        QtMocHelpers::PropertyData<double>(664, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 122),
        // property 'isBand23WidthImmutable'
        QtMocHelpers::PropertyData<bool>(665, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand23WidthValue'
        QtMocHelpers::PropertyData<double>(666, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band24Width'
        QtMocHelpers::PropertyData<double>(667, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 123),
        // property 'isBand24WidthImmutable'
        QtMocHelpers::PropertyData<bool>(668, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand24WidthValue'
        QtMocHelpers::PropertyData<double>(669, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band25Width'
        QtMocHelpers::PropertyData<double>(670, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 124),
        // property 'isBand25WidthImmutable'
        QtMocHelpers::PropertyData<bool>(671, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand25WidthValue'
        QtMocHelpers::PropertyData<double>(672, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band26Width'
        QtMocHelpers::PropertyData<double>(673, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 125),
        // property 'isBand26WidthImmutable'
        QtMocHelpers::PropertyData<bool>(674, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand26WidthValue'
        QtMocHelpers::PropertyData<double>(675, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band27Width'
        QtMocHelpers::PropertyData<double>(676, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 126),
        // property 'isBand27WidthImmutable'
        QtMocHelpers::PropertyData<bool>(677, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand27WidthValue'
        QtMocHelpers::PropertyData<double>(678, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band28Width'
        QtMocHelpers::PropertyData<double>(679, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 127),
        // property 'isBand28WidthImmutable'
        QtMocHelpers::PropertyData<bool>(680, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand28WidthValue'
        QtMocHelpers::PropertyData<double>(681, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band29Width'
        QtMocHelpers::PropertyData<double>(682, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 128),
        // property 'isBand29WidthImmutable'
        QtMocHelpers::PropertyData<bool>(683, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand29WidthValue'
        QtMocHelpers::PropertyData<double>(684, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band30Width'
        QtMocHelpers::PropertyData<double>(685, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 129),
        // property 'isBand30WidthImmutable'
        QtMocHelpers::PropertyData<bool>(686, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand30WidthValue'
        QtMocHelpers::PropertyData<double>(687, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band31Width'
        QtMocHelpers::PropertyData<double>(688, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 130),
        // property 'isBand31WidthImmutable'
        QtMocHelpers::PropertyData<bool>(689, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand31WidthValue'
        QtMocHelpers::PropertyData<double>(690, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0Type'
        QtMocHelpers::PropertyData<int>(691, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 131),
        // property 'isBand0TypeImmutable'
        QtMocHelpers::PropertyData<bool>(692, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0TypeValue'
        QtMocHelpers::PropertyData<int>(693, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1Type'
        QtMocHelpers::PropertyData<int>(694, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 132),
        // property 'isBand1TypeImmutable'
        QtMocHelpers::PropertyData<bool>(695, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1TypeValue'
        QtMocHelpers::PropertyData<int>(696, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2Type'
        QtMocHelpers::PropertyData<int>(697, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 133),
        // property 'isBand2TypeImmutable'
        QtMocHelpers::PropertyData<bool>(698, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2TypeValue'
        QtMocHelpers::PropertyData<int>(699, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3Type'
        QtMocHelpers::PropertyData<int>(700, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 134),
        // property 'isBand3TypeImmutable'
        QtMocHelpers::PropertyData<bool>(701, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3TypeValue'
        QtMocHelpers::PropertyData<int>(702, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4Type'
        QtMocHelpers::PropertyData<int>(703, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 135),
        // property 'isBand4TypeImmutable'
        QtMocHelpers::PropertyData<bool>(704, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4TypeValue'
        QtMocHelpers::PropertyData<int>(705, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5Type'
        QtMocHelpers::PropertyData<int>(706, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 136),
        // property 'isBand5TypeImmutable'
        QtMocHelpers::PropertyData<bool>(707, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5TypeValue'
        QtMocHelpers::PropertyData<int>(708, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6Type'
        QtMocHelpers::PropertyData<int>(709, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 137),
        // property 'isBand6TypeImmutable'
        QtMocHelpers::PropertyData<bool>(710, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6TypeValue'
        QtMocHelpers::PropertyData<int>(711, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7Type'
        QtMocHelpers::PropertyData<int>(712, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 138),
        // property 'isBand7TypeImmutable'
        QtMocHelpers::PropertyData<bool>(713, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7TypeValue'
        QtMocHelpers::PropertyData<int>(714, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band8Type'
        QtMocHelpers::PropertyData<int>(715, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 139),
        // property 'isBand8TypeImmutable'
        QtMocHelpers::PropertyData<bool>(716, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand8TypeValue'
        QtMocHelpers::PropertyData<int>(717, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band9Type'
        QtMocHelpers::PropertyData<int>(718, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 140),
        // property 'isBand9TypeImmutable'
        QtMocHelpers::PropertyData<bool>(719, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand9TypeValue'
        QtMocHelpers::PropertyData<int>(720, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band10Type'
        QtMocHelpers::PropertyData<int>(721, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 141),
        // property 'isBand10TypeImmutable'
        QtMocHelpers::PropertyData<bool>(722, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand10TypeValue'
        QtMocHelpers::PropertyData<int>(723, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band11Type'
        QtMocHelpers::PropertyData<int>(724, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 142),
        // property 'isBand11TypeImmutable'
        QtMocHelpers::PropertyData<bool>(725, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand11TypeValue'
        QtMocHelpers::PropertyData<int>(726, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band12Type'
        QtMocHelpers::PropertyData<int>(727, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 143),
        // property 'isBand12TypeImmutable'
        QtMocHelpers::PropertyData<bool>(728, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand12TypeValue'
        QtMocHelpers::PropertyData<int>(729, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band13Type'
        QtMocHelpers::PropertyData<int>(730, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 144),
        // property 'isBand13TypeImmutable'
        QtMocHelpers::PropertyData<bool>(731, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand13TypeValue'
        QtMocHelpers::PropertyData<int>(732, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band14Type'
        QtMocHelpers::PropertyData<int>(733, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 145),
        // property 'isBand14TypeImmutable'
        QtMocHelpers::PropertyData<bool>(734, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand14TypeValue'
        QtMocHelpers::PropertyData<int>(735, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band15Type'
        QtMocHelpers::PropertyData<int>(736, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 146),
        // property 'isBand15TypeImmutable'
        QtMocHelpers::PropertyData<bool>(737, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand15TypeValue'
        QtMocHelpers::PropertyData<int>(738, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band16Type'
        QtMocHelpers::PropertyData<int>(739, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 147),
        // property 'isBand16TypeImmutable'
        QtMocHelpers::PropertyData<bool>(740, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand16TypeValue'
        QtMocHelpers::PropertyData<int>(741, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band17Type'
        QtMocHelpers::PropertyData<int>(742, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 148),
        // property 'isBand17TypeImmutable'
        QtMocHelpers::PropertyData<bool>(743, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand17TypeValue'
        QtMocHelpers::PropertyData<int>(744, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band18Type'
        QtMocHelpers::PropertyData<int>(745, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 149),
        // property 'isBand18TypeImmutable'
        QtMocHelpers::PropertyData<bool>(746, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand18TypeValue'
        QtMocHelpers::PropertyData<int>(747, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band19Type'
        QtMocHelpers::PropertyData<int>(748, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 150),
        // property 'isBand19TypeImmutable'
        QtMocHelpers::PropertyData<bool>(749, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand19TypeValue'
        QtMocHelpers::PropertyData<int>(750, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band20Type'
        QtMocHelpers::PropertyData<int>(751, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 151),
        // property 'isBand20TypeImmutable'
        QtMocHelpers::PropertyData<bool>(752, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand20TypeValue'
        QtMocHelpers::PropertyData<int>(753, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band21Type'
        QtMocHelpers::PropertyData<int>(754, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 152),
        // property 'isBand21TypeImmutable'
        QtMocHelpers::PropertyData<bool>(755, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand21TypeValue'
        QtMocHelpers::PropertyData<int>(756, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band22Type'
        QtMocHelpers::PropertyData<int>(757, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 153),
        // property 'isBand22TypeImmutable'
        QtMocHelpers::PropertyData<bool>(758, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand22TypeValue'
        QtMocHelpers::PropertyData<int>(759, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band23Type'
        QtMocHelpers::PropertyData<int>(760, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 154),
        // property 'isBand23TypeImmutable'
        QtMocHelpers::PropertyData<bool>(761, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand23TypeValue'
        QtMocHelpers::PropertyData<int>(762, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band24Type'
        QtMocHelpers::PropertyData<int>(763, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 155),
        // property 'isBand24TypeImmutable'
        QtMocHelpers::PropertyData<bool>(764, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand24TypeValue'
        QtMocHelpers::PropertyData<int>(765, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band25Type'
        QtMocHelpers::PropertyData<int>(766, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 156),
        // property 'isBand25TypeImmutable'
        QtMocHelpers::PropertyData<bool>(767, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand25TypeValue'
        QtMocHelpers::PropertyData<int>(768, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band26Type'
        QtMocHelpers::PropertyData<int>(769, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 157),
        // property 'isBand26TypeImmutable'
        QtMocHelpers::PropertyData<bool>(770, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand26TypeValue'
        QtMocHelpers::PropertyData<int>(771, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band27Type'
        QtMocHelpers::PropertyData<int>(772, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 158),
        // property 'isBand27TypeImmutable'
        QtMocHelpers::PropertyData<bool>(773, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand27TypeValue'
        QtMocHelpers::PropertyData<int>(774, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band28Type'
        QtMocHelpers::PropertyData<int>(775, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 159),
        // property 'isBand28TypeImmutable'
        QtMocHelpers::PropertyData<bool>(776, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand28TypeValue'
        QtMocHelpers::PropertyData<int>(777, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band29Type'
        QtMocHelpers::PropertyData<int>(778, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 160),
        // property 'isBand29TypeImmutable'
        QtMocHelpers::PropertyData<bool>(779, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand29TypeValue'
        QtMocHelpers::PropertyData<int>(780, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band30Type'
        QtMocHelpers::PropertyData<int>(781, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 161),
        // property 'isBand30TypeImmutable'
        QtMocHelpers::PropertyData<bool>(782, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand30TypeValue'
        QtMocHelpers::PropertyData<int>(783, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band31Type'
        QtMocHelpers::PropertyData<int>(784, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 162),
        // property 'isBand31TypeImmutable'
        QtMocHelpers::PropertyData<bool>(785, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand31TypeValue'
        QtMocHelpers::PropertyData<int>(786, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0Mode'
        QtMocHelpers::PropertyData<int>(787, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 163),
        // property 'isBand0ModeImmutable'
        QtMocHelpers::PropertyData<bool>(788, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0ModeValue'
        QtMocHelpers::PropertyData<int>(789, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1Mode'
        QtMocHelpers::PropertyData<int>(790, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 164),
        // property 'isBand1ModeImmutable'
        QtMocHelpers::PropertyData<bool>(791, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1ModeValue'
        QtMocHelpers::PropertyData<int>(792, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2Mode'
        QtMocHelpers::PropertyData<int>(793, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 165),
        // property 'isBand2ModeImmutable'
        QtMocHelpers::PropertyData<bool>(794, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2ModeValue'
        QtMocHelpers::PropertyData<int>(795, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3Mode'
        QtMocHelpers::PropertyData<int>(796, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 166),
        // property 'isBand3ModeImmutable'
        QtMocHelpers::PropertyData<bool>(797, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3ModeValue'
        QtMocHelpers::PropertyData<int>(798, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4Mode'
        QtMocHelpers::PropertyData<int>(799, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 167),
        // property 'isBand4ModeImmutable'
        QtMocHelpers::PropertyData<bool>(800, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4ModeValue'
        QtMocHelpers::PropertyData<int>(801, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5Mode'
        QtMocHelpers::PropertyData<int>(802, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 168),
        // property 'isBand5ModeImmutable'
        QtMocHelpers::PropertyData<bool>(803, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5ModeValue'
        QtMocHelpers::PropertyData<int>(804, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6Mode'
        QtMocHelpers::PropertyData<int>(805, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 169),
        // property 'isBand6ModeImmutable'
        QtMocHelpers::PropertyData<bool>(806, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6ModeValue'
        QtMocHelpers::PropertyData<int>(807, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7Mode'
        QtMocHelpers::PropertyData<int>(808, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 170),
        // property 'isBand7ModeImmutable'
        QtMocHelpers::PropertyData<bool>(809, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7ModeValue'
        QtMocHelpers::PropertyData<int>(810, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band8Mode'
        QtMocHelpers::PropertyData<int>(811, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 171),
        // property 'isBand8ModeImmutable'
        QtMocHelpers::PropertyData<bool>(812, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand8ModeValue'
        QtMocHelpers::PropertyData<int>(813, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band9Mode'
        QtMocHelpers::PropertyData<int>(814, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 172),
        // property 'isBand9ModeImmutable'
        QtMocHelpers::PropertyData<bool>(815, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand9ModeValue'
        QtMocHelpers::PropertyData<int>(816, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band10Mode'
        QtMocHelpers::PropertyData<int>(817, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 173),
        // property 'isBand10ModeImmutable'
        QtMocHelpers::PropertyData<bool>(818, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand10ModeValue'
        QtMocHelpers::PropertyData<int>(819, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band11Mode'
        QtMocHelpers::PropertyData<int>(820, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 174),
        // property 'isBand11ModeImmutable'
        QtMocHelpers::PropertyData<bool>(821, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand11ModeValue'
        QtMocHelpers::PropertyData<int>(822, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band12Mode'
        QtMocHelpers::PropertyData<int>(823, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 175),
        // property 'isBand12ModeImmutable'
        QtMocHelpers::PropertyData<bool>(824, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand12ModeValue'
        QtMocHelpers::PropertyData<int>(825, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band13Mode'
        QtMocHelpers::PropertyData<int>(826, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 176),
        // property 'isBand13ModeImmutable'
        QtMocHelpers::PropertyData<bool>(827, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand13ModeValue'
        QtMocHelpers::PropertyData<int>(828, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band14Mode'
        QtMocHelpers::PropertyData<int>(829, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 177),
        // property 'isBand14ModeImmutable'
        QtMocHelpers::PropertyData<bool>(830, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand14ModeValue'
        QtMocHelpers::PropertyData<int>(831, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band15Mode'
        QtMocHelpers::PropertyData<int>(832, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 178),
        // property 'isBand15ModeImmutable'
        QtMocHelpers::PropertyData<bool>(833, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand15ModeValue'
        QtMocHelpers::PropertyData<int>(834, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band16Mode'
        QtMocHelpers::PropertyData<int>(835, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 179),
        // property 'isBand16ModeImmutable'
        QtMocHelpers::PropertyData<bool>(836, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand16ModeValue'
        QtMocHelpers::PropertyData<int>(837, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band17Mode'
        QtMocHelpers::PropertyData<int>(838, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 180),
        // property 'isBand17ModeImmutable'
        QtMocHelpers::PropertyData<bool>(839, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand17ModeValue'
        QtMocHelpers::PropertyData<int>(840, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band18Mode'
        QtMocHelpers::PropertyData<int>(841, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 181),
        // property 'isBand18ModeImmutable'
        QtMocHelpers::PropertyData<bool>(842, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand18ModeValue'
        QtMocHelpers::PropertyData<int>(843, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band19Mode'
        QtMocHelpers::PropertyData<int>(844, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 182),
        // property 'isBand19ModeImmutable'
        QtMocHelpers::PropertyData<bool>(845, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand19ModeValue'
        QtMocHelpers::PropertyData<int>(846, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band20Mode'
        QtMocHelpers::PropertyData<int>(847, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 183),
        // property 'isBand20ModeImmutable'
        QtMocHelpers::PropertyData<bool>(848, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand20ModeValue'
        QtMocHelpers::PropertyData<int>(849, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band21Mode'
        QtMocHelpers::PropertyData<int>(850, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 184),
        // property 'isBand21ModeImmutable'
        QtMocHelpers::PropertyData<bool>(851, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand21ModeValue'
        QtMocHelpers::PropertyData<int>(852, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band22Mode'
        QtMocHelpers::PropertyData<int>(853, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 185),
        // property 'isBand22ModeImmutable'
        QtMocHelpers::PropertyData<bool>(854, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand22ModeValue'
        QtMocHelpers::PropertyData<int>(855, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band23Mode'
        QtMocHelpers::PropertyData<int>(856, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 186),
        // property 'isBand23ModeImmutable'
        QtMocHelpers::PropertyData<bool>(857, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand23ModeValue'
        QtMocHelpers::PropertyData<int>(858, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band24Mode'
        QtMocHelpers::PropertyData<int>(859, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 187),
        // property 'isBand24ModeImmutable'
        QtMocHelpers::PropertyData<bool>(860, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand24ModeValue'
        QtMocHelpers::PropertyData<int>(861, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band25Mode'
        QtMocHelpers::PropertyData<int>(862, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 188),
        // property 'isBand25ModeImmutable'
        QtMocHelpers::PropertyData<bool>(863, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand25ModeValue'
        QtMocHelpers::PropertyData<int>(864, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band26Mode'
        QtMocHelpers::PropertyData<int>(865, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 189),
        // property 'isBand26ModeImmutable'
        QtMocHelpers::PropertyData<bool>(866, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand26ModeValue'
        QtMocHelpers::PropertyData<int>(867, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band27Mode'
        QtMocHelpers::PropertyData<int>(868, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 190),
        // property 'isBand27ModeImmutable'
        QtMocHelpers::PropertyData<bool>(869, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand27ModeValue'
        QtMocHelpers::PropertyData<int>(870, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band28Mode'
        QtMocHelpers::PropertyData<int>(871, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 191),
        // property 'isBand28ModeImmutable'
        QtMocHelpers::PropertyData<bool>(872, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand28ModeValue'
        QtMocHelpers::PropertyData<int>(873, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band29Mode'
        QtMocHelpers::PropertyData<int>(874, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 192),
        // property 'isBand29ModeImmutable'
        QtMocHelpers::PropertyData<bool>(875, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand29ModeValue'
        QtMocHelpers::PropertyData<int>(876, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band30Mode'
        QtMocHelpers::PropertyData<int>(877, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 193),
        // property 'isBand30ModeImmutable'
        QtMocHelpers::PropertyData<bool>(878, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand30ModeValue'
        QtMocHelpers::PropertyData<int>(879, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band31Mode'
        QtMocHelpers::PropertyData<int>(880, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 194),
        // property 'isBand31ModeImmutable'
        QtMocHelpers::PropertyData<bool>(881, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand31ModeValue'
        QtMocHelpers::PropertyData<int>(882, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0Slope'
        QtMocHelpers::PropertyData<int>(883, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 195),
        // property 'isBand0SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(884, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0SlopeValue'
        QtMocHelpers::PropertyData<int>(885, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1Slope'
        QtMocHelpers::PropertyData<int>(886, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 196),
        // property 'isBand1SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(887, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1SlopeValue'
        QtMocHelpers::PropertyData<int>(888, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2Slope'
        QtMocHelpers::PropertyData<int>(889, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 197),
        // property 'isBand2SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(890, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2SlopeValue'
        QtMocHelpers::PropertyData<int>(891, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3Slope'
        QtMocHelpers::PropertyData<int>(892, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 198),
        // property 'isBand3SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(893, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3SlopeValue'
        QtMocHelpers::PropertyData<int>(894, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4Slope'
        QtMocHelpers::PropertyData<int>(895, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 199),
        // property 'isBand4SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(896, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4SlopeValue'
        QtMocHelpers::PropertyData<int>(897, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5Slope'
        QtMocHelpers::PropertyData<int>(898, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 200),
        // property 'isBand5SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(899, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5SlopeValue'
        QtMocHelpers::PropertyData<int>(900, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6Slope'
        QtMocHelpers::PropertyData<int>(901, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 201),
        // property 'isBand6SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(902, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6SlopeValue'
        QtMocHelpers::PropertyData<int>(903, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7Slope'
        QtMocHelpers::PropertyData<int>(904, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 202),
        // property 'isBand7SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(905, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7SlopeValue'
        QtMocHelpers::PropertyData<int>(906, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band8Slope'
        QtMocHelpers::PropertyData<int>(907, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 203),
        // property 'isBand8SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(908, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand8SlopeValue'
        QtMocHelpers::PropertyData<int>(909, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band9Slope'
        QtMocHelpers::PropertyData<int>(910, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 204),
        // property 'isBand9SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(911, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand9SlopeValue'
        QtMocHelpers::PropertyData<int>(912, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band10Slope'
        QtMocHelpers::PropertyData<int>(913, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 205),
        // property 'isBand10SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(914, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand10SlopeValue'
        QtMocHelpers::PropertyData<int>(915, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band11Slope'
        QtMocHelpers::PropertyData<int>(916, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 206),
        // property 'isBand11SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(917, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand11SlopeValue'
        QtMocHelpers::PropertyData<int>(918, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band12Slope'
        QtMocHelpers::PropertyData<int>(919, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 207),
        // property 'isBand12SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(920, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand12SlopeValue'
        QtMocHelpers::PropertyData<int>(921, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band13Slope'
        QtMocHelpers::PropertyData<int>(922, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 208),
        // property 'isBand13SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(923, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand13SlopeValue'
        QtMocHelpers::PropertyData<int>(924, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band14Slope'
        QtMocHelpers::PropertyData<int>(925, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 209),
        // property 'isBand14SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(926, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand14SlopeValue'
        QtMocHelpers::PropertyData<int>(927, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band15Slope'
        QtMocHelpers::PropertyData<int>(928, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 210),
        // property 'isBand15SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(929, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand15SlopeValue'
        QtMocHelpers::PropertyData<int>(930, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band16Slope'
        QtMocHelpers::PropertyData<int>(931, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 211),
        // property 'isBand16SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(932, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand16SlopeValue'
        QtMocHelpers::PropertyData<int>(933, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band17Slope'
        QtMocHelpers::PropertyData<int>(934, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 212),
        // property 'isBand17SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(935, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand17SlopeValue'
        QtMocHelpers::PropertyData<int>(936, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band18Slope'
        QtMocHelpers::PropertyData<int>(937, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 213),
        // property 'isBand18SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(938, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand18SlopeValue'
        QtMocHelpers::PropertyData<int>(939, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band19Slope'
        QtMocHelpers::PropertyData<int>(940, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 214),
        // property 'isBand19SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(941, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand19SlopeValue'
        QtMocHelpers::PropertyData<int>(942, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band20Slope'
        QtMocHelpers::PropertyData<int>(943, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 215),
        // property 'isBand20SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(944, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand20SlopeValue'
        QtMocHelpers::PropertyData<int>(945, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band21Slope'
        QtMocHelpers::PropertyData<int>(946, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 216),
        // property 'isBand21SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(947, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand21SlopeValue'
        QtMocHelpers::PropertyData<int>(948, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band22Slope'
        QtMocHelpers::PropertyData<int>(949, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 217),
        // property 'isBand22SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(950, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand22SlopeValue'
        QtMocHelpers::PropertyData<int>(951, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band23Slope'
        QtMocHelpers::PropertyData<int>(952, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 218),
        // property 'isBand23SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(953, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand23SlopeValue'
        QtMocHelpers::PropertyData<int>(954, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band24Slope'
        QtMocHelpers::PropertyData<int>(955, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 219),
        // property 'isBand24SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(956, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand24SlopeValue'
        QtMocHelpers::PropertyData<int>(957, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band25Slope'
        QtMocHelpers::PropertyData<int>(958, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 220),
        // property 'isBand25SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(959, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand25SlopeValue'
        QtMocHelpers::PropertyData<int>(960, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band26Slope'
        QtMocHelpers::PropertyData<int>(961, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 221),
        // property 'isBand26SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(962, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand26SlopeValue'
        QtMocHelpers::PropertyData<int>(963, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band27Slope'
        QtMocHelpers::PropertyData<int>(964, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 222),
        // property 'isBand27SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(965, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand27SlopeValue'
        QtMocHelpers::PropertyData<int>(966, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band28Slope'
        QtMocHelpers::PropertyData<int>(967, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 223),
        // property 'isBand28SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(968, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand28SlopeValue'
        QtMocHelpers::PropertyData<int>(969, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band29Slope'
        QtMocHelpers::PropertyData<int>(970, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 224),
        // property 'isBand29SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(971, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand29SlopeValue'
        QtMocHelpers::PropertyData<int>(972, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band30Slope'
        QtMocHelpers::PropertyData<int>(973, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 225),
        // property 'isBand30SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(974, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand30SlopeValue'
        QtMocHelpers::PropertyData<int>(975, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band31Slope'
        QtMocHelpers::PropertyData<int>(976, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 226),
        // property 'isBand31SlopeImmutable'
        QtMocHelpers::PropertyData<bool>(977, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand31SlopeValue'
        QtMocHelpers::PropertyData<int>(978, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0Solo'
        QtMocHelpers::PropertyData<bool>(979, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 227),
        // property 'isBand0SoloImmutable'
        QtMocHelpers::PropertyData<bool>(980, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0SoloValue'
        QtMocHelpers::PropertyData<bool>(981, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1Solo'
        QtMocHelpers::PropertyData<bool>(982, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 228),
        // property 'isBand1SoloImmutable'
        QtMocHelpers::PropertyData<bool>(983, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1SoloValue'
        QtMocHelpers::PropertyData<bool>(984, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2Solo'
        QtMocHelpers::PropertyData<bool>(985, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 229),
        // property 'isBand2SoloImmutable'
        QtMocHelpers::PropertyData<bool>(986, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2SoloValue'
        QtMocHelpers::PropertyData<bool>(987, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3Solo'
        QtMocHelpers::PropertyData<bool>(988, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 230),
        // property 'isBand3SoloImmutable'
        QtMocHelpers::PropertyData<bool>(989, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3SoloValue'
        QtMocHelpers::PropertyData<bool>(990, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4Solo'
        QtMocHelpers::PropertyData<bool>(991, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 231),
        // property 'isBand4SoloImmutable'
        QtMocHelpers::PropertyData<bool>(992, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4SoloValue'
        QtMocHelpers::PropertyData<bool>(993, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5Solo'
        QtMocHelpers::PropertyData<bool>(994, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 232),
        // property 'isBand5SoloImmutable'
        QtMocHelpers::PropertyData<bool>(995, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5SoloValue'
        QtMocHelpers::PropertyData<bool>(996, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6Solo'
        QtMocHelpers::PropertyData<bool>(997, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 233),
        // property 'isBand6SoloImmutable'
        QtMocHelpers::PropertyData<bool>(998, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6SoloValue'
        QtMocHelpers::PropertyData<bool>(999, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7Solo'
        QtMocHelpers::PropertyData<bool>(1000, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 234),
        // property 'isBand7SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1001, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7SoloValue'
        QtMocHelpers::PropertyData<bool>(1002, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band8Solo'
        QtMocHelpers::PropertyData<bool>(1003, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 235),
        // property 'isBand8SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1004, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand8SoloValue'
        QtMocHelpers::PropertyData<bool>(1005, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band9Solo'
        QtMocHelpers::PropertyData<bool>(1006, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 236),
        // property 'isBand9SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1007, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand9SoloValue'
        QtMocHelpers::PropertyData<bool>(1008, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band10Solo'
        QtMocHelpers::PropertyData<bool>(1009, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 237),
        // property 'isBand10SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1010, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand10SoloValue'
        QtMocHelpers::PropertyData<bool>(1011, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band11Solo'
        QtMocHelpers::PropertyData<bool>(1012, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 238),
        // property 'isBand11SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1013, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand11SoloValue'
        QtMocHelpers::PropertyData<bool>(1014, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band12Solo'
        QtMocHelpers::PropertyData<bool>(1015, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 239),
        // property 'isBand12SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1016, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand12SoloValue'
        QtMocHelpers::PropertyData<bool>(1017, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band13Solo'
        QtMocHelpers::PropertyData<bool>(1018, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 240),
        // property 'isBand13SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1019, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand13SoloValue'
        QtMocHelpers::PropertyData<bool>(1020, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band14Solo'
        QtMocHelpers::PropertyData<bool>(1021, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 241),
        // property 'isBand14SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1022, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand14SoloValue'
        QtMocHelpers::PropertyData<bool>(1023, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band15Solo'
        QtMocHelpers::PropertyData<bool>(1024, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 242),
        // property 'isBand15SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1025, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand15SoloValue'
        QtMocHelpers::PropertyData<bool>(1026, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band16Solo'
        QtMocHelpers::PropertyData<bool>(1027, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 243),
        // property 'isBand16SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1028, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand16SoloValue'
        QtMocHelpers::PropertyData<bool>(1029, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band17Solo'
        QtMocHelpers::PropertyData<bool>(1030, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 244),
        // property 'isBand17SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1031, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand17SoloValue'
        QtMocHelpers::PropertyData<bool>(1032, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band18Solo'
        QtMocHelpers::PropertyData<bool>(1033, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 245),
        // property 'isBand18SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1034, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand18SoloValue'
        QtMocHelpers::PropertyData<bool>(1035, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band19Solo'
        QtMocHelpers::PropertyData<bool>(1036, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 246),
        // property 'isBand19SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1037, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand19SoloValue'
        QtMocHelpers::PropertyData<bool>(1038, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band20Solo'
        QtMocHelpers::PropertyData<bool>(1039, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 247),
        // property 'isBand20SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1040, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand20SoloValue'
        QtMocHelpers::PropertyData<bool>(1041, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band21Solo'
        QtMocHelpers::PropertyData<bool>(1042, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 248),
        // property 'isBand21SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1043, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand21SoloValue'
        QtMocHelpers::PropertyData<bool>(1044, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band22Solo'
        QtMocHelpers::PropertyData<bool>(1045, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 249),
        // property 'isBand22SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1046, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand22SoloValue'
        QtMocHelpers::PropertyData<bool>(1047, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band23Solo'
        QtMocHelpers::PropertyData<bool>(1048, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 250),
        // property 'isBand23SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1049, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand23SoloValue'
        QtMocHelpers::PropertyData<bool>(1050, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band24Solo'
        QtMocHelpers::PropertyData<bool>(1051, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 251),
        // property 'isBand24SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1052, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand24SoloValue'
        QtMocHelpers::PropertyData<bool>(1053, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band25Solo'
        QtMocHelpers::PropertyData<bool>(1054, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 252),
        // property 'isBand25SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1055, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand25SoloValue'
        QtMocHelpers::PropertyData<bool>(1056, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band26Solo'
        QtMocHelpers::PropertyData<bool>(1057, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 253),
        // property 'isBand26SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1058, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand26SoloValue'
        QtMocHelpers::PropertyData<bool>(1059, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band27Solo'
        QtMocHelpers::PropertyData<bool>(1060, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 254),
        // property 'isBand27SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1061, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand27SoloValue'
        QtMocHelpers::PropertyData<bool>(1062, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band28Solo'
        QtMocHelpers::PropertyData<bool>(1063, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 255),
        // property 'isBand28SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1064, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand28SoloValue'
        QtMocHelpers::PropertyData<bool>(1065, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band29Solo'
        QtMocHelpers::PropertyData<bool>(1066, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 256),
        // property 'isBand29SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1067, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand29SoloValue'
        QtMocHelpers::PropertyData<bool>(1068, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band30Solo'
        QtMocHelpers::PropertyData<bool>(1069, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 257),
        // property 'isBand30SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1070, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand30SoloValue'
        QtMocHelpers::PropertyData<bool>(1071, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band31Solo'
        QtMocHelpers::PropertyData<bool>(1072, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 258),
        // property 'isBand31SoloImmutable'
        QtMocHelpers::PropertyData<bool>(1073, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand31SoloValue'
        QtMocHelpers::PropertyData<bool>(1074, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0Mute'
        QtMocHelpers::PropertyData<bool>(1075, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 259),
        // property 'isBand0MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1076, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0MuteValue'
        QtMocHelpers::PropertyData<bool>(1077, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1Mute'
        QtMocHelpers::PropertyData<bool>(1078, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 260),
        // property 'isBand1MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1079, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1MuteValue'
        QtMocHelpers::PropertyData<bool>(1080, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2Mute'
        QtMocHelpers::PropertyData<bool>(1081, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 261),
        // property 'isBand2MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1082, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2MuteValue'
        QtMocHelpers::PropertyData<bool>(1083, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3Mute'
        QtMocHelpers::PropertyData<bool>(1084, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 262),
        // property 'isBand3MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1085, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3MuteValue'
        QtMocHelpers::PropertyData<bool>(1086, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4Mute'
        QtMocHelpers::PropertyData<bool>(1087, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 263),
        // property 'isBand4MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1088, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4MuteValue'
        QtMocHelpers::PropertyData<bool>(1089, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5Mute'
        QtMocHelpers::PropertyData<bool>(1090, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 264),
        // property 'isBand5MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1091, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5MuteValue'
        QtMocHelpers::PropertyData<bool>(1092, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6Mute'
        QtMocHelpers::PropertyData<bool>(1093, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 265),
        // property 'isBand6MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1094, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6MuteValue'
        QtMocHelpers::PropertyData<bool>(1095, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7Mute'
        QtMocHelpers::PropertyData<bool>(1096, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 266),
        // property 'isBand7MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1097, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7MuteValue'
        QtMocHelpers::PropertyData<bool>(1098, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band8Mute'
        QtMocHelpers::PropertyData<bool>(1099, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 267),
        // property 'isBand8MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1100, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand8MuteValue'
        QtMocHelpers::PropertyData<bool>(1101, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band9Mute'
        QtMocHelpers::PropertyData<bool>(1102, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 268),
        // property 'isBand9MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1103, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand9MuteValue'
        QtMocHelpers::PropertyData<bool>(1104, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band10Mute'
        QtMocHelpers::PropertyData<bool>(1105, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 269),
        // property 'isBand10MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1106, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand10MuteValue'
        QtMocHelpers::PropertyData<bool>(1107, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band11Mute'
        QtMocHelpers::PropertyData<bool>(1108, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 270),
        // property 'isBand11MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1109, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand11MuteValue'
        QtMocHelpers::PropertyData<bool>(1110, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band12Mute'
        QtMocHelpers::PropertyData<bool>(1111, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 271),
        // property 'isBand12MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1112, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand12MuteValue'
        QtMocHelpers::PropertyData<bool>(1113, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band13Mute'
        QtMocHelpers::PropertyData<bool>(1114, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 272),
        // property 'isBand13MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1115, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand13MuteValue'
        QtMocHelpers::PropertyData<bool>(1116, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band14Mute'
        QtMocHelpers::PropertyData<bool>(1117, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 273),
        // property 'isBand14MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1118, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand14MuteValue'
        QtMocHelpers::PropertyData<bool>(1119, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band15Mute'
        QtMocHelpers::PropertyData<bool>(1120, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 274),
        // property 'isBand15MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1121, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand15MuteValue'
        QtMocHelpers::PropertyData<bool>(1122, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band16Mute'
        QtMocHelpers::PropertyData<bool>(1123, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 275),
        // property 'isBand16MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1124, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand16MuteValue'
        QtMocHelpers::PropertyData<bool>(1125, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band17Mute'
        QtMocHelpers::PropertyData<bool>(1126, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 276),
        // property 'isBand17MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1127, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand17MuteValue'
        QtMocHelpers::PropertyData<bool>(1128, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band18Mute'
        QtMocHelpers::PropertyData<bool>(1129, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 277),
        // property 'isBand18MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1130, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand18MuteValue'
        QtMocHelpers::PropertyData<bool>(1131, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band19Mute'
        QtMocHelpers::PropertyData<bool>(1132, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 278),
        // property 'isBand19MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1133, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand19MuteValue'
        QtMocHelpers::PropertyData<bool>(1134, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band20Mute'
        QtMocHelpers::PropertyData<bool>(1135, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 279),
        // property 'isBand20MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1136, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand20MuteValue'
        QtMocHelpers::PropertyData<bool>(1137, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band21Mute'
        QtMocHelpers::PropertyData<bool>(1138, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 280),
        // property 'isBand21MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1139, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand21MuteValue'
        QtMocHelpers::PropertyData<bool>(1140, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band22Mute'
        QtMocHelpers::PropertyData<bool>(1141, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 281),
        // property 'isBand22MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1142, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand22MuteValue'
        QtMocHelpers::PropertyData<bool>(1143, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band23Mute'
        QtMocHelpers::PropertyData<bool>(1144, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 282),
        // property 'isBand23MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1145, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand23MuteValue'
        QtMocHelpers::PropertyData<bool>(1146, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band24Mute'
        QtMocHelpers::PropertyData<bool>(1147, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 283),
        // property 'isBand24MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1148, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand24MuteValue'
        QtMocHelpers::PropertyData<bool>(1149, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band25Mute'
        QtMocHelpers::PropertyData<bool>(1150, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 284),
        // property 'isBand25MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1151, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand25MuteValue'
        QtMocHelpers::PropertyData<bool>(1152, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band26Mute'
        QtMocHelpers::PropertyData<bool>(1153, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 285),
        // property 'isBand26MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1154, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand26MuteValue'
        QtMocHelpers::PropertyData<bool>(1155, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band27Mute'
        QtMocHelpers::PropertyData<bool>(1156, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 286),
        // property 'isBand27MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1157, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand27MuteValue'
        QtMocHelpers::PropertyData<bool>(1158, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band28Mute'
        QtMocHelpers::PropertyData<bool>(1159, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 287),
        // property 'isBand28MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1160, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand28MuteValue'
        QtMocHelpers::PropertyData<bool>(1161, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band29Mute'
        QtMocHelpers::PropertyData<bool>(1162, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 288),
        // property 'isBand29MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1163, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand29MuteValue'
        QtMocHelpers::PropertyData<bool>(1164, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band30Mute'
        QtMocHelpers::PropertyData<bool>(1165, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 289),
        // property 'isBand30MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1166, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand30MuteValue'
        QtMocHelpers::PropertyData<bool>(1167, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band31Mute'
        QtMocHelpers::PropertyData<bool>(1168, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 290),
        // property 'isBand31MuteImmutable'
        QtMocHelpers::PropertyData<bool>(1169, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand31MuteValue'
        QtMocHelpers::PropertyData<bool>(1170, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DbEqualizerChannel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbEqualizerChannel::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DbEqualizerChannelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DbEqualizerChannelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18DbEqualizerChannelE_t>.metaTypes,
    nullptr
} };

void DbEqualizerChannel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbEqualizerChannel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bandModeLabelsChanged(); break;
        case 1: _t->bandTypeLabelsChanged(); break;
        case 2: _t->bandSlopeLabelsChanged(); break;
        case 3: _t->band0GainChanged(); break;
        case 4: _t->band1GainChanged(); break;
        case 5: _t->band2GainChanged(); break;
        case 6: _t->band3GainChanged(); break;
        case 7: _t->band4GainChanged(); break;
        case 8: _t->band5GainChanged(); break;
        case 9: _t->band6GainChanged(); break;
        case 10: _t->band7GainChanged(); break;
        case 11: _t->band8GainChanged(); break;
        case 12: _t->band9GainChanged(); break;
        case 13: _t->band10GainChanged(); break;
        case 14: _t->band11GainChanged(); break;
        case 15: _t->band12GainChanged(); break;
        case 16: _t->band13GainChanged(); break;
        case 17: _t->band14GainChanged(); break;
        case 18: _t->band15GainChanged(); break;
        case 19: _t->band16GainChanged(); break;
        case 20: _t->band17GainChanged(); break;
        case 21: _t->band18GainChanged(); break;
        case 22: _t->band19GainChanged(); break;
        case 23: _t->band20GainChanged(); break;
        case 24: _t->band21GainChanged(); break;
        case 25: _t->band22GainChanged(); break;
        case 26: _t->band23GainChanged(); break;
        case 27: _t->band24GainChanged(); break;
        case 28: _t->band25GainChanged(); break;
        case 29: _t->band26GainChanged(); break;
        case 30: _t->band27GainChanged(); break;
        case 31: _t->band28GainChanged(); break;
        case 32: _t->band29GainChanged(); break;
        case 33: _t->band30GainChanged(); break;
        case 34: _t->band31GainChanged(); break;
        case 35: _t->band0FrequencyChanged(); break;
        case 36: _t->band1FrequencyChanged(); break;
        case 37: _t->band2FrequencyChanged(); break;
        case 38: _t->band3FrequencyChanged(); break;
        case 39: _t->band4FrequencyChanged(); break;
        case 40: _t->band5FrequencyChanged(); break;
        case 41: _t->band6FrequencyChanged(); break;
        case 42: _t->band7FrequencyChanged(); break;
        case 43: _t->band8FrequencyChanged(); break;
        case 44: _t->band9FrequencyChanged(); break;
        case 45: _t->band10FrequencyChanged(); break;
        case 46: _t->band11FrequencyChanged(); break;
        case 47: _t->band12FrequencyChanged(); break;
        case 48: _t->band13FrequencyChanged(); break;
        case 49: _t->band14FrequencyChanged(); break;
        case 50: _t->band15FrequencyChanged(); break;
        case 51: _t->band16FrequencyChanged(); break;
        case 52: _t->band17FrequencyChanged(); break;
        case 53: _t->band18FrequencyChanged(); break;
        case 54: _t->band19FrequencyChanged(); break;
        case 55: _t->band20FrequencyChanged(); break;
        case 56: _t->band21FrequencyChanged(); break;
        case 57: _t->band22FrequencyChanged(); break;
        case 58: _t->band23FrequencyChanged(); break;
        case 59: _t->band24FrequencyChanged(); break;
        case 60: _t->band25FrequencyChanged(); break;
        case 61: _t->band26FrequencyChanged(); break;
        case 62: _t->band27FrequencyChanged(); break;
        case 63: _t->band28FrequencyChanged(); break;
        case 64: _t->band29FrequencyChanged(); break;
        case 65: _t->band30FrequencyChanged(); break;
        case 66: _t->band31FrequencyChanged(); break;
        case 67: _t->band0QChanged(); break;
        case 68: _t->band1QChanged(); break;
        case 69: _t->band2QChanged(); break;
        case 70: _t->band3QChanged(); break;
        case 71: _t->band4QChanged(); break;
        case 72: _t->band5QChanged(); break;
        case 73: _t->band6QChanged(); break;
        case 74: _t->band7QChanged(); break;
        case 75: _t->band8QChanged(); break;
        case 76: _t->band9QChanged(); break;
        case 77: _t->band10QChanged(); break;
        case 78: _t->band11QChanged(); break;
        case 79: _t->band12QChanged(); break;
        case 80: _t->band13QChanged(); break;
        case 81: _t->band14QChanged(); break;
        case 82: _t->band15QChanged(); break;
        case 83: _t->band16QChanged(); break;
        case 84: _t->band17QChanged(); break;
        case 85: _t->band18QChanged(); break;
        case 86: _t->band19QChanged(); break;
        case 87: _t->band20QChanged(); break;
        case 88: _t->band21QChanged(); break;
        case 89: _t->band22QChanged(); break;
        case 90: _t->band23QChanged(); break;
        case 91: _t->band24QChanged(); break;
        case 92: _t->band25QChanged(); break;
        case 93: _t->band26QChanged(); break;
        case 94: _t->band27QChanged(); break;
        case 95: _t->band28QChanged(); break;
        case 96: _t->band29QChanged(); break;
        case 97: _t->band30QChanged(); break;
        case 98: _t->band31QChanged(); break;
        case 99: _t->band0WidthChanged(); break;
        case 100: _t->band1WidthChanged(); break;
        case 101: _t->band2WidthChanged(); break;
        case 102: _t->band3WidthChanged(); break;
        case 103: _t->band4WidthChanged(); break;
        case 104: _t->band5WidthChanged(); break;
        case 105: _t->band6WidthChanged(); break;
        case 106: _t->band7WidthChanged(); break;
        case 107: _t->band8WidthChanged(); break;
        case 108: _t->band9WidthChanged(); break;
        case 109: _t->band10WidthChanged(); break;
        case 110: _t->band11WidthChanged(); break;
        case 111: _t->band12WidthChanged(); break;
        case 112: _t->band13WidthChanged(); break;
        case 113: _t->band14WidthChanged(); break;
        case 114: _t->band15WidthChanged(); break;
        case 115: _t->band16WidthChanged(); break;
        case 116: _t->band17WidthChanged(); break;
        case 117: _t->band18WidthChanged(); break;
        case 118: _t->band19WidthChanged(); break;
        case 119: _t->band20WidthChanged(); break;
        case 120: _t->band21WidthChanged(); break;
        case 121: _t->band22WidthChanged(); break;
        case 122: _t->band23WidthChanged(); break;
        case 123: _t->band24WidthChanged(); break;
        case 124: _t->band25WidthChanged(); break;
        case 125: _t->band26WidthChanged(); break;
        case 126: _t->band27WidthChanged(); break;
        case 127: _t->band28WidthChanged(); break;
        case 128: _t->band29WidthChanged(); break;
        case 129: _t->band30WidthChanged(); break;
        case 130: _t->band31WidthChanged(); break;
        case 131: _t->band0TypeChanged(); break;
        case 132: _t->band1TypeChanged(); break;
        case 133: _t->band2TypeChanged(); break;
        case 134: _t->band3TypeChanged(); break;
        case 135: _t->band4TypeChanged(); break;
        case 136: _t->band5TypeChanged(); break;
        case 137: _t->band6TypeChanged(); break;
        case 138: _t->band7TypeChanged(); break;
        case 139: _t->band8TypeChanged(); break;
        case 140: _t->band9TypeChanged(); break;
        case 141: _t->band10TypeChanged(); break;
        case 142: _t->band11TypeChanged(); break;
        case 143: _t->band12TypeChanged(); break;
        case 144: _t->band13TypeChanged(); break;
        case 145: _t->band14TypeChanged(); break;
        case 146: _t->band15TypeChanged(); break;
        case 147: _t->band16TypeChanged(); break;
        case 148: _t->band17TypeChanged(); break;
        case 149: _t->band18TypeChanged(); break;
        case 150: _t->band19TypeChanged(); break;
        case 151: _t->band20TypeChanged(); break;
        case 152: _t->band21TypeChanged(); break;
        case 153: _t->band22TypeChanged(); break;
        case 154: _t->band23TypeChanged(); break;
        case 155: _t->band24TypeChanged(); break;
        case 156: _t->band25TypeChanged(); break;
        case 157: _t->band26TypeChanged(); break;
        case 158: _t->band27TypeChanged(); break;
        case 159: _t->band28TypeChanged(); break;
        case 160: _t->band29TypeChanged(); break;
        case 161: _t->band30TypeChanged(); break;
        case 162: _t->band31TypeChanged(); break;
        case 163: _t->band0ModeChanged(); break;
        case 164: _t->band1ModeChanged(); break;
        case 165: _t->band2ModeChanged(); break;
        case 166: _t->band3ModeChanged(); break;
        case 167: _t->band4ModeChanged(); break;
        case 168: _t->band5ModeChanged(); break;
        case 169: _t->band6ModeChanged(); break;
        case 170: _t->band7ModeChanged(); break;
        case 171: _t->band8ModeChanged(); break;
        case 172: _t->band9ModeChanged(); break;
        case 173: _t->band10ModeChanged(); break;
        case 174: _t->band11ModeChanged(); break;
        case 175: _t->band12ModeChanged(); break;
        case 176: _t->band13ModeChanged(); break;
        case 177: _t->band14ModeChanged(); break;
        case 178: _t->band15ModeChanged(); break;
        case 179: _t->band16ModeChanged(); break;
        case 180: _t->band17ModeChanged(); break;
        case 181: _t->band18ModeChanged(); break;
        case 182: _t->band19ModeChanged(); break;
        case 183: _t->band20ModeChanged(); break;
        case 184: _t->band21ModeChanged(); break;
        case 185: _t->band22ModeChanged(); break;
        case 186: _t->band23ModeChanged(); break;
        case 187: _t->band24ModeChanged(); break;
        case 188: _t->band25ModeChanged(); break;
        case 189: _t->band26ModeChanged(); break;
        case 190: _t->band27ModeChanged(); break;
        case 191: _t->band28ModeChanged(); break;
        case 192: _t->band29ModeChanged(); break;
        case 193: _t->band30ModeChanged(); break;
        case 194: _t->band31ModeChanged(); break;
        case 195: _t->band0SlopeChanged(); break;
        case 196: _t->band1SlopeChanged(); break;
        case 197: _t->band2SlopeChanged(); break;
        case 198: _t->band3SlopeChanged(); break;
        case 199: _t->band4SlopeChanged(); break;
        case 200: _t->band5SlopeChanged(); break;
        case 201: _t->band6SlopeChanged(); break;
        case 202: _t->band7SlopeChanged(); break;
        case 203: _t->band8SlopeChanged(); break;
        case 204: _t->band9SlopeChanged(); break;
        case 205: _t->band10SlopeChanged(); break;
        case 206: _t->band11SlopeChanged(); break;
        case 207: _t->band12SlopeChanged(); break;
        case 208: _t->band13SlopeChanged(); break;
        case 209: _t->band14SlopeChanged(); break;
        case 210: _t->band15SlopeChanged(); break;
        case 211: _t->band16SlopeChanged(); break;
        case 212: _t->band17SlopeChanged(); break;
        case 213: _t->band18SlopeChanged(); break;
        case 214: _t->band19SlopeChanged(); break;
        case 215: _t->band20SlopeChanged(); break;
        case 216: _t->band21SlopeChanged(); break;
        case 217: _t->band22SlopeChanged(); break;
        case 218: _t->band23SlopeChanged(); break;
        case 219: _t->band24SlopeChanged(); break;
        case 220: _t->band25SlopeChanged(); break;
        case 221: _t->band26SlopeChanged(); break;
        case 222: _t->band27SlopeChanged(); break;
        case 223: _t->band28SlopeChanged(); break;
        case 224: _t->band29SlopeChanged(); break;
        case 225: _t->band30SlopeChanged(); break;
        case 226: _t->band31SlopeChanged(); break;
        case 227: _t->band0SoloChanged(); break;
        case 228: _t->band1SoloChanged(); break;
        case 229: _t->band2SoloChanged(); break;
        case 230: _t->band3SoloChanged(); break;
        case 231: _t->band4SoloChanged(); break;
        case 232: _t->band5SoloChanged(); break;
        case 233: _t->band6SoloChanged(); break;
        case 234: _t->band7SoloChanged(); break;
        case 235: _t->band8SoloChanged(); break;
        case 236: _t->band9SoloChanged(); break;
        case 237: _t->band10SoloChanged(); break;
        case 238: _t->band11SoloChanged(); break;
        case 239: _t->band12SoloChanged(); break;
        case 240: _t->band13SoloChanged(); break;
        case 241: _t->band14SoloChanged(); break;
        case 242: _t->band15SoloChanged(); break;
        case 243: _t->band16SoloChanged(); break;
        case 244: _t->band17SoloChanged(); break;
        case 245: _t->band18SoloChanged(); break;
        case 246: _t->band19SoloChanged(); break;
        case 247: _t->band20SoloChanged(); break;
        case 248: _t->band21SoloChanged(); break;
        case 249: _t->band22SoloChanged(); break;
        case 250: _t->band23SoloChanged(); break;
        case 251: _t->band24SoloChanged(); break;
        case 252: _t->band25SoloChanged(); break;
        case 253: _t->band26SoloChanged(); break;
        case 254: _t->band27SoloChanged(); break;
        case 255: _t->band28SoloChanged(); break;
        case 256: _t->band29SoloChanged(); break;
        case 257: _t->band30SoloChanged(); break;
        case 258: _t->band31SoloChanged(); break;
        case 259: _t->band0MuteChanged(); break;
        case 260: _t->band1MuteChanged(); break;
        case 261: _t->band2MuteChanged(); break;
        case 262: _t->band3MuteChanged(); break;
        case 263: _t->band4MuteChanged(); break;
        case 264: _t->band5MuteChanged(); break;
        case 265: _t->band6MuteChanged(); break;
        case 266: _t->band7MuteChanged(); break;
        case 267: _t->band8MuteChanged(); break;
        case 268: _t->band9MuteChanged(); break;
        case 269: _t->band10MuteChanged(); break;
        case 270: _t->band11MuteChanged(); break;
        case 271: _t->band12MuteChanged(); break;
        case 272: _t->band13MuteChanged(); break;
        case 273: _t->band14MuteChanged(); break;
        case 274: _t->band15MuteChanged(); break;
        case 275: _t->band16MuteChanged(); break;
        case 276: _t->band17MuteChanged(); break;
        case 277: _t->band18MuteChanged(); break;
        case 278: _t->band19MuteChanged(); break;
        case 279: _t->band20MuteChanged(); break;
        case 280: _t->band21MuteChanged(); break;
        case 281: _t->band22MuteChanged(); break;
        case 282: _t->band23MuteChanged(); break;
        case 283: _t->band24MuteChanged(); break;
        case 284: _t->band25MuteChanged(); break;
        case 285: _t->band26MuteChanged(); break;
        case 286: _t->band27MuteChanged(); break;
        case 287: _t->band28MuteChanged(); break;
        case 288: _t->band29MuteChanged(); break;
        case 289: _t->band30MuteChanged(); break;
        case 290: _t->band31MuteChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::bandModeLabelsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::bandTypeLabelsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::bandSlopeLabelsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band0GainChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band1GainChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band2GainChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band3GainChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band4GainChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band5GainChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band6GainChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band7GainChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band8GainChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band9GainChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band10GainChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band11GainChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band12GainChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band13GainChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band14GainChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band15GainChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band16GainChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band17GainChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band18GainChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band19GainChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band20GainChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band21GainChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band22GainChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band23GainChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band24GainChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band25GainChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band26GainChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band27GainChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band28GainChanged, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band29GainChanged, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band30GainChanged, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band31GainChanged, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band0FrequencyChanged, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band1FrequencyChanged, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band2FrequencyChanged, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band3FrequencyChanged, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band4FrequencyChanged, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band5FrequencyChanged, 40))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band6FrequencyChanged, 41))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band7FrequencyChanged, 42))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band8FrequencyChanged, 43))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band9FrequencyChanged, 44))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band10FrequencyChanged, 45))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band11FrequencyChanged, 46))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band12FrequencyChanged, 47))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band13FrequencyChanged, 48))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band14FrequencyChanged, 49))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band15FrequencyChanged, 50))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band16FrequencyChanged, 51))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band17FrequencyChanged, 52))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band18FrequencyChanged, 53))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band19FrequencyChanged, 54))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band20FrequencyChanged, 55))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band21FrequencyChanged, 56))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band22FrequencyChanged, 57))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band23FrequencyChanged, 58))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band24FrequencyChanged, 59))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band25FrequencyChanged, 60))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band26FrequencyChanged, 61))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band27FrequencyChanged, 62))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band28FrequencyChanged, 63))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band29FrequencyChanged, 64))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band30FrequencyChanged, 65))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band31FrequencyChanged, 66))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band0QChanged, 67))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band1QChanged, 68))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band2QChanged, 69))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band3QChanged, 70))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band4QChanged, 71))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band5QChanged, 72))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band6QChanged, 73))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band7QChanged, 74))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band8QChanged, 75))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band9QChanged, 76))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band10QChanged, 77))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band11QChanged, 78))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band12QChanged, 79))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band13QChanged, 80))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band14QChanged, 81))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band15QChanged, 82))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band16QChanged, 83))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band17QChanged, 84))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band18QChanged, 85))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band19QChanged, 86))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band20QChanged, 87))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band21QChanged, 88))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band22QChanged, 89))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band23QChanged, 90))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band24QChanged, 91))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band25QChanged, 92))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band26QChanged, 93))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band27QChanged, 94))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band28QChanged, 95))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band29QChanged, 96))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band30QChanged, 97))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band31QChanged, 98))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band0WidthChanged, 99))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band1WidthChanged, 100))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band2WidthChanged, 101))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band3WidthChanged, 102))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band4WidthChanged, 103))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band5WidthChanged, 104))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band6WidthChanged, 105))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band7WidthChanged, 106))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band8WidthChanged, 107))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band9WidthChanged, 108))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band10WidthChanged, 109))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band11WidthChanged, 110))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band12WidthChanged, 111))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band13WidthChanged, 112))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band14WidthChanged, 113))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band15WidthChanged, 114))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band16WidthChanged, 115))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band17WidthChanged, 116))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band18WidthChanged, 117))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band19WidthChanged, 118))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band20WidthChanged, 119))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band21WidthChanged, 120))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band22WidthChanged, 121))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band23WidthChanged, 122))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band24WidthChanged, 123))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band25WidthChanged, 124))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band26WidthChanged, 125))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band27WidthChanged, 126))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band28WidthChanged, 127))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band29WidthChanged, 128))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band30WidthChanged, 129))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band31WidthChanged, 130))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band0TypeChanged, 131))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band1TypeChanged, 132))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band2TypeChanged, 133))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band3TypeChanged, 134))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band4TypeChanged, 135))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band5TypeChanged, 136))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band6TypeChanged, 137))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band7TypeChanged, 138))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band8TypeChanged, 139))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band9TypeChanged, 140))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band10TypeChanged, 141))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band11TypeChanged, 142))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band12TypeChanged, 143))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band13TypeChanged, 144))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band14TypeChanged, 145))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band15TypeChanged, 146))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band16TypeChanged, 147))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band17TypeChanged, 148))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band18TypeChanged, 149))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band19TypeChanged, 150))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band20TypeChanged, 151))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band21TypeChanged, 152))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band22TypeChanged, 153))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band23TypeChanged, 154))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band24TypeChanged, 155))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band25TypeChanged, 156))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band26TypeChanged, 157))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band27TypeChanged, 158))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band28TypeChanged, 159))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band29TypeChanged, 160))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band30TypeChanged, 161))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band31TypeChanged, 162))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band0ModeChanged, 163))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band1ModeChanged, 164))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band2ModeChanged, 165))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band3ModeChanged, 166))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band4ModeChanged, 167))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band5ModeChanged, 168))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band6ModeChanged, 169))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band7ModeChanged, 170))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band8ModeChanged, 171))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band9ModeChanged, 172))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band10ModeChanged, 173))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band11ModeChanged, 174))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band12ModeChanged, 175))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band13ModeChanged, 176))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band14ModeChanged, 177))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band15ModeChanged, 178))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band16ModeChanged, 179))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band17ModeChanged, 180))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band18ModeChanged, 181))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band19ModeChanged, 182))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band20ModeChanged, 183))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band21ModeChanged, 184))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band22ModeChanged, 185))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band23ModeChanged, 186))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band24ModeChanged, 187))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band25ModeChanged, 188))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band26ModeChanged, 189))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band27ModeChanged, 190))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band28ModeChanged, 191))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band29ModeChanged, 192))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band30ModeChanged, 193))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band31ModeChanged, 194))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band0SlopeChanged, 195))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band1SlopeChanged, 196))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band2SlopeChanged, 197))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band3SlopeChanged, 198))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band4SlopeChanged, 199))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band5SlopeChanged, 200))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band6SlopeChanged, 201))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band7SlopeChanged, 202))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band8SlopeChanged, 203))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band9SlopeChanged, 204))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band10SlopeChanged, 205))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band11SlopeChanged, 206))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band12SlopeChanged, 207))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band13SlopeChanged, 208))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band14SlopeChanged, 209))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band15SlopeChanged, 210))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band16SlopeChanged, 211))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band17SlopeChanged, 212))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band18SlopeChanged, 213))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band19SlopeChanged, 214))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band20SlopeChanged, 215))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band21SlopeChanged, 216))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band22SlopeChanged, 217))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band23SlopeChanged, 218))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band24SlopeChanged, 219))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band25SlopeChanged, 220))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band26SlopeChanged, 221))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band27SlopeChanged, 222))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band28SlopeChanged, 223))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band29SlopeChanged, 224))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band30SlopeChanged, 225))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band31SlopeChanged, 226))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band0SoloChanged, 227))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band1SoloChanged, 228))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band2SoloChanged, 229))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band3SoloChanged, 230))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band4SoloChanged, 231))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band5SoloChanged, 232))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band6SoloChanged, 233))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band7SoloChanged, 234))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band8SoloChanged, 235))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band9SoloChanged, 236))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band10SoloChanged, 237))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band11SoloChanged, 238))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band12SoloChanged, 239))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band13SoloChanged, 240))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band14SoloChanged, 241))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band15SoloChanged, 242))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band16SoloChanged, 243))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band17SoloChanged, 244))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band18SoloChanged, 245))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band19SoloChanged, 246))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band20SoloChanged, 247))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band21SoloChanged, 248))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band22SoloChanged, 249))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band23SoloChanged, 250))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band24SoloChanged, 251))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band25SoloChanged, 252))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band26SoloChanged, 253))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band27SoloChanged, 254))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band28SoloChanged, 255))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band29SoloChanged, 256))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band30SoloChanged, 257))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band31SoloChanged, 258))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band0MuteChanged, 259))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band1MuteChanged, 260))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band2MuteChanged, 261))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band3MuteChanged, 262))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band4MuteChanged, 263))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band5MuteChanged, 264))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band6MuteChanged, 265))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band7MuteChanged, 266))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band8MuteChanged, 267))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band9MuteChanged, 268))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band10MuteChanged, 269))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band11MuteChanged, 270))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band12MuteChanged, 271))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band13MuteChanged, 272))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band14MuteChanged, 273))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band15MuteChanged, 274))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band16MuteChanged, 275))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band17MuteChanged, 276))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band18MuteChanged, 277))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band19MuteChanged, 278))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band20MuteChanged, 279))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band21MuteChanged, 280))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band22MuteChanged, 281))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band23MuteChanged, 282))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band24MuteChanged, 283))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band25MuteChanged, 284))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band26MuteChanged, 285))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band27MuteChanged, 286))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band28MuteChanged, 287))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band29MuteChanged, 288))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band30MuteChanged, 289))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbEqualizerChannel::*)()>(_a, &DbEqualizerChannel::band31MuteChanged, 290))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->bandModeLabels(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isBandModeLabelsImmutable(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->defaultBandModeLabelsValue(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->bandTypeLabels(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isBandTypeLabelsImmutable(); break;
        case 5: *reinterpret_cast<QStringList*>(_v) = _t->defaultBandTypeLabelsValue(); break;
        case 6: *reinterpret_cast<QStringList*>(_v) = _t->bandSlopeLabels(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isBandSlopeLabelsImmutable(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->defaultBandSlopeLabelsValue(); break;
        case 9: *reinterpret_cast<double*>(_v) = _t->band0Gain(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isBand0GainImmutable(); break;
        case 11: *reinterpret_cast<double*>(_v) = _t->defaultBand0GainValue(); break;
        case 12: *reinterpret_cast<double*>(_v) = _t->band1Gain(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isBand1GainImmutable(); break;
        case 14: *reinterpret_cast<double*>(_v) = _t->defaultBand1GainValue(); break;
        case 15: *reinterpret_cast<double*>(_v) = _t->band2Gain(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isBand2GainImmutable(); break;
        case 17: *reinterpret_cast<double*>(_v) = _t->defaultBand2GainValue(); break;
        case 18: *reinterpret_cast<double*>(_v) = _t->band3Gain(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isBand3GainImmutable(); break;
        case 20: *reinterpret_cast<double*>(_v) = _t->defaultBand3GainValue(); break;
        case 21: *reinterpret_cast<double*>(_v) = _t->band4Gain(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isBand4GainImmutable(); break;
        case 23: *reinterpret_cast<double*>(_v) = _t->defaultBand4GainValue(); break;
        case 24: *reinterpret_cast<double*>(_v) = _t->band5Gain(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isBand5GainImmutable(); break;
        case 26: *reinterpret_cast<double*>(_v) = _t->defaultBand5GainValue(); break;
        case 27: *reinterpret_cast<double*>(_v) = _t->band6Gain(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isBand6GainImmutable(); break;
        case 29: *reinterpret_cast<double*>(_v) = _t->defaultBand6GainValue(); break;
        case 30: *reinterpret_cast<double*>(_v) = _t->band7Gain(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isBand7GainImmutable(); break;
        case 32: *reinterpret_cast<double*>(_v) = _t->defaultBand7GainValue(); break;
        case 33: *reinterpret_cast<double*>(_v) = _t->band8Gain(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isBand8GainImmutable(); break;
        case 35: *reinterpret_cast<double*>(_v) = _t->defaultBand8GainValue(); break;
        case 36: *reinterpret_cast<double*>(_v) = _t->band9Gain(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isBand9GainImmutable(); break;
        case 38: *reinterpret_cast<double*>(_v) = _t->defaultBand9GainValue(); break;
        case 39: *reinterpret_cast<double*>(_v) = _t->band10Gain(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->isBand10GainImmutable(); break;
        case 41: *reinterpret_cast<double*>(_v) = _t->defaultBand10GainValue(); break;
        case 42: *reinterpret_cast<double*>(_v) = _t->band11Gain(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->isBand11GainImmutable(); break;
        case 44: *reinterpret_cast<double*>(_v) = _t->defaultBand11GainValue(); break;
        case 45: *reinterpret_cast<double*>(_v) = _t->band12Gain(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->isBand12GainImmutable(); break;
        case 47: *reinterpret_cast<double*>(_v) = _t->defaultBand12GainValue(); break;
        case 48: *reinterpret_cast<double*>(_v) = _t->band13Gain(); break;
        case 49: *reinterpret_cast<bool*>(_v) = _t->isBand13GainImmutable(); break;
        case 50: *reinterpret_cast<double*>(_v) = _t->defaultBand13GainValue(); break;
        case 51: *reinterpret_cast<double*>(_v) = _t->band14Gain(); break;
        case 52: *reinterpret_cast<bool*>(_v) = _t->isBand14GainImmutable(); break;
        case 53: *reinterpret_cast<double*>(_v) = _t->defaultBand14GainValue(); break;
        case 54: *reinterpret_cast<double*>(_v) = _t->band15Gain(); break;
        case 55: *reinterpret_cast<bool*>(_v) = _t->isBand15GainImmutable(); break;
        case 56: *reinterpret_cast<double*>(_v) = _t->defaultBand15GainValue(); break;
        case 57: *reinterpret_cast<double*>(_v) = _t->band16Gain(); break;
        case 58: *reinterpret_cast<bool*>(_v) = _t->isBand16GainImmutable(); break;
        case 59: *reinterpret_cast<double*>(_v) = _t->defaultBand16GainValue(); break;
        case 60: *reinterpret_cast<double*>(_v) = _t->band17Gain(); break;
        case 61: *reinterpret_cast<bool*>(_v) = _t->isBand17GainImmutable(); break;
        case 62: *reinterpret_cast<double*>(_v) = _t->defaultBand17GainValue(); break;
        case 63: *reinterpret_cast<double*>(_v) = _t->band18Gain(); break;
        case 64: *reinterpret_cast<bool*>(_v) = _t->isBand18GainImmutable(); break;
        case 65: *reinterpret_cast<double*>(_v) = _t->defaultBand18GainValue(); break;
        case 66: *reinterpret_cast<double*>(_v) = _t->band19Gain(); break;
        case 67: *reinterpret_cast<bool*>(_v) = _t->isBand19GainImmutable(); break;
        case 68: *reinterpret_cast<double*>(_v) = _t->defaultBand19GainValue(); break;
        case 69: *reinterpret_cast<double*>(_v) = _t->band20Gain(); break;
        case 70: *reinterpret_cast<bool*>(_v) = _t->isBand20GainImmutable(); break;
        case 71: *reinterpret_cast<double*>(_v) = _t->defaultBand20GainValue(); break;
        case 72: *reinterpret_cast<double*>(_v) = _t->band21Gain(); break;
        case 73: *reinterpret_cast<bool*>(_v) = _t->isBand21GainImmutable(); break;
        case 74: *reinterpret_cast<double*>(_v) = _t->defaultBand21GainValue(); break;
        case 75: *reinterpret_cast<double*>(_v) = _t->band22Gain(); break;
        case 76: *reinterpret_cast<bool*>(_v) = _t->isBand22GainImmutable(); break;
        case 77: *reinterpret_cast<double*>(_v) = _t->defaultBand22GainValue(); break;
        case 78: *reinterpret_cast<double*>(_v) = _t->band23Gain(); break;
        case 79: *reinterpret_cast<bool*>(_v) = _t->isBand23GainImmutable(); break;
        case 80: *reinterpret_cast<double*>(_v) = _t->defaultBand23GainValue(); break;
        case 81: *reinterpret_cast<double*>(_v) = _t->band24Gain(); break;
        case 82: *reinterpret_cast<bool*>(_v) = _t->isBand24GainImmutable(); break;
        case 83: *reinterpret_cast<double*>(_v) = _t->defaultBand24GainValue(); break;
        case 84: *reinterpret_cast<double*>(_v) = _t->band25Gain(); break;
        case 85: *reinterpret_cast<bool*>(_v) = _t->isBand25GainImmutable(); break;
        case 86: *reinterpret_cast<double*>(_v) = _t->defaultBand25GainValue(); break;
        case 87: *reinterpret_cast<double*>(_v) = _t->band26Gain(); break;
        case 88: *reinterpret_cast<bool*>(_v) = _t->isBand26GainImmutable(); break;
        case 89: *reinterpret_cast<double*>(_v) = _t->defaultBand26GainValue(); break;
        case 90: *reinterpret_cast<double*>(_v) = _t->band27Gain(); break;
        case 91: *reinterpret_cast<bool*>(_v) = _t->isBand27GainImmutable(); break;
        case 92: *reinterpret_cast<double*>(_v) = _t->defaultBand27GainValue(); break;
        case 93: *reinterpret_cast<double*>(_v) = _t->band28Gain(); break;
        case 94: *reinterpret_cast<bool*>(_v) = _t->isBand28GainImmutable(); break;
        case 95: *reinterpret_cast<double*>(_v) = _t->defaultBand28GainValue(); break;
        case 96: *reinterpret_cast<double*>(_v) = _t->band29Gain(); break;
        case 97: *reinterpret_cast<bool*>(_v) = _t->isBand29GainImmutable(); break;
        case 98: *reinterpret_cast<double*>(_v) = _t->defaultBand29GainValue(); break;
        case 99: *reinterpret_cast<double*>(_v) = _t->band30Gain(); break;
        case 100: *reinterpret_cast<bool*>(_v) = _t->isBand30GainImmutable(); break;
        case 101: *reinterpret_cast<double*>(_v) = _t->defaultBand30GainValue(); break;
        case 102: *reinterpret_cast<double*>(_v) = _t->band31Gain(); break;
        case 103: *reinterpret_cast<bool*>(_v) = _t->isBand31GainImmutable(); break;
        case 104: *reinterpret_cast<double*>(_v) = _t->defaultBand31GainValue(); break;
        case 105: *reinterpret_cast<double*>(_v) = _t->band0Frequency(); break;
        case 106: *reinterpret_cast<bool*>(_v) = _t->isBand0FrequencyImmutable(); break;
        case 107: *reinterpret_cast<double*>(_v) = _t->defaultBand0FrequencyValue(); break;
        case 108: *reinterpret_cast<double*>(_v) = _t->band1Frequency(); break;
        case 109: *reinterpret_cast<bool*>(_v) = _t->isBand1FrequencyImmutable(); break;
        case 110: *reinterpret_cast<double*>(_v) = _t->defaultBand1FrequencyValue(); break;
        case 111: *reinterpret_cast<double*>(_v) = _t->band2Frequency(); break;
        case 112: *reinterpret_cast<bool*>(_v) = _t->isBand2FrequencyImmutable(); break;
        case 113: *reinterpret_cast<double*>(_v) = _t->defaultBand2FrequencyValue(); break;
        case 114: *reinterpret_cast<double*>(_v) = _t->band3Frequency(); break;
        case 115: *reinterpret_cast<bool*>(_v) = _t->isBand3FrequencyImmutable(); break;
        case 116: *reinterpret_cast<double*>(_v) = _t->defaultBand3FrequencyValue(); break;
        case 117: *reinterpret_cast<double*>(_v) = _t->band4Frequency(); break;
        case 118: *reinterpret_cast<bool*>(_v) = _t->isBand4FrequencyImmutable(); break;
        case 119: *reinterpret_cast<double*>(_v) = _t->defaultBand4FrequencyValue(); break;
        case 120: *reinterpret_cast<double*>(_v) = _t->band5Frequency(); break;
        case 121: *reinterpret_cast<bool*>(_v) = _t->isBand5FrequencyImmutable(); break;
        case 122: *reinterpret_cast<double*>(_v) = _t->defaultBand5FrequencyValue(); break;
        case 123: *reinterpret_cast<double*>(_v) = _t->band6Frequency(); break;
        case 124: *reinterpret_cast<bool*>(_v) = _t->isBand6FrequencyImmutable(); break;
        case 125: *reinterpret_cast<double*>(_v) = _t->defaultBand6FrequencyValue(); break;
        case 126: *reinterpret_cast<double*>(_v) = _t->band7Frequency(); break;
        case 127: *reinterpret_cast<bool*>(_v) = _t->isBand7FrequencyImmutable(); break;
        case 128: *reinterpret_cast<double*>(_v) = _t->defaultBand7FrequencyValue(); break;
        case 129: *reinterpret_cast<double*>(_v) = _t->band8Frequency(); break;
        case 130: *reinterpret_cast<bool*>(_v) = _t->isBand8FrequencyImmutable(); break;
        case 131: *reinterpret_cast<double*>(_v) = _t->defaultBand8FrequencyValue(); break;
        case 132: *reinterpret_cast<double*>(_v) = _t->band9Frequency(); break;
        case 133: *reinterpret_cast<bool*>(_v) = _t->isBand9FrequencyImmutable(); break;
        case 134: *reinterpret_cast<double*>(_v) = _t->defaultBand9FrequencyValue(); break;
        case 135: *reinterpret_cast<double*>(_v) = _t->band10Frequency(); break;
        case 136: *reinterpret_cast<bool*>(_v) = _t->isBand10FrequencyImmutable(); break;
        case 137: *reinterpret_cast<double*>(_v) = _t->defaultBand10FrequencyValue(); break;
        case 138: *reinterpret_cast<double*>(_v) = _t->band11Frequency(); break;
        case 139: *reinterpret_cast<bool*>(_v) = _t->isBand11FrequencyImmutable(); break;
        case 140: *reinterpret_cast<double*>(_v) = _t->defaultBand11FrequencyValue(); break;
        case 141: *reinterpret_cast<double*>(_v) = _t->band12Frequency(); break;
        case 142: *reinterpret_cast<bool*>(_v) = _t->isBand12FrequencyImmutable(); break;
        case 143: *reinterpret_cast<double*>(_v) = _t->defaultBand12FrequencyValue(); break;
        case 144: *reinterpret_cast<double*>(_v) = _t->band13Frequency(); break;
        case 145: *reinterpret_cast<bool*>(_v) = _t->isBand13FrequencyImmutable(); break;
        case 146: *reinterpret_cast<double*>(_v) = _t->defaultBand13FrequencyValue(); break;
        case 147: *reinterpret_cast<double*>(_v) = _t->band14Frequency(); break;
        case 148: *reinterpret_cast<bool*>(_v) = _t->isBand14FrequencyImmutable(); break;
        case 149: *reinterpret_cast<double*>(_v) = _t->defaultBand14FrequencyValue(); break;
        case 150: *reinterpret_cast<double*>(_v) = _t->band15Frequency(); break;
        case 151: *reinterpret_cast<bool*>(_v) = _t->isBand15FrequencyImmutable(); break;
        case 152: *reinterpret_cast<double*>(_v) = _t->defaultBand15FrequencyValue(); break;
        case 153: *reinterpret_cast<double*>(_v) = _t->band16Frequency(); break;
        case 154: *reinterpret_cast<bool*>(_v) = _t->isBand16FrequencyImmutable(); break;
        case 155: *reinterpret_cast<double*>(_v) = _t->defaultBand16FrequencyValue(); break;
        case 156: *reinterpret_cast<double*>(_v) = _t->band17Frequency(); break;
        case 157: *reinterpret_cast<bool*>(_v) = _t->isBand17FrequencyImmutable(); break;
        case 158: *reinterpret_cast<double*>(_v) = _t->defaultBand17FrequencyValue(); break;
        case 159: *reinterpret_cast<double*>(_v) = _t->band18Frequency(); break;
        case 160: *reinterpret_cast<bool*>(_v) = _t->isBand18FrequencyImmutable(); break;
        case 161: *reinterpret_cast<double*>(_v) = _t->defaultBand18FrequencyValue(); break;
        case 162: *reinterpret_cast<double*>(_v) = _t->band19Frequency(); break;
        case 163: *reinterpret_cast<bool*>(_v) = _t->isBand19FrequencyImmutable(); break;
        case 164: *reinterpret_cast<double*>(_v) = _t->defaultBand19FrequencyValue(); break;
        case 165: *reinterpret_cast<double*>(_v) = _t->band20Frequency(); break;
        case 166: *reinterpret_cast<bool*>(_v) = _t->isBand20FrequencyImmutable(); break;
        case 167: *reinterpret_cast<double*>(_v) = _t->defaultBand20FrequencyValue(); break;
        case 168: *reinterpret_cast<double*>(_v) = _t->band21Frequency(); break;
        case 169: *reinterpret_cast<bool*>(_v) = _t->isBand21FrequencyImmutable(); break;
        case 170: *reinterpret_cast<double*>(_v) = _t->defaultBand21FrequencyValue(); break;
        case 171: *reinterpret_cast<double*>(_v) = _t->band22Frequency(); break;
        case 172: *reinterpret_cast<bool*>(_v) = _t->isBand22FrequencyImmutable(); break;
        case 173: *reinterpret_cast<double*>(_v) = _t->defaultBand22FrequencyValue(); break;
        case 174: *reinterpret_cast<double*>(_v) = _t->band23Frequency(); break;
        case 175: *reinterpret_cast<bool*>(_v) = _t->isBand23FrequencyImmutable(); break;
        case 176: *reinterpret_cast<double*>(_v) = _t->defaultBand23FrequencyValue(); break;
        case 177: *reinterpret_cast<double*>(_v) = _t->band24Frequency(); break;
        case 178: *reinterpret_cast<bool*>(_v) = _t->isBand24FrequencyImmutable(); break;
        case 179: *reinterpret_cast<double*>(_v) = _t->defaultBand24FrequencyValue(); break;
        case 180: *reinterpret_cast<double*>(_v) = _t->band25Frequency(); break;
        case 181: *reinterpret_cast<bool*>(_v) = _t->isBand25FrequencyImmutable(); break;
        case 182: *reinterpret_cast<double*>(_v) = _t->defaultBand25FrequencyValue(); break;
        case 183: *reinterpret_cast<double*>(_v) = _t->band26Frequency(); break;
        case 184: *reinterpret_cast<bool*>(_v) = _t->isBand26FrequencyImmutable(); break;
        case 185: *reinterpret_cast<double*>(_v) = _t->defaultBand26FrequencyValue(); break;
        case 186: *reinterpret_cast<double*>(_v) = _t->band27Frequency(); break;
        case 187: *reinterpret_cast<bool*>(_v) = _t->isBand27FrequencyImmutable(); break;
        case 188: *reinterpret_cast<double*>(_v) = _t->defaultBand27FrequencyValue(); break;
        case 189: *reinterpret_cast<double*>(_v) = _t->band28Frequency(); break;
        case 190: *reinterpret_cast<bool*>(_v) = _t->isBand28FrequencyImmutable(); break;
        case 191: *reinterpret_cast<double*>(_v) = _t->defaultBand28FrequencyValue(); break;
        case 192: *reinterpret_cast<double*>(_v) = _t->band29Frequency(); break;
        case 193: *reinterpret_cast<bool*>(_v) = _t->isBand29FrequencyImmutable(); break;
        case 194: *reinterpret_cast<double*>(_v) = _t->defaultBand29FrequencyValue(); break;
        case 195: *reinterpret_cast<double*>(_v) = _t->band30Frequency(); break;
        case 196: *reinterpret_cast<bool*>(_v) = _t->isBand30FrequencyImmutable(); break;
        case 197: *reinterpret_cast<double*>(_v) = _t->defaultBand30FrequencyValue(); break;
        case 198: *reinterpret_cast<double*>(_v) = _t->band31Frequency(); break;
        case 199: *reinterpret_cast<bool*>(_v) = _t->isBand31FrequencyImmutable(); break;
        case 200: *reinterpret_cast<double*>(_v) = _t->defaultBand31FrequencyValue(); break;
        case 201: *reinterpret_cast<double*>(_v) = _t->band0Q(); break;
        case 202: *reinterpret_cast<bool*>(_v) = _t->isBand0QImmutable(); break;
        case 203: *reinterpret_cast<double*>(_v) = _t->defaultBand0QValue(); break;
        case 204: *reinterpret_cast<double*>(_v) = _t->band1Q(); break;
        case 205: *reinterpret_cast<bool*>(_v) = _t->isBand1QImmutable(); break;
        case 206: *reinterpret_cast<double*>(_v) = _t->defaultBand1QValue(); break;
        case 207: *reinterpret_cast<double*>(_v) = _t->band2Q(); break;
        case 208: *reinterpret_cast<bool*>(_v) = _t->isBand2QImmutable(); break;
        case 209: *reinterpret_cast<double*>(_v) = _t->defaultBand2QValue(); break;
        case 210: *reinterpret_cast<double*>(_v) = _t->band3Q(); break;
        case 211: *reinterpret_cast<bool*>(_v) = _t->isBand3QImmutable(); break;
        case 212: *reinterpret_cast<double*>(_v) = _t->defaultBand3QValue(); break;
        case 213: *reinterpret_cast<double*>(_v) = _t->band4Q(); break;
        case 214: *reinterpret_cast<bool*>(_v) = _t->isBand4QImmutable(); break;
        case 215: *reinterpret_cast<double*>(_v) = _t->defaultBand4QValue(); break;
        case 216: *reinterpret_cast<double*>(_v) = _t->band5Q(); break;
        case 217: *reinterpret_cast<bool*>(_v) = _t->isBand5QImmutable(); break;
        case 218: *reinterpret_cast<double*>(_v) = _t->defaultBand5QValue(); break;
        case 219: *reinterpret_cast<double*>(_v) = _t->band6Q(); break;
        case 220: *reinterpret_cast<bool*>(_v) = _t->isBand6QImmutable(); break;
        case 221: *reinterpret_cast<double*>(_v) = _t->defaultBand6QValue(); break;
        case 222: *reinterpret_cast<double*>(_v) = _t->band7Q(); break;
        case 223: *reinterpret_cast<bool*>(_v) = _t->isBand7QImmutable(); break;
        case 224: *reinterpret_cast<double*>(_v) = _t->defaultBand7QValue(); break;
        case 225: *reinterpret_cast<double*>(_v) = _t->band8Q(); break;
        case 226: *reinterpret_cast<bool*>(_v) = _t->isBand8QImmutable(); break;
        case 227: *reinterpret_cast<double*>(_v) = _t->defaultBand8QValue(); break;
        case 228: *reinterpret_cast<double*>(_v) = _t->band9Q(); break;
        case 229: *reinterpret_cast<bool*>(_v) = _t->isBand9QImmutable(); break;
        case 230: *reinterpret_cast<double*>(_v) = _t->defaultBand9QValue(); break;
        case 231: *reinterpret_cast<double*>(_v) = _t->band10Q(); break;
        case 232: *reinterpret_cast<bool*>(_v) = _t->isBand10QImmutable(); break;
        case 233: *reinterpret_cast<double*>(_v) = _t->defaultBand10QValue(); break;
        case 234: *reinterpret_cast<double*>(_v) = _t->band11Q(); break;
        case 235: *reinterpret_cast<bool*>(_v) = _t->isBand11QImmutable(); break;
        case 236: *reinterpret_cast<double*>(_v) = _t->defaultBand11QValue(); break;
        case 237: *reinterpret_cast<double*>(_v) = _t->band12Q(); break;
        case 238: *reinterpret_cast<bool*>(_v) = _t->isBand12QImmutable(); break;
        case 239: *reinterpret_cast<double*>(_v) = _t->defaultBand12QValue(); break;
        case 240: *reinterpret_cast<double*>(_v) = _t->band13Q(); break;
        case 241: *reinterpret_cast<bool*>(_v) = _t->isBand13QImmutable(); break;
        case 242: *reinterpret_cast<double*>(_v) = _t->defaultBand13QValue(); break;
        case 243: *reinterpret_cast<double*>(_v) = _t->band14Q(); break;
        case 244: *reinterpret_cast<bool*>(_v) = _t->isBand14QImmutable(); break;
        case 245: *reinterpret_cast<double*>(_v) = _t->defaultBand14QValue(); break;
        case 246: *reinterpret_cast<double*>(_v) = _t->band15Q(); break;
        case 247: *reinterpret_cast<bool*>(_v) = _t->isBand15QImmutable(); break;
        case 248: *reinterpret_cast<double*>(_v) = _t->defaultBand15QValue(); break;
        case 249: *reinterpret_cast<double*>(_v) = _t->band16Q(); break;
        case 250: *reinterpret_cast<bool*>(_v) = _t->isBand16QImmutable(); break;
        case 251: *reinterpret_cast<double*>(_v) = _t->defaultBand16QValue(); break;
        case 252: *reinterpret_cast<double*>(_v) = _t->band17Q(); break;
        case 253: *reinterpret_cast<bool*>(_v) = _t->isBand17QImmutable(); break;
        case 254: *reinterpret_cast<double*>(_v) = _t->defaultBand17QValue(); break;
        case 255: *reinterpret_cast<double*>(_v) = _t->band18Q(); break;
        case 256: *reinterpret_cast<bool*>(_v) = _t->isBand18QImmutable(); break;
        case 257: *reinterpret_cast<double*>(_v) = _t->defaultBand18QValue(); break;
        case 258: *reinterpret_cast<double*>(_v) = _t->band19Q(); break;
        case 259: *reinterpret_cast<bool*>(_v) = _t->isBand19QImmutable(); break;
        case 260: *reinterpret_cast<double*>(_v) = _t->defaultBand19QValue(); break;
        case 261: *reinterpret_cast<double*>(_v) = _t->band20Q(); break;
        case 262: *reinterpret_cast<bool*>(_v) = _t->isBand20QImmutable(); break;
        case 263: *reinterpret_cast<double*>(_v) = _t->defaultBand20QValue(); break;
        case 264: *reinterpret_cast<double*>(_v) = _t->band21Q(); break;
        case 265: *reinterpret_cast<bool*>(_v) = _t->isBand21QImmutable(); break;
        case 266: *reinterpret_cast<double*>(_v) = _t->defaultBand21QValue(); break;
        case 267: *reinterpret_cast<double*>(_v) = _t->band22Q(); break;
        case 268: *reinterpret_cast<bool*>(_v) = _t->isBand22QImmutable(); break;
        case 269: *reinterpret_cast<double*>(_v) = _t->defaultBand22QValue(); break;
        case 270: *reinterpret_cast<double*>(_v) = _t->band23Q(); break;
        case 271: *reinterpret_cast<bool*>(_v) = _t->isBand23QImmutable(); break;
        case 272: *reinterpret_cast<double*>(_v) = _t->defaultBand23QValue(); break;
        case 273: *reinterpret_cast<double*>(_v) = _t->band24Q(); break;
        case 274: *reinterpret_cast<bool*>(_v) = _t->isBand24QImmutable(); break;
        case 275: *reinterpret_cast<double*>(_v) = _t->defaultBand24QValue(); break;
        case 276: *reinterpret_cast<double*>(_v) = _t->band25Q(); break;
        case 277: *reinterpret_cast<bool*>(_v) = _t->isBand25QImmutable(); break;
        case 278: *reinterpret_cast<double*>(_v) = _t->defaultBand25QValue(); break;
        case 279: *reinterpret_cast<double*>(_v) = _t->band26Q(); break;
        case 280: *reinterpret_cast<bool*>(_v) = _t->isBand26QImmutable(); break;
        case 281: *reinterpret_cast<double*>(_v) = _t->defaultBand26QValue(); break;
        case 282: *reinterpret_cast<double*>(_v) = _t->band27Q(); break;
        case 283: *reinterpret_cast<bool*>(_v) = _t->isBand27QImmutable(); break;
        case 284: *reinterpret_cast<double*>(_v) = _t->defaultBand27QValue(); break;
        case 285: *reinterpret_cast<double*>(_v) = _t->band28Q(); break;
        case 286: *reinterpret_cast<bool*>(_v) = _t->isBand28QImmutable(); break;
        case 287: *reinterpret_cast<double*>(_v) = _t->defaultBand28QValue(); break;
        case 288: *reinterpret_cast<double*>(_v) = _t->band29Q(); break;
        case 289: *reinterpret_cast<bool*>(_v) = _t->isBand29QImmutable(); break;
        case 290: *reinterpret_cast<double*>(_v) = _t->defaultBand29QValue(); break;
        case 291: *reinterpret_cast<double*>(_v) = _t->band30Q(); break;
        case 292: *reinterpret_cast<bool*>(_v) = _t->isBand30QImmutable(); break;
        case 293: *reinterpret_cast<double*>(_v) = _t->defaultBand30QValue(); break;
        case 294: *reinterpret_cast<double*>(_v) = _t->band31Q(); break;
        case 295: *reinterpret_cast<bool*>(_v) = _t->isBand31QImmutable(); break;
        case 296: *reinterpret_cast<double*>(_v) = _t->defaultBand31QValue(); break;
        case 297: *reinterpret_cast<double*>(_v) = _t->band0Width(); break;
        case 298: *reinterpret_cast<bool*>(_v) = _t->isBand0WidthImmutable(); break;
        case 299: *reinterpret_cast<double*>(_v) = _t->defaultBand0WidthValue(); break;
        case 300: *reinterpret_cast<double*>(_v) = _t->band1Width(); break;
        case 301: *reinterpret_cast<bool*>(_v) = _t->isBand1WidthImmutable(); break;
        case 302: *reinterpret_cast<double*>(_v) = _t->defaultBand1WidthValue(); break;
        case 303: *reinterpret_cast<double*>(_v) = _t->band2Width(); break;
        case 304: *reinterpret_cast<bool*>(_v) = _t->isBand2WidthImmutable(); break;
        case 305: *reinterpret_cast<double*>(_v) = _t->defaultBand2WidthValue(); break;
        case 306: *reinterpret_cast<double*>(_v) = _t->band3Width(); break;
        case 307: *reinterpret_cast<bool*>(_v) = _t->isBand3WidthImmutable(); break;
        case 308: *reinterpret_cast<double*>(_v) = _t->defaultBand3WidthValue(); break;
        case 309: *reinterpret_cast<double*>(_v) = _t->band4Width(); break;
        case 310: *reinterpret_cast<bool*>(_v) = _t->isBand4WidthImmutable(); break;
        case 311: *reinterpret_cast<double*>(_v) = _t->defaultBand4WidthValue(); break;
        case 312: *reinterpret_cast<double*>(_v) = _t->band5Width(); break;
        case 313: *reinterpret_cast<bool*>(_v) = _t->isBand5WidthImmutable(); break;
        case 314: *reinterpret_cast<double*>(_v) = _t->defaultBand5WidthValue(); break;
        case 315: *reinterpret_cast<double*>(_v) = _t->band6Width(); break;
        case 316: *reinterpret_cast<bool*>(_v) = _t->isBand6WidthImmutable(); break;
        case 317: *reinterpret_cast<double*>(_v) = _t->defaultBand6WidthValue(); break;
        case 318: *reinterpret_cast<double*>(_v) = _t->band7Width(); break;
        case 319: *reinterpret_cast<bool*>(_v) = _t->isBand7WidthImmutable(); break;
        case 320: *reinterpret_cast<double*>(_v) = _t->defaultBand7WidthValue(); break;
        case 321: *reinterpret_cast<double*>(_v) = _t->band8Width(); break;
        case 322: *reinterpret_cast<bool*>(_v) = _t->isBand8WidthImmutable(); break;
        case 323: *reinterpret_cast<double*>(_v) = _t->defaultBand8WidthValue(); break;
        case 324: *reinterpret_cast<double*>(_v) = _t->band9Width(); break;
        case 325: *reinterpret_cast<bool*>(_v) = _t->isBand9WidthImmutable(); break;
        case 326: *reinterpret_cast<double*>(_v) = _t->defaultBand9WidthValue(); break;
        case 327: *reinterpret_cast<double*>(_v) = _t->band10Width(); break;
        case 328: *reinterpret_cast<bool*>(_v) = _t->isBand10WidthImmutable(); break;
        case 329: *reinterpret_cast<double*>(_v) = _t->defaultBand10WidthValue(); break;
        case 330: *reinterpret_cast<double*>(_v) = _t->band11Width(); break;
        case 331: *reinterpret_cast<bool*>(_v) = _t->isBand11WidthImmutable(); break;
        case 332: *reinterpret_cast<double*>(_v) = _t->defaultBand11WidthValue(); break;
        case 333: *reinterpret_cast<double*>(_v) = _t->band12Width(); break;
        case 334: *reinterpret_cast<bool*>(_v) = _t->isBand12WidthImmutable(); break;
        case 335: *reinterpret_cast<double*>(_v) = _t->defaultBand12WidthValue(); break;
        case 336: *reinterpret_cast<double*>(_v) = _t->band13Width(); break;
        case 337: *reinterpret_cast<bool*>(_v) = _t->isBand13WidthImmutable(); break;
        case 338: *reinterpret_cast<double*>(_v) = _t->defaultBand13WidthValue(); break;
        case 339: *reinterpret_cast<double*>(_v) = _t->band14Width(); break;
        case 340: *reinterpret_cast<bool*>(_v) = _t->isBand14WidthImmutable(); break;
        case 341: *reinterpret_cast<double*>(_v) = _t->defaultBand14WidthValue(); break;
        case 342: *reinterpret_cast<double*>(_v) = _t->band15Width(); break;
        case 343: *reinterpret_cast<bool*>(_v) = _t->isBand15WidthImmutable(); break;
        case 344: *reinterpret_cast<double*>(_v) = _t->defaultBand15WidthValue(); break;
        case 345: *reinterpret_cast<double*>(_v) = _t->band16Width(); break;
        case 346: *reinterpret_cast<bool*>(_v) = _t->isBand16WidthImmutable(); break;
        case 347: *reinterpret_cast<double*>(_v) = _t->defaultBand16WidthValue(); break;
        case 348: *reinterpret_cast<double*>(_v) = _t->band17Width(); break;
        case 349: *reinterpret_cast<bool*>(_v) = _t->isBand17WidthImmutable(); break;
        case 350: *reinterpret_cast<double*>(_v) = _t->defaultBand17WidthValue(); break;
        case 351: *reinterpret_cast<double*>(_v) = _t->band18Width(); break;
        case 352: *reinterpret_cast<bool*>(_v) = _t->isBand18WidthImmutable(); break;
        case 353: *reinterpret_cast<double*>(_v) = _t->defaultBand18WidthValue(); break;
        case 354: *reinterpret_cast<double*>(_v) = _t->band19Width(); break;
        case 355: *reinterpret_cast<bool*>(_v) = _t->isBand19WidthImmutable(); break;
        case 356: *reinterpret_cast<double*>(_v) = _t->defaultBand19WidthValue(); break;
        case 357: *reinterpret_cast<double*>(_v) = _t->band20Width(); break;
        case 358: *reinterpret_cast<bool*>(_v) = _t->isBand20WidthImmutable(); break;
        case 359: *reinterpret_cast<double*>(_v) = _t->defaultBand20WidthValue(); break;
        case 360: *reinterpret_cast<double*>(_v) = _t->band21Width(); break;
        case 361: *reinterpret_cast<bool*>(_v) = _t->isBand21WidthImmutable(); break;
        case 362: *reinterpret_cast<double*>(_v) = _t->defaultBand21WidthValue(); break;
        case 363: *reinterpret_cast<double*>(_v) = _t->band22Width(); break;
        case 364: *reinterpret_cast<bool*>(_v) = _t->isBand22WidthImmutable(); break;
        case 365: *reinterpret_cast<double*>(_v) = _t->defaultBand22WidthValue(); break;
        case 366: *reinterpret_cast<double*>(_v) = _t->band23Width(); break;
        case 367: *reinterpret_cast<bool*>(_v) = _t->isBand23WidthImmutable(); break;
        case 368: *reinterpret_cast<double*>(_v) = _t->defaultBand23WidthValue(); break;
        case 369: *reinterpret_cast<double*>(_v) = _t->band24Width(); break;
        case 370: *reinterpret_cast<bool*>(_v) = _t->isBand24WidthImmutable(); break;
        case 371: *reinterpret_cast<double*>(_v) = _t->defaultBand24WidthValue(); break;
        case 372: *reinterpret_cast<double*>(_v) = _t->band25Width(); break;
        case 373: *reinterpret_cast<bool*>(_v) = _t->isBand25WidthImmutable(); break;
        case 374: *reinterpret_cast<double*>(_v) = _t->defaultBand25WidthValue(); break;
        case 375: *reinterpret_cast<double*>(_v) = _t->band26Width(); break;
        case 376: *reinterpret_cast<bool*>(_v) = _t->isBand26WidthImmutable(); break;
        case 377: *reinterpret_cast<double*>(_v) = _t->defaultBand26WidthValue(); break;
        case 378: *reinterpret_cast<double*>(_v) = _t->band27Width(); break;
        case 379: *reinterpret_cast<bool*>(_v) = _t->isBand27WidthImmutable(); break;
        case 380: *reinterpret_cast<double*>(_v) = _t->defaultBand27WidthValue(); break;
        case 381: *reinterpret_cast<double*>(_v) = _t->band28Width(); break;
        case 382: *reinterpret_cast<bool*>(_v) = _t->isBand28WidthImmutable(); break;
        case 383: *reinterpret_cast<double*>(_v) = _t->defaultBand28WidthValue(); break;
        case 384: *reinterpret_cast<double*>(_v) = _t->band29Width(); break;
        case 385: *reinterpret_cast<bool*>(_v) = _t->isBand29WidthImmutable(); break;
        case 386: *reinterpret_cast<double*>(_v) = _t->defaultBand29WidthValue(); break;
        case 387: *reinterpret_cast<double*>(_v) = _t->band30Width(); break;
        case 388: *reinterpret_cast<bool*>(_v) = _t->isBand30WidthImmutable(); break;
        case 389: *reinterpret_cast<double*>(_v) = _t->defaultBand30WidthValue(); break;
        case 390: *reinterpret_cast<double*>(_v) = _t->band31Width(); break;
        case 391: *reinterpret_cast<bool*>(_v) = _t->isBand31WidthImmutable(); break;
        case 392: *reinterpret_cast<double*>(_v) = _t->defaultBand31WidthValue(); break;
        case 393: *reinterpret_cast<int*>(_v) = _t->band0Type(); break;
        case 394: *reinterpret_cast<bool*>(_v) = _t->isBand0TypeImmutable(); break;
        case 395: *reinterpret_cast<int*>(_v) = _t->defaultBand0TypeValue(); break;
        case 396: *reinterpret_cast<int*>(_v) = _t->band1Type(); break;
        case 397: *reinterpret_cast<bool*>(_v) = _t->isBand1TypeImmutable(); break;
        case 398: *reinterpret_cast<int*>(_v) = _t->defaultBand1TypeValue(); break;
        case 399: *reinterpret_cast<int*>(_v) = _t->band2Type(); break;
        case 400: *reinterpret_cast<bool*>(_v) = _t->isBand2TypeImmutable(); break;
        case 401: *reinterpret_cast<int*>(_v) = _t->defaultBand2TypeValue(); break;
        case 402: *reinterpret_cast<int*>(_v) = _t->band3Type(); break;
        case 403: *reinterpret_cast<bool*>(_v) = _t->isBand3TypeImmutable(); break;
        case 404: *reinterpret_cast<int*>(_v) = _t->defaultBand3TypeValue(); break;
        case 405: *reinterpret_cast<int*>(_v) = _t->band4Type(); break;
        case 406: *reinterpret_cast<bool*>(_v) = _t->isBand4TypeImmutable(); break;
        case 407: *reinterpret_cast<int*>(_v) = _t->defaultBand4TypeValue(); break;
        case 408: *reinterpret_cast<int*>(_v) = _t->band5Type(); break;
        case 409: *reinterpret_cast<bool*>(_v) = _t->isBand5TypeImmutable(); break;
        case 410: *reinterpret_cast<int*>(_v) = _t->defaultBand5TypeValue(); break;
        case 411: *reinterpret_cast<int*>(_v) = _t->band6Type(); break;
        case 412: *reinterpret_cast<bool*>(_v) = _t->isBand6TypeImmutable(); break;
        case 413: *reinterpret_cast<int*>(_v) = _t->defaultBand6TypeValue(); break;
        case 414: *reinterpret_cast<int*>(_v) = _t->band7Type(); break;
        case 415: *reinterpret_cast<bool*>(_v) = _t->isBand7TypeImmutable(); break;
        case 416: *reinterpret_cast<int*>(_v) = _t->defaultBand7TypeValue(); break;
        case 417: *reinterpret_cast<int*>(_v) = _t->band8Type(); break;
        case 418: *reinterpret_cast<bool*>(_v) = _t->isBand8TypeImmutable(); break;
        case 419: *reinterpret_cast<int*>(_v) = _t->defaultBand8TypeValue(); break;
        case 420: *reinterpret_cast<int*>(_v) = _t->band9Type(); break;
        case 421: *reinterpret_cast<bool*>(_v) = _t->isBand9TypeImmutable(); break;
        case 422: *reinterpret_cast<int*>(_v) = _t->defaultBand9TypeValue(); break;
        case 423: *reinterpret_cast<int*>(_v) = _t->band10Type(); break;
        case 424: *reinterpret_cast<bool*>(_v) = _t->isBand10TypeImmutable(); break;
        case 425: *reinterpret_cast<int*>(_v) = _t->defaultBand10TypeValue(); break;
        case 426: *reinterpret_cast<int*>(_v) = _t->band11Type(); break;
        case 427: *reinterpret_cast<bool*>(_v) = _t->isBand11TypeImmutable(); break;
        case 428: *reinterpret_cast<int*>(_v) = _t->defaultBand11TypeValue(); break;
        case 429: *reinterpret_cast<int*>(_v) = _t->band12Type(); break;
        case 430: *reinterpret_cast<bool*>(_v) = _t->isBand12TypeImmutable(); break;
        case 431: *reinterpret_cast<int*>(_v) = _t->defaultBand12TypeValue(); break;
        case 432: *reinterpret_cast<int*>(_v) = _t->band13Type(); break;
        case 433: *reinterpret_cast<bool*>(_v) = _t->isBand13TypeImmutable(); break;
        case 434: *reinterpret_cast<int*>(_v) = _t->defaultBand13TypeValue(); break;
        case 435: *reinterpret_cast<int*>(_v) = _t->band14Type(); break;
        case 436: *reinterpret_cast<bool*>(_v) = _t->isBand14TypeImmutable(); break;
        case 437: *reinterpret_cast<int*>(_v) = _t->defaultBand14TypeValue(); break;
        case 438: *reinterpret_cast<int*>(_v) = _t->band15Type(); break;
        case 439: *reinterpret_cast<bool*>(_v) = _t->isBand15TypeImmutable(); break;
        case 440: *reinterpret_cast<int*>(_v) = _t->defaultBand15TypeValue(); break;
        case 441: *reinterpret_cast<int*>(_v) = _t->band16Type(); break;
        case 442: *reinterpret_cast<bool*>(_v) = _t->isBand16TypeImmutable(); break;
        case 443: *reinterpret_cast<int*>(_v) = _t->defaultBand16TypeValue(); break;
        case 444: *reinterpret_cast<int*>(_v) = _t->band17Type(); break;
        case 445: *reinterpret_cast<bool*>(_v) = _t->isBand17TypeImmutable(); break;
        case 446: *reinterpret_cast<int*>(_v) = _t->defaultBand17TypeValue(); break;
        case 447: *reinterpret_cast<int*>(_v) = _t->band18Type(); break;
        case 448: *reinterpret_cast<bool*>(_v) = _t->isBand18TypeImmutable(); break;
        case 449: *reinterpret_cast<int*>(_v) = _t->defaultBand18TypeValue(); break;
        case 450: *reinterpret_cast<int*>(_v) = _t->band19Type(); break;
        case 451: *reinterpret_cast<bool*>(_v) = _t->isBand19TypeImmutable(); break;
        case 452: *reinterpret_cast<int*>(_v) = _t->defaultBand19TypeValue(); break;
        case 453: *reinterpret_cast<int*>(_v) = _t->band20Type(); break;
        case 454: *reinterpret_cast<bool*>(_v) = _t->isBand20TypeImmutable(); break;
        case 455: *reinterpret_cast<int*>(_v) = _t->defaultBand20TypeValue(); break;
        case 456: *reinterpret_cast<int*>(_v) = _t->band21Type(); break;
        case 457: *reinterpret_cast<bool*>(_v) = _t->isBand21TypeImmutable(); break;
        case 458: *reinterpret_cast<int*>(_v) = _t->defaultBand21TypeValue(); break;
        case 459: *reinterpret_cast<int*>(_v) = _t->band22Type(); break;
        case 460: *reinterpret_cast<bool*>(_v) = _t->isBand22TypeImmutable(); break;
        case 461: *reinterpret_cast<int*>(_v) = _t->defaultBand22TypeValue(); break;
        case 462: *reinterpret_cast<int*>(_v) = _t->band23Type(); break;
        case 463: *reinterpret_cast<bool*>(_v) = _t->isBand23TypeImmutable(); break;
        case 464: *reinterpret_cast<int*>(_v) = _t->defaultBand23TypeValue(); break;
        case 465: *reinterpret_cast<int*>(_v) = _t->band24Type(); break;
        case 466: *reinterpret_cast<bool*>(_v) = _t->isBand24TypeImmutable(); break;
        case 467: *reinterpret_cast<int*>(_v) = _t->defaultBand24TypeValue(); break;
        case 468: *reinterpret_cast<int*>(_v) = _t->band25Type(); break;
        case 469: *reinterpret_cast<bool*>(_v) = _t->isBand25TypeImmutable(); break;
        case 470: *reinterpret_cast<int*>(_v) = _t->defaultBand25TypeValue(); break;
        case 471: *reinterpret_cast<int*>(_v) = _t->band26Type(); break;
        case 472: *reinterpret_cast<bool*>(_v) = _t->isBand26TypeImmutable(); break;
        case 473: *reinterpret_cast<int*>(_v) = _t->defaultBand26TypeValue(); break;
        case 474: *reinterpret_cast<int*>(_v) = _t->band27Type(); break;
        case 475: *reinterpret_cast<bool*>(_v) = _t->isBand27TypeImmutable(); break;
        case 476: *reinterpret_cast<int*>(_v) = _t->defaultBand27TypeValue(); break;
        case 477: *reinterpret_cast<int*>(_v) = _t->band28Type(); break;
        case 478: *reinterpret_cast<bool*>(_v) = _t->isBand28TypeImmutable(); break;
        case 479: *reinterpret_cast<int*>(_v) = _t->defaultBand28TypeValue(); break;
        case 480: *reinterpret_cast<int*>(_v) = _t->band29Type(); break;
        case 481: *reinterpret_cast<bool*>(_v) = _t->isBand29TypeImmutable(); break;
        case 482: *reinterpret_cast<int*>(_v) = _t->defaultBand29TypeValue(); break;
        case 483: *reinterpret_cast<int*>(_v) = _t->band30Type(); break;
        case 484: *reinterpret_cast<bool*>(_v) = _t->isBand30TypeImmutable(); break;
        case 485: *reinterpret_cast<int*>(_v) = _t->defaultBand30TypeValue(); break;
        case 486: *reinterpret_cast<int*>(_v) = _t->band31Type(); break;
        case 487: *reinterpret_cast<bool*>(_v) = _t->isBand31TypeImmutable(); break;
        case 488: *reinterpret_cast<int*>(_v) = _t->defaultBand31TypeValue(); break;
        case 489: *reinterpret_cast<int*>(_v) = _t->band0Mode(); break;
        case 490: *reinterpret_cast<bool*>(_v) = _t->isBand0ModeImmutable(); break;
        case 491: *reinterpret_cast<int*>(_v) = _t->defaultBand0ModeValue(); break;
        case 492: *reinterpret_cast<int*>(_v) = _t->band1Mode(); break;
        case 493: *reinterpret_cast<bool*>(_v) = _t->isBand1ModeImmutable(); break;
        case 494: *reinterpret_cast<int*>(_v) = _t->defaultBand1ModeValue(); break;
        case 495: *reinterpret_cast<int*>(_v) = _t->band2Mode(); break;
        case 496: *reinterpret_cast<bool*>(_v) = _t->isBand2ModeImmutable(); break;
        case 497: *reinterpret_cast<int*>(_v) = _t->defaultBand2ModeValue(); break;
        case 498: *reinterpret_cast<int*>(_v) = _t->band3Mode(); break;
        case 499: *reinterpret_cast<bool*>(_v) = _t->isBand3ModeImmutable(); break;
        case 500: *reinterpret_cast<int*>(_v) = _t->defaultBand3ModeValue(); break;
        case 501: *reinterpret_cast<int*>(_v) = _t->band4Mode(); break;
        case 502: *reinterpret_cast<bool*>(_v) = _t->isBand4ModeImmutable(); break;
        case 503: *reinterpret_cast<int*>(_v) = _t->defaultBand4ModeValue(); break;
        case 504: *reinterpret_cast<int*>(_v) = _t->band5Mode(); break;
        case 505: *reinterpret_cast<bool*>(_v) = _t->isBand5ModeImmutable(); break;
        case 506: *reinterpret_cast<int*>(_v) = _t->defaultBand5ModeValue(); break;
        case 507: *reinterpret_cast<int*>(_v) = _t->band6Mode(); break;
        case 508: *reinterpret_cast<bool*>(_v) = _t->isBand6ModeImmutable(); break;
        case 509: *reinterpret_cast<int*>(_v) = _t->defaultBand6ModeValue(); break;
        case 510: *reinterpret_cast<int*>(_v) = _t->band7Mode(); break;
        case 511: *reinterpret_cast<bool*>(_v) = _t->isBand7ModeImmutable(); break;
        case 512: *reinterpret_cast<int*>(_v) = _t->defaultBand7ModeValue(); break;
        case 513: *reinterpret_cast<int*>(_v) = _t->band8Mode(); break;
        case 514: *reinterpret_cast<bool*>(_v) = _t->isBand8ModeImmutable(); break;
        case 515: *reinterpret_cast<int*>(_v) = _t->defaultBand8ModeValue(); break;
        case 516: *reinterpret_cast<int*>(_v) = _t->band9Mode(); break;
        case 517: *reinterpret_cast<bool*>(_v) = _t->isBand9ModeImmutable(); break;
        case 518: *reinterpret_cast<int*>(_v) = _t->defaultBand9ModeValue(); break;
        case 519: *reinterpret_cast<int*>(_v) = _t->band10Mode(); break;
        case 520: *reinterpret_cast<bool*>(_v) = _t->isBand10ModeImmutable(); break;
        case 521: *reinterpret_cast<int*>(_v) = _t->defaultBand10ModeValue(); break;
        case 522: *reinterpret_cast<int*>(_v) = _t->band11Mode(); break;
        case 523: *reinterpret_cast<bool*>(_v) = _t->isBand11ModeImmutable(); break;
        case 524: *reinterpret_cast<int*>(_v) = _t->defaultBand11ModeValue(); break;
        case 525: *reinterpret_cast<int*>(_v) = _t->band12Mode(); break;
        case 526: *reinterpret_cast<bool*>(_v) = _t->isBand12ModeImmutable(); break;
        case 527: *reinterpret_cast<int*>(_v) = _t->defaultBand12ModeValue(); break;
        case 528: *reinterpret_cast<int*>(_v) = _t->band13Mode(); break;
        case 529: *reinterpret_cast<bool*>(_v) = _t->isBand13ModeImmutable(); break;
        case 530: *reinterpret_cast<int*>(_v) = _t->defaultBand13ModeValue(); break;
        case 531: *reinterpret_cast<int*>(_v) = _t->band14Mode(); break;
        case 532: *reinterpret_cast<bool*>(_v) = _t->isBand14ModeImmutable(); break;
        case 533: *reinterpret_cast<int*>(_v) = _t->defaultBand14ModeValue(); break;
        case 534: *reinterpret_cast<int*>(_v) = _t->band15Mode(); break;
        case 535: *reinterpret_cast<bool*>(_v) = _t->isBand15ModeImmutable(); break;
        case 536: *reinterpret_cast<int*>(_v) = _t->defaultBand15ModeValue(); break;
        case 537: *reinterpret_cast<int*>(_v) = _t->band16Mode(); break;
        case 538: *reinterpret_cast<bool*>(_v) = _t->isBand16ModeImmutable(); break;
        case 539: *reinterpret_cast<int*>(_v) = _t->defaultBand16ModeValue(); break;
        case 540: *reinterpret_cast<int*>(_v) = _t->band17Mode(); break;
        case 541: *reinterpret_cast<bool*>(_v) = _t->isBand17ModeImmutable(); break;
        case 542: *reinterpret_cast<int*>(_v) = _t->defaultBand17ModeValue(); break;
        case 543: *reinterpret_cast<int*>(_v) = _t->band18Mode(); break;
        case 544: *reinterpret_cast<bool*>(_v) = _t->isBand18ModeImmutable(); break;
        case 545: *reinterpret_cast<int*>(_v) = _t->defaultBand18ModeValue(); break;
        case 546: *reinterpret_cast<int*>(_v) = _t->band19Mode(); break;
        case 547: *reinterpret_cast<bool*>(_v) = _t->isBand19ModeImmutable(); break;
        case 548: *reinterpret_cast<int*>(_v) = _t->defaultBand19ModeValue(); break;
        case 549: *reinterpret_cast<int*>(_v) = _t->band20Mode(); break;
        case 550: *reinterpret_cast<bool*>(_v) = _t->isBand20ModeImmutable(); break;
        case 551: *reinterpret_cast<int*>(_v) = _t->defaultBand20ModeValue(); break;
        case 552: *reinterpret_cast<int*>(_v) = _t->band21Mode(); break;
        case 553: *reinterpret_cast<bool*>(_v) = _t->isBand21ModeImmutable(); break;
        case 554: *reinterpret_cast<int*>(_v) = _t->defaultBand21ModeValue(); break;
        case 555: *reinterpret_cast<int*>(_v) = _t->band22Mode(); break;
        case 556: *reinterpret_cast<bool*>(_v) = _t->isBand22ModeImmutable(); break;
        case 557: *reinterpret_cast<int*>(_v) = _t->defaultBand22ModeValue(); break;
        case 558: *reinterpret_cast<int*>(_v) = _t->band23Mode(); break;
        case 559: *reinterpret_cast<bool*>(_v) = _t->isBand23ModeImmutable(); break;
        case 560: *reinterpret_cast<int*>(_v) = _t->defaultBand23ModeValue(); break;
        case 561: *reinterpret_cast<int*>(_v) = _t->band24Mode(); break;
        case 562: *reinterpret_cast<bool*>(_v) = _t->isBand24ModeImmutable(); break;
        case 563: *reinterpret_cast<int*>(_v) = _t->defaultBand24ModeValue(); break;
        case 564: *reinterpret_cast<int*>(_v) = _t->band25Mode(); break;
        case 565: *reinterpret_cast<bool*>(_v) = _t->isBand25ModeImmutable(); break;
        case 566: *reinterpret_cast<int*>(_v) = _t->defaultBand25ModeValue(); break;
        case 567: *reinterpret_cast<int*>(_v) = _t->band26Mode(); break;
        case 568: *reinterpret_cast<bool*>(_v) = _t->isBand26ModeImmutable(); break;
        case 569: *reinterpret_cast<int*>(_v) = _t->defaultBand26ModeValue(); break;
        case 570: *reinterpret_cast<int*>(_v) = _t->band27Mode(); break;
        case 571: *reinterpret_cast<bool*>(_v) = _t->isBand27ModeImmutable(); break;
        case 572: *reinterpret_cast<int*>(_v) = _t->defaultBand27ModeValue(); break;
        case 573: *reinterpret_cast<int*>(_v) = _t->band28Mode(); break;
        case 574: *reinterpret_cast<bool*>(_v) = _t->isBand28ModeImmutable(); break;
        case 575: *reinterpret_cast<int*>(_v) = _t->defaultBand28ModeValue(); break;
        case 576: *reinterpret_cast<int*>(_v) = _t->band29Mode(); break;
        case 577: *reinterpret_cast<bool*>(_v) = _t->isBand29ModeImmutable(); break;
        case 578: *reinterpret_cast<int*>(_v) = _t->defaultBand29ModeValue(); break;
        case 579: *reinterpret_cast<int*>(_v) = _t->band30Mode(); break;
        case 580: *reinterpret_cast<bool*>(_v) = _t->isBand30ModeImmutable(); break;
        case 581: *reinterpret_cast<int*>(_v) = _t->defaultBand30ModeValue(); break;
        case 582: *reinterpret_cast<int*>(_v) = _t->band31Mode(); break;
        case 583: *reinterpret_cast<bool*>(_v) = _t->isBand31ModeImmutable(); break;
        case 584: *reinterpret_cast<int*>(_v) = _t->defaultBand31ModeValue(); break;
        case 585: *reinterpret_cast<int*>(_v) = _t->band0Slope(); break;
        case 586: *reinterpret_cast<bool*>(_v) = _t->isBand0SlopeImmutable(); break;
        case 587: *reinterpret_cast<int*>(_v) = _t->defaultBand0SlopeValue(); break;
        case 588: *reinterpret_cast<int*>(_v) = _t->band1Slope(); break;
        case 589: *reinterpret_cast<bool*>(_v) = _t->isBand1SlopeImmutable(); break;
        case 590: *reinterpret_cast<int*>(_v) = _t->defaultBand1SlopeValue(); break;
        case 591: *reinterpret_cast<int*>(_v) = _t->band2Slope(); break;
        case 592: *reinterpret_cast<bool*>(_v) = _t->isBand2SlopeImmutable(); break;
        case 593: *reinterpret_cast<int*>(_v) = _t->defaultBand2SlopeValue(); break;
        case 594: *reinterpret_cast<int*>(_v) = _t->band3Slope(); break;
        case 595: *reinterpret_cast<bool*>(_v) = _t->isBand3SlopeImmutable(); break;
        case 596: *reinterpret_cast<int*>(_v) = _t->defaultBand3SlopeValue(); break;
        case 597: *reinterpret_cast<int*>(_v) = _t->band4Slope(); break;
        case 598: *reinterpret_cast<bool*>(_v) = _t->isBand4SlopeImmutable(); break;
        case 599: *reinterpret_cast<int*>(_v) = _t->defaultBand4SlopeValue(); break;
        case 600: *reinterpret_cast<int*>(_v) = _t->band5Slope(); break;
        case 601: *reinterpret_cast<bool*>(_v) = _t->isBand5SlopeImmutable(); break;
        case 602: *reinterpret_cast<int*>(_v) = _t->defaultBand5SlopeValue(); break;
        case 603: *reinterpret_cast<int*>(_v) = _t->band6Slope(); break;
        case 604: *reinterpret_cast<bool*>(_v) = _t->isBand6SlopeImmutable(); break;
        case 605: *reinterpret_cast<int*>(_v) = _t->defaultBand6SlopeValue(); break;
        case 606: *reinterpret_cast<int*>(_v) = _t->band7Slope(); break;
        case 607: *reinterpret_cast<bool*>(_v) = _t->isBand7SlopeImmutable(); break;
        case 608: *reinterpret_cast<int*>(_v) = _t->defaultBand7SlopeValue(); break;
        case 609: *reinterpret_cast<int*>(_v) = _t->band8Slope(); break;
        case 610: *reinterpret_cast<bool*>(_v) = _t->isBand8SlopeImmutable(); break;
        case 611: *reinterpret_cast<int*>(_v) = _t->defaultBand8SlopeValue(); break;
        case 612: *reinterpret_cast<int*>(_v) = _t->band9Slope(); break;
        case 613: *reinterpret_cast<bool*>(_v) = _t->isBand9SlopeImmutable(); break;
        case 614: *reinterpret_cast<int*>(_v) = _t->defaultBand9SlopeValue(); break;
        case 615: *reinterpret_cast<int*>(_v) = _t->band10Slope(); break;
        case 616: *reinterpret_cast<bool*>(_v) = _t->isBand10SlopeImmutable(); break;
        case 617: *reinterpret_cast<int*>(_v) = _t->defaultBand10SlopeValue(); break;
        case 618: *reinterpret_cast<int*>(_v) = _t->band11Slope(); break;
        case 619: *reinterpret_cast<bool*>(_v) = _t->isBand11SlopeImmutable(); break;
        case 620: *reinterpret_cast<int*>(_v) = _t->defaultBand11SlopeValue(); break;
        case 621: *reinterpret_cast<int*>(_v) = _t->band12Slope(); break;
        case 622: *reinterpret_cast<bool*>(_v) = _t->isBand12SlopeImmutable(); break;
        case 623: *reinterpret_cast<int*>(_v) = _t->defaultBand12SlopeValue(); break;
        case 624: *reinterpret_cast<int*>(_v) = _t->band13Slope(); break;
        case 625: *reinterpret_cast<bool*>(_v) = _t->isBand13SlopeImmutable(); break;
        case 626: *reinterpret_cast<int*>(_v) = _t->defaultBand13SlopeValue(); break;
        case 627: *reinterpret_cast<int*>(_v) = _t->band14Slope(); break;
        case 628: *reinterpret_cast<bool*>(_v) = _t->isBand14SlopeImmutable(); break;
        case 629: *reinterpret_cast<int*>(_v) = _t->defaultBand14SlopeValue(); break;
        case 630: *reinterpret_cast<int*>(_v) = _t->band15Slope(); break;
        case 631: *reinterpret_cast<bool*>(_v) = _t->isBand15SlopeImmutable(); break;
        case 632: *reinterpret_cast<int*>(_v) = _t->defaultBand15SlopeValue(); break;
        case 633: *reinterpret_cast<int*>(_v) = _t->band16Slope(); break;
        case 634: *reinterpret_cast<bool*>(_v) = _t->isBand16SlopeImmutable(); break;
        case 635: *reinterpret_cast<int*>(_v) = _t->defaultBand16SlopeValue(); break;
        case 636: *reinterpret_cast<int*>(_v) = _t->band17Slope(); break;
        case 637: *reinterpret_cast<bool*>(_v) = _t->isBand17SlopeImmutable(); break;
        case 638: *reinterpret_cast<int*>(_v) = _t->defaultBand17SlopeValue(); break;
        case 639: *reinterpret_cast<int*>(_v) = _t->band18Slope(); break;
        case 640: *reinterpret_cast<bool*>(_v) = _t->isBand18SlopeImmutable(); break;
        case 641: *reinterpret_cast<int*>(_v) = _t->defaultBand18SlopeValue(); break;
        case 642: *reinterpret_cast<int*>(_v) = _t->band19Slope(); break;
        case 643: *reinterpret_cast<bool*>(_v) = _t->isBand19SlopeImmutable(); break;
        case 644: *reinterpret_cast<int*>(_v) = _t->defaultBand19SlopeValue(); break;
        case 645: *reinterpret_cast<int*>(_v) = _t->band20Slope(); break;
        case 646: *reinterpret_cast<bool*>(_v) = _t->isBand20SlopeImmutable(); break;
        case 647: *reinterpret_cast<int*>(_v) = _t->defaultBand20SlopeValue(); break;
        case 648: *reinterpret_cast<int*>(_v) = _t->band21Slope(); break;
        case 649: *reinterpret_cast<bool*>(_v) = _t->isBand21SlopeImmutable(); break;
        case 650: *reinterpret_cast<int*>(_v) = _t->defaultBand21SlopeValue(); break;
        case 651: *reinterpret_cast<int*>(_v) = _t->band22Slope(); break;
        case 652: *reinterpret_cast<bool*>(_v) = _t->isBand22SlopeImmutable(); break;
        case 653: *reinterpret_cast<int*>(_v) = _t->defaultBand22SlopeValue(); break;
        case 654: *reinterpret_cast<int*>(_v) = _t->band23Slope(); break;
        case 655: *reinterpret_cast<bool*>(_v) = _t->isBand23SlopeImmutable(); break;
        case 656: *reinterpret_cast<int*>(_v) = _t->defaultBand23SlopeValue(); break;
        case 657: *reinterpret_cast<int*>(_v) = _t->band24Slope(); break;
        case 658: *reinterpret_cast<bool*>(_v) = _t->isBand24SlopeImmutable(); break;
        case 659: *reinterpret_cast<int*>(_v) = _t->defaultBand24SlopeValue(); break;
        case 660: *reinterpret_cast<int*>(_v) = _t->band25Slope(); break;
        case 661: *reinterpret_cast<bool*>(_v) = _t->isBand25SlopeImmutable(); break;
        case 662: *reinterpret_cast<int*>(_v) = _t->defaultBand25SlopeValue(); break;
        case 663: *reinterpret_cast<int*>(_v) = _t->band26Slope(); break;
        case 664: *reinterpret_cast<bool*>(_v) = _t->isBand26SlopeImmutable(); break;
        case 665: *reinterpret_cast<int*>(_v) = _t->defaultBand26SlopeValue(); break;
        case 666: *reinterpret_cast<int*>(_v) = _t->band27Slope(); break;
        case 667: *reinterpret_cast<bool*>(_v) = _t->isBand27SlopeImmutable(); break;
        case 668: *reinterpret_cast<int*>(_v) = _t->defaultBand27SlopeValue(); break;
        case 669: *reinterpret_cast<int*>(_v) = _t->band28Slope(); break;
        case 670: *reinterpret_cast<bool*>(_v) = _t->isBand28SlopeImmutable(); break;
        case 671: *reinterpret_cast<int*>(_v) = _t->defaultBand28SlopeValue(); break;
        case 672: *reinterpret_cast<int*>(_v) = _t->band29Slope(); break;
        case 673: *reinterpret_cast<bool*>(_v) = _t->isBand29SlopeImmutable(); break;
        case 674: *reinterpret_cast<int*>(_v) = _t->defaultBand29SlopeValue(); break;
        case 675: *reinterpret_cast<int*>(_v) = _t->band30Slope(); break;
        case 676: *reinterpret_cast<bool*>(_v) = _t->isBand30SlopeImmutable(); break;
        case 677: *reinterpret_cast<int*>(_v) = _t->defaultBand30SlopeValue(); break;
        case 678: *reinterpret_cast<int*>(_v) = _t->band31Slope(); break;
        case 679: *reinterpret_cast<bool*>(_v) = _t->isBand31SlopeImmutable(); break;
        case 680: *reinterpret_cast<int*>(_v) = _t->defaultBand31SlopeValue(); break;
        case 681: *reinterpret_cast<bool*>(_v) = _t->band0Solo(); break;
        case 682: *reinterpret_cast<bool*>(_v) = _t->isBand0SoloImmutable(); break;
        case 683: *reinterpret_cast<bool*>(_v) = _t->defaultBand0SoloValue(); break;
        case 684: *reinterpret_cast<bool*>(_v) = _t->band1Solo(); break;
        case 685: *reinterpret_cast<bool*>(_v) = _t->isBand1SoloImmutable(); break;
        case 686: *reinterpret_cast<bool*>(_v) = _t->defaultBand1SoloValue(); break;
        case 687: *reinterpret_cast<bool*>(_v) = _t->band2Solo(); break;
        case 688: *reinterpret_cast<bool*>(_v) = _t->isBand2SoloImmutable(); break;
        case 689: *reinterpret_cast<bool*>(_v) = _t->defaultBand2SoloValue(); break;
        case 690: *reinterpret_cast<bool*>(_v) = _t->band3Solo(); break;
        case 691: *reinterpret_cast<bool*>(_v) = _t->isBand3SoloImmutable(); break;
        case 692: *reinterpret_cast<bool*>(_v) = _t->defaultBand3SoloValue(); break;
        case 693: *reinterpret_cast<bool*>(_v) = _t->band4Solo(); break;
        case 694: *reinterpret_cast<bool*>(_v) = _t->isBand4SoloImmutable(); break;
        case 695: *reinterpret_cast<bool*>(_v) = _t->defaultBand4SoloValue(); break;
        case 696: *reinterpret_cast<bool*>(_v) = _t->band5Solo(); break;
        case 697: *reinterpret_cast<bool*>(_v) = _t->isBand5SoloImmutable(); break;
        case 698: *reinterpret_cast<bool*>(_v) = _t->defaultBand5SoloValue(); break;
        case 699: *reinterpret_cast<bool*>(_v) = _t->band6Solo(); break;
        case 700: *reinterpret_cast<bool*>(_v) = _t->isBand6SoloImmutable(); break;
        case 701: *reinterpret_cast<bool*>(_v) = _t->defaultBand6SoloValue(); break;
        case 702: *reinterpret_cast<bool*>(_v) = _t->band7Solo(); break;
        case 703: *reinterpret_cast<bool*>(_v) = _t->isBand7SoloImmutable(); break;
        case 704: *reinterpret_cast<bool*>(_v) = _t->defaultBand7SoloValue(); break;
        case 705: *reinterpret_cast<bool*>(_v) = _t->band8Solo(); break;
        case 706: *reinterpret_cast<bool*>(_v) = _t->isBand8SoloImmutable(); break;
        case 707: *reinterpret_cast<bool*>(_v) = _t->defaultBand8SoloValue(); break;
        case 708: *reinterpret_cast<bool*>(_v) = _t->band9Solo(); break;
        case 709: *reinterpret_cast<bool*>(_v) = _t->isBand9SoloImmutable(); break;
        case 710: *reinterpret_cast<bool*>(_v) = _t->defaultBand9SoloValue(); break;
        case 711: *reinterpret_cast<bool*>(_v) = _t->band10Solo(); break;
        case 712: *reinterpret_cast<bool*>(_v) = _t->isBand10SoloImmutable(); break;
        case 713: *reinterpret_cast<bool*>(_v) = _t->defaultBand10SoloValue(); break;
        case 714: *reinterpret_cast<bool*>(_v) = _t->band11Solo(); break;
        case 715: *reinterpret_cast<bool*>(_v) = _t->isBand11SoloImmutable(); break;
        case 716: *reinterpret_cast<bool*>(_v) = _t->defaultBand11SoloValue(); break;
        case 717: *reinterpret_cast<bool*>(_v) = _t->band12Solo(); break;
        case 718: *reinterpret_cast<bool*>(_v) = _t->isBand12SoloImmutable(); break;
        case 719: *reinterpret_cast<bool*>(_v) = _t->defaultBand12SoloValue(); break;
        case 720: *reinterpret_cast<bool*>(_v) = _t->band13Solo(); break;
        case 721: *reinterpret_cast<bool*>(_v) = _t->isBand13SoloImmutable(); break;
        case 722: *reinterpret_cast<bool*>(_v) = _t->defaultBand13SoloValue(); break;
        case 723: *reinterpret_cast<bool*>(_v) = _t->band14Solo(); break;
        case 724: *reinterpret_cast<bool*>(_v) = _t->isBand14SoloImmutable(); break;
        case 725: *reinterpret_cast<bool*>(_v) = _t->defaultBand14SoloValue(); break;
        case 726: *reinterpret_cast<bool*>(_v) = _t->band15Solo(); break;
        case 727: *reinterpret_cast<bool*>(_v) = _t->isBand15SoloImmutable(); break;
        case 728: *reinterpret_cast<bool*>(_v) = _t->defaultBand15SoloValue(); break;
        case 729: *reinterpret_cast<bool*>(_v) = _t->band16Solo(); break;
        case 730: *reinterpret_cast<bool*>(_v) = _t->isBand16SoloImmutable(); break;
        case 731: *reinterpret_cast<bool*>(_v) = _t->defaultBand16SoloValue(); break;
        case 732: *reinterpret_cast<bool*>(_v) = _t->band17Solo(); break;
        case 733: *reinterpret_cast<bool*>(_v) = _t->isBand17SoloImmutable(); break;
        case 734: *reinterpret_cast<bool*>(_v) = _t->defaultBand17SoloValue(); break;
        case 735: *reinterpret_cast<bool*>(_v) = _t->band18Solo(); break;
        case 736: *reinterpret_cast<bool*>(_v) = _t->isBand18SoloImmutable(); break;
        case 737: *reinterpret_cast<bool*>(_v) = _t->defaultBand18SoloValue(); break;
        case 738: *reinterpret_cast<bool*>(_v) = _t->band19Solo(); break;
        case 739: *reinterpret_cast<bool*>(_v) = _t->isBand19SoloImmutable(); break;
        case 740: *reinterpret_cast<bool*>(_v) = _t->defaultBand19SoloValue(); break;
        case 741: *reinterpret_cast<bool*>(_v) = _t->band20Solo(); break;
        case 742: *reinterpret_cast<bool*>(_v) = _t->isBand20SoloImmutable(); break;
        case 743: *reinterpret_cast<bool*>(_v) = _t->defaultBand20SoloValue(); break;
        case 744: *reinterpret_cast<bool*>(_v) = _t->band21Solo(); break;
        case 745: *reinterpret_cast<bool*>(_v) = _t->isBand21SoloImmutable(); break;
        case 746: *reinterpret_cast<bool*>(_v) = _t->defaultBand21SoloValue(); break;
        case 747: *reinterpret_cast<bool*>(_v) = _t->band22Solo(); break;
        case 748: *reinterpret_cast<bool*>(_v) = _t->isBand22SoloImmutable(); break;
        case 749: *reinterpret_cast<bool*>(_v) = _t->defaultBand22SoloValue(); break;
        case 750: *reinterpret_cast<bool*>(_v) = _t->band23Solo(); break;
        case 751: *reinterpret_cast<bool*>(_v) = _t->isBand23SoloImmutable(); break;
        case 752: *reinterpret_cast<bool*>(_v) = _t->defaultBand23SoloValue(); break;
        case 753: *reinterpret_cast<bool*>(_v) = _t->band24Solo(); break;
        case 754: *reinterpret_cast<bool*>(_v) = _t->isBand24SoloImmutable(); break;
        case 755: *reinterpret_cast<bool*>(_v) = _t->defaultBand24SoloValue(); break;
        case 756: *reinterpret_cast<bool*>(_v) = _t->band25Solo(); break;
        case 757: *reinterpret_cast<bool*>(_v) = _t->isBand25SoloImmutable(); break;
        case 758: *reinterpret_cast<bool*>(_v) = _t->defaultBand25SoloValue(); break;
        case 759: *reinterpret_cast<bool*>(_v) = _t->band26Solo(); break;
        case 760: *reinterpret_cast<bool*>(_v) = _t->isBand26SoloImmutable(); break;
        case 761: *reinterpret_cast<bool*>(_v) = _t->defaultBand26SoloValue(); break;
        case 762: *reinterpret_cast<bool*>(_v) = _t->band27Solo(); break;
        case 763: *reinterpret_cast<bool*>(_v) = _t->isBand27SoloImmutable(); break;
        case 764: *reinterpret_cast<bool*>(_v) = _t->defaultBand27SoloValue(); break;
        case 765: *reinterpret_cast<bool*>(_v) = _t->band28Solo(); break;
        case 766: *reinterpret_cast<bool*>(_v) = _t->isBand28SoloImmutable(); break;
        case 767: *reinterpret_cast<bool*>(_v) = _t->defaultBand28SoloValue(); break;
        case 768: *reinterpret_cast<bool*>(_v) = _t->band29Solo(); break;
        case 769: *reinterpret_cast<bool*>(_v) = _t->isBand29SoloImmutable(); break;
        case 770: *reinterpret_cast<bool*>(_v) = _t->defaultBand29SoloValue(); break;
        case 771: *reinterpret_cast<bool*>(_v) = _t->band30Solo(); break;
        case 772: *reinterpret_cast<bool*>(_v) = _t->isBand30SoloImmutable(); break;
        case 773: *reinterpret_cast<bool*>(_v) = _t->defaultBand30SoloValue(); break;
        case 774: *reinterpret_cast<bool*>(_v) = _t->band31Solo(); break;
        case 775: *reinterpret_cast<bool*>(_v) = _t->isBand31SoloImmutable(); break;
        case 776: *reinterpret_cast<bool*>(_v) = _t->defaultBand31SoloValue(); break;
        case 777: *reinterpret_cast<bool*>(_v) = _t->band0Mute(); break;
        case 778: *reinterpret_cast<bool*>(_v) = _t->isBand0MuteImmutable(); break;
        case 779: *reinterpret_cast<bool*>(_v) = _t->defaultBand0MuteValue(); break;
        case 780: *reinterpret_cast<bool*>(_v) = _t->band1Mute(); break;
        case 781: *reinterpret_cast<bool*>(_v) = _t->isBand1MuteImmutable(); break;
        case 782: *reinterpret_cast<bool*>(_v) = _t->defaultBand1MuteValue(); break;
        case 783: *reinterpret_cast<bool*>(_v) = _t->band2Mute(); break;
        case 784: *reinterpret_cast<bool*>(_v) = _t->isBand2MuteImmutable(); break;
        case 785: *reinterpret_cast<bool*>(_v) = _t->defaultBand2MuteValue(); break;
        case 786: *reinterpret_cast<bool*>(_v) = _t->band3Mute(); break;
        case 787: *reinterpret_cast<bool*>(_v) = _t->isBand3MuteImmutable(); break;
        case 788: *reinterpret_cast<bool*>(_v) = _t->defaultBand3MuteValue(); break;
        case 789: *reinterpret_cast<bool*>(_v) = _t->band4Mute(); break;
        case 790: *reinterpret_cast<bool*>(_v) = _t->isBand4MuteImmutable(); break;
        case 791: *reinterpret_cast<bool*>(_v) = _t->defaultBand4MuteValue(); break;
        case 792: *reinterpret_cast<bool*>(_v) = _t->band5Mute(); break;
        case 793: *reinterpret_cast<bool*>(_v) = _t->isBand5MuteImmutable(); break;
        case 794: *reinterpret_cast<bool*>(_v) = _t->defaultBand5MuteValue(); break;
        case 795: *reinterpret_cast<bool*>(_v) = _t->band6Mute(); break;
        case 796: *reinterpret_cast<bool*>(_v) = _t->isBand6MuteImmutable(); break;
        case 797: *reinterpret_cast<bool*>(_v) = _t->defaultBand6MuteValue(); break;
        case 798: *reinterpret_cast<bool*>(_v) = _t->band7Mute(); break;
        case 799: *reinterpret_cast<bool*>(_v) = _t->isBand7MuteImmutable(); break;
        case 800: *reinterpret_cast<bool*>(_v) = _t->defaultBand7MuteValue(); break;
        case 801: *reinterpret_cast<bool*>(_v) = _t->band8Mute(); break;
        case 802: *reinterpret_cast<bool*>(_v) = _t->isBand8MuteImmutable(); break;
        case 803: *reinterpret_cast<bool*>(_v) = _t->defaultBand8MuteValue(); break;
        case 804: *reinterpret_cast<bool*>(_v) = _t->band9Mute(); break;
        case 805: *reinterpret_cast<bool*>(_v) = _t->isBand9MuteImmutable(); break;
        case 806: *reinterpret_cast<bool*>(_v) = _t->defaultBand9MuteValue(); break;
        case 807: *reinterpret_cast<bool*>(_v) = _t->band10Mute(); break;
        case 808: *reinterpret_cast<bool*>(_v) = _t->isBand10MuteImmutable(); break;
        case 809: *reinterpret_cast<bool*>(_v) = _t->defaultBand10MuteValue(); break;
        case 810: *reinterpret_cast<bool*>(_v) = _t->band11Mute(); break;
        case 811: *reinterpret_cast<bool*>(_v) = _t->isBand11MuteImmutable(); break;
        case 812: *reinterpret_cast<bool*>(_v) = _t->defaultBand11MuteValue(); break;
        case 813: *reinterpret_cast<bool*>(_v) = _t->band12Mute(); break;
        case 814: *reinterpret_cast<bool*>(_v) = _t->isBand12MuteImmutable(); break;
        case 815: *reinterpret_cast<bool*>(_v) = _t->defaultBand12MuteValue(); break;
        case 816: *reinterpret_cast<bool*>(_v) = _t->band13Mute(); break;
        case 817: *reinterpret_cast<bool*>(_v) = _t->isBand13MuteImmutable(); break;
        case 818: *reinterpret_cast<bool*>(_v) = _t->defaultBand13MuteValue(); break;
        case 819: *reinterpret_cast<bool*>(_v) = _t->band14Mute(); break;
        case 820: *reinterpret_cast<bool*>(_v) = _t->isBand14MuteImmutable(); break;
        case 821: *reinterpret_cast<bool*>(_v) = _t->defaultBand14MuteValue(); break;
        case 822: *reinterpret_cast<bool*>(_v) = _t->band15Mute(); break;
        case 823: *reinterpret_cast<bool*>(_v) = _t->isBand15MuteImmutable(); break;
        case 824: *reinterpret_cast<bool*>(_v) = _t->defaultBand15MuteValue(); break;
        case 825: *reinterpret_cast<bool*>(_v) = _t->band16Mute(); break;
        case 826: *reinterpret_cast<bool*>(_v) = _t->isBand16MuteImmutable(); break;
        case 827: *reinterpret_cast<bool*>(_v) = _t->defaultBand16MuteValue(); break;
        case 828: *reinterpret_cast<bool*>(_v) = _t->band17Mute(); break;
        case 829: *reinterpret_cast<bool*>(_v) = _t->isBand17MuteImmutable(); break;
        case 830: *reinterpret_cast<bool*>(_v) = _t->defaultBand17MuteValue(); break;
        case 831: *reinterpret_cast<bool*>(_v) = _t->band18Mute(); break;
        case 832: *reinterpret_cast<bool*>(_v) = _t->isBand18MuteImmutable(); break;
        case 833: *reinterpret_cast<bool*>(_v) = _t->defaultBand18MuteValue(); break;
        case 834: *reinterpret_cast<bool*>(_v) = _t->band19Mute(); break;
        case 835: *reinterpret_cast<bool*>(_v) = _t->isBand19MuteImmutable(); break;
        case 836: *reinterpret_cast<bool*>(_v) = _t->defaultBand19MuteValue(); break;
        case 837: *reinterpret_cast<bool*>(_v) = _t->band20Mute(); break;
        case 838: *reinterpret_cast<bool*>(_v) = _t->isBand20MuteImmutable(); break;
        case 839: *reinterpret_cast<bool*>(_v) = _t->defaultBand20MuteValue(); break;
        case 840: *reinterpret_cast<bool*>(_v) = _t->band21Mute(); break;
        case 841: *reinterpret_cast<bool*>(_v) = _t->isBand21MuteImmutable(); break;
        case 842: *reinterpret_cast<bool*>(_v) = _t->defaultBand21MuteValue(); break;
        case 843: *reinterpret_cast<bool*>(_v) = _t->band22Mute(); break;
        case 844: *reinterpret_cast<bool*>(_v) = _t->isBand22MuteImmutable(); break;
        case 845: *reinterpret_cast<bool*>(_v) = _t->defaultBand22MuteValue(); break;
        case 846: *reinterpret_cast<bool*>(_v) = _t->band23Mute(); break;
        case 847: *reinterpret_cast<bool*>(_v) = _t->isBand23MuteImmutable(); break;
        case 848: *reinterpret_cast<bool*>(_v) = _t->defaultBand23MuteValue(); break;
        case 849: *reinterpret_cast<bool*>(_v) = _t->band24Mute(); break;
        case 850: *reinterpret_cast<bool*>(_v) = _t->isBand24MuteImmutable(); break;
        case 851: *reinterpret_cast<bool*>(_v) = _t->defaultBand24MuteValue(); break;
        case 852: *reinterpret_cast<bool*>(_v) = _t->band25Mute(); break;
        case 853: *reinterpret_cast<bool*>(_v) = _t->isBand25MuteImmutable(); break;
        case 854: *reinterpret_cast<bool*>(_v) = _t->defaultBand25MuteValue(); break;
        case 855: *reinterpret_cast<bool*>(_v) = _t->band26Mute(); break;
        case 856: *reinterpret_cast<bool*>(_v) = _t->isBand26MuteImmutable(); break;
        case 857: *reinterpret_cast<bool*>(_v) = _t->defaultBand26MuteValue(); break;
        case 858: *reinterpret_cast<bool*>(_v) = _t->band27Mute(); break;
        case 859: *reinterpret_cast<bool*>(_v) = _t->isBand27MuteImmutable(); break;
        case 860: *reinterpret_cast<bool*>(_v) = _t->defaultBand27MuteValue(); break;
        case 861: *reinterpret_cast<bool*>(_v) = _t->band28Mute(); break;
        case 862: *reinterpret_cast<bool*>(_v) = _t->isBand28MuteImmutable(); break;
        case 863: *reinterpret_cast<bool*>(_v) = _t->defaultBand28MuteValue(); break;
        case 864: *reinterpret_cast<bool*>(_v) = _t->band29Mute(); break;
        case 865: *reinterpret_cast<bool*>(_v) = _t->isBand29MuteImmutable(); break;
        case 866: *reinterpret_cast<bool*>(_v) = _t->defaultBand29MuteValue(); break;
        case 867: *reinterpret_cast<bool*>(_v) = _t->band30Mute(); break;
        case 868: *reinterpret_cast<bool*>(_v) = _t->isBand30MuteImmutable(); break;
        case 869: *reinterpret_cast<bool*>(_v) = _t->defaultBand30MuteValue(); break;
        case 870: *reinterpret_cast<bool*>(_v) = _t->band31Mute(); break;
        case 871: *reinterpret_cast<bool*>(_v) = _t->isBand31MuteImmutable(); break;
        case 872: *reinterpret_cast<bool*>(_v) = _t->defaultBand31MuteValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBandModeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 3: _t->setBandTypeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 6: _t->setBandSlopeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 9: _t->setBand0Gain(*reinterpret_cast<double*>(_v)); break;
        case 12: _t->setBand1Gain(*reinterpret_cast<double*>(_v)); break;
        case 15: _t->setBand2Gain(*reinterpret_cast<double*>(_v)); break;
        case 18: _t->setBand3Gain(*reinterpret_cast<double*>(_v)); break;
        case 21: _t->setBand4Gain(*reinterpret_cast<double*>(_v)); break;
        case 24: _t->setBand5Gain(*reinterpret_cast<double*>(_v)); break;
        case 27: _t->setBand6Gain(*reinterpret_cast<double*>(_v)); break;
        case 30: _t->setBand7Gain(*reinterpret_cast<double*>(_v)); break;
        case 33: _t->setBand8Gain(*reinterpret_cast<double*>(_v)); break;
        case 36: _t->setBand9Gain(*reinterpret_cast<double*>(_v)); break;
        case 39: _t->setBand10Gain(*reinterpret_cast<double*>(_v)); break;
        case 42: _t->setBand11Gain(*reinterpret_cast<double*>(_v)); break;
        case 45: _t->setBand12Gain(*reinterpret_cast<double*>(_v)); break;
        case 48: _t->setBand13Gain(*reinterpret_cast<double*>(_v)); break;
        case 51: _t->setBand14Gain(*reinterpret_cast<double*>(_v)); break;
        case 54: _t->setBand15Gain(*reinterpret_cast<double*>(_v)); break;
        case 57: _t->setBand16Gain(*reinterpret_cast<double*>(_v)); break;
        case 60: _t->setBand17Gain(*reinterpret_cast<double*>(_v)); break;
        case 63: _t->setBand18Gain(*reinterpret_cast<double*>(_v)); break;
        case 66: _t->setBand19Gain(*reinterpret_cast<double*>(_v)); break;
        case 69: _t->setBand20Gain(*reinterpret_cast<double*>(_v)); break;
        case 72: _t->setBand21Gain(*reinterpret_cast<double*>(_v)); break;
        case 75: _t->setBand22Gain(*reinterpret_cast<double*>(_v)); break;
        case 78: _t->setBand23Gain(*reinterpret_cast<double*>(_v)); break;
        case 81: _t->setBand24Gain(*reinterpret_cast<double*>(_v)); break;
        case 84: _t->setBand25Gain(*reinterpret_cast<double*>(_v)); break;
        case 87: _t->setBand26Gain(*reinterpret_cast<double*>(_v)); break;
        case 90: _t->setBand27Gain(*reinterpret_cast<double*>(_v)); break;
        case 93: _t->setBand28Gain(*reinterpret_cast<double*>(_v)); break;
        case 96: _t->setBand29Gain(*reinterpret_cast<double*>(_v)); break;
        case 99: _t->setBand30Gain(*reinterpret_cast<double*>(_v)); break;
        case 102: _t->setBand31Gain(*reinterpret_cast<double*>(_v)); break;
        case 105: _t->setBand0Frequency(*reinterpret_cast<double*>(_v)); break;
        case 108: _t->setBand1Frequency(*reinterpret_cast<double*>(_v)); break;
        case 111: _t->setBand2Frequency(*reinterpret_cast<double*>(_v)); break;
        case 114: _t->setBand3Frequency(*reinterpret_cast<double*>(_v)); break;
        case 117: _t->setBand4Frequency(*reinterpret_cast<double*>(_v)); break;
        case 120: _t->setBand5Frequency(*reinterpret_cast<double*>(_v)); break;
        case 123: _t->setBand6Frequency(*reinterpret_cast<double*>(_v)); break;
        case 126: _t->setBand7Frequency(*reinterpret_cast<double*>(_v)); break;
        case 129: _t->setBand8Frequency(*reinterpret_cast<double*>(_v)); break;
        case 132: _t->setBand9Frequency(*reinterpret_cast<double*>(_v)); break;
        case 135: _t->setBand10Frequency(*reinterpret_cast<double*>(_v)); break;
        case 138: _t->setBand11Frequency(*reinterpret_cast<double*>(_v)); break;
        case 141: _t->setBand12Frequency(*reinterpret_cast<double*>(_v)); break;
        case 144: _t->setBand13Frequency(*reinterpret_cast<double*>(_v)); break;
        case 147: _t->setBand14Frequency(*reinterpret_cast<double*>(_v)); break;
        case 150: _t->setBand15Frequency(*reinterpret_cast<double*>(_v)); break;
        case 153: _t->setBand16Frequency(*reinterpret_cast<double*>(_v)); break;
        case 156: _t->setBand17Frequency(*reinterpret_cast<double*>(_v)); break;
        case 159: _t->setBand18Frequency(*reinterpret_cast<double*>(_v)); break;
        case 162: _t->setBand19Frequency(*reinterpret_cast<double*>(_v)); break;
        case 165: _t->setBand20Frequency(*reinterpret_cast<double*>(_v)); break;
        case 168: _t->setBand21Frequency(*reinterpret_cast<double*>(_v)); break;
        case 171: _t->setBand22Frequency(*reinterpret_cast<double*>(_v)); break;
        case 174: _t->setBand23Frequency(*reinterpret_cast<double*>(_v)); break;
        case 177: _t->setBand24Frequency(*reinterpret_cast<double*>(_v)); break;
        case 180: _t->setBand25Frequency(*reinterpret_cast<double*>(_v)); break;
        case 183: _t->setBand26Frequency(*reinterpret_cast<double*>(_v)); break;
        case 186: _t->setBand27Frequency(*reinterpret_cast<double*>(_v)); break;
        case 189: _t->setBand28Frequency(*reinterpret_cast<double*>(_v)); break;
        case 192: _t->setBand29Frequency(*reinterpret_cast<double*>(_v)); break;
        case 195: _t->setBand30Frequency(*reinterpret_cast<double*>(_v)); break;
        case 198: _t->setBand31Frequency(*reinterpret_cast<double*>(_v)); break;
        case 201: _t->setBand0Q(*reinterpret_cast<double*>(_v)); break;
        case 204: _t->setBand1Q(*reinterpret_cast<double*>(_v)); break;
        case 207: _t->setBand2Q(*reinterpret_cast<double*>(_v)); break;
        case 210: _t->setBand3Q(*reinterpret_cast<double*>(_v)); break;
        case 213: _t->setBand4Q(*reinterpret_cast<double*>(_v)); break;
        case 216: _t->setBand5Q(*reinterpret_cast<double*>(_v)); break;
        case 219: _t->setBand6Q(*reinterpret_cast<double*>(_v)); break;
        case 222: _t->setBand7Q(*reinterpret_cast<double*>(_v)); break;
        case 225: _t->setBand8Q(*reinterpret_cast<double*>(_v)); break;
        case 228: _t->setBand9Q(*reinterpret_cast<double*>(_v)); break;
        case 231: _t->setBand10Q(*reinterpret_cast<double*>(_v)); break;
        case 234: _t->setBand11Q(*reinterpret_cast<double*>(_v)); break;
        case 237: _t->setBand12Q(*reinterpret_cast<double*>(_v)); break;
        case 240: _t->setBand13Q(*reinterpret_cast<double*>(_v)); break;
        case 243: _t->setBand14Q(*reinterpret_cast<double*>(_v)); break;
        case 246: _t->setBand15Q(*reinterpret_cast<double*>(_v)); break;
        case 249: _t->setBand16Q(*reinterpret_cast<double*>(_v)); break;
        case 252: _t->setBand17Q(*reinterpret_cast<double*>(_v)); break;
        case 255: _t->setBand18Q(*reinterpret_cast<double*>(_v)); break;
        case 258: _t->setBand19Q(*reinterpret_cast<double*>(_v)); break;
        case 261: _t->setBand20Q(*reinterpret_cast<double*>(_v)); break;
        case 264: _t->setBand21Q(*reinterpret_cast<double*>(_v)); break;
        case 267: _t->setBand22Q(*reinterpret_cast<double*>(_v)); break;
        case 270: _t->setBand23Q(*reinterpret_cast<double*>(_v)); break;
        case 273: _t->setBand24Q(*reinterpret_cast<double*>(_v)); break;
        case 276: _t->setBand25Q(*reinterpret_cast<double*>(_v)); break;
        case 279: _t->setBand26Q(*reinterpret_cast<double*>(_v)); break;
        case 282: _t->setBand27Q(*reinterpret_cast<double*>(_v)); break;
        case 285: _t->setBand28Q(*reinterpret_cast<double*>(_v)); break;
        case 288: _t->setBand29Q(*reinterpret_cast<double*>(_v)); break;
        case 291: _t->setBand30Q(*reinterpret_cast<double*>(_v)); break;
        case 294: _t->setBand31Q(*reinterpret_cast<double*>(_v)); break;
        case 297: _t->setBand0Width(*reinterpret_cast<double*>(_v)); break;
        case 300: _t->setBand1Width(*reinterpret_cast<double*>(_v)); break;
        case 303: _t->setBand2Width(*reinterpret_cast<double*>(_v)); break;
        case 306: _t->setBand3Width(*reinterpret_cast<double*>(_v)); break;
        case 309: _t->setBand4Width(*reinterpret_cast<double*>(_v)); break;
        case 312: _t->setBand5Width(*reinterpret_cast<double*>(_v)); break;
        case 315: _t->setBand6Width(*reinterpret_cast<double*>(_v)); break;
        case 318: _t->setBand7Width(*reinterpret_cast<double*>(_v)); break;
        case 321: _t->setBand8Width(*reinterpret_cast<double*>(_v)); break;
        case 324: _t->setBand9Width(*reinterpret_cast<double*>(_v)); break;
        case 327: _t->setBand10Width(*reinterpret_cast<double*>(_v)); break;
        case 330: _t->setBand11Width(*reinterpret_cast<double*>(_v)); break;
        case 333: _t->setBand12Width(*reinterpret_cast<double*>(_v)); break;
        case 336: _t->setBand13Width(*reinterpret_cast<double*>(_v)); break;
        case 339: _t->setBand14Width(*reinterpret_cast<double*>(_v)); break;
        case 342: _t->setBand15Width(*reinterpret_cast<double*>(_v)); break;
        case 345: _t->setBand16Width(*reinterpret_cast<double*>(_v)); break;
        case 348: _t->setBand17Width(*reinterpret_cast<double*>(_v)); break;
        case 351: _t->setBand18Width(*reinterpret_cast<double*>(_v)); break;
        case 354: _t->setBand19Width(*reinterpret_cast<double*>(_v)); break;
        case 357: _t->setBand20Width(*reinterpret_cast<double*>(_v)); break;
        case 360: _t->setBand21Width(*reinterpret_cast<double*>(_v)); break;
        case 363: _t->setBand22Width(*reinterpret_cast<double*>(_v)); break;
        case 366: _t->setBand23Width(*reinterpret_cast<double*>(_v)); break;
        case 369: _t->setBand24Width(*reinterpret_cast<double*>(_v)); break;
        case 372: _t->setBand25Width(*reinterpret_cast<double*>(_v)); break;
        case 375: _t->setBand26Width(*reinterpret_cast<double*>(_v)); break;
        case 378: _t->setBand27Width(*reinterpret_cast<double*>(_v)); break;
        case 381: _t->setBand28Width(*reinterpret_cast<double*>(_v)); break;
        case 384: _t->setBand29Width(*reinterpret_cast<double*>(_v)); break;
        case 387: _t->setBand30Width(*reinterpret_cast<double*>(_v)); break;
        case 390: _t->setBand31Width(*reinterpret_cast<double*>(_v)); break;
        case 393: _t->setBand0Type(*reinterpret_cast<int*>(_v)); break;
        case 396: _t->setBand1Type(*reinterpret_cast<int*>(_v)); break;
        case 399: _t->setBand2Type(*reinterpret_cast<int*>(_v)); break;
        case 402: _t->setBand3Type(*reinterpret_cast<int*>(_v)); break;
        case 405: _t->setBand4Type(*reinterpret_cast<int*>(_v)); break;
        case 408: _t->setBand5Type(*reinterpret_cast<int*>(_v)); break;
        case 411: _t->setBand6Type(*reinterpret_cast<int*>(_v)); break;
        case 414: _t->setBand7Type(*reinterpret_cast<int*>(_v)); break;
        case 417: _t->setBand8Type(*reinterpret_cast<int*>(_v)); break;
        case 420: _t->setBand9Type(*reinterpret_cast<int*>(_v)); break;
        case 423: _t->setBand10Type(*reinterpret_cast<int*>(_v)); break;
        case 426: _t->setBand11Type(*reinterpret_cast<int*>(_v)); break;
        case 429: _t->setBand12Type(*reinterpret_cast<int*>(_v)); break;
        case 432: _t->setBand13Type(*reinterpret_cast<int*>(_v)); break;
        case 435: _t->setBand14Type(*reinterpret_cast<int*>(_v)); break;
        case 438: _t->setBand15Type(*reinterpret_cast<int*>(_v)); break;
        case 441: _t->setBand16Type(*reinterpret_cast<int*>(_v)); break;
        case 444: _t->setBand17Type(*reinterpret_cast<int*>(_v)); break;
        case 447: _t->setBand18Type(*reinterpret_cast<int*>(_v)); break;
        case 450: _t->setBand19Type(*reinterpret_cast<int*>(_v)); break;
        case 453: _t->setBand20Type(*reinterpret_cast<int*>(_v)); break;
        case 456: _t->setBand21Type(*reinterpret_cast<int*>(_v)); break;
        case 459: _t->setBand22Type(*reinterpret_cast<int*>(_v)); break;
        case 462: _t->setBand23Type(*reinterpret_cast<int*>(_v)); break;
        case 465: _t->setBand24Type(*reinterpret_cast<int*>(_v)); break;
        case 468: _t->setBand25Type(*reinterpret_cast<int*>(_v)); break;
        case 471: _t->setBand26Type(*reinterpret_cast<int*>(_v)); break;
        case 474: _t->setBand27Type(*reinterpret_cast<int*>(_v)); break;
        case 477: _t->setBand28Type(*reinterpret_cast<int*>(_v)); break;
        case 480: _t->setBand29Type(*reinterpret_cast<int*>(_v)); break;
        case 483: _t->setBand30Type(*reinterpret_cast<int*>(_v)); break;
        case 486: _t->setBand31Type(*reinterpret_cast<int*>(_v)); break;
        case 489: _t->setBand0Mode(*reinterpret_cast<int*>(_v)); break;
        case 492: _t->setBand1Mode(*reinterpret_cast<int*>(_v)); break;
        case 495: _t->setBand2Mode(*reinterpret_cast<int*>(_v)); break;
        case 498: _t->setBand3Mode(*reinterpret_cast<int*>(_v)); break;
        case 501: _t->setBand4Mode(*reinterpret_cast<int*>(_v)); break;
        case 504: _t->setBand5Mode(*reinterpret_cast<int*>(_v)); break;
        case 507: _t->setBand6Mode(*reinterpret_cast<int*>(_v)); break;
        case 510: _t->setBand7Mode(*reinterpret_cast<int*>(_v)); break;
        case 513: _t->setBand8Mode(*reinterpret_cast<int*>(_v)); break;
        case 516: _t->setBand9Mode(*reinterpret_cast<int*>(_v)); break;
        case 519: _t->setBand10Mode(*reinterpret_cast<int*>(_v)); break;
        case 522: _t->setBand11Mode(*reinterpret_cast<int*>(_v)); break;
        case 525: _t->setBand12Mode(*reinterpret_cast<int*>(_v)); break;
        case 528: _t->setBand13Mode(*reinterpret_cast<int*>(_v)); break;
        case 531: _t->setBand14Mode(*reinterpret_cast<int*>(_v)); break;
        case 534: _t->setBand15Mode(*reinterpret_cast<int*>(_v)); break;
        case 537: _t->setBand16Mode(*reinterpret_cast<int*>(_v)); break;
        case 540: _t->setBand17Mode(*reinterpret_cast<int*>(_v)); break;
        case 543: _t->setBand18Mode(*reinterpret_cast<int*>(_v)); break;
        case 546: _t->setBand19Mode(*reinterpret_cast<int*>(_v)); break;
        case 549: _t->setBand20Mode(*reinterpret_cast<int*>(_v)); break;
        case 552: _t->setBand21Mode(*reinterpret_cast<int*>(_v)); break;
        case 555: _t->setBand22Mode(*reinterpret_cast<int*>(_v)); break;
        case 558: _t->setBand23Mode(*reinterpret_cast<int*>(_v)); break;
        case 561: _t->setBand24Mode(*reinterpret_cast<int*>(_v)); break;
        case 564: _t->setBand25Mode(*reinterpret_cast<int*>(_v)); break;
        case 567: _t->setBand26Mode(*reinterpret_cast<int*>(_v)); break;
        case 570: _t->setBand27Mode(*reinterpret_cast<int*>(_v)); break;
        case 573: _t->setBand28Mode(*reinterpret_cast<int*>(_v)); break;
        case 576: _t->setBand29Mode(*reinterpret_cast<int*>(_v)); break;
        case 579: _t->setBand30Mode(*reinterpret_cast<int*>(_v)); break;
        case 582: _t->setBand31Mode(*reinterpret_cast<int*>(_v)); break;
        case 585: _t->setBand0Slope(*reinterpret_cast<int*>(_v)); break;
        case 588: _t->setBand1Slope(*reinterpret_cast<int*>(_v)); break;
        case 591: _t->setBand2Slope(*reinterpret_cast<int*>(_v)); break;
        case 594: _t->setBand3Slope(*reinterpret_cast<int*>(_v)); break;
        case 597: _t->setBand4Slope(*reinterpret_cast<int*>(_v)); break;
        case 600: _t->setBand5Slope(*reinterpret_cast<int*>(_v)); break;
        case 603: _t->setBand6Slope(*reinterpret_cast<int*>(_v)); break;
        case 606: _t->setBand7Slope(*reinterpret_cast<int*>(_v)); break;
        case 609: _t->setBand8Slope(*reinterpret_cast<int*>(_v)); break;
        case 612: _t->setBand9Slope(*reinterpret_cast<int*>(_v)); break;
        case 615: _t->setBand10Slope(*reinterpret_cast<int*>(_v)); break;
        case 618: _t->setBand11Slope(*reinterpret_cast<int*>(_v)); break;
        case 621: _t->setBand12Slope(*reinterpret_cast<int*>(_v)); break;
        case 624: _t->setBand13Slope(*reinterpret_cast<int*>(_v)); break;
        case 627: _t->setBand14Slope(*reinterpret_cast<int*>(_v)); break;
        case 630: _t->setBand15Slope(*reinterpret_cast<int*>(_v)); break;
        case 633: _t->setBand16Slope(*reinterpret_cast<int*>(_v)); break;
        case 636: _t->setBand17Slope(*reinterpret_cast<int*>(_v)); break;
        case 639: _t->setBand18Slope(*reinterpret_cast<int*>(_v)); break;
        case 642: _t->setBand19Slope(*reinterpret_cast<int*>(_v)); break;
        case 645: _t->setBand20Slope(*reinterpret_cast<int*>(_v)); break;
        case 648: _t->setBand21Slope(*reinterpret_cast<int*>(_v)); break;
        case 651: _t->setBand22Slope(*reinterpret_cast<int*>(_v)); break;
        case 654: _t->setBand23Slope(*reinterpret_cast<int*>(_v)); break;
        case 657: _t->setBand24Slope(*reinterpret_cast<int*>(_v)); break;
        case 660: _t->setBand25Slope(*reinterpret_cast<int*>(_v)); break;
        case 663: _t->setBand26Slope(*reinterpret_cast<int*>(_v)); break;
        case 666: _t->setBand27Slope(*reinterpret_cast<int*>(_v)); break;
        case 669: _t->setBand28Slope(*reinterpret_cast<int*>(_v)); break;
        case 672: _t->setBand29Slope(*reinterpret_cast<int*>(_v)); break;
        case 675: _t->setBand30Slope(*reinterpret_cast<int*>(_v)); break;
        case 678: _t->setBand31Slope(*reinterpret_cast<int*>(_v)); break;
        case 681: _t->setBand0Solo(*reinterpret_cast<bool*>(_v)); break;
        case 684: _t->setBand1Solo(*reinterpret_cast<bool*>(_v)); break;
        case 687: _t->setBand2Solo(*reinterpret_cast<bool*>(_v)); break;
        case 690: _t->setBand3Solo(*reinterpret_cast<bool*>(_v)); break;
        case 693: _t->setBand4Solo(*reinterpret_cast<bool*>(_v)); break;
        case 696: _t->setBand5Solo(*reinterpret_cast<bool*>(_v)); break;
        case 699: _t->setBand6Solo(*reinterpret_cast<bool*>(_v)); break;
        case 702: _t->setBand7Solo(*reinterpret_cast<bool*>(_v)); break;
        case 705: _t->setBand8Solo(*reinterpret_cast<bool*>(_v)); break;
        case 708: _t->setBand9Solo(*reinterpret_cast<bool*>(_v)); break;
        case 711: _t->setBand10Solo(*reinterpret_cast<bool*>(_v)); break;
        case 714: _t->setBand11Solo(*reinterpret_cast<bool*>(_v)); break;
        case 717: _t->setBand12Solo(*reinterpret_cast<bool*>(_v)); break;
        case 720: _t->setBand13Solo(*reinterpret_cast<bool*>(_v)); break;
        case 723: _t->setBand14Solo(*reinterpret_cast<bool*>(_v)); break;
        case 726: _t->setBand15Solo(*reinterpret_cast<bool*>(_v)); break;
        case 729: _t->setBand16Solo(*reinterpret_cast<bool*>(_v)); break;
        case 732: _t->setBand17Solo(*reinterpret_cast<bool*>(_v)); break;
        case 735: _t->setBand18Solo(*reinterpret_cast<bool*>(_v)); break;
        case 738: _t->setBand19Solo(*reinterpret_cast<bool*>(_v)); break;
        case 741: _t->setBand20Solo(*reinterpret_cast<bool*>(_v)); break;
        case 744: _t->setBand21Solo(*reinterpret_cast<bool*>(_v)); break;
        case 747: _t->setBand22Solo(*reinterpret_cast<bool*>(_v)); break;
        case 750: _t->setBand23Solo(*reinterpret_cast<bool*>(_v)); break;
        case 753: _t->setBand24Solo(*reinterpret_cast<bool*>(_v)); break;
        case 756: _t->setBand25Solo(*reinterpret_cast<bool*>(_v)); break;
        case 759: _t->setBand26Solo(*reinterpret_cast<bool*>(_v)); break;
        case 762: _t->setBand27Solo(*reinterpret_cast<bool*>(_v)); break;
        case 765: _t->setBand28Solo(*reinterpret_cast<bool*>(_v)); break;
        case 768: _t->setBand29Solo(*reinterpret_cast<bool*>(_v)); break;
        case 771: _t->setBand30Solo(*reinterpret_cast<bool*>(_v)); break;
        case 774: _t->setBand31Solo(*reinterpret_cast<bool*>(_v)); break;
        case 777: _t->setBand0Mute(*reinterpret_cast<bool*>(_v)); break;
        case 780: _t->setBand1Mute(*reinterpret_cast<bool*>(_v)); break;
        case 783: _t->setBand2Mute(*reinterpret_cast<bool*>(_v)); break;
        case 786: _t->setBand3Mute(*reinterpret_cast<bool*>(_v)); break;
        case 789: _t->setBand4Mute(*reinterpret_cast<bool*>(_v)); break;
        case 792: _t->setBand5Mute(*reinterpret_cast<bool*>(_v)); break;
        case 795: _t->setBand6Mute(*reinterpret_cast<bool*>(_v)); break;
        case 798: _t->setBand7Mute(*reinterpret_cast<bool*>(_v)); break;
        case 801: _t->setBand8Mute(*reinterpret_cast<bool*>(_v)); break;
        case 804: _t->setBand9Mute(*reinterpret_cast<bool*>(_v)); break;
        case 807: _t->setBand10Mute(*reinterpret_cast<bool*>(_v)); break;
        case 810: _t->setBand11Mute(*reinterpret_cast<bool*>(_v)); break;
        case 813: _t->setBand12Mute(*reinterpret_cast<bool*>(_v)); break;
        case 816: _t->setBand13Mute(*reinterpret_cast<bool*>(_v)); break;
        case 819: _t->setBand14Mute(*reinterpret_cast<bool*>(_v)); break;
        case 822: _t->setBand15Mute(*reinterpret_cast<bool*>(_v)); break;
        case 825: _t->setBand16Mute(*reinterpret_cast<bool*>(_v)); break;
        case 828: _t->setBand17Mute(*reinterpret_cast<bool*>(_v)); break;
        case 831: _t->setBand18Mute(*reinterpret_cast<bool*>(_v)); break;
        case 834: _t->setBand19Mute(*reinterpret_cast<bool*>(_v)); break;
        case 837: _t->setBand20Mute(*reinterpret_cast<bool*>(_v)); break;
        case 840: _t->setBand21Mute(*reinterpret_cast<bool*>(_v)); break;
        case 843: _t->setBand22Mute(*reinterpret_cast<bool*>(_v)); break;
        case 846: _t->setBand23Mute(*reinterpret_cast<bool*>(_v)); break;
        case 849: _t->setBand24Mute(*reinterpret_cast<bool*>(_v)); break;
        case 852: _t->setBand25Mute(*reinterpret_cast<bool*>(_v)); break;
        case 855: _t->setBand26Mute(*reinterpret_cast<bool*>(_v)); break;
        case 858: _t->setBand27Mute(*reinterpret_cast<bool*>(_v)); break;
        case 861: _t->setBand28Mute(*reinterpret_cast<bool*>(_v)); break;
        case 864: _t->setBand29Mute(*reinterpret_cast<bool*>(_v)); break;
        case 867: _t->setBand30Mute(*reinterpret_cast<bool*>(_v)); break;
        case 870: _t->setBand31Mute(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbEqualizerChannel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbEqualizerChannel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DbEqualizerChannelE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbEqualizerChannel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 291)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 291;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 291)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 291;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 873;
    }
    return _id;
}

// SIGNAL 0
void DbEqualizerChannel::bandModeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbEqualizerChannel::bandTypeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbEqualizerChannel::bandSlopeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbEqualizerChannel::band0GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DbEqualizerChannel::band1GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DbEqualizerChannel::band2GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DbEqualizerChannel::band3GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DbEqualizerChannel::band4GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DbEqualizerChannel::band5GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DbEqualizerChannel::band6GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DbEqualizerChannel::band7GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DbEqualizerChannel::band8GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void DbEqualizerChannel::band9GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void DbEqualizerChannel::band10GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void DbEqualizerChannel::band11GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void DbEqualizerChannel::band12GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void DbEqualizerChannel::band13GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void DbEqualizerChannel::band14GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void DbEqualizerChannel::band15GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void DbEqualizerChannel::band16GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void DbEqualizerChannel::band17GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void DbEqualizerChannel::band18GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void DbEqualizerChannel::band19GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void DbEqualizerChannel::band20GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void DbEqualizerChannel::band21GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void DbEqualizerChannel::band22GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void DbEqualizerChannel::band23GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void DbEqualizerChannel::band24GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void DbEqualizerChannel::band25GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void DbEqualizerChannel::band26GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void DbEqualizerChannel::band27GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void DbEqualizerChannel::band28GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void DbEqualizerChannel::band29GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}

// SIGNAL 33
void DbEqualizerChannel::band30GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 33, nullptr);
}

// SIGNAL 34
void DbEqualizerChannel::band31GainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 34, nullptr);
}

// SIGNAL 35
void DbEqualizerChannel::band0FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 35, nullptr);
}

// SIGNAL 36
void DbEqualizerChannel::band1FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 36, nullptr);
}

// SIGNAL 37
void DbEqualizerChannel::band2FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 37, nullptr);
}

// SIGNAL 38
void DbEqualizerChannel::band3FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 38, nullptr);
}

// SIGNAL 39
void DbEqualizerChannel::band4FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 39, nullptr);
}

// SIGNAL 40
void DbEqualizerChannel::band5FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 40, nullptr);
}

// SIGNAL 41
void DbEqualizerChannel::band6FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 41, nullptr);
}

// SIGNAL 42
void DbEqualizerChannel::band7FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 42, nullptr);
}

// SIGNAL 43
void DbEqualizerChannel::band8FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 43, nullptr);
}

// SIGNAL 44
void DbEqualizerChannel::band9FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 44, nullptr);
}

// SIGNAL 45
void DbEqualizerChannel::band10FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 45, nullptr);
}

// SIGNAL 46
void DbEqualizerChannel::band11FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 46, nullptr);
}

// SIGNAL 47
void DbEqualizerChannel::band12FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 47, nullptr);
}

// SIGNAL 48
void DbEqualizerChannel::band13FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 48, nullptr);
}

// SIGNAL 49
void DbEqualizerChannel::band14FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 49, nullptr);
}

// SIGNAL 50
void DbEqualizerChannel::band15FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 50, nullptr);
}

// SIGNAL 51
void DbEqualizerChannel::band16FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 51, nullptr);
}

// SIGNAL 52
void DbEqualizerChannel::band17FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 52, nullptr);
}

// SIGNAL 53
void DbEqualizerChannel::band18FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 53, nullptr);
}

// SIGNAL 54
void DbEqualizerChannel::band19FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 54, nullptr);
}

// SIGNAL 55
void DbEqualizerChannel::band20FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 55, nullptr);
}

// SIGNAL 56
void DbEqualizerChannel::band21FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 56, nullptr);
}

// SIGNAL 57
void DbEqualizerChannel::band22FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 57, nullptr);
}

// SIGNAL 58
void DbEqualizerChannel::band23FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 58, nullptr);
}

// SIGNAL 59
void DbEqualizerChannel::band24FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 59, nullptr);
}

// SIGNAL 60
void DbEqualizerChannel::band25FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 60, nullptr);
}

// SIGNAL 61
void DbEqualizerChannel::band26FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 61, nullptr);
}

// SIGNAL 62
void DbEqualizerChannel::band27FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 62, nullptr);
}

// SIGNAL 63
void DbEqualizerChannel::band28FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 63, nullptr);
}

// SIGNAL 64
void DbEqualizerChannel::band29FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 64, nullptr);
}

// SIGNAL 65
void DbEqualizerChannel::band30FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 65, nullptr);
}

// SIGNAL 66
void DbEqualizerChannel::band31FrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 66, nullptr);
}

// SIGNAL 67
void DbEqualizerChannel::band0QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 67, nullptr);
}

// SIGNAL 68
void DbEqualizerChannel::band1QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 68, nullptr);
}

// SIGNAL 69
void DbEqualizerChannel::band2QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 69, nullptr);
}

// SIGNAL 70
void DbEqualizerChannel::band3QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 70, nullptr);
}

// SIGNAL 71
void DbEqualizerChannel::band4QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 71, nullptr);
}

// SIGNAL 72
void DbEqualizerChannel::band5QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 72, nullptr);
}

// SIGNAL 73
void DbEqualizerChannel::band6QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 73, nullptr);
}

// SIGNAL 74
void DbEqualizerChannel::band7QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 74, nullptr);
}

// SIGNAL 75
void DbEqualizerChannel::band8QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 75, nullptr);
}

// SIGNAL 76
void DbEqualizerChannel::band9QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 76, nullptr);
}

// SIGNAL 77
void DbEqualizerChannel::band10QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 77, nullptr);
}

// SIGNAL 78
void DbEqualizerChannel::band11QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 78, nullptr);
}

// SIGNAL 79
void DbEqualizerChannel::band12QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 79, nullptr);
}

// SIGNAL 80
void DbEqualizerChannel::band13QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 80, nullptr);
}

// SIGNAL 81
void DbEqualizerChannel::band14QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 81, nullptr);
}

// SIGNAL 82
void DbEqualizerChannel::band15QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 82, nullptr);
}

// SIGNAL 83
void DbEqualizerChannel::band16QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 83, nullptr);
}

// SIGNAL 84
void DbEqualizerChannel::band17QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 84, nullptr);
}

// SIGNAL 85
void DbEqualizerChannel::band18QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 85, nullptr);
}

// SIGNAL 86
void DbEqualizerChannel::band19QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 86, nullptr);
}

// SIGNAL 87
void DbEqualizerChannel::band20QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 87, nullptr);
}

// SIGNAL 88
void DbEqualizerChannel::band21QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 88, nullptr);
}

// SIGNAL 89
void DbEqualizerChannel::band22QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 89, nullptr);
}

// SIGNAL 90
void DbEqualizerChannel::band23QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 90, nullptr);
}

// SIGNAL 91
void DbEqualizerChannel::band24QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 91, nullptr);
}

// SIGNAL 92
void DbEqualizerChannel::band25QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 92, nullptr);
}

// SIGNAL 93
void DbEqualizerChannel::band26QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 93, nullptr);
}

// SIGNAL 94
void DbEqualizerChannel::band27QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 94, nullptr);
}

// SIGNAL 95
void DbEqualizerChannel::band28QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 95, nullptr);
}

// SIGNAL 96
void DbEqualizerChannel::band29QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 96, nullptr);
}

// SIGNAL 97
void DbEqualizerChannel::band30QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 97, nullptr);
}

// SIGNAL 98
void DbEqualizerChannel::band31QChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 98, nullptr);
}

// SIGNAL 99
void DbEqualizerChannel::band0WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 99, nullptr);
}

// SIGNAL 100
void DbEqualizerChannel::band1WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 100, nullptr);
}

// SIGNAL 101
void DbEqualizerChannel::band2WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 101, nullptr);
}

// SIGNAL 102
void DbEqualizerChannel::band3WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 102, nullptr);
}

// SIGNAL 103
void DbEqualizerChannel::band4WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 103, nullptr);
}

// SIGNAL 104
void DbEqualizerChannel::band5WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 104, nullptr);
}

// SIGNAL 105
void DbEqualizerChannel::band6WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 105, nullptr);
}

// SIGNAL 106
void DbEqualizerChannel::band7WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 106, nullptr);
}

// SIGNAL 107
void DbEqualizerChannel::band8WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 107, nullptr);
}

// SIGNAL 108
void DbEqualizerChannel::band9WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 108, nullptr);
}

// SIGNAL 109
void DbEqualizerChannel::band10WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 109, nullptr);
}

// SIGNAL 110
void DbEqualizerChannel::band11WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 110, nullptr);
}

// SIGNAL 111
void DbEqualizerChannel::band12WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 111, nullptr);
}

// SIGNAL 112
void DbEqualizerChannel::band13WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 112, nullptr);
}

// SIGNAL 113
void DbEqualizerChannel::band14WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 113, nullptr);
}

// SIGNAL 114
void DbEqualizerChannel::band15WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 114, nullptr);
}

// SIGNAL 115
void DbEqualizerChannel::band16WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 115, nullptr);
}

// SIGNAL 116
void DbEqualizerChannel::band17WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 116, nullptr);
}

// SIGNAL 117
void DbEqualizerChannel::band18WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 117, nullptr);
}

// SIGNAL 118
void DbEqualizerChannel::band19WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 118, nullptr);
}

// SIGNAL 119
void DbEqualizerChannel::band20WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 119, nullptr);
}

// SIGNAL 120
void DbEqualizerChannel::band21WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 120, nullptr);
}

// SIGNAL 121
void DbEqualizerChannel::band22WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 121, nullptr);
}

// SIGNAL 122
void DbEqualizerChannel::band23WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 122, nullptr);
}

// SIGNAL 123
void DbEqualizerChannel::band24WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 123, nullptr);
}

// SIGNAL 124
void DbEqualizerChannel::band25WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 124, nullptr);
}

// SIGNAL 125
void DbEqualizerChannel::band26WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 125, nullptr);
}

// SIGNAL 126
void DbEqualizerChannel::band27WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 126, nullptr);
}

// SIGNAL 127
void DbEqualizerChannel::band28WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 127, nullptr);
}

// SIGNAL 128
void DbEqualizerChannel::band29WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 128, nullptr);
}

// SIGNAL 129
void DbEqualizerChannel::band30WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 129, nullptr);
}

// SIGNAL 130
void DbEqualizerChannel::band31WidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 130, nullptr);
}

// SIGNAL 131
void DbEqualizerChannel::band0TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 131, nullptr);
}

// SIGNAL 132
void DbEqualizerChannel::band1TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 132, nullptr);
}

// SIGNAL 133
void DbEqualizerChannel::band2TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 133, nullptr);
}

// SIGNAL 134
void DbEqualizerChannel::band3TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 134, nullptr);
}

// SIGNAL 135
void DbEqualizerChannel::band4TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 135, nullptr);
}

// SIGNAL 136
void DbEqualizerChannel::band5TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 136, nullptr);
}

// SIGNAL 137
void DbEqualizerChannel::band6TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 137, nullptr);
}

// SIGNAL 138
void DbEqualizerChannel::band7TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 138, nullptr);
}

// SIGNAL 139
void DbEqualizerChannel::band8TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 139, nullptr);
}

// SIGNAL 140
void DbEqualizerChannel::band9TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 140, nullptr);
}

// SIGNAL 141
void DbEqualizerChannel::band10TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 141, nullptr);
}

// SIGNAL 142
void DbEqualizerChannel::band11TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 142, nullptr);
}

// SIGNAL 143
void DbEqualizerChannel::band12TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 143, nullptr);
}

// SIGNAL 144
void DbEqualizerChannel::band13TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 144, nullptr);
}

// SIGNAL 145
void DbEqualizerChannel::band14TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 145, nullptr);
}

// SIGNAL 146
void DbEqualizerChannel::band15TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 146, nullptr);
}

// SIGNAL 147
void DbEqualizerChannel::band16TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 147, nullptr);
}

// SIGNAL 148
void DbEqualizerChannel::band17TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 148, nullptr);
}

// SIGNAL 149
void DbEqualizerChannel::band18TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 149, nullptr);
}

// SIGNAL 150
void DbEqualizerChannel::band19TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 150, nullptr);
}

// SIGNAL 151
void DbEqualizerChannel::band20TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 151, nullptr);
}

// SIGNAL 152
void DbEqualizerChannel::band21TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 152, nullptr);
}

// SIGNAL 153
void DbEqualizerChannel::band22TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 153, nullptr);
}

// SIGNAL 154
void DbEqualizerChannel::band23TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 154, nullptr);
}

// SIGNAL 155
void DbEqualizerChannel::band24TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 155, nullptr);
}

// SIGNAL 156
void DbEqualizerChannel::band25TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 156, nullptr);
}

// SIGNAL 157
void DbEqualizerChannel::band26TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 157, nullptr);
}

// SIGNAL 158
void DbEqualizerChannel::band27TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 158, nullptr);
}

// SIGNAL 159
void DbEqualizerChannel::band28TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 159, nullptr);
}

// SIGNAL 160
void DbEqualizerChannel::band29TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 160, nullptr);
}

// SIGNAL 161
void DbEqualizerChannel::band30TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 161, nullptr);
}

// SIGNAL 162
void DbEqualizerChannel::band31TypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 162, nullptr);
}

// SIGNAL 163
void DbEqualizerChannel::band0ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 163, nullptr);
}

// SIGNAL 164
void DbEqualizerChannel::band1ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 164, nullptr);
}

// SIGNAL 165
void DbEqualizerChannel::band2ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 165, nullptr);
}

// SIGNAL 166
void DbEqualizerChannel::band3ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 166, nullptr);
}

// SIGNAL 167
void DbEqualizerChannel::band4ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 167, nullptr);
}

// SIGNAL 168
void DbEqualizerChannel::band5ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 168, nullptr);
}

// SIGNAL 169
void DbEqualizerChannel::band6ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 169, nullptr);
}

// SIGNAL 170
void DbEqualizerChannel::band7ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 170, nullptr);
}

// SIGNAL 171
void DbEqualizerChannel::band8ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 171, nullptr);
}

// SIGNAL 172
void DbEqualizerChannel::band9ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 172, nullptr);
}

// SIGNAL 173
void DbEqualizerChannel::band10ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 173, nullptr);
}

// SIGNAL 174
void DbEqualizerChannel::band11ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 174, nullptr);
}

// SIGNAL 175
void DbEqualizerChannel::band12ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 175, nullptr);
}

// SIGNAL 176
void DbEqualizerChannel::band13ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 176, nullptr);
}

// SIGNAL 177
void DbEqualizerChannel::band14ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 177, nullptr);
}

// SIGNAL 178
void DbEqualizerChannel::band15ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 178, nullptr);
}

// SIGNAL 179
void DbEqualizerChannel::band16ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 179, nullptr);
}

// SIGNAL 180
void DbEqualizerChannel::band17ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 180, nullptr);
}

// SIGNAL 181
void DbEqualizerChannel::band18ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 181, nullptr);
}

// SIGNAL 182
void DbEqualizerChannel::band19ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 182, nullptr);
}

// SIGNAL 183
void DbEqualizerChannel::band20ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 183, nullptr);
}

// SIGNAL 184
void DbEqualizerChannel::band21ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 184, nullptr);
}

// SIGNAL 185
void DbEqualizerChannel::band22ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 185, nullptr);
}

// SIGNAL 186
void DbEqualizerChannel::band23ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 186, nullptr);
}

// SIGNAL 187
void DbEqualizerChannel::band24ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 187, nullptr);
}

// SIGNAL 188
void DbEqualizerChannel::band25ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 188, nullptr);
}

// SIGNAL 189
void DbEqualizerChannel::band26ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 189, nullptr);
}

// SIGNAL 190
void DbEqualizerChannel::band27ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 190, nullptr);
}

// SIGNAL 191
void DbEqualizerChannel::band28ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 191, nullptr);
}

// SIGNAL 192
void DbEqualizerChannel::band29ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 192, nullptr);
}

// SIGNAL 193
void DbEqualizerChannel::band30ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 193, nullptr);
}

// SIGNAL 194
void DbEqualizerChannel::band31ModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 194, nullptr);
}

// SIGNAL 195
void DbEqualizerChannel::band0SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 195, nullptr);
}

// SIGNAL 196
void DbEqualizerChannel::band1SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 196, nullptr);
}

// SIGNAL 197
void DbEqualizerChannel::band2SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 197, nullptr);
}

// SIGNAL 198
void DbEqualizerChannel::band3SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 198, nullptr);
}

// SIGNAL 199
void DbEqualizerChannel::band4SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 199, nullptr);
}

// SIGNAL 200
void DbEqualizerChannel::band5SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 200, nullptr);
}

// SIGNAL 201
void DbEqualizerChannel::band6SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 201, nullptr);
}

// SIGNAL 202
void DbEqualizerChannel::band7SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 202, nullptr);
}

// SIGNAL 203
void DbEqualizerChannel::band8SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 203, nullptr);
}

// SIGNAL 204
void DbEqualizerChannel::band9SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 204, nullptr);
}

// SIGNAL 205
void DbEqualizerChannel::band10SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 205, nullptr);
}

// SIGNAL 206
void DbEqualizerChannel::band11SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 206, nullptr);
}

// SIGNAL 207
void DbEqualizerChannel::band12SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 207, nullptr);
}

// SIGNAL 208
void DbEqualizerChannel::band13SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 208, nullptr);
}

// SIGNAL 209
void DbEqualizerChannel::band14SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 209, nullptr);
}

// SIGNAL 210
void DbEqualizerChannel::band15SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 210, nullptr);
}

// SIGNAL 211
void DbEqualizerChannel::band16SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 211, nullptr);
}

// SIGNAL 212
void DbEqualizerChannel::band17SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 212, nullptr);
}

// SIGNAL 213
void DbEqualizerChannel::band18SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 213, nullptr);
}

// SIGNAL 214
void DbEqualizerChannel::band19SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 214, nullptr);
}

// SIGNAL 215
void DbEqualizerChannel::band20SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 215, nullptr);
}

// SIGNAL 216
void DbEqualizerChannel::band21SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 216, nullptr);
}

// SIGNAL 217
void DbEqualizerChannel::band22SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 217, nullptr);
}

// SIGNAL 218
void DbEqualizerChannel::band23SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 218, nullptr);
}

// SIGNAL 219
void DbEqualizerChannel::band24SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 219, nullptr);
}

// SIGNAL 220
void DbEqualizerChannel::band25SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 220, nullptr);
}

// SIGNAL 221
void DbEqualizerChannel::band26SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 221, nullptr);
}

// SIGNAL 222
void DbEqualizerChannel::band27SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 222, nullptr);
}

// SIGNAL 223
void DbEqualizerChannel::band28SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 223, nullptr);
}

// SIGNAL 224
void DbEqualizerChannel::band29SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 224, nullptr);
}

// SIGNAL 225
void DbEqualizerChannel::band30SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 225, nullptr);
}

// SIGNAL 226
void DbEqualizerChannel::band31SlopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 226, nullptr);
}

// SIGNAL 227
void DbEqualizerChannel::band0SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 227, nullptr);
}

// SIGNAL 228
void DbEqualizerChannel::band1SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 228, nullptr);
}

// SIGNAL 229
void DbEqualizerChannel::band2SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 229, nullptr);
}

// SIGNAL 230
void DbEqualizerChannel::band3SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 230, nullptr);
}

// SIGNAL 231
void DbEqualizerChannel::band4SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 231, nullptr);
}

// SIGNAL 232
void DbEqualizerChannel::band5SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 232, nullptr);
}

// SIGNAL 233
void DbEqualizerChannel::band6SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 233, nullptr);
}

// SIGNAL 234
void DbEqualizerChannel::band7SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 234, nullptr);
}

// SIGNAL 235
void DbEqualizerChannel::band8SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 235, nullptr);
}

// SIGNAL 236
void DbEqualizerChannel::band9SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 236, nullptr);
}

// SIGNAL 237
void DbEqualizerChannel::band10SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 237, nullptr);
}

// SIGNAL 238
void DbEqualizerChannel::band11SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 238, nullptr);
}

// SIGNAL 239
void DbEqualizerChannel::band12SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 239, nullptr);
}

// SIGNAL 240
void DbEqualizerChannel::band13SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 240, nullptr);
}

// SIGNAL 241
void DbEqualizerChannel::band14SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 241, nullptr);
}

// SIGNAL 242
void DbEqualizerChannel::band15SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 242, nullptr);
}

// SIGNAL 243
void DbEqualizerChannel::band16SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 243, nullptr);
}

// SIGNAL 244
void DbEqualizerChannel::band17SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 244, nullptr);
}

// SIGNAL 245
void DbEqualizerChannel::band18SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 245, nullptr);
}

// SIGNAL 246
void DbEqualizerChannel::band19SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 246, nullptr);
}

// SIGNAL 247
void DbEqualizerChannel::band20SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 247, nullptr);
}

// SIGNAL 248
void DbEqualizerChannel::band21SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 248, nullptr);
}

// SIGNAL 249
void DbEqualizerChannel::band22SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 249, nullptr);
}

// SIGNAL 250
void DbEqualizerChannel::band23SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 250, nullptr);
}

// SIGNAL 251
void DbEqualizerChannel::band24SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 251, nullptr);
}

// SIGNAL 252
void DbEqualizerChannel::band25SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 252, nullptr);
}

// SIGNAL 253
void DbEqualizerChannel::band26SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 253, nullptr);
}

// SIGNAL 254
void DbEqualizerChannel::band27SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 254, nullptr);
}

// SIGNAL 255
void DbEqualizerChannel::band28SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 255, nullptr);
}

// SIGNAL 256
void DbEqualizerChannel::band29SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 256, nullptr);
}

// SIGNAL 257
void DbEqualizerChannel::band30SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 257, nullptr);
}

// SIGNAL 258
void DbEqualizerChannel::band31SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 258, nullptr);
}

// SIGNAL 259
void DbEqualizerChannel::band0MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 259, nullptr);
}

// SIGNAL 260
void DbEqualizerChannel::band1MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 260, nullptr);
}

// SIGNAL 261
void DbEqualizerChannel::band2MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 261, nullptr);
}

// SIGNAL 262
void DbEqualizerChannel::band3MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 262, nullptr);
}

// SIGNAL 263
void DbEqualizerChannel::band4MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 263, nullptr);
}

// SIGNAL 264
void DbEqualizerChannel::band5MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 264, nullptr);
}

// SIGNAL 265
void DbEqualizerChannel::band6MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 265, nullptr);
}

// SIGNAL 266
void DbEqualizerChannel::band7MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 266, nullptr);
}

// SIGNAL 267
void DbEqualizerChannel::band8MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 267, nullptr);
}

// SIGNAL 268
void DbEqualizerChannel::band9MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 268, nullptr);
}

// SIGNAL 269
void DbEqualizerChannel::band10MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 269, nullptr);
}

// SIGNAL 270
void DbEqualizerChannel::band11MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 270, nullptr);
}

// SIGNAL 271
void DbEqualizerChannel::band12MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 271, nullptr);
}

// SIGNAL 272
void DbEqualizerChannel::band13MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 272, nullptr);
}

// SIGNAL 273
void DbEqualizerChannel::band14MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 273, nullptr);
}

// SIGNAL 274
void DbEqualizerChannel::band15MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 274, nullptr);
}

// SIGNAL 275
void DbEqualizerChannel::band16MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 275, nullptr);
}

// SIGNAL 276
void DbEqualizerChannel::band17MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 276, nullptr);
}

// SIGNAL 277
void DbEqualizerChannel::band18MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 277, nullptr);
}

// SIGNAL 278
void DbEqualizerChannel::band19MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 278, nullptr);
}

// SIGNAL 279
void DbEqualizerChannel::band20MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 279, nullptr);
}

// SIGNAL 280
void DbEqualizerChannel::band21MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 280, nullptr);
}

// SIGNAL 281
void DbEqualizerChannel::band22MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 281, nullptr);
}

// SIGNAL 282
void DbEqualizerChannel::band23MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 282, nullptr);
}

// SIGNAL 283
void DbEqualizerChannel::band24MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 283, nullptr);
}

// SIGNAL 284
void DbEqualizerChannel::band25MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 284, nullptr);
}

// SIGNAL 285
void DbEqualizerChannel::band26MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 285, nullptr);
}

// SIGNAL 286
void DbEqualizerChannel::band27MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 286, nullptr);
}

// SIGNAL 287
void DbEqualizerChannel::band28MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 287, nullptr);
}

// SIGNAL 288
void DbEqualizerChannel::band29MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 288, nullptr);
}

// SIGNAL 289
void DbEqualizerChannel::band30MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 289, nullptr);
}

// SIGNAL 290
void DbEqualizerChannel::band31MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 290, nullptr);
}
QT_WARNING_POP
