/****************************************************************************
** Meta object code from reading C++ file 'easyeffects_db_multiband_compressor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../easyeffects_db_multiband_compressor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'easyeffects_db_multiband_compressor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21DbMultibandCompressorE_t {};
} // unnamed namespace

template <> constexpr inline auto DbMultibandCompressor::qt_create_metaobjectdata<qt_meta_tag_ZN21DbMultibandCompressorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DbMultibandCompressor",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "bypassChanged",
        "inputGainChanged",
        "outputGainChanged",
        "dryChanged",
        "wetChanged",
        "viewSidechainChanged",
        "externalSidechainEnabledChanged",
        "stereoSplitChanged",
        "compressorModeLabelsChanged",
        "compressorModeChanged",
        "envelopeBoostLabelsChanged",
        "envelopeBoostChanged",
        "inputToSidechainChanged",
        "inputToLinkChanged",
        "sidechainToInputChanged",
        "sidechainToLinkChanged",
        "linkToSidechainChanged",
        "linkToInputChanged",
        "band1EnableChanged",
        "band2EnableChanged",
        "band3EnableChanged",
        "band4EnableChanged",
        "band5EnableChanged",
        "band6EnableChanged",
        "band7EnableChanged",
        "band1SplitFrequencyChanged",
        "band2SplitFrequencyChanged",
        "band3SplitFrequencyChanged",
        "band4SplitFrequencyChanged",
        "band5SplitFrequencyChanged",
        "band6SplitFrequencyChanged",
        "band7SplitFrequencyChanged",
        "sidechainInputDeviceChanged",
        "sidechainTypeLabelsChanged",
        "band0SidechainTypeChanged",
        "band1SidechainTypeChanged",
        "band2SidechainTypeChanged",
        "band3SidechainTypeChanged",
        "band4SidechainTypeChanged",
        "band5SidechainTypeChanged",
        "band6SidechainTypeChanged",
        "band7SidechainTypeChanged",
        "sidechainModeLabelsChanged",
        "band0SidechainModeChanged",
        "band1SidechainModeChanged",
        "band2SidechainModeChanged",
        "band3SidechainModeChanged",
        "band4SidechainModeChanged",
        "band5SidechainModeChanged",
        "band6SidechainModeChanged",
        "band7SidechainModeChanged",
        "sidechainSourceLabelsChanged",
        "band0SidechainSourceChanged",
        "band1SidechainSourceChanged",
        "band2SidechainSourceChanged",
        "band3SidechainSourceChanged",
        "band4SidechainSourceChanged",
        "band5SidechainSourceChanged",
        "band6SidechainSourceChanged",
        "band7SidechainSourceChanged",
        "stereoSplitSourceLabelsChanged",
        "band0StereoSplitSourceChanged",
        "band1StereoSplitSourceChanged",
        "band2StereoSplitSourceChanged",
        "band3StereoSplitSourceChanged",
        "band4StereoSplitSourceChanged",
        "band5StereoSplitSourceChanged",
        "band6StereoSplitSourceChanged",
        "band7StereoSplitSourceChanged",
        "band0SidechainLookaheadChanged",
        "band1SidechainLookaheadChanged",
        "band2SidechainLookaheadChanged",
        "band3SidechainLookaheadChanged",
        "band4SidechainLookaheadChanged",
        "band5SidechainLookaheadChanged",
        "band6SidechainLookaheadChanged",
        "band7SidechainLookaheadChanged",
        "band0SidechainReactivityChanged",
        "band1SidechainReactivityChanged",
        "band2SidechainReactivityChanged",
        "band3SidechainReactivityChanged",
        "band4SidechainReactivityChanged",
        "band5SidechainReactivityChanged",
        "band6SidechainReactivityChanged",
        "band7SidechainReactivityChanged",
        "band0SidechainPreampChanged",
        "band1SidechainPreampChanged",
        "band2SidechainPreampChanged",
        "band3SidechainPreampChanged",
        "band4SidechainPreampChanged",
        "band5SidechainPreampChanged",
        "band6SidechainPreampChanged",
        "band7SidechainPreampChanged",
        "band0SidechainCustomLowcutFilterChanged",
        "band1SidechainCustomLowcutFilterChanged",
        "band2SidechainCustomLowcutFilterChanged",
        "band3SidechainCustomLowcutFilterChanged",
        "band4SidechainCustomLowcutFilterChanged",
        "band5SidechainCustomLowcutFilterChanged",
        "band6SidechainCustomLowcutFilterChanged",
        "band7SidechainCustomLowcutFilterChanged",
        "band0SidechainCustomHighcutFilterChanged",
        "band1SidechainCustomHighcutFilterChanged",
        "band2SidechainCustomHighcutFilterChanged",
        "band3SidechainCustomHighcutFilterChanged",
        "band4SidechainCustomHighcutFilterChanged",
        "band5SidechainCustomHighcutFilterChanged",
        "band6SidechainCustomHighcutFilterChanged",
        "band7SidechainCustomHighcutFilterChanged",
        "band0SidechainLowcutFrequencyChanged",
        "band1SidechainLowcutFrequencyChanged",
        "band2SidechainLowcutFrequencyChanged",
        "band3SidechainLowcutFrequencyChanged",
        "band4SidechainLowcutFrequencyChanged",
        "band5SidechainLowcutFrequencyChanged",
        "band6SidechainLowcutFrequencyChanged",
        "band7SidechainLowcutFrequencyChanged",
        "band0SidechainHighcutFrequencyChanged",
        "band1SidechainHighcutFrequencyChanged",
        "band2SidechainHighcutFrequencyChanged",
        "band3SidechainHighcutFrequencyChanged",
        "band4SidechainHighcutFrequencyChanged",
        "band5SidechainHighcutFrequencyChanged",
        "band6SidechainHighcutFrequencyChanged",
        "band7SidechainHighcutFrequencyChanged",
        "compressionModeLabelsChanged",
        "band0CompressionModeChanged",
        "band1CompressionModeChanged",
        "band2CompressionModeChanged",
        "band3CompressionModeChanged",
        "band4CompressionModeChanged",
        "band5CompressionModeChanged",
        "band6CompressionModeChanged",
        "band7CompressionModeChanged",
        "band0CompressorEnableChanged",
        "band1CompressorEnableChanged",
        "band2CompressorEnableChanged",
        "band3CompressorEnableChanged",
        "band4CompressorEnableChanged",
        "band5CompressorEnableChanged",
        "band6CompressorEnableChanged",
        "band7CompressorEnableChanged",
        "band0SoloChanged",
        "band1SoloChanged",
        "band2SoloChanged",
        "band3SoloChanged",
        "band4SoloChanged",
        "band5SoloChanged",
        "band6SoloChanged",
        "band7SoloChanged",
        "band0MuteChanged",
        "band1MuteChanged",
        "band2MuteChanged",
        "band3MuteChanged",
        "band4MuteChanged",
        "band5MuteChanged",
        "band6MuteChanged",
        "band7MuteChanged",
        "band0AttackThresholdChanged",
        "band1AttackThresholdChanged",
        "band2AttackThresholdChanged",
        "band3AttackThresholdChanged",
        "band4AttackThresholdChanged",
        "band5AttackThresholdChanged",
        "band6AttackThresholdChanged",
        "band7AttackThresholdChanged",
        "band0AttackTimeChanged",
        "band1AttackTimeChanged",
        "band2AttackTimeChanged",
        "band3AttackTimeChanged",
        "band4AttackTimeChanged",
        "band5AttackTimeChanged",
        "band6AttackTimeChanged",
        "band7AttackTimeChanged",
        "band0ReleaseThresholdChanged",
        "band1ReleaseThresholdChanged",
        "band2ReleaseThresholdChanged",
        "band3ReleaseThresholdChanged",
        "band4ReleaseThresholdChanged",
        "band5ReleaseThresholdChanged",
        "band6ReleaseThresholdChanged",
        "band7ReleaseThresholdChanged",
        "band0ReleaseTimeChanged",
        "band1ReleaseTimeChanged",
        "band2ReleaseTimeChanged",
        "band3ReleaseTimeChanged",
        "band4ReleaseTimeChanged",
        "band5ReleaseTimeChanged",
        "band6ReleaseTimeChanged",
        "band7ReleaseTimeChanged",
        "band0RatioChanged",
        "band1RatioChanged",
        "band2RatioChanged",
        "band3RatioChanged",
        "band4RatioChanged",
        "band5RatioChanged",
        "band6RatioChanged",
        "band7RatioChanged",
        "band0KneeChanged",
        "band1KneeChanged",
        "band2KneeChanged",
        "band3KneeChanged",
        "band4KneeChanged",
        "band5KneeChanged",
        "band6KneeChanged",
        "band7KneeChanged",
        "band0BoostThresholdChanged",
        "band1BoostThresholdChanged",
        "band2BoostThresholdChanged",
        "band3BoostThresholdChanged",
        "band4BoostThresholdChanged",
        "band5BoostThresholdChanged",
        "band6BoostThresholdChanged",
        "band7BoostThresholdChanged",
        "band0BoostAmountChanged",
        "band1BoostAmountChanged",
        "band2BoostAmountChanged",
        "band3BoostAmountChanged",
        "band4BoostAmountChanged",
        "band5BoostAmountChanged",
        "band6BoostAmountChanged",
        "band7BoostAmountChanged",
        "band0MakeupChanged",
        "band1MakeupChanged",
        "band2MakeupChanged",
        "band3MakeupChanged",
        "band4MakeupChanged",
        "band5MakeupChanged",
        "band6MakeupChanged",
        "band7MakeupChanged",
        "bypass",
        "isBypassImmutable",
        "defaultBypassValue",
        "inputGain",
        "isInputGainImmutable",
        "defaultInputGainValue",
        "outputGain",
        "isOutputGainImmutable",
        "defaultOutputGainValue",
        "dry",
        "isDryImmutable",
        "defaultDryValue",
        "wet",
        "isWetImmutable",
        "defaultWetValue",
        "viewSidechain",
        "isViewSidechainImmutable",
        "defaultViewSidechainValue",
        "externalSidechainEnabled",
        "isExternalSidechainEnabledImmutable",
        "defaultExternalSidechainEnabledValue",
        "stereoSplit",
        "isStereoSplitImmutable",
        "defaultStereoSplitValue",
        "compressorModeLabels",
        "isCompressorModeLabelsImmutable",
        "defaultCompressorModeLabelsValue",
        "compressorMode",
        "isCompressorModeImmutable",
        "defaultCompressorModeValue",
        "envelopeBoostLabels",
        "isEnvelopeBoostLabelsImmutable",
        "defaultEnvelopeBoostLabelsValue",
        "envelopeBoost",
        "isEnvelopeBoostImmutable",
        "defaultEnvelopeBoostValue",
        "inputToSidechain",
        "isInputToSidechainImmutable",
        "defaultInputToSidechainValue",
        "inputToLink",
        "isInputToLinkImmutable",
        "defaultInputToLinkValue",
        "sidechainToInput",
        "isSidechainToInputImmutable",
        "defaultSidechainToInputValue",
        "sidechainToLink",
        "isSidechainToLinkImmutable",
        "defaultSidechainToLinkValue",
        "linkToSidechain",
        "isLinkToSidechainImmutable",
        "defaultLinkToSidechainValue",
        "linkToInput",
        "isLinkToInputImmutable",
        "defaultLinkToInputValue",
        "band1Enable",
        "isBand1EnableImmutable",
        "defaultBand1EnableValue",
        "band2Enable",
        "isBand2EnableImmutable",
        "defaultBand2EnableValue",
        "band3Enable",
        "isBand3EnableImmutable",
        "defaultBand3EnableValue",
        "band4Enable",
        "isBand4EnableImmutable",
        "defaultBand4EnableValue",
        "band5Enable",
        "isBand5EnableImmutable",
        "defaultBand5EnableValue",
        "band6Enable",
        "isBand6EnableImmutable",
        "defaultBand6EnableValue",
        "band7Enable",
        "isBand7EnableImmutable",
        "defaultBand7EnableValue",
        "band1SplitFrequency",
        "isBand1SplitFrequencyImmutable",
        "defaultBand1SplitFrequencyValue",
        "band2SplitFrequency",
        "isBand2SplitFrequencyImmutable",
        "defaultBand2SplitFrequencyValue",
        "band3SplitFrequency",
        "isBand3SplitFrequencyImmutable",
        "defaultBand3SplitFrequencyValue",
        "band4SplitFrequency",
        "isBand4SplitFrequencyImmutable",
        "defaultBand4SplitFrequencyValue",
        "band5SplitFrequency",
        "isBand5SplitFrequencyImmutable",
        "defaultBand5SplitFrequencyValue",
        "band6SplitFrequency",
        "isBand6SplitFrequencyImmutable",
        "defaultBand6SplitFrequencyValue",
        "band7SplitFrequency",
        "isBand7SplitFrequencyImmutable",
        "defaultBand7SplitFrequencyValue",
        "sidechainInputDevice",
        "isSidechainInputDeviceImmutable",
        "defaultSidechainInputDeviceValue",
        "sidechainTypeLabels",
        "isSidechainTypeLabelsImmutable",
        "defaultSidechainTypeLabelsValue",
        "band0SidechainType",
        "isBand0SidechainTypeImmutable",
        "defaultBand0SidechainTypeValue",
        "band1SidechainType",
        "isBand1SidechainTypeImmutable",
        "defaultBand1SidechainTypeValue",
        "band2SidechainType",
        "isBand2SidechainTypeImmutable",
        "defaultBand2SidechainTypeValue",
        "band3SidechainType",
        "isBand3SidechainTypeImmutable",
        "defaultBand3SidechainTypeValue",
        "band4SidechainType",
        "isBand4SidechainTypeImmutable",
        "defaultBand4SidechainTypeValue",
        "band5SidechainType",
        "isBand5SidechainTypeImmutable",
        "defaultBand5SidechainTypeValue",
        "band6SidechainType",
        "isBand6SidechainTypeImmutable",
        "defaultBand6SidechainTypeValue",
        "band7SidechainType",
        "isBand7SidechainTypeImmutable",
        "defaultBand7SidechainTypeValue",
        "sidechainModeLabels",
        "isSidechainModeLabelsImmutable",
        "defaultSidechainModeLabelsValue",
        "band0SidechainMode",
        "isBand0SidechainModeImmutable",
        "defaultBand0SidechainModeValue",
        "band1SidechainMode",
        "isBand1SidechainModeImmutable",
        "defaultBand1SidechainModeValue",
        "band2SidechainMode",
        "isBand2SidechainModeImmutable",
        "defaultBand2SidechainModeValue",
        "band3SidechainMode",
        "isBand3SidechainModeImmutable",
        "defaultBand3SidechainModeValue",
        "band4SidechainMode",
        "isBand4SidechainModeImmutable",
        "defaultBand4SidechainModeValue",
        "band5SidechainMode",
        "isBand5SidechainModeImmutable",
        "defaultBand5SidechainModeValue",
        "band6SidechainMode",
        "isBand6SidechainModeImmutable",
        "defaultBand6SidechainModeValue",
        "band7SidechainMode",
        "isBand7SidechainModeImmutable",
        "defaultBand7SidechainModeValue",
        "sidechainSourceLabels",
        "isSidechainSourceLabelsImmutable",
        "defaultSidechainSourceLabelsValue",
        "band0SidechainSource",
        "isBand0SidechainSourceImmutable",
        "defaultBand0SidechainSourceValue",
        "band1SidechainSource",
        "isBand1SidechainSourceImmutable",
        "defaultBand1SidechainSourceValue",
        "band2SidechainSource",
        "isBand2SidechainSourceImmutable",
        "defaultBand2SidechainSourceValue",
        "band3SidechainSource",
        "isBand3SidechainSourceImmutable",
        "defaultBand3SidechainSourceValue",
        "band4SidechainSource",
        "isBand4SidechainSourceImmutable",
        "defaultBand4SidechainSourceValue",
        "band5SidechainSource",
        "isBand5SidechainSourceImmutable",
        "defaultBand5SidechainSourceValue",
        "band6SidechainSource",
        "isBand6SidechainSourceImmutable",
        "defaultBand6SidechainSourceValue",
        "band7SidechainSource",
        "isBand7SidechainSourceImmutable",
        "defaultBand7SidechainSourceValue",
        "stereoSplitSourceLabels",
        "isStereoSplitSourceLabelsImmutable",
        "defaultStereoSplitSourceLabelsValue",
        "band0StereoSplitSource",
        "isBand0StereoSplitSourceImmutable",
        "defaultBand0StereoSplitSourceValue",
        "band1StereoSplitSource",
        "isBand1StereoSplitSourceImmutable",
        "defaultBand1StereoSplitSourceValue",
        "band2StereoSplitSource",
        "isBand2StereoSplitSourceImmutable",
        "defaultBand2StereoSplitSourceValue",
        "band3StereoSplitSource",
        "isBand3StereoSplitSourceImmutable",
        "defaultBand3StereoSplitSourceValue",
        "band4StereoSplitSource",
        "isBand4StereoSplitSourceImmutable",
        "defaultBand4StereoSplitSourceValue",
        "band5StereoSplitSource",
        "isBand5StereoSplitSourceImmutable",
        "defaultBand5StereoSplitSourceValue",
        "band6StereoSplitSource",
        "isBand6StereoSplitSourceImmutable",
        "defaultBand6StereoSplitSourceValue",
        "band7StereoSplitSource",
        "isBand7StereoSplitSourceImmutable",
        "defaultBand7StereoSplitSourceValue",
        "band0SidechainLookahead",
        "isBand0SidechainLookaheadImmutable",
        "defaultBand0SidechainLookaheadValue",
        "band1SidechainLookahead",
        "isBand1SidechainLookaheadImmutable",
        "defaultBand1SidechainLookaheadValue",
        "band2SidechainLookahead",
        "isBand2SidechainLookaheadImmutable",
        "defaultBand2SidechainLookaheadValue",
        "band3SidechainLookahead",
        "isBand3SidechainLookaheadImmutable",
        "defaultBand3SidechainLookaheadValue",
        "band4SidechainLookahead",
        "isBand4SidechainLookaheadImmutable",
        "defaultBand4SidechainLookaheadValue",
        "band5SidechainLookahead",
        "isBand5SidechainLookaheadImmutable",
        "defaultBand5SidechainLookaheadValue",
        "band6SidechainLookahead",
        "isBand6SidechainLookaheadImmutable",
        "defaultBand6SidechainLookaheadValue",
        "band7SidechainLookahead",
        "isBand7SidechainLookaheadImmutable",
        "defaultBand7SidechainLookaheadValue",
        "band0SidechainReactivity",
        "isBand0SidechainReactivityImmutable",
        "defaultBand0SidechainReactivityValue",
        "band1SidechainReactivity",
        "isBand1SidechainReactivityImmutable",
        "defaultBand1SidechainReactivityValue",
        "band2SidechainReactivity",
        "isBand2SidechainReactivityImmutable",
        "defaultBand2SidechainReactivityValue",
        "band3SidechainReactivity",
        "isBand3SidechainReactivityImmutable",
        "defaultBand3SidechainReactivityValue",
        "band4SidechainReactivity",
        "isBand4SidechainReactivityImmutable",
        "defaultBand4SidechainReactivityValue",
        "band5SidechainReactivity",
        "isBand5SidechainReactivityImmutable",
        "defaultBand5SidechainReactivityValue",
        "band6SidechainReactivity",
        "isBand6SidechainReactivityImmutable",
        "defaultBand6SidechainReactivityValue",
        "band7SidechainReactivity",
        "isBand7SidechainReactivityImmutable",
        "defaultBand7SidechainReactivityValue",
        "band0SidechainPreamp",
        "isBand0SidechainPreampImmutable",
        "defaultBand0SidechainPreampValue",
        "band1SidechainPreamp",
        "isBand1SidechainPreampImmutable",
        "defaultBand1SidechainPreampValue",
        "band2SidechainPreamp",
        "isBand2SidechainPreampImmutable",
        "defaultBand2SidechainPreampValue",
        "band3SidechainPreamp",
        "isBand3SidechainPreampImmutable",
        "defaultBand3SidechainPreampValue",
        "band4SidechainPreamp",
        "isBand4SidechainPreampImmutable",
        "defaultBand4SidechainPreampValue",
        "band5SidechainPreamp",
        "isBand5SidechainPreampImmutable",
        "defaultBand5SidechainPreampValue",
        "band6SidechainPreamp",
        "isBand6SidechainPreampImmutable",
        "defaultBand6SidechainPreampValue",
        "band7SidechainPreamp",
        "isBand7SidechainPreampImmutable",
        "defaultBand7SidechainPreampValue",
        "band0SidechainCustomLowcutFilter",
        "isBand0SidechainCustomLowcutFilterImmutable",
        "defaultBand0SidechainCustomLowcutFilterValue",
        "band1SidechainCustomLowcutFilter",
        "isBand1SidechainCustomLowcutFilterImmutable",
        "defaultBand1SidechainCustomLowcutFilterValue",
        "band2SidechainCustomLowcutFilter",
        "isBand2SidechainCustomLowcutFilterImmutable",
        "defaultBand2SidechainCustomLowcutFilterValue",
        "band3SidechainCustomLowcutFilter",
        "isBand3SidechainCustomLowcutFilterImmutable",
        "defaultBand3SidechainCustomLowcutFilterValue",
        "band4SidechainCustomLowcutFilter",
        "isBand4SidechainCustomLowcutFilterImmutable",
        "defaultBand4SidechainCustomLowcutFilterValue",
        "band5SidechainCustomLowcutFilter",
        "isBand5SidechainCustomLowcutFilterImmutable",
        "defaultBand5SidechainCustomLowcutFilterValue",
        "band6SidechainCustomLowcutFilter",
        "isBand6SidechainCustomLowcutFilterImmutable",
        "defaultBand6SidechainCustomLowcutFilterValue",
        "band7SidechainCustomLowcutFilter",
        "isBand7SidechainCustomLowcutFilterImmutable",
        "defaultBand7SidechainCustomLowcutFilterValue",
        "band0SidechainCustomHighcutFilter",
        "isBand0SidechainCustomHighcutFilterImmutable",
        "defaultBand0SidechainCustomHighcutFilterValue",
        "band1SidechainCustomHighcutFilter",
        "isBand1SidechainCustomHighcutFilterImmutable",
        "defaultBand1SidechainCustomHighcutFilterValue",
        "band2SidechainCustomHighcutFilter",
        "isBand2SidechainCustomHighcutFilterImmutable",
        "defaultBand2SidechainCustomHighcutFilterValue",
        "band3SidechainCustomHighcutFilter",
        "isBand3SidechainCustomHighcutFilterImmutable",
        "defaultBand3SidechainCustomHighcutFilterValue",
        "band4SidechainCustomHighcutFilter",
        "isBand4SidechainCustomHighcutFilterImmutable",
        "defaultBand4SidechainCustomHighcutFilterValue",
        "band5SidechainCustomHighcutFilter",
        "isBand5SidechainCustomHighcutFilterImmutable",
        "defaultBand5SidechainCustomHighcutFilterValue",
        "band6SidechainCustomHighcutFilter",
        "isBand6SidechainCustomHighcutFilterImmutable",
        "defaultBand6SidechainCustomHighcutFilterValue",
        "band7SidechainCustomHighcutFilter",
        "isBand7SidechainCustomHighcutFilterImmutable",
        "defaultBand7SidechainCustomHighcutFilterValue",
        "band0SidechainLowcutFrequency",
        "isBand0SidechainLowcutFrequencyImmutable",
        "defaultBand0SidechainLowcutFrequencyValue",
        "band1SidechainLowcutFrequency",
        "isBand1SidechainLowcutFrequencyImmutable",
        "defaultBand1SidechainLowcutFrequencyValue",
        "band2SidechainLowcutFrequency",
        "isBand2SidechainLowcutFrequencyImmutable",
        "defaultBand2SidechainLowcutFrequencyValue",
        "band3SidechainLowcutFrequency",
        "isBand3SidechainLowcutFrequencyImmutable",
        "defaultBand3SidechainLowcutFrequencyValue",
        "band4SidechainLowcutFrequency",
        "isBand4SidechainLowcutFrequencyImmutable",
        "defaultBand4SidechainLowcutFrequencyValue",
        "band5SidechainLowcutFrequency",
        "isBand5SidechainLowcutFrequencyImmutable",
        "defaultBand5SidechainLowcutFrequencyValue",
        "band6SidechainLowcutFrequency",
        "isBand6SidechainLowcutFrequencyImmutable",
        "defaultBand6SidechainLowcutFrequencyValue",
        "band7SidechainLowcutFrequency",
        "isBand7SidechainLowcutFrequencyImmutable",
        "defaultBand7SidechainLowcutFrequencyValue",
        "band0SidechainHighcutFrequency",
        "isBand0SidechainHighcutFrequencyImmutable",
        "defaultBand0SidechainHighcutFrequencyValue",
        "band1SidechainHighcutFrequency",
        "isBand1SidechainHighcutFrequencyImmutable",
        "defaultBand1SidechainHighcutFrequencyValue",
        "band2SidechainHighcutFrequency",
        "isBand2SidechainHighcutFrequencyImmutable",
        "defaultBand2SidechainHighcutFrequencyValue",
        "band3SidechainHighcutFrequency",
        "isBand3SidechainHighcutFrequencyImmutable",
        "defaultBand3SidechainHighcutFrequencyValue",
        "band4SidechainHighcutFrequency",
        "isBand4SidechainHighcutFrequencyImmutable",
        "defaultBand4SidechainHighcutFrequencyValue",
        "band5SidechainHighcutFrequency",
        "isBand5SidechainHighcutFrequencyImmutable",
        "defaultBand5SidechainHighcutFrequencyValue",
        "band6SidechainHighcutFrequency",
        "isBand6SidechainHighcutFrequencyImmutable",
        "defaultBand6SidechainHighcutFrequencyValue",
        "band7SidechainHighcutFrequency",
        "isBand7SidechainHighcutFrequencyImmutable",
        "defaultBand7SidechainHighcutFrequencyValue",
        "compressionModeLabels",
        "isCompressionModeLabelsImmutable",
        "defaultCompressionModeLabelsValue",
        "band0CompressionMode",
        "isBand0CompressionModeImmutable",
        "defaultBand0CompressionModeValue",
        "band1CompressionMode",
        "isBand1CompressionModeImmutable",
        "defaultBand1CompressionModeValue",
        "band2CompressionMode",
        "isBand2CompressionModeImmutable",
        "defaultBand2CompressionModeValue",
        "band3CompressionMode",
        "isBand3CompressionModeImmutable",
        "defaultBand3CompressionModeValue",
        "band4CompressionMode",
        "isBand4CompressionModeImmutable",
        "defaultBand4CompressionModeValue",
        "band5CompressionMode",
        "isBand5CompressionModeImmutable",
        "defaultBand5CompressionModeValue",
        "band6CompressionMode",
        "isBand6CompressionModeImmutable",
        "defaultBand6CompressionModeValue",
        "band7CompressionMode",
        "isBand7CompressionModeImmutable",
        "defaultBand7CompressionModeValue",
        "band0CompressorEnable",
        "isBand0CompressorEnableImmutable",
        "defaultBand0CompressorEnableValue",
        "band1CompressorEnable",
        "isBand1CompressorEnableImmutable",
        "defaultBand1CompressorEnableValue",
        "band2CompressorEnable",
        "isBand2CompressorEnableImmutable",
        "defaultBand2CompressorEnableValue",
        "band3CompressorEnable",
        "isBand3CompressorEnableImmutable",
        "defaultBand3CompressorEnableValue",
        "band4CompressorEnable",
        "isBand4CompressorEnableImmutable",
        "defaultBand4CompressorEnableValue",
        "band5CompressorEnable",
        "isBand5CompressorEnableImmutable",
        "defaultBand5CompressorEnableValue",
        "band6CompressorEnable",
        "isBand6CompressorEnableImmutable",
        "defaultBand6CompressorEnableValue",
        "band7CompressorEnable",
        "isBand7CompressorEnableImmutable",
        "defaultBand7CompressorEnableValue",
        "band0Solo",
        "isBand0SoloImmutable",
        "defaultBand0SoloValue",
        "band1Solo",
        "isBand1SoloImmutable",
        "defaultBand1SoloValue",
        "band2Solo",
        "isBand2SoloImmutable",
        "defaultBand2SoloValue",
        "band3Solo",
        "isBand3SoloImmutable",
        "defaultBand3SoloValue",
        "band4Solo",
        "isBand4SoloImmutable",
        "defaultBand4SoloValue",
        "band5Solo",
        "isBand5SoloImmutable",
        "defaultBand5SoloValue",
        "band6Solo",
        "isBand6SoloImmutable",
        "defaultBand6SoloValue",
        "band7Solo",
        "isBand7SoloImmutable",
        "defaultBand7SoloValue",
        "band0Mute",
        "isBand0MuteImmutable",
        "defaultBand0MuteValue",
        "band1Mute",
        "isBand1MuteImmutable",
        "defaultBand1MuteValue",
        "band2Mute",
        "isBand2MuteImmutable",
        "defaultBand2MuteValue",
        "band3Mute",
        "isBand3MuteImmutable",
        "defaultBand3MuteValue",
        "band4Mute",
        "isBand4MuteImmutable",
        "defaultBand4MuteValue",
        "band5Mute",
        "isBand5MuteImmutable",
        "defaultBand5MuteValue",
        "band6Mute",
        "isBand6MuteImmutable",
        "defaultBand6MuteValue",
        "band7Mute",
        "isBand7MuteImmutable",
        "defaultBand7MuteValue",
        "band0AttackThreshold",
        "isBand0AttackThresholdImmutable",
        "defaultBand0AttackThresholdValue",
        "band1AttackThreshold",
        "isBand1AttackThresholdImmutable",
        "defaultBand1AttackThresholdValue",
        "band2AttackThreshold",
        "isBand2AttackThresholdImmutable",
        "defaultBand2AttackThresholdValue",
        "band3AttackThreshold",
        "isBand3AttackThresholdImmutable",
        "defaultBand3AttackThresholdValue",
        "band4AttackThreshold",
        "isBand4AttackThresholdImmutable",
        "defaultBand4AttackThresholdValue",
        "band5AttackThreshold",
        "isBand5AttackThresholdImmutable",
        "defaultBand5AttackThresholdValue",
        "band6AttackThreshold",
        "isBand6AttackThresholdImmutable",
        "defaultBand6AttackThresholdValue",
        "band7AttackThreshold",
        "isBand7AttackThresholdImmutable",
        "defaultBand7AttackThresholdValue",
        "band0AttackTime",
        "isBand0AttackTimeImmutable",
        "defaultBand0AttackTimeValue",
        "band1AttackTime",
        "isBand1AttackTimeImmutable",
        "defaultBand1AttackTimeValue",
        "band2AttackTime",
        "isBand2AttackTimeImmutable",
        "defaultBand2AttackTimeValue",
        "band3AttackTime",
        "isBand3AttackTimeImmutable",
        "defaultBand3AttackTimeValue",
        "band4AttackTime",
        "isBand4AttackTimeImmutable",
        "defaultBand4AttackTimeValue",
        "band5AttackTime",
        "isBand5AttackTimeImmutable",
        "defaultBand5AttackTimeValue",
        "band6AttackTime",
        "isBand6AttackTimeImmutable",
        "defaultBand6AttackTimeValue",
        "band7AttackTime",
        "isBand7AttackTimeImmutable",
        "defaultBand7AttackTimeValue",
        "band0ReleaseThreshold",
        "isBand0ReleaseThresholdImmutable",
        "defaultBand0ReleaseThresholdValue",
        "band1ReleaseThreshold",
        "isBand1ReleaseThresholdImmutable",
        "defaultBand1ReleaseThresholdValue",
        "band2ReleaseThreshold",
        "isBand2ReleaseThresholdImmutable",
        "defaultBand2ReleaseThresholdValue",
        "band3ReleaseThreshold",
        "isBand3ReleaseThresholdImmutable",
        "defaultBand3ReleaseThresholdValue",
        "band4ReleaseThreshold",
        "isBand4ReleaseThresholdImmutable",
        "defaultBand4ReleaseThresholdValue",
        "band5ReleaseThreshold",
        "isBand5ReleaseThresholdImmutable",
        "defaultBand5ReleaseThresholdValue",
        "band6ReleaseThreshold",
        "isBand6ReleaseThresholdImmutable",
        "defaultBand6ReleaseThresholdValue",
        "band7ReleaseThreshold",
        "isBand7ReleaseThresholdImmutable",
        "defaultBand7ReleaseThresholdValue",
        "band0ReleaseTime",
        "isBand0ReleaseTimeImmutable",
        "defaultBand0ReleaseTimeValue",
        "band1ReleaseTime",
        "isBand1ReleaseTimeImmutable",
        "defaultBand1ReleaseTimeValue",
        "band2ReleaseTime",
        "isBand2ReleaseTimeImmutable",
        "defaultBand2ReleaseTimeValue",
        "band3ReleaseTime",
        "isBand3ReleaseTimeImmutable",
        "defaultBand3ReleaseTimeValue",
        "band4ReleaseTime",
        "isBand4ReleaseTimeImmutable",
        "defaultBand4ReleaseTimeValue",
        "band5ReleaseTime",
        "isBand5ReleaseTimeImmutable",
        "defaultBand5ReleaseTimeValue",
        "band6ReleaseTime",
        "isBand6ReleaseTimeImmutable",
        "defaultBand6ReleaseTimeValue",
        "band7ReleaseTime",
        "isBand7ReleaseTimeImmutable",
        "defaultBand7ReleaseTimeValue",
        "band0Ratio",
        "isBand0RatioImmutable",
        "defaultBand0RatioValue",
        "band1Ratio",
        "isBand1RatioImmutable",
        "defaultBand1RatioValue",
        "band2Ratio",
        "isBand2RatioImmutable",
        "defaultBand2RatioValue",
        "band3Ratio",
        "isBand3RatioImmutable",
        "defaultBand3RatioValue",
        "band4Ratio",
        "isBand4RatioImmutable",
        "defaultBand4RatioValue",
        "band5Ratio",
        "isBand5RatioImmutable",
        "defaultBand5RatioValue",
        "band6Ratio",
        "isBand6RatioImmutable",
        "defaultBand6RatioValue",
        "band7Ratio",
        "isBand7RatioImmutable",
        "defaultBand7RatioValue",
        "band0Knee",
        "isBand0KneeImmutable",
        "defaultBand0KneeValue",
        "band1Knee",
        "isBand1KneeImmutable",
        "defaultBand1KneeValue",
        "band2Knee",
        "isBand2KneeImmutable",
        "defaultBand2KneeValue",
        "band3Knee",
        "isBand3KneeImmutable",
        "defaultBand3KneeValue",
        "band4Knee",
        "isBand4KneeImmutable",
        "defaultBand4KneeValue",
        "band5Knee",
        "isBand5KneeImmutable",
        "defaultBand5KneeValue",
        "band6Knee",
        "isBand6KneeImmutable",
        "defaultBand6KneeValue",
        "band7Knee",
        "isBand7KneeImmutable",
        "defaultBand7KneeValue",
        "band0BoostThreshold",
        "isBand0BoostThresholdImmutable",
        "defaultBand0BoostThresholdValue",
        "band1BoostThreshold",
        "isBand1BoostThresholdImmutable",
        "defaultBand1BoostThresholdValue",
        "band2BoostThreshold",
        "isBand2BoostThresholdImmutable",
        "defaultBand2BoostThresholdValue",
        "band3BoostThreshold",
        "isBand3BoostThresholdImmutable",
        "defaultBand3BoostThresholdValue",
        "band4BoostThreshold",
        "isBand4BoostThresholdImmutable",
        "defaultBand4BoostThresholdValue",
        "band5BoostThreshold",
        "isBand5BoostThresholdImmutable",
        "defaultBand5BoostThresholdValue",
        "band6BoostThreshold",
        "isBand6BoostThresholdImmutable",
        "defaultBand6BoostThresholdValue",
        "band7BoostThreshold",
        "isBand7BoostThresholdImmutable",
        "defaultBand7BoostThresholdValue",
        "band0BoostAmount",
        "isBand0BoostAmountImmutable",
        "defaultBand0BoostAmountValue",
        "band1BoostAmount",
        "isBand1BoostAmountImmutable",
        "defaultBand1BoostAmountValue",
        "band2BoostAmount",
        "isBand2BoostAmountImmutable",
        "defaultBand2BoostAmountValue",
        "band3BoostAmount",
        "isBand3BoostAmountImmutable",
        "defaultBand3BoostAmountValue",
        "band4BoostAmount",
        "isBand4BoostAmountImmutable",
        "defaultBand4BoostAmountValue",
        "band5BoostAmount",
        "isBand5BoostAmountImmutable",
        "defaultBand5BoostAmountValue",
        "band6BoostAmount",
        "isBand6BoostAmountImmutable",
        "defaultBand6BoostAmountValue",
        "band7BoostAmount",
        "isBand7BoostAmountImmutable",
        "defaultBand7BoostAmountValue",
        "band0Makeup",
        "isBand0MakeupImmutable",
        "defaultBand0MakeupValue",
        "band1Makeup",
        "isBand1MakeupImmutable",
        "defaultBand1MakeupValue",
        "band2Makeup",
        "isBand2MakeupImmutable",
        "defaultBand2MakeupValue",
        "band3Makeup",
        "isBand3MakeupImmutable",
        "defaultBand3MakeupValue",
        "band4Makeup",
        "isBand4MakeupImmutable",
        "defaultBand4MakeupValue",
        "band5Makeup",
        "isBand5MakeupImmutable",
        "defaultBand5MakeupValue",
        "band6Makeup",
        "isBand6MakeupImmutable",
        "defaultBand6MakeupValue",
        "band7Makeup",
        "isBand7MakeupImmutable",
        "defaultBand7MakeupValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bypassChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputGainChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputGainChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dryChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wetChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'viewSidechainChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'externalSidechainEnabledChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stereoSplitChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'compressorModeLabelsChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'compressorModeChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'envelopeBoostLabelsChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'envelopeBoostChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputToSidechainChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputToLinkChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainToInputChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainToLinkChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'linkToSidechainChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'linkToInputChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1EnableChanged'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2EnableChanged'
        QtMocHelpers::SignalData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3EnableChanged'
        QtMocHelpers::SignalData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4EnableChanged'
        QtMocHelpers::SignalData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5EnableChanged'
        QtMocHelpers::SignalData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6EnableChanged'
        QtMocHelpers::SignalData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7EnableChanged'
        QtMocHelpers::SignalData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1SplitFrequencyChanged'
        QtMocHelpers::SignalData<void()>(32, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2SplitFrequencyChanged'
        QtMocHelpers::SignalData<void()>(33, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3SplitFrequencyChanged'
        QtMocHelpers::SignalData<void()>(34, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4SplitFrequencyChanged'
        QtMocHelpers::SignalData<void()>(35, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5SplitFrequencyChanged'
        QtMocHelpers::SignalData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6SplitFrequencyChanged'
        QtMocHelpers::SignalData<void()>(37, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7SplitFrequencyChanged'
        QtMocHelpers::SignalData<void()>(38, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainInputDeviceChanged'
        QtMocHelpers::SignalData<void()>(39, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainTypeLabelsChanged'
        QtMocHelpers::SignalData<void()>(40, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0SidechainTypeChanged'
        QtMocHelpers::SignalData<void()>(41, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1SidechainTypeChanged'
        QtMocHelpers::SignalData<void()>(42, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2SidechainTypeChanged'
        QtMocHelpers::SignalData<void()>(43, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3SidechainTypeChanged'
        QtMocHelpers::SignalData<void()>(44, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4SidechainTypeChanged'
        QtMocHelpers::SignalData<void()>(45, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5SidechainTypeChanged'
        QtMocHelpers::SignalData<void()>(46, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6SidechainTypeChanged'
        QtMocHelpers::SignalData<void()>(47, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7SidechainTypeChanged'
        QtMocHelpers::SignalData<void()>(48, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainModeLabelsChanged'
        QtMocHelpers::SignalData<void()>(49, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0SidechainModeChanged'
        QtMocHelpers::SignalData<void()>(50, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1SidechainModeChanged'
        QtMocHelpers::SignalData<void()>(51, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2SidechainModeChanged'
        QtMocHelpers::SignalData<void()>(52, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3SidechainModeChanged'
        QtMocHelpers::SignalData<void()>(53, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4SidechainModeChanged'
        QtMocHelpers::SignalData<void()>(54, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5SidechainModeChanged'
        QtMocHelpers::SignalData<void()>(55, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6SidechainModeChanged'
        QtMocHelpers::SignalData<void()>(56, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7SidechainModeChanged'
        QtMocHelpers::SignalData<void()>(57, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sidechainSourceLabelsChanged'
        QtMocHelpers::SignalData<void()>(58, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0SidechainSourceChanged'
        QtMocHelpers::SignalData<void()>(59, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1SidechainSourceChanged'
        QtMocHelpers::SignalData<void()>(60, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2SidechainSourceChanged'
        QtMocHelpers::SignalData<void()>(61, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3SidechainSourceChanged'
        QtMocHelpers::SignalData<void()>(62, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4SidechainSourceChanged'
        QtMocHelpers::SignalData<void()>(63, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5SidechainSourceChanged'
        QtMocHelpers::SignalData<void()>(64, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6SidechainSourceChanged'
        QtMocHelpers::SignalData<void()>(65, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7SidechainSourceChanged'
        QtMocHelpers::SignalData<void()>(66, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stereoSplitSourceLabelsChanged'
        QtMocHelpers::SignalData<void()>(67, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0StereoSplitSourceChanged'
        QtMocHelpers::SignalData<void()>(68, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1StereoSplitSourceChanged'
        QtMocHelpers::SignalData<void()>(69, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2StereoSplitSourceChanged'
        QtMocHelpers::SignalData<void()>(70, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3StereoSplitSourceChanged'
        QtMocHelpers::SignalData<void()>(71, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4StereoSplitSourceChanged'
        QtMocHelpers::SignalData<void()>(72, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5StereoSplitSourceChanged'
        QtMocHelpers::SignalData<void()>(73, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6StereoSplitSourceChanged'
        QtMocHelpers::SignalData<void()>(74, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7StereoSplitSourceChanged'
        QtMocHelpers::SignalData<void()>(75, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0SidechainLookaheadChanged'
        QtMocHelpers::SignalData<void()>(76, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1SidechainLookaheadChanged'
        QtMocHelpers::SignalData<void()>(77, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2SidechainLookaheadChanged'
        QtMocHelpers::SignalData<void()>(78, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3SidechainLookaheadChanged'
        QtMocHelpers::SignalData<void()>(79, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4SidechainLookaheadChanged'
        QtMocHelpers::SignalData<void()>(80, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5SidechainLookaheadChanged'
        QtMocHelpers::SignalData<void()>(81, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6SidechainLookaheadChanged'
        QtMocHelpers::SignalData<void()>(82, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7SidechainLookaheadChanged'
        QtMocHelpers::SignalData<void()>(83, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0SidechainReactivityChanged'
        QtMocHelpers::SignalData<void()>(84, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1SidechainReactivityChanged'
        QtMocHelpers::SignalData<void()>(85, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2SidechainReactivityChanged'
        QtMocHelpers::SignalData<void()>(86, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3SidechainReactivityChanged'
        QtMocHelpers::SignalData<void()>(87, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4SidechainReactivityChanged'
        QtMocHelpers::SignalData<void()>(88, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5SidechainReactivityChanged'
        QtMocHelpers::SignalData<void()>(89, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6SidechainReactivityChanged'
        QtMocHelpers::SignalData<void()>(90, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7SidechainReactivityChanged'
        QtMocHelpers::SignalData<void()>(91, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0SidechainPreampChanged'
        QtMocHelpers::SignalData<void()>(92, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1SidechainPreampChanged'
        QtMocHelpers::SignalData<void()>(93, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2SidechainPreampChanged'
        QtMocHelpers::SignalData<void()>(94, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3SidechainPreampChanged'
        QtMocHelpers::SignalData<void()>(95, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4SidechainPreampChanged'
        QtMocHelpers::SignalData<void()>(96, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5SidechainPreampChanged'
        QtMocHelpers::SignalData<void()>(97, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6SidechainPreampChanged'
        QtMocHelpers::SignalData<void()>(98, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7SidechainPreampChanged'
        QtMocHelpers::SignalData<void()>(99, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0SidechainCustomLowcutFilterChanged'
        QtMocHelpers::SignalData<void()>(100, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1SidechainCustomLowcutFilterChanged'
        QtMocHelpers::SignalData<void()>(101, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2SidechainCustomLowcutFilterChanged'
        QtMocHelpers::SignalData<void()>(102, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3SidechainCustomLowcutFilterChanged'
        QtMocHelpers::SignalData<void()>(103, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4SidechainCustomLowcutFilterChanged'
        QtMocHelpers::SignalData<void()>(104, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5SidechainCustomLowcutFilterChanged'
        QtMocHelpers::SignalData<void()>(105, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6SidechainCustomLowcutFilterChanged'
        QtMocHelpers::SignalData<void()>(106, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7SidechainCustomLowcutFilterChanged'
        QtMocHelpers::SignalData<void()>(107, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0SidechainCustomHighcutFilterChanged'
        QtMocHelpers::SignalData<void()>(108, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1SidechainCustomHighcutFilterChanged'
        QtMocHelpers::SignalData<void()>(109, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2SidechainCustomHighcutFilterChanged'
        QtMocHelpers::SignalData<void()>(110, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3SidechainCustomHighcutFilterChanged'
        QtMocHelpers::SignalData<void()>(111, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4SidechainCustomHighcutFilterChanged'
        QtMocHelpers::SignalData<void()>(112, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5SidechainCustomHighcutFilterChanged'
        QtMocHelpers::SignalData<void()>(113, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6SidechainCustomHighcutFilterChanged'
        QtMocHelpers::SignalData<void()>(114, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7SidechainCustomHighcutFilterChanged'
        QtMocHelpers::SignalData<void()>(115, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0SidechainLowcutFrequencyChanged'
        QtMocHelpers::SignalData<void()>(116, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1SidechainLowcutFrequencyChanged'
        QtMocHelpers::SignalData<void()>(117, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2SidechainLowcutFrequencyChanged'
        QtMocHelpers::SignalData<void()>(118, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3SidechainLowcutFrequencyChanged'
        QtMocHelpers::SignalData<void()>(119, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4SidechainLowcutFrequencyChanged'
        QtMocHelpers::SignalData<void()>(120, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5SidechainLowcutFrequencyChanged'
        QtMocHelpers::SignalData<void()>(121, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6SidechainLowcutFrequencyChanged'
        QtMocHelpers::SignalData<void()>(122, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7SidechainLowcutFrequencyChanged'
        QtMocHelpers::SignalData<void()>(123, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0SidechainHighcutFrequencyChanged'
        QtMocHelpers::SignalData<void()>(124, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1SidechainHighcutFrequencyChanged'
        QtMocHelpers::SignalData<void()>(125, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2SidechainHighcutFrequencyChanged'
        QtMocHelpers::SignalData<void()>(126, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3SidechainHighcutFrequencyChanged'
        QtMocHelpers::SignalData<void()>(127, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4SidechainHighcutFrequencyChanged'
        QtMocHelpers::SignalData<void()>(128, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5SidechainHighcutFrequencyChanged'
        QtMocHelpers::SignalData<void()>(129, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6SidechainHighcutFrequencyChanged'
        QtMocHelpers::SignalData<void()>(130, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7SidechainHighcutFrequencyChanged'
        QtMocHelpers::SignalData<void()>(131, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'compressionModeLabelsChanged'
        QtMocHelpers::SignalData<void()>(132, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0CompressionModeChanged'
        QtMocHelpers::SignalData<void()>(133, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1CompressionModeChanged'
        QtMocHelpers::SignalData<void()>(134, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2CompressionModeChanged'
        QtMocHelpers::SignalData<void()>(135, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3CompressionModeChanged'
        QtMocHelpers::SignalData<void()>(136, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4CompressionModeChanged'
        QtMocHelpers::SignalData<void()>(137, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5CompressionModeChanged'
        QtMocHelpers::SignalData<void()>(138, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6CompressionModeChanged'
        QtMocHelpers::SignalData<void()>(139, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7CompressionModeChanged'
        QtMocHelpers::SignalData<void()>(140, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0CompressorEnableChanged'
        QtMocHelpers::SignalData<void()>(141, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1CompressorEnableChanged'
        QtMocHelpers::SignalData<void()>(142, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2CompressorEnableChanged'
        QtMocHelpers::SignalData<void()>(143, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3CompressorEnableChanged'
        QtMocHelpers::SignalData<void()>(144, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4CompressorEnableChanged'
        QtMocHelpers::SignalData<void()>(145, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5CompressorEnableChanged'
        QtMocHelpers::SignalData<void()>(146, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6CompressorEnableChanged'
        QtMocHelpers::SignalData<void()>(147, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7CompressorEnableChanged'
        QtMocHelpers::SignalData<void()>(148, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0SoloChanged'
        QtMocHelpers::SignalData<void()>(149, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1SoloChanged'
        QtMocHelpers::SignalData<void()>(150, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2SoloChanged'
        QtMocHelpers::SignalData<void()>(151, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3SoloChanged'
        QtMocHelpers::SignalData<void()>(152, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4SoloChanged'
        QtMocHelpers::SignalData<void()>(153, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5SoloChanged'
        QtMocHelpers::SignalData<void()>(154, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6SoloChanged'
        QtMocHelpers::SignalData<void()>(155, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7SoloChanged'
        QtMocHelpers::SignalData<void()>(156, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0MuteChanged'
        QtMocHelpers::SignalData<void()>(157, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1MuteChanged'
        QtMocHelpers::SignalData<void()>(158, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2MuteChanged'
        QtMocHelpers::SignalData<void()>(159, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3MuteChanged'
        QtMocHelpers::SignalData<void()>(160, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4MuteChanged'
        QtMocHelpers::SignalData<void()>(161, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5MuteChanged'
        QtMocHelpers::SignalData<void()>(162, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6MuteChanged'
        QtMocHelpers::SignalData<void()>(163, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7MuteChanged'
        QtMocHelpers::SignalData<void()>(164, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0AttackThresholdChanged'
        QtMocHelpers::SignalData<void()>(165, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1AttackThresholdChanged'
        QtMocHelpers::SignalData<void()>(166, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2AttackThresholdChanged'
        QtMocHelpers::SignalData<void()>(167, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3AttackThresholdChanged'
        QtMocHelpers::SignalData<void()>(168, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4AttackThresholdChanged'
        QtMocHelpers::SignalData<void()>(169, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5AttackThresholdChanged'
        QtMocHelpers::SignalData<void()>(170, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6AttackThresholdChanged'
        QtMocHelpers::SignalData<void()>(171, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7AttackThresholdChanged'
        QtMocHelpers::SignalData<void()>(172, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0AttackTimeChanged'
        QtMocHelpers::SignalData<void()>(173, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1AttackTimeChanged'
        QtMocHelpers::SignalData<void()>(174, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2AttackTimeChanged'
        QtMocHelpers::SignalData<void()>(175, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3AttackTimeChanged'
        QtMocHelpers::SignalData<void()>(176, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4AttackTimeChanged'
        QtMocHelpers::SignalData<void()>(177, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5AttackTimeChanged'
        QtMocHelpers::SignalData<void()>(178, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6AttackTimeChanged'
        QtMocHelpers::SignalData<void()>(179, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7AttackTimeChanged'
        QtMocHelpers::SignalData<void()>(180, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0ReleaseThresholdChanged'
        QtMocHelpers::SignalData<void()>(181, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1ReleaseThresholdChanged'
        QtMocHelpers::SignalData<void()>(182, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2ReleaseThresholdChanged'
        QtMocHelpers::SignalData<void()>(183, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3ReleaseThresholdChanged'
        QtMocHelpers::SignalData<void()>(184, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4ReleaseThresholdChanged'
        QtMocHelpers::SignalData<void()>(185, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5ReleaseThresholdChanged'
        QtMocHelpers::SignalData<void()>(186, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6ReleaseThresholdChanged'
        QtMocHelpers::SignalData<void()>(187, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7ReleaseThresholdChanged'
        QtMocHelpers::SignalData<void()>(188, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0ReleaseTimeChanged'
        QtMocHelpers::SignalData<void()>(189, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1ReleaseTimeChanged'
        QtMocHelpers::SignalData<void()>(190, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2ReleaseTimeChanged'
        QtMocHelpers::SignalData<void()>(191, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3ReleaseTimeChanged'
        QtMocHelpers::SignalData<void()>(192, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4ReleaseTimeChanged'
        QtMocHelpers::SignalData<void()>(193, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5ReleaseTimeChanged'
        QtMocHelpers::SignalData<void()>(194, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6ReleaseTimeChanged'
        QtMocHelpers::SignalData<void()>(195, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7ReleaseTimeChanged'
        QtMocHelpers::SignalData<void()>(196, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0RatioChanged'
        QtMocHelpers::SignalData<void()>(197, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1RatioChanged'
        QtMocHelpers::SignalData<void()>(198, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2RatioChanged'
        QtMocHelpers::SignalData<void()>(199, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3RatioChanged'
        QtMocHelpers::SignalData<void()>(200, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4RatioChanged'
        QtMocHelpers::SignalData<void()>(201, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5RatioChanged'
        QtMocHelpers::SignalData<void()>(202, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6RatioChanged'
        QtMocHelpers::SignalData<void()>(203, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7RatioChanged'
        QtMocHelpers::SignalData<void()>(204, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0KneeChanged'
        QtMocHelpers::SignalData<void()>(205, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1KneeChanged'
        QtMocHelpers::SignalData<void()>(206, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2KneeChanged'
        QtMocHelpers::SignalData<void()>(207, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3KneeChanged'
        QtMocHelpers::SignalData<void()>(208, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4KneeChanged'
        QtMocHelpers::SignalData<void()>(209, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5KneeChanged'
        QtMocHelpers::SignalData<void()>(210, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6KneeChanged'
        QtMocHelpers::SignalData<void()>(211, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7KneeChanged'
        QtMocHelpers::SignalData<void()>(212, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0BoostThresholdChanged'
        QtMocHelpers::SignalData<void()>(213, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1BoostThresholdChanged'
        QtMocHelpers::SignalData<void()>(214, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2BoostThresholdChanged'
        QtMocHelpers::SignalData<void()>(215, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3BoostThresholdChanged'
        QtMocHelpers::SignalData<void()>(216, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4BoostThresholdChanged'
        QtMocHelpers::SignalData<void()>(217, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5BoostThresholdChanged'
        QtMocHelpers::SignalData<void()>(218, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6BoostThresholdChanged'
        QtMocHelpers::SignalData<void()>(219, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7BoostThresholdChanged'
        QtMocHelpers::SignalData<void()>(220, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0BoostAmountChanged'
        QtMocHelpers::SignalData<void()>(221, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1BoostAmountChanged'
        QtMocHelpers::SignalData<void()>(222, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2BoostAmountChanged'
        QtMocHelpers::SignalData<void()>(223, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3BoostAmountChanged'
        QtMocHelpers::SignalData<void()>(224, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4BoostAmountChanged'
        QtMocHelpers::SignalData<void()>(225, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5BoostAmountChanged'
        QtMocHelpers::SignalData<void()>(226, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6BoostAmountChanged'
        QtMocHelpers::SignalData<void()>(227, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7BoostAmountChanged'
        QtMocHelpers::SignalData<void()>(228, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band0MakeupChanged'
        QtMocHelpers::SignalData<void()>(229, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band1MakeupChanged'
        QtMocHelpers::SignalData<void()>(230, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band2MakeupChanged'
        QtMocHelpers::SignalData<void()>(231, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band3MakeupChanged'
        QtMocHelpers::SignalData<void()>(232, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band4MakeupChanged'
        QtMocHelpers::SignalData<void()>(233, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band5MakeupChanged'
        QtMocHelpers::SignalData<void()>(234, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band6MakeupChanged'
        QtMocHelpers::SignalData<void()>(235, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'band7MakeupChanged'
        QtMocHelpers::SignalData<void()>(236, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bypass'
        QtMocHelpers::PropertyData<bool>(237, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isBypassImmutable'
        QtMocHelpers::PropertyData<bool>(238, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBypassValue'
        QtMocHelpers::PropertyData<bool>(239, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputGain'
        QtMocHelpers::PropertyData<double>(240, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isInputGainImmutable'
        QtMocHelpers::PropertyData<bool>(241, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputGainValue'
        QtMocHelpers::PropertyData<double>(242, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'outputGain'
        QtMocHelpers::PropertyData<double>(243, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isOutputGainImmutable'
        QtMocHelpers::PropertyData<bool>(244, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOutputGainValue'
        QtMocHelpers::PropertyData<double>(245, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dry'
        QtMocHelpers::PropertyData<double>(246, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isDryImmutable'
        QtMocHelpers::PropertyData<bool>(247, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDryValue'
        QtMocHelpers::PropertyData<double>(248, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'wet'
        QtMocHelpers::PropertyData<double>(249, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isWetImmutable'
        QtMocHelpers::PropertyData<bool>(250, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWetValue'
        QtMocHelpers::PropertyData<double>(251, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'viewSidechain'
        QtMocHelpers::PropertyData<bool>(252, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isViewSidechainImmutable'
        QtMocHelpers::PropertyData<bool>(253, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultViewSidechainValue'
        QtMocHelpers::PropertyData<bool>(254, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'externalSidechainEnabled'
        QtMocHelpers::PropertyData<bool>(255, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isExternalSidechainEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(256, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultExternalSidechainEnabledValue'
        QtMocHelpers::PropertyData<bool>(257, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stereoSplit'
        QtMocHelpers::PropertyData<bool>(258, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isStereoSplitImmutable'
        QtMocHelpers::PropertyData<bool>(259, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultStereoSplitValue'
        QtMocHelpers::PropertyData<bool>(260, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'compressorModeLabels'
        QtMocHelpers::PropertyData<QStringList>(261, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isCompressorModeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(262, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCompressorModeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(263, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'compressorMode'
        QtMocHelpers::PropertyData<int>(264, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isCompressorModeImmutable'
        QtMocHelpers::PropertyData<bool>(265, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCompressorModeValue'
        QtMocHelpers::PropertyData<int>(266, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'envelopeBoostLabels'
        QtMocHelpers::PropertyData<QStringList>(267, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isEnvelopeBoostLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(268, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnvelopeBoostLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(269, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'envelopeBoost'
        QtMocHelpers::PropertyData<int>(270, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isEnvelopeBoostImmutable'
        QtMocHelpers::PropertyData<bool>(271, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnvelopeBoostValue'
        QtMocHelpers::PropertyData<int>(272, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputToSidechain'
        QtMocHelpers::PropertyData<double>(273, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isInputToSidechainImmutable'
        QtMocHelpers::PropertyData<bool>(274, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputToSidechainValue'
        QtMocHelpers::PropertyData<double>(275, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inputToLink'
        QtMocHelpers::PropertyData<double>(276, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isInputToLinkImmutable'
        QtMocHelpers::PropertyData<bool>(277, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInputToLinkValue'
        QtMocHelpers::PropertyData<double>(278, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainToInput'
        QtMocHelpers::PropertyData<double>(279, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isSidechainToInputImmutable'
        QtMocHelpers::PropertyData<bool>(280, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainToInputValue'
        QtMocHelpers::PropertyData<double>(281, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainToLink'
        QtMocHelpers::PropertyData<double>(282, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isSidechainToLinkImmutable'
        QtMocHelpers::PropertyData<bool>(283, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainToLinkValue'
        QtMocHelpers::PropertyData<double>(284, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'linkToSidechain'
        QtMocHelpers::PropertyData<double>(285, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isLinkToSidechainImmutable'
        QtMocHelpers::PropertyData<bool>(286, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLinkToSidechainValue'
        QtMocHelpers::PropertyData<double>(287, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'linkToInput'
        QtMocHelpers::PropertyData<double>(288, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'isLinkToInputImmutable'
        QtMocHelpers::PropertyData<bool>(289, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLinkToInputValue'
        QtMocHelpers::PropertyData<double>(290, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1Enable'
        QtMocHelpers::PropertyData<bool>(291, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'isBand1EnableImmutable'
        QtMocHelpers::PropertyData<bool>(292, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1EnableValue'
        QtMocHelpers::PropertyData<bool>(293, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2Enable'
        QtMocHelpers::PropertyData<bool>(294, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'isBand2EnableImmutable'
        QtMocHelpers::PropertyData<bool>(295, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2EnableValue'
        QtMocHelpers::PropertyData<bool>(296, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3Enable'
        QtMocHelpers::PropertyData<bool>(297, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'isBand3EnableImmutable'
        QtMocHelpers::PropertyData<bool>(298, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3EnableValue'
        QtMocHelpers::PropertyData<bool>(299, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4Enable'
        QtMocHelpers::PropertyData<bool>(300, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'isBand4EnableImmutable'
        QtMocHelpers::PropertyData<bool>(301, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4EnableValue'
        QtMocHelpers::PropertyData<bool>(302, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5Enable'
        QtMocHelpers::PropertyData<bool>(303, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'isBand5EnableImmutable'
        QtMocHelpers::PropertyData<bool>(304, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5EnableValue'
        QtMocHelpers::PropertyData<bool>(305, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6Enable'
        QtMocHelpers::PropertyData<bool>(306, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'isBand6EnableImmutable'
        QtMocHelpers::PropertyData<bool>(307, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6EnableValue'
        QtMocHelpers::PropertyData<bool>(308, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7Enable'
        QtMocHelpers::PropertyData<bool>(309, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'isBand7EnableImmutable'
        QtMocHelpers::PropertyData<bool>(310, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7EnableValue'
        QtMocHelpers::PropertyData<bool>(311, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1SplitFrequency'
        QtMocHelpers::PropertyData<double>(312, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 25),
        // property 'isBand1SplitFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(313, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1SplitFrequencyValue'
        QtMocHelpers::PropertyData<double>(314, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2SplitFrequency'
        QtMocHelpers::PropertyData<double>(315, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 26),
        // property 'isBand2SplitFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(316, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2SplitFrequencyValue'
        QtMocHelpers::PropertyData<double>(317, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3SplitFrequency'
        QtMocHelpers::PropertyData<double>(318, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 27),
        // property 'isBand3SplitFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(319, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3SplitFrequencyValue'
        QtMocHelpers::PropertyData<double>(320, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4SplitFrequency'
        QtMocHelpers::PropertyData<double>(321, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 28),
        // property 'isBand4SplitFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(322, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4SplitFrequencyValue'
        QtMocHelpers::PropertyData<double>(323, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5SplitFrequency'
        QtMocHelpers::PropertyData<double>(324, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 29),
        // property 'isBand5SplitFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(325, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5SplitFrequencyValue'
        QtMocHelpers::PropertyData<double>(326, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6SplitFrequency'
        QtMocHelpers::PropertyData<double>(327, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 30),
        // property 'isBand6SplitFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(328, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6SplitFrequencyValue'
        QtMocHelpers::PropertyData<double>(329, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7SplitFrequency'
        QtMocHelpers::PropertyData<double>(330, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 31),
        // property 'isBand7SplitFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(331, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7SplitFrequencyValue'
        QtMocHelpers::PropertyData<double>(332, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainInputDevice'
        QtMocHelpers::PropertyData<QString>(333, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 32),
        // property 'isSidechainInputDeviceImmutable'
        QtMocHelpers::PropertyData<bool>(334, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainInputDeviceValue'
        QtMocHelpers::PropertyData<QString>(335, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainTypeLabels'
        QtMocHelpers::PropertyData<QStringList>(336, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 33),
        // property 'isSidechainTypeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(337, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainTypeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(338, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0SidechainType'
        QtMocHelpers::PropertyData<int>(339, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 34),
        // property 'isBand0SidechainTypeImmutable'
        QtMocHelpers::PropertyData<bool>(340, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0SidechainTypeValue'
        QtMocHelpers::PropertyData<int>(341, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1SidechainType'
        QtMocHelpers::PropertyData<int>(342, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 35),
        // property 'isBand1SidechainTypeImmutable'
        QtMocHelpers::PropertyData<bool>(343, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1SidechainTypeValue'
        QtMocHelpers::PropertyData<int>(344, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2SidechainType'
        QtMocHelpers::PropertyData<int>(345, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 36),
        // property 'isBand2SidechainTypeImmutable'
        QtMocHelpers::PropertyData<bool>(346, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2SidechainTypeValue'
        QtMocHelpers::PropertyData<int>(347, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3SidechainType'
        QtMocHelpers::PropertyData<int>(348, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 37),
        // property 'isBand3SidechainTypeImmutable'
        QtMocHelpers::PropertyData<bool>(349, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3SidechainTypeValue'
        QtMocHelpers::PropertyData<int>(350, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4SidechainType'
        QtMocHelpers::PropertyData<int>(351, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 38),
        // property 'isBand4SidechainTypeImmutable'
        QtMocHelpers::PropertyData<bool>(352, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4SidechainTypeValue'
        QtMocHelpers::PropertyData<int>(353, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5SidechainType'
        QtMocHelpers::PropertyData<int>(354, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 39),
        // property 'isBand5SidechainTypeImmutable'
        QtMocHelpers::PropertyData<bool>(355, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5SidechainTypeValue'
        QtMocHelpers::PropertyData<int>(356, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6SidechainType'
        QtMocHelpers::PropertyData<int>(357, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 40),
        // property 'isBand6SidechainTypeImmutable'
        QtMocHelpers::PropertyData<bool>(358, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6SidechainTypeValue'
        QtMocHelpers::PropertyData<int>(359, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7SidechainType'
        QtMocHelpers::PropertyData<int>(360, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 41),
        // property 'isBand7SidechainTypeImmutable'
        QtMocHelpers::PropertyData<bool>(361, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7SidechainTypeValue'
        QtMocHelpers::PropertyData<int>(362, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainModeLabels'
        QtMocHelpers::PropertyData<QStringList>(363, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 42),
        // property 'isSidechainModeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(364, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainModeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(365, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0SidechainMode'
        QtMocHelpers::PropertyData<int>(366, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 43),
        // property 'isBand0SidechainModeImmutable'
        QtMocHelpers::PropertyData<bool>(367, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0SidechainModeValue'
        QtMocHelpers::PropertyData<int>(368, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1SidechainMode'
        QtMocHelpers::PropertyData<int>(369, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 44),
        // property 'isBand1SidechainModeImmutable'
        QtMocHelpers::PropertyData<bool>(370, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1SidechainModeValue'
        QtMocHelpers::PropertyData<int>(371, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2SidechainMode'
        QtMocHelpers::PropertyData<int>(372, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 45),
        // property 'isBand2SidechainModeImmutable'
        QtMocHelpers::PropertyData<bool>(373, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2SidechainModeValue'
        QtMocHelpers::PropertyData<int>(374, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3SidechainMode'
        QtMocHelpers::PropertyData<int>(375, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 46),
        // property 'isBand3SidechainModeImmutable'
        QtMocHelpers::PropertyData<bool>(376, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3SidechainModeValue'
        QtMocHelpers::PropertyData<int>(377, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4SidechainMode'
        QtMocHelpers::PropertyData<int>(378, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 47),
        // property 'isBand4SidechainModeImmutable'
        QtMocHelpers::PropertyData<bool>(379, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4SidechainModeValue'
        QtMocHelpers::PropertyData<int>(380, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5SidechainMode'
        QtMocHelpers::PropertyData<int>(381, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 48),
        // property 'isBand5SidechainModeImmutable'
        QtMocHelpers::PropertyData<bool>(382, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5SidechainModeValue'
        QtMocHelpers::PropertyData<int>(383, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6SidechainMode'
        QtMocHelpers::PropertyData<int>(384, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 49),
        // property 'isBand6SidechainModeImmutable'
        QtMocHelpers::PropertyData<bool>(385, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6SidechainModeValue'
        QtMocHelpers::PropertyData<int>(386, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7SidechainMode'
        QtMocHelpers::PropertyData<int>(387, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 50),
        // property 'isBand7SidechainModeImmutable'
        QtMocHelpers::PropertyData<bool>(388, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7SidechainModeValue'
        QtMocHelpers::PropertyData<int>(389, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sidechainSourceLabels'
        QtMocHelpers::PropertyData<QStringList>(390, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 51),
        // property 'isSidechainSourceLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(391, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSidechainSourceLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(392, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0SidechainSource'
        QtMocHelpers::PropertyData<int>(393, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 52),
        // property 'isBand0SidechainSourceImmutable'
        QtMocHelpers::PropertyData<bool>(394, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0SidechainSourceValue'
        QtMocHelpers::PropertyData<int>(395, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1SidechainSource'
        QtMocHelpers::PropertyData<int>(396, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 53),
        // property 'isBand1SidechainSourceImmutable'
        QtMocHelpers::PropertyData<bool>(397, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1SidechainSourceValue'
        QtMocHelpers::PropertyData<int>(398, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2SidechainSource'
        QtMocHelpers::PropertyData<int>(399, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 54),
        // property 'isBand2SidechainSourceImmutable'
        QtMocHelpers::PropertyData<bool>(400, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2SidechainSourceValue'
        QtMocHelpers::PropertyData<int>(401, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3SidechainSource'
        QtMocHelpers::PropertyData<int>(402, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 55),
        // property 'isBand3SidechainSourceImmutable'
        QtMocHelpers::PropertyData<bool>(403, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3SidechainSourceValue'
        QtMocHelpers::PropertyData<int>(404, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4SidechainSource'
        QtMocHelpers::PropertyData<int>(405, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 56),
        // property 'isBand4SidechainSourceImmutable'
        QtMocHelpers::PropertyData<bool>(406, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4SidechainSourceValue'
        QtMocHelpers::PropertyData<int>(407, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5SidechainSource'
        QtMocHelpers::PropertyData<int>(408, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 57),
        // property 'isBand5SidechainSourceImmutable'
        QtMocHelpers::PropertyData<bool>(409, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5SidechainSourceValue'
        QtMocHelpers::PropertyData<int>(410, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6SidechainSource'
        QtMocHelpers::PropertyData<int>(411, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 58),
        // property 'isBand6SidechainSourceImmutable'
        QtMocHelpers::PropertyData<bool>(412, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6SidechainSourceValue'
        QtMocHelpers::PropertyData<int>(413, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7SidechainSource'
        QtMocHelpers::PropertyData<int>(414, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 59),
        // property 'isBand7SidechainSourceImmutable'
        QtMocHelpers::PropertyData<bool>(415, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7SidechainSourceValue'
        QtMocHelpers::PropertyData<int>(416, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stereoSplitSourceLabels'
        QtMocHelpers::PropertyData<QStringList>(417, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 60),
        // property 'isStereoSplitSourceLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(418, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultStereoSplitSourceLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(419, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0StereoSplitSource'
        QtMocHelpers::PropertyData<int>(420, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 61),
        // property 'isBand0StereoSplitSourceImmutable'
        QtMocHelpers::PropertyData<bool>(421, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0StereoSplitSourceValue'
        QtMocHelpers::PropertyData<int>(422, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1StereoSplitSource'
        QtMocHelpers::PropertyData<int>(423, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 62),
        // property 'isBand1StereoSplitSourceImmutable'
        QtMocHelpers::PropertyData<bool>(424, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1StereoSplitSourceValue'
        QtMocHelpers::PropertyData<int>(425, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2StereoSplitSource'
        QtMocHelpers::PropertyData<int>(426, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 63),
        // property 'isBand2StereoSplitSourceImmutable'
        QtMocHelpers::PropertyData<bool>(427, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2StereoSplitSourceValue'
        QtMocHelpers::PropertyData<int>(428, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3StereoSplitSource'
        QtMocHelpers::PropertyData<int>(429, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 64),
        // property 'isBand3StereoSplitSourceImmutable'
        QtMocHelpers::PropertyData<bool>(430, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3StereoSplitSourceValue'
        QtMocHelpers::PropertyData<int>(431, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4StereoSplitSource'
        QtMocHelpers::PropertyData<int>(432, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 65),
        // property 'isBand4StereoSplitSourceImmutable'
        QtMocHelpers::PropertyData<bool>(433, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4StereoSplitSourceValue'
        QtMocHelpers::PropertyData<int>(434, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5StereoSplitSource'
        QtMocHelpers::PropertyData<int>(435, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 66),
        // property 'isBand5StereoSplitSourceImmutable'
        QtMocHelpers::PropertyData<bool>(436, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5StereoSplitSourceValue'
        QtMocHelpers::PropertyData<int>(437, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6StereoSplitSource'
        QtMocHelpers::PropertyData<int>(438, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 67),
        // property 'isBand6StereoSplitSourceImmutable'
        QtMocHelpers::PropertyData<bool>(439, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6StereoSplitSourceValue'
        QtMocHelpers::PropertyData<int>(440, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7StereoSplitSource'
        QtMocHelpers::PropertyData<int>(441, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 68),
        // property 'isBand7StereoSplitSourceImmutable'
        QtMocHelpers::PropertyData<bool>(442, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7StereoSplitSourceValue'
        QtMocHelpers::PropertyData<int>(443, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0SidechainLookahead'
        QtMocHelpers::PropertyData<double>(444, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 69),
        // property 'isBand0SidechainLookaheadImmutable'
        QtMocHelpers::PropertyData<bool>(445, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0SidechainLookaheadValue'
        QtMocHelpers::PropertyData<double>(446, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1SidechainLookahead'
        QtMocHelpers::PropertyData<double>(447, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 70),
        // property 'isBand1SidechainLookaheadImmutable'
        QtMocHelpers::PropertyData<bool>(448, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1SidechainLookaheadValue'
        QtMocHelpers::PropertyData<double>(449, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2SidechainLookahead'
        QtMocHelpers::PropertyData<double>(450, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 71),
        // property 'isBand2SidechainLookaheadImmutable'
        QtMocHelpers::PropertyData<bool>(451, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2SidechainLookaheadValue'
        QtMocHelpers::PropertyData<double>(452, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3SidechainLookahead'
        QtMocHelpers::PropertyData<double>(453, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 72),
        // property 'isBand3SidechainLookaheadImmutable'
        QtMocHelpers::PropertyData<bool>(454, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3SidechainLookaheadValue'
        QtMocHelpers::PropertyData<double>(455, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4SidechainLookahead'
        QtMocHelpers::PropertyData<double>(456, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 73),
        // property 'isBand4SidechainLookaheadImmutable'
        QtMocHelpers::PropertyData<bool>(457, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4SidechainLookaheadValue'
        QtMocHelpers::PropertyData<double>(458, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5SidechainLookahead'
        QtMocHelpers::PropertyData<double>(459, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 74),
        // property 'isBand5SidechainLookaheadImmutable'
        QtMocHelpers::PropertyData<bool>(460, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5SidechainLookaheadValue'
        QtMocHelpers::PropertyData<double>(461, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6SidechainLookahead'
        QtMocHelpers::PropertyData<double>(462, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 75),
        // property 'isBand6SidechainLookaheadImmutable'
        QtMocHelpers::PropertyData<bool>(463, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6SidechainLookaheadValue'
        QtMocHelpers::PropertyData<double>(464, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7SidechainLookahead'
        QtMocHelpers::PropertyData<double>(465, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 76),
        // property 'isBand7SidechainLookaheadImmutable'
        QtMocHelpers::PropertyData<bool>(466, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7SidechainLookaheadValue'
        QtMocHelpers::PropertyData<double>(467, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0SidechainReactivity'
        QtMocHelpers::PropertyData<double>(468, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 77),
        // property 'isBand0SidechainReactivityImmutable'
        QtMocHelpers::PropertyData<bool>(469, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0SidechainReactivityValue'
        QtMocHelpers::PropertyData<double>(470, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1SidechainReactivity'
        QtMocHelpers::PropertyData<double>(471, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 78),
        // property 'isBand1SidechainReactivityImmutable'
        QtMocHelpers::PropertyData<bool>(472, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1SidechainReactivityValue'
        QtMocHelpers::PropertyData<double>(473, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2SidechainReactivity'
        QtMocHelpers::PropertyData<double>(474, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 79),
        // property 'isBand2SidechainReactivityImmutable'
        QtMocHelpers::PropertyData<bool>(475, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2SidechainReactivityValue'
        QtMocHelpers::PropertyData<double>(476, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3SidechainReactivity'
        QtMocHelpers::PropertyData<double>(477, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 80),
        // property 'isBand3SidechainReactivityImmutable'
        QtMocHelpers::PropertyData<bool>(478, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3SidechainReactivityValue'
        QtMocHelpers::PropertyData<double>(479, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4SidechainReactivity'
        QtMocHelpers::PropertyData<double>(480, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 81),
        // property 'isBand4SidechainReactivityImmutable'
        QtMocHelpers::PropertyData<bool>(481, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4SidechainReactivityValue'
        QtMocHelpers::PropertyData<double>(482, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5SidechainReactivity'
        QtMocHelpers::PropertyData<double>(483, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 82),
        // property 'isBand5SidechainReactivityImmutable'
        QtMocHelpers::PropertyData<bool>(484, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5SidechainReactivityValue'
        QtMocHelpers::PropertyData<double>(485, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6SidechainReactivity'
        QtMocHelpers::PropertyData<double>(486, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 83),
        // property 'isBand6SidechainReactivityImmutable'
        QtMocHelpers::PropertyData<bool>(487, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6SidechainReactivityValue'
        QtMocHelpers::PropertyData<double>(488, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7SidechainReactivity'
        QtMocHelpers::PropertyData<double>(489, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 84),
        // property 'isBand7SidechainReactivityImmutable'
        QtMocHelpers::PropertyData<bool>(490, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7SidechainReactivityValue'
        QtMocHelpers::PropertyData<double>(491, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0SidechainPreamp'
        QtMocHelpers::PropertyData<double>(492, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 85),
        // property 'isBand0SidechainPreampImmutable'
        QtMocHelpers::PropertyData<bool>(493, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0SidechainPreampValue'
        QtMocHelpers::PropertyData<double>(494, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1SidechainPreamp'
        QtMocHelpers::PropertyData<double>(495, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 86),
        // property 'isBand1SidechainPreampImmutable'
        QtMocHelpers::PropertyData<bool>(496, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1SidechainPreampValue'
        QtMocHelpers::PropertyData<double>(497, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2SidechainPreamp'
        QtMocHelpers::PropertyData<double>(498, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 87),
        // property 'isBand2SidechainPreampImmutable'
        QtMocHelpers::PropertyData<bool>(499, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2SidechainPreampValue'
        QtMocHelpers::PropertyData<double>(500, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3SidechainPreamp'
        QtMocHelpers::PropertyData<double>(501, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 88),
        // property 'isBand3SidechainPreampImmutable'
        QtMocHelpers::PropertyData<bool>(502, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3SidechainPreampValue'
        QtMocHelpers::PropertyData<double>(503, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4SidechainPreamp'
        QtMocHelpers::PropertyData<double>(504, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 89),
        // property 'isBand4SidechainPreampImmutable'
        QtMocHelpers::PropertyData<bool>(505, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4SidechainPreampValue'
        QtMocHelpers::PropertyData<double>(506, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5SidechainPreamp'
        QtMocHelpers::PropertyData<double>(507, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 90),
        // property 'isBand5SidechainPreampImmutable'
        QtMocHelpers::PropertyData<bool>(508, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5SidechainPreampValue'
        QtMocHelpers::PropertyData<double>(509, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6SidechainPreamp'
        QtMocHelpers::PropertyData<double>(510, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 91),
        // property 'isBand6SidechainPreampImmutable'
        QtMocHelpers::PropertyData<bool>(511, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6SidechainPreampValue'
        QtMocHelpers::PropertyData<double>(512, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7SidechainPreamp'
        QtMocHelpers::PropertyData<double>(513, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 92),
        // property 'isBand7SidechainPreampImmutable'
        QtMocHelpers::PropertyData<bool>(514, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7SidechainPreampValue'
        QtMocHelpers::PropertyData<double>(515, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0SidechainCustomLowcutFilter'
        QtMocHelpers::PropertyData<bool>(516, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 93),
        // property 'isBand0SidechainCustomLowcutFilterImmutable'
        QtMocHelpers::PropertyData<bool>(517, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0SidechainCustomLowcutFilterValue'
        QtMocHelpers::PropertyData<bool>(518, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1SidechainCustomLowcutFilter'
        QtMocHelpers::PropertyData<bool>(519, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 94),
        // property 'isBand1SidechainCustomLowcutFilterImmutable'
        QtMocHelpers::PropertyData<bool>(520, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1SidechainCustomLowcutFilterValue'
        QtMocHelpers::PropertyData<bool>(521, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2SidechainCustomLowcutFilter'
        QtMocHelpers::PropertyData<bool>(522, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 95),
        // property 'isBand2SidechainCustomLowcutFilterImmutable'
        QtMocHelpers::PropertyData<bool>(523, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2SidechainCustomLowcutFilterValue'
        QtMocHelpers::PropertyData<bool>(524, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3SidechainCustomLowcutFilter'
        QtMocHelpers::PropertyData<bool>(525, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 96),
        // property 'isBand3SidechainCustomLowcutFilterImmutable'
        QtMocHelpers::PropertyData<bool>(526, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3SidechainCustomLowcutFilterValue'
        QtMocHelpers::PropertyData<bool>(527, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4SidechainCustomLowcutFilter'
        QtMocHelpers::PropertyData<bool>(528, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 97),
        // property 'isBand4SidechainCustomLowcutFilterImmutable'
        QtMocHelpers::PropertyData<bool>(529, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4SidechainCustomLowcutFilterValue'
        QtMocHelpers::PropertyData<bool>(530, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5SidechainCustomLowcutFilter'
        QtMocHelpers::PropertyData<bool>(531, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 98),
        // property 'isBand5SidechainCustomLowcutFilterImmutable'
        QtMocHelpers::PropertyData<bool>(532, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5SidechainCustomLowcutFilterValue'
        QtMocHelpers::PropertyData<bool>(533, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6SidechainCustomLowcutFilter'
        QtMocHelpers::PropertyData<bool>(534, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 99),
        // property 'isBand6SidechainCustomLowcutFilterImmutable'
        QtMocHelpers::PropertyData<bool>(535, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6SidechainCustomLowcutFilterValue'
        QtMocHelpers::PropertyData<bool>(536, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7SidechainCustomLowcutFilter'
        QtMocHelpers::PropertyData<bool>(537, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 100),
        // property 'isBand7SidechainCustomLowcutFilterImmutable'
        QtMocHelpers::PropertyData<bool>(538, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7SidechainCustomLowcutFilterValue'
        QtMocHelpers::PropertyData<bool>(539, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0SidechainCustomHighcutFilter'
        QtMocHelpers::PropertyData<bool>(540, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 101),
        // property 'isBand0SidechainCustomHighcutFilterImmutable'
        QtMocHelpers::PropertyData<bool>(541, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0SidechainCustomHighcutFilterValue'
        QtMocHelpers::PropertyData<bool>(542, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1SidechainCustomHighcutFilter'
        QtMocHelpers::PropertyData<bool>(543, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 102),
        // property 'isBand1SidechainCustomHighcutFilterImmutable'
        QtMocHelpers::PropertyData<bool>(544, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1SidechainCustomHighcutFilterValue'
        QtMocHelpers::PropertyData<bool>(545, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2SidechainCustomHighcutFilter'
        QtMocHelpers::PropertyData<bool>(546, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 103),
        // property 'isBand2SidechainCustomHighcutFilterImmutable'
        QtMocHelpers::PropertyData<bool>(547, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2SidechainCustomHighcutFilterValue'
        QtMocHelpers::PropertyData<bool>(548, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3SidechainCustomHighcutFilter'
        QtMocHelpers::PropertyData<bool>(549, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 104),
        // property 'isBand3SidechainCustomHighcutFilterImmutable'
        QtMocHelpers::PropertyData<bool>(550, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3SidechainCustomHighcutFilterValue'
        QtMocHelpers::PropertyData<bool>(551, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4SidechainCustomHighcutFilter'
        QtMocHelpers::PropertyData<bool>(552, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 105),
        // property 'isBand4SidechainCustomHighcutFilterImmutable'
        QtMocHelpers::PropertyData<bool>(553, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4SidechainCustomHighcutFilterValue'
        QtMocHelpers::PropertyData<bool>(554, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5SidechainCustomHighcutFilter'
        QtMocHelpers::PropertyData<bool>(555, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 106),
        // property 'isBand5SidechainCustomHighcutFilterImmutable'
        QtMocHelpers::PropertyData<bool>(556, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5SidechainCustomHighcutFilterValue'
        QtMocHelpers::PropertyData<bool>(557, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6SidechainCustomHighcutFilter'
        QtMocHelpers::PropertyData<bool>(558, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 107),
        // property 'isBand6SidechainCustomHighcutFilterImmutable'
        QtMocHelpers::PropertyData<bool>(559, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6SidechainCustomHighcutFilterValue'
        QtMocHelpers::PropertyData<bool>(560, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7SidechainCustomHighcutFilter'
        QtMocHelpers::PropertyData<bool>(561, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 108),
        // property 'isBand7SidechainCustomHighcutFilterImmutable'
        QtMocHelpers::PropertyData<bool>(562, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7SidechainCustomHighcutFilterValue'
        QtMocHelpers::PropertyData<bool>(563, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0SidechainLowcutFrequency'
        QtMocHelpers::PropertyData<double>(564, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 109),
        // property 'isBand0SidechainLowcutFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(565, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0SidechainLowcutFrequencyValue'
        QtMocHelpers::PropertyData<double>(566, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1SidechainLowcutFrequency'
        QtMocHelpers::PropertyData<double>(567, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 110),
        // property 'isBand1SidechainLowcutFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(568, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1SidechainLowcutFrequencyValue'
        QtMocHelpers::PropertyData<double>(569, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2SidechainLowcutFrequency'
        QtMocHelpers::PropertyData<double>(570, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 111),
        // property 'isBand2SidechainLowcutFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(571, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2SidechainLowcutFrequencyValue'
        QtMocHelpers::PropertyData<double>(572, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3SidechainLowcutFrequency'
        QtMocHelpers::PropertyData<double>(573, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 112),
        // property 'isBand3SidechainLowcutFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(574, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3SidechainLowcutFrequencyValue'
        QtMocHelpers::PropertyData<double>(575, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4SidechainLowcutFrequency'
        QtMocHelpers::PropertyData<double>(576, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 113),
        // property 'isBand4SidechainLowcutFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(577, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4SidechainLowcutFrequencyValue'
        QtMocHelpers::PropertyData<double>(578, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5SidechainLowcutFrequency'
        QtMocHelpers::PropertyData<double>(579, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 114),
        // property 'isBand5SidechainLowcutFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(580, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5SidechainLowcutFrequencyValue'
        QtMocHelpers::PropertyData<double>(581, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6SidechainLowcutFrequency'
        QtMocHelpers::PropertyData<double>(582, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 115),
        // property 'isBand6SidechainLowcutFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(583, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6SidechainLowcutFrequencyValue'
        QtMocHelpers::PropertyData<double>(584, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7SidechainLowcutFrequency'
        QtMocHelpers::PropertyData<double>(585, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 116),
        // property 'isBand7SidechainLowcutFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(586, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7SidechainLowcutFrequencyValue'
        QtMocHelpers::PropertyData<double>(587, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0SidechainHighcutFrequency'
        QtMocHelpers::PropertyData<double>(588, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 117),
        // property 'isBand0SidechainHighcutFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(589, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0SidechainHighcutFrequencyValue'
        QtMocHelpers::PropertyData<double>(590, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1SidechainHighcutFrequency'
        QtMocHelpers::PropertyData<double>(591, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 118),
        // property 'isBand1SidechainHighcutFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(592, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1SidechainHighcutFrequencyValue'
        QtMocHelpers::PropertyData<double>(593, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2SidechainHighcutFrequency'
        QtMocHelpers::PropertyData<double>(594, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 119),
        // property 'isBand2SidechainHighcutFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(595, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2SidechainHighcutFrequencyValue'
        QtMocHelpers::PropertyData<double>(596, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3SidechainHighcutFrequency'
        QtMocHelpers::PropertyData<double>(597, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 120),
        // property 'isBand3SidechainHighcutFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(598, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3SidechainHighcutFrequencyValue'
        QtMocHelpers::PropertyData<double>(599, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4SidechainHighcutFrequency'
        QtMocHelpers::PropertyData<double>(600, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 121),
        // property 'isBand4SidechainHighcutFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(601, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4SidechainHighcutFrequencyValue'
        QtMocHelpers::PropertyData<double>(602, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5SidechainHighcutFrequency'
        QtMocHelpers::PropertyData<double>(603, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 122),
        // property 'isBand5SidechainHighcutFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(604, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5SidechainHighcutFrequencyValue'
        QtMocHelpers::PropertyData<double>(605, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6SidechainHighcutFrequency'
        QtMocHelpers::PropertyData<double>(606, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 123),
        // property 'isBand6SidechainHighcutFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(607, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6SidechainHighcutFrequencyValue'
        QtMocHelpers::PropertyData<double>(608, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7SidechainHighcutFrequency'
        QtMocHelpers::PropertyData<double>(609, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 124),
        // property 'isBand7SidechainHighcutFrequencyImmutable'
        QtMocHelpers::PropertyData<bool>(610, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7SidechainHighcutFrequencyValue'
        QtMocHelpers::PropertyData<double>(611, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'compressionModeLabels'
        QtMocHelpers::PropertyData<QStringList>(612, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 125),
        // property 'isCompressionModeLabelsImmutable'
        QtMocHelpers::PropertyData<bool>(613, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCompressionModeLabelsValue'
        QtMocHelpers::PropertyData<QStringList>(614, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0CompressionMode'
        QtMocHelpers::PropertyData<int>(615, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 126),
        // property 'isBand0CompressionModeImmutable'
        QtMocHelpers::PropertyData<bool>(616, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0CompressionModeValue'
        QtMocHelpers::PropertyData<int>(617, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1CompressionMode'
        QtMocHelpers::PropertyData<int>(618, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 127),
        // property 'isBand1CompressionModeImmutable'
        QtMocHelpers::PropertyData<bool>(619, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1CompressionModeValue'
        QtMocHelpers::PropertyData<int>(620, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2CompressionMode'
        QtMocHelpers::PropertyData<int>(621, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 128),
        // property 'isBand2CompressionModeImmutable'
        QtMocHelpers::PropertyData<bool>(622, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2CompressionModeValue'
        QtMocHelpers::PropertyData<int>(623, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3CompressionMode'
        QtMocHelpers::PropertyData<int>(624, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 129),
        // property 'isBand3CompressionModeImmutable'
        QtMocHelpers::PropertyData<bool>(625, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3CompressionModeValue'
        QtMocHelpers::PropertyData<int>(626, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4CompressionMode'
        QtMocHelpers::PropertyData<int>(627, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 130),
        // property 'isBand4CompressionModeImmutable'
        QtMocHelpers::PropertyData<bool>(628, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4CompressionModeValue'
        QtMocHelpers::PropertyData<int>(629, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5CompressionMode'
        QtMocHelpers::PropertyData<int>(630, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 131),
        // property 'isBand5CompressionModeImmutable'
        QtMocHelpers::PropertyData<bool>(631, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5CompressionModeValue'
        QtMocHelpers::PropertyData<int>(632, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6CompressionMode'
        QtMocHelpers::PropertyData<int>(633, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 132),
        // property 'isBand6CompressionModeImmutable'
        QtMocHelpers::PropertyData<bool>(634, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6CompressionModeValue'
        QtMocHelpers::PropertyData<int>(635, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7CompressionMode'
        QtMocHelpers::PropertyData<int>(636, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 133),
        // property 'isBand7CompressionModeImmutable'
        QtMocHelpers::PropertyData<bool>(637, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7CompressionModeValue'
        QtMocHelpers::PropertyData<int>(638, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0CompressorEnable'
        QtMocHelpers::PropertyData<bool>(639, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 134),
        // property 'isBand0CompressorEnableImmutable'
        QtMocHelpers::PropertyData<bool>(640, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0CompressorEnableValue'
        QtMocHelpers::PropertyData<bool>(641, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1CompressorEnable'
        QtMocHelpers::PropertyData<bool>(642, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 135),
        // property 'isBand1CompressorEnableImmutable'
        QtMocHelpers::PropertyData<bool>(643, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1CompressorEnableValue'
        QtMocHelpers::PropertyData<bool>(644, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2CompressorEnable'
        QtMocHelpers::PropertyData<bool>(645, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 136),
        // property 'isBand2CompressorEnableImmutable'
        QtMocHelpers::PropertyData<bool>(646, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2CompressorEnableValue'
        QtMocHelpers::PropertyData<bool>(647, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3CompressorEnable'
        QtMocHelpers::PropertyData<bool>(648, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 137),
        // property 'isBand3CompressorEnableImmutable'
        QtMocHelpers::PropertyData<bool>(649, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3CompressorEnableValue'
        QtMocHelpers::PropertyData<bool>(650, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4CompressorEnable'
        QtMocHelpers::PropertyData<bool>(651, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 138),
        // property 'isBand4CompressorEnableImmutable'
        QtMocHelpers::PropertyData<bool>(652, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4CompressorEnableValue'
        QtMocHelpers::PropertyData<bool>(653, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5CompressorEnable'
        QtMocHelpers::PropertyData<bool>(654, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 139),
        // property 'isBand5CompressorEnableImmutable'
        QtMocHelpers::PropertyData<bool>(655, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5CompressorEnableValue'
        QtMocHelpers::PropertyData<bool>(656, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6CompressorEnable'
        QtMocHelpers::PropertyData<bool>(657, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 140),
        // property 'isBand6CompressorEnableImmutable'
        QtMocHelpers::PropertyData<bool>(658, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6CompressorEnableValue'
        QtMocHelpers::PropertyData<bool>(659, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7CompressorEnable'
        QtMocHelpers::PropertyData<bool>(660, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 141),
        // property 'isBand7CompressorEnableImmutable'
        QtMocHelpers::PropertyData<bool>(661, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7CompressorEnableValue'
        QtMocHelpers::PropertyData<bool>(662, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0Solo'
        QtMocHelpers::PropertyData<bool>(663, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 142),
        // property 'isBand0SoloImmutable'
        QtMocHelpers::PropertyData<bool>(664, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0SoloValue'
        QtMocHelpers::PropertyData<bool>(665, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1Solo'
        QtMocHelpers::PropertyData<bool>(666, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 143),
        // property 'isBand1SoloImmutable'
        QtMocHelpers::PropertyData<bool>(667, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1SoloValue'
        QtMocHelpers::PropertyData<bool>(668, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2Solo'
        QtMocHelpers::PropertyData<bool>(669, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 144),
        // property 'isBand2SoloImmutable'
        QtMocHelpers::PropertyData<bool>(670, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2SoloValue'
        QtMocHelpers::PropertyData<bool>(671, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3Solo'
        QtMocHelpers::PropertyData<bool>(672, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 145),
        // property 'isBand3SoloImmutable'
        QtMocHelpers::PropertyData<bool>(673, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3SoloValue'
        QtMocHelpers::PropertyData<bool>(674, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4Solo'
        QtMocHelpers::PropertyData<bool>(675, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 146),
        // property 'isBand4SoloImmutable'
        QtMocHelpers::PropertyData<bool>(676, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4SoloValue'
        QtMocHelpers::PropertyData<bool>(677, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5Solo'
        QtMocHelpers::PropertyData<bool>(678, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 147),
        // property 'isBand5SoloImmutable'
        QtMocHelpers::PropertyData<bool>(679, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5SoloValue'
        QtMocHelpers::PropertyData<bool>(680, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6Solo'
        QtMocHelpers::PropertyData<bool>(681, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 148),
        // property 'isBand6SoloImmutable'
        QtMocHelpers::PropertyData<bool>(682, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6SoloValue'
        QtMocHelpers::PropertyData<bool>(683, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7Solo'
        QtMocHelpers::PropertyData<bool>(684, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 149),
        // property 'isBand7SoloImmutable'
        QtMocHelpers::PropertyData<bool>(685, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7SoloValue'
        QtMocHelpers::PropertyData<bool>(686, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0Mute'
        QtMocHelpers::PropertyData<bool>(687, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 150),
        // property 'isBand0MuteImmutable'
        QtMocHelpers::PropertyData<bool>(688, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0MuteValue'
        QtMocHelpers::PropertyData<bool>(689, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1Mute'
        QtMocHelpers::PropertyData<bool>(690, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 151),
        // property 'isBand1MuteImmutable'
        QtMocHelpers::PropertyData<bool>(691, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1MuteValue'
        QtMocHelpers::PropertyData<bool>(692, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2Mute'
        QtMocHelpers::PropertyData<bool>(693, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 152),
        // property 'isBand2MuteImmutable'
        QtMocHelpers::PropertyData<bool>(694, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2MuteValue'
        QtMocHelpers::PropertyData<bool>(695, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3Mute'
        QtMocHelpers::PropertyData<bool>(696, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 153),
        // property 'isBand3MuteImmutable'
        QtMocHelpers::PropertyData<bool>(697, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3MuteValue'
        QtMocHelpers::PropertyData<bool>(698, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4Mute'
        QtMocHelpers::PropertyData<bool>(699, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 154),
        // property 'isBand4MuteImmutable'
        QtMocHelpers::PropertyData<bool>(700, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4MuteValue'
        QtMocHelpers::PropertyData<bool>(701, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5Mute'
        QtMocHelpers::PropertyData<bool>(702, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 155),
        // property 'isBand5MuteImmutable'
        QtMocHelpers::PropertyData<bool>(703, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5MuteValue'
        QtMocHelpers::PropertyData<bool>(704, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6Mute'
        QtMocHelpers::PropertyData<bool>(705, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 156),
        // property 'isBand6MuteImmutable'
        QtMocHelpers::PropertyData<bool>(706, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6MuteValue'
        QtMocHelpers::PropertyData<bool>(707, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7Mute'
        QtMocHelpers::PropertyData<bool>(708, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 157),
        // property 'isBand7MuteImmutable'
        QtMocHelpers::PropertyData<bool>(709, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7MuteValue'
        QtMocHelpers::PropertyData<bool>(710, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0AttackThreshold'
        QtMocHelpers::PropertyData<double>(711, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 158),
        // property 'isBand0AttackThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(712, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0AttackThresholdValue'
        QtMocHelpers::PropertyData<double>(713, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1AttackThreshold'
        QtMocHelpers::PropertyData<double>(714, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 159),
        // property 'isBand1AttackThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(715, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1AttackThresholdValue'
        QtMocHelpers::PropertyData<double>(716, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2AttackThreshold'
        QtMocHelpers::PropertyData<double>(717, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 160),
        // property 'isBand2AttackThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(718, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2AttackThresholdValue'
        QtMocHelpers::PropertyData<double>(719, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3AttackThreshold'
        QtMocHelpers::PropertyData<double>(720, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 161),
        // property 'isBand3AttackThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(721, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3AttackThresholdValue'
        QtMocHelpers::PropertyData<double>(722, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4AttackThreshold'
        QtMocHelpers::PropertyData<double>(723, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 162),
        // property 'isBand4AttackThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(724, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4AttackThresholdValue'
        QtMocHelpers::PropertyData<double>(725, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5AttackThreshold'
        QtMocHelpers::PropertyData<double>(726, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 163),
        // property 'isBand5AttackThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(727, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5AttackThresholdValue'
        QtMocHelpers::PropertyData<double>(728, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6AttackThreshold'
        QtMocHelpers::PropertyData<double>(729, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 164),
        // property 'isBand6AttackThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(730, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6AttackThresholdValue'
        QtMocHelpers::PropertyData<double>(731, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7AttackThreshold'
        QtMocHelpers::PropertyData<double>(732, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 165),
        // property 'isBand7AttackThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(733, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7AttackThresholdValue'
        QtMocHelpers::PropertyData<double>(734, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0AttackTime'
        QtMocHelpers::PropertyData<double>(735, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 166),
        // property 'isBand0AttackTimeImmutable'
        QtMocHelpers::PropertyData<bool>(736, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0AttackTimeValue'
        QtMocHelpers::PropertyData<double>(737, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1AttackTime'
        QtMocHelpers::PropertyData<double>(738, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 167),
        // property 'isBand1AttackTimeImmutable'
        QtMocHelpers::PropertyData<bool>(739, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1AttackTimeValue'
        QtMocHelpers::PropertyData<double>(740, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2AttackTime'
        QtMocHelpers::PropertyData<double>(741, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 168),
        // property 'isBand2AttackTimeImmutable'
        QtMocHelpers::PropertyData<bool>(742, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2AttackTimeValue'
        QtMocHelpers::PropertyData<double>(743, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3AttackTime'
        QtMocHelpers::PropertyData<double>(744, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 169),
        // property 'isBand3AttackTimeImmutable'
        QtMocHelpers::PropertyData<bool>(745, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3AttackTimeValue'
        QtMocHelpers::PropertyData<double>(746, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4AttackTime'
        QtMocHelpers::PropertyData<double>(747, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 170),
        // property 'isBand4AttackTimeImmutable'
        QtMocHelpers::PropertyData<bool>(748, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4AttackTimeValue'
        QtMocHelpers::PropertyData<double>(749, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5AttackTime'
        QtMocHelpers::PropertyData<double>(750, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 171),
        // property 'isBand5AttackTimeImmutable'
        QtMocHelpers::PropertyData<bool>(751, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5AttackTimeValue'
        QtMocHelpers::PropertyData<double>(752, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6AttackTime'
        QtMocHelpers::PropertyData<double>(753, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 172),
        // property 'isBand6AttackTimeImmutable'
        QtMocHelpers::PropertyData<bool>(754, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6AttackTimeValue'
        QtMocHelpers::PropertyData<double>(755, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7AttackTime'
        QtMocHelpers::PropertyData<double>(756, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 173),
        // property 'isBand7AttackTimeImmutable'
        QtMocHelpers::PropertyData<bool>(757, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7AttackTimeValue'
        QtMocHelpers::PropertyData<double>(758, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0ReleaseThreshold'
        QtMocHelpers::PropertyData<double>(759, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 174),
        // property 'isBand0ReleaseThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(760, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0ReleaseThresholdValue'
        QtMocHelpers::PropertyData<double>(761, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1ReleaseThreshold'
        QtMocHelpers::PropertyData<double>(762, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 175),
        // property 'isBand1ReleaseThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(763, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1ReleaseThresholdValue'
        QtMocHelpers::PropertyData<double>(764, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2ReleaseThreshold'
        QtMocHelpers::PropertyData<double>(765, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 176),
        // property 'isBand2ReleaseThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(766, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2ReleaseThresholdValue'
        QtMocHelpers::PropertyData<double>(767, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3ReleaseThreshold'
        QtMocHelpers::PropertyData<double>(768, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 177),
        // property 'isBand3ReleaseThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(769, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3ReleaseThresholdValue'
        QtMocHelpers::PropertyData<double>(770, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4ReleaseThreshold'
        QtMocHelpers::PropertyData<double>(771, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 178),
        // property 'isBand4ReleaseThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(772, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4ReleaseThresholdValue'
        QtMocHelpers::PropertyData<double>(773, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5ReleaseThreshold'
        QtMocHelpers::PropertyData<double>(774, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 179),
        // property 'isBand5ReleaseThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(775, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5ReleaseThresholdValue'
        QtMocHelpers::PropertyData<double>(776, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6ReleaseThreshold'
        QtMocHelpers::PropertyData<double>(777, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 180),
        // property 'isBand6ReleaseThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(778, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6ReleaseThresholdValue'
        QtMocHelpers::PropertyData<double>(779, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7ReleaseThreshold'
        QtMocHelpers::PropertyData<double>(780, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 181),
        // property 'isBand7ReleaseThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(781, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7ReleaseThresholdValue'
        QtMocHelpers::PropertyData<double>(782, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0ReleaseTime'
        QtMocHelpers::PropertyData<double>(783, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 182),
        // property 'isBand0ReleaseTimeImmutable'
        QtMocHelpers::PropertyData<bool>(784, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0ReleaseTimeValue'
        QtMocHelpers::PropertyData<double>(785, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1ReleaseTime'
        QtMocHelpers::PropertyData<double>(786, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 183),
        // property 'isBand1ReleaseTimeImmutable'
        QtMocHelpers::PropertyData<bool>(787, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1ReleaseTimeValue'
        QtMocHelpers::PropertyData<double>(788, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2ReleaseTime'
        QtMocHelpers::PropertyData<double>(789, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 184),
        // property 'isBand2ReleaseTimeImmutable'
        QtMocHelpers::PropertyData<bool>(790, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2ReleaseTimeValue'
        QtMocHelpers::PropertyData<double>(791, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3ReleaseTime'
        QtMocHelpers::PropertyData<double>(792, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 185),
        // property 'isBand3ReleaseTimeImmutable'
        QtMocHelpers::PropertyData<bool>(793, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3ReleaseTimeValue'
        QtMocHelpers::PropertyData<double>(794, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4ReleaseTime'
        QtMocHelpers::PropertyData<double>(795, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 186),
        // property 'isBand4ReleaseTimeImmutable'
        QtMocHelpers::PropertyData<bool>(796, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4ReleaseTimeValue'
        QtMocHelpers::PropertyData<double>(797, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5ReleaseTime'
        QtMocHelpers::PropertyData<double>(798, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 187),
        // property 'isBand5ReleaseTimeImmutable'
        QtMocHelpers::PropertyData<bool>(799, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5ReleaseTimeValue'
        QtMocHelpers::PropertyData<double>(800, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6ReleaseTime'
        QtMocHelpers::PropertyData<double>(801, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 188),
        // property 'isBand6ReleaseTimeImmutable'
        QtMocHelpers::PropertyData<bool>(802, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6ReleaseTimeValue'
        QtMocHelpers::PropertyData<double>(803, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7ReleaseTime'
        QtMocHelpers::PropertyData<double>(804, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 189),
        // property 'isBand7ReleaseTimeImmutable'
        QtMocHelpers::PropertyData<bool>(805, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7ReleaseTimeValue'
        QtMocHelpers::PropertyData<double>(806, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0Ratio'
        QtMocHelpers::PropertyData<double>(807, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 190),
        // property 'isBand0RatioImmutable'
        QtMocHelpers::PropertyData<bool>(808, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0RatioValue'
        QtMocHelpers::PropertyData<double>(809, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1Ratio'
        QtMocHelpers::PropertyData<double>(810, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 191),
        // property 'isBand1RatioImmutable'
        QtMocHelpers::PropertyData<bool>(811, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1RatioValue'
        QtMocHelpers::PropertyData<double>(812, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2Ratio'
        QtMocHelpers::PropertyData<double>(813, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 192),
        // property 'isBand2RatioImmutable'
        QtMocHelpers::PropertyData<bool>(814, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2RatioValue'
        QtMocHelpers::PropertyData<double>(815, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3Ratio'
        QtMocHelpers::PropertyData<double>(816, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 193),
        // property 'isBand3RatioImmutable'
        QtMocHelpers::PropertyData<bool>(817, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3RatioValue'
        QtMocHelpers::PropertyData<double>(818, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4Ratio'
        QtMocHelpers::PropertyData<double>(819, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 194),
        // property 'isBand4RatioImmutable'
        QtMocHelpers::PropertyData<bool>(820, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4RatioValue'
        QtMocHelpers::PropertyData<double>(821, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5Ratio'
        QtMocHelpers::PropertyData<double>(822, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 195),
        // property 'isBand5RatioImmutable'
        QtMocHelpers::PropertyData<bool>(823, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5RatioValue'
        QtMocHelpers::PropertyData<double>(824, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6Ratio'
        QtMocHelpers::PropertyData<double>(825, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 196),
        // property 'isBand6RatioImmutable'
        QtMocHelpers::PropertyData<bool>(826, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6RatioValue'
        QtMocHelpers::PropertyData<double>(827, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7Ratio'
        QtMocHelpers::PropertyData<double>(828, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 197),
        // property 'isBand7RatioImmutable'
        QtMocHelpers::PropertyData<bool>(829, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7RatioValue'
        QtMocHelpers::PropertyData<double>(830, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0Knee'
        QtMocHelpers::PropertyData<double>(831, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 198),
        // property 'isBand0KneeImmutable'
        QtMocHelpers::PropertyData<bool>(832, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0KneeValue'
        QtMocHelpers::PropertyData<double>(833, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1Knee'
        QtMocHelpers::PropertyData<double>(834, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 199),
        // property 'isBand1KneeImmutable'
        QtMocHelpers::PropertyData<bool>(835, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1KneeValue'
        QtMocHelpers::PropertyData<double>(836, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2Knee'
        QtMocHelpers::PropertyData<double>(837, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 200),
        // property 'isBand2KneeImmutable'
        QtMocHelpers::PropertyData<bool>(838, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2KneeValue'
        QtMocHelpers::PropertyData<double>(839, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3Knee'
        QtMocHelpers::PropertyData<double>(840, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 201),
        // property 'isBand3KneeImmutable'
        QtMocHelpers::PropertyData<bool>(841, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3KneeValue'
        QtMocHelpers::PropertyData<double>(842, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4Knee'
        QtMocHelpers::PropertyData<double>(843, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 202),
        // property 'isBand4KneeImmutable'
        QtMocHelpers::PropertyData<bool>(844, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4KneeValue'
        QtMocHelpers::PropertyData<double>(845, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5Knee'
        QtMocHelpers::PropertyData<double>(846, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 203),
        // property 'isBand5KneeImmutable'
        QtMocHelpers::PropertyData<bool>(847, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5KneeValue'
        QtMocHelpers::PropertyData<double>(848, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6Knee'
        QtMocHelpers::PropertyData<double>(849, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 204),
        // property 'isBand6KneeImmutable'
        QtMocHelpers::PropertyData<bool>(850, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6KneeValue'
        QtMocHelpers::PropertyData<double>(851, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7Knee'
        QtMocHelpers::PropertyData<double>(852, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 205),
        // property 'isBand7KneeImmutable'
        QtMocHelpers::PropertyData<bool>(853, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7KneeValue'
        QtMocHelpers::PropertyData<double>(854, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0BoostThreshold'
        QtMocHelpers::PropertyData<double>(855, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 206),
        // property 'isBand0BoostThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(856, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0BoostThresholdValue'
        QtMocHelpers::PropertyData<double>(857, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1BoostThreshold'
        QtMocHelpers::PropertyData<double>(858, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 207),
        // property 'isBand1BoostThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(859, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1BoostThresholdValue'
        QtMocHelpers::PropertyData<double>(860, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2BoostThreshold'
        QtMocHelpers::PropertyData<double>(861, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 208),
        // property 'isBand2BoostThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(862, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2BoostThresholdValue'
        QtMocHelpers::PropertyData<double>(863, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3BoostThreshold'
        QtMocHelpers::PropertyData<double>(864, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 209),
        // property 'isBand3BoostThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(865, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3BoostThresholdValue'
        QtMocHelpers::PropertyData<double>(866, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4BoostThreshold'
        QtMocHelpers::PropertyData<double>(867, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 210),
        // property 'isBand4BoostThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(868, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4BoostThresholdValue'
        QtMocHelpers::PropertyData<double>(869, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5BoostThreshold'
        QtMocHelpers::PropertyData<double>(870, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 211),
        // property 'isBand5BoostThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(871, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5BoostThresholdValue'
        QtMocHelpers::PropertyData<double>(872, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6BoostThreshold'
        QtMocHelpers::PropertyData<double>(873, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 212),
        // property 'isBand6BoostThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(874, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6BoostThresholdValue'
        QtMocHelpers::PropertyData<double>(875, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7BoostThreshold'
        QtMocHelpers::PropertyData<double>(876, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 213),
        // property 'isBand7BoostThresholdImmutable'
        QtMocHelpers::PropertyData<bool>(877, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7BoostThresholdValue'
        QtMocHelpers::PropertyData<double>(878, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0BoostAmount'
        QtMocHelpers::PropertyData<double>(879, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 214),
        // property 'isBand0BoostAmountImmutable'
        QtMocHelpers::PropertyData<bool>(880, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0BoostAmountValue'
        QtMocHelpers::PropertyData<double>(881, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1BoostAmount'
        QtMocHelpers::PropertyData<double>(882, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 215),
        // property 'isBand1BoostAmountImmutable'
        QtMocHelpers::PropertyData<bool>(883, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1BoostAmountValue'
        QtMocHelpers::PropertyData<double>(884, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2BoostAmount'
        QtMocHelpers::PropertyData<double>(885, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 216),
        // property 'isBand2BoostAmountImmutable'
        QtMocHelpers::PropertyData<bool>(886, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2BoostAmountValue'
        QtMocHelpers::PropertyData<double>(887, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3BoostAmount'
        QtMocHelpers::PropertyData<double>(888, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 217),
        // property 'isBand3BoostAmountImmutable'
        QtMocHelpers::PropertyData<bool>(889, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3BoostAmountValue'
        QtMocHelpers::PropertyData<double>(890, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4BoostAmount'
        QtMocHelpers::PropertyData<double>(891, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 218),
        // property 'isBand4BoostAmountImmutable'
        QtMocHelpers::PropertyData<bool>(892, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4BoostAmountValue'
        QtMocHelpers::PropertyData<double>(893, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5BoostAmount'
        QtMocHelpers::PropertyData<double>(894, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 219),
        // property 'isBand5BoostAmountImmutable'
        QtMocHelpers::PropertyData<bool>(895, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5BoostAmountValue'
        QtMocHelpers::PropertyData<double>(896, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6BoostAmount'
        QtMocHelpers::PropertyData<double>(897, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 220),
        // property 'isBand6BoostAmountImmutable'
        QtMocHelpers::PropertyData<bool>(898, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6BoostAmountValue'
        QtMocHelpers::PropertyData<double>(899, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7BoostAmount'
        QtMocHelpers::PropertyData<double>(900, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 221),
        // property 'isBand7BoostAmountImmutable'
        QtMocHelpers::PropertyData<bool>(901, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7BoostAmountValue'
        QtMocHelpers::PropertyData<double>(902, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band0Makeup'
        QtMocHelpers::PropertyData<double>(903, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 222),
        // property 'isBand0MakeupImmutable'
        QtMocHelpers::PropertyData<bool>(904, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand0MakeupValue'
        QtMocHelpers::PropertyData<double>(905, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band1Makeup'
        QtMocHelpers::PropertyData<double>(906, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 223),
        // property 'isBand1MakeupImmutable'
        QtMocHelpers::PropertyData<bool>(907, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand1MakeupValue'
        QtMocHelpers::PropertyData<double>(908, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band2Makeup'
        QtMocHelpers::PropertyData<double>(909, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 224),
        // property 'isBand2MakeupImmutable'
        QtMocHelpers::PropertyData<bool>(910, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand2MakeupValue'
        QtMocHelpers::PropertyData<double>(911, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band3Makeup'
        QtMocHelpers::PropertyData<double>(912, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 225),
        // property 'isBand3MakeupImmutable'
        QtMocHelpers::PropertyData<bool>(913, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand3MakeupValue'
        QtMocHelpers::PropertyData<double>(914, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band4Makeup'
        QtMocHelpers::PropertyData<double>(915, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 226),
        // property 'isBand4MakeupImmutable'
        QtMocHelpers::PropertyData<bool>(916, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand4MakeupValue'
        QtMocHelpers::PropertyData<double>(917, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band5Makeup'
        QtMocHelpers::PropertyData<double>(918, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 227),
        // property 'isBand5MakeupImmutable'
        QtMocHelpers::PropertyData<bool>(919, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand5MakeupValue'
        QtMocHelpers::PropertyData<double>(920, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band6Makeup'
        QtMocHelpers::PropertyData<double>(921, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 228),
        // property 'isBand6MakeupImmutable'
        QtMocHelpers::PropertyData<bool>(922, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand6MakeupValue'
        QtMocHelpers::PropertyData<double>(923, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'band7Makeup'
        QtMocHelpers::PropertyData<double>(924, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 229),
        // property 'isBand7MakeupImmutable'
        QtMocHelpers::PropertyData<bool>(925, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBand7MakeupValue'
        QtMocHelpers::PropertyData<double>(926, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DbMultibandCompressor, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DbMultibandCompressor::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigBaseEE::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21DbMultibandCompressorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21DbMultibandCompressorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21DbMultibandCompressorE_t>.metaTypes,
    nullptr
} };

void DbMultibandCompressor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DbMultibandCompressor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bypassChanged(); break;
        case 1: _t->inputGainChanged(); break;
        case 2: _t->outputGainChanged(); break;
        case 3: _t->dryChanged(); break;
        case 4: _t->wetChanged(); break;
        case 5: _t->viewSidechainChanged(); break;
        case 6: _t->externalSidechainEnabledChanged(); break;
        case 7: _t->stereoSplitChanged(); break;
        case 8: _t->compressorModeLabelsChanged(); break;
        case 9: _t->compressorModeChanged(); break;
        case 10: _t->envelopeBoostLabelsChanged(); break;
        case 11: _t->envelopeBoostChanged(); break;
        case 12: _t->inputToSidechainChanged(); break;
        case 13: _t->inputToLinkChanged(); break;
        case 14: _t->sidechainToInputChanged(); break;
        case 15: _t->sidechainToLinkChanged(); break;
        case 16: _t->linkToSidechainChanged(); break;
        case 17: _t->linkToInputChanged(); break;
        case 18: _t->band1EnableChanged(); break;
        case 19: _t->band2EnableChanged(); break;
        case 20: _t->band3EnableChanged(); break;
        case 21: _t->band4EnableChanged(); break;
        case 22: _t->band5EnableChanged(); break;
        case 23: _t->band6EnableChanged(); break;
        case 24: _t->band7EnableChanged(); break;
        case 25: _t->band1SplitFrequencyChanged(); break;
        case 26: _t->band2SplitFrequencyChanged(); break;
        case 27: _t->band3SplitFrequencyChanged(); break;
        case 28: _t->band4SplitFrequencyChanged(); break;
        case 29: _t->band5SplitFrequencyChanged(); break;
        case 30: _t->band6SplitFrequencyChanged(); break;
        case 31: _t->band7SplitFrequencyChanged(); break;
        case 32: _t->sidechainInputDeviceChanged(); break;
        case 33: _t->sidechainTypeLabelsChanged(); break;
        case 34: _t->band0SidechainTypeChanged(); break;
        case 35: _t->band1SidechainTypeChanged(); break;
        case 36: _t->band2SidechainTypeChanged(); break;
        case 37: _t->band3SidechainTypeChanged(); break;
        case 38: _t->band4SidechainTypeChanged(); break;
        case 39: _t->band5SidechainTypeChanged(); break;
        case 40: _t->band6SidechainTypeChanged(); break;
        case 41: _t->band7SidechainTypeChanged(); break;
        case 42: _t->sidechainModeLabelsChanged(); break;
        case 43: _t->band0SidechainModeChanged(); break;
        case 44: _t->band1SidechainModeChanged(); break;
        case 45: _t->band2SidechainModeChanged(); break;
        case 46: _t->band3SidechainModeChanged(); break;
        case 47: _t->band4SidechainModeChanged(); break;
        case 48: _t->band5SidechainModeChanged(); break;
        case 49: _t->band6SidechainModeChanged(); break;
        case 50: _t->band7SidechainModeChanged(); break;
        case 51: _t->sidechainSourceLabelsChanged(); break;
        case 52: _t->band0SidechainSourceChanged(); break;
        case 53: _t->band1SidechainSourceChanged(); break;
        case 54: _t->band2SidechainSourceChanged(); break;
        case 55: _t->band3SidechainSourceChanged(); break;
        case 56: _t->band4SidechainSourceChanged(); break;
        case 57: _t->band5SidechainSourceChanged(); break;
        case 58: _t->band6SidechainSourceChanged(); break;
        case 59: _t->band7SidechainSourceChanged(); break;
        case 60: _t->stereoSplitSourceLabelsChanged(); break;
        case 61: _t->band0StereoSplitSourceChanged(); break;
        case 62: _t->band1StereoSplitSourceChanged(); break;
        case 63: _t->band2StereoSplitSourceChanged(); break;
        case 64: _t->band3StereoSplitSourceChanged(); break;
        case 65: _t->band4StereoSplitSourceChanged(); break;
        case 66: _t->band5StereoSplitSourceChanged(); break;
        case 67: _t->band6StereoSplitSourceChanged(); break;
        case 68: _t->band7StereoSplitSourceChanged(); break;
        case 69: _t->band0SidechainLookaheadChanged(); break;
        case 70: _t->band1SidechainLookaheadChanged(); break;
        case 71: _t->band2SidechainLookaheadChanged(); break;
        case 72: _t->band3SidechainLookaheadChanged(); break;
        case 73: _t->band4SidechainLookaheadChanged(); break;
        case 74: _t->band5SidechainLookaheadChanged(); break;
        case 75: _t->band6SidechainLookaheadChanged(); break;
        case 76: _t->band7SidechainLookaheadChanged(); break;
        case 77: _t->band0SidechainReactivityChanged(); break;
        case 78: _t->band1SidechainReactivityChanged(); break;
        case 79: _t->band2SidechainReactivityChanged(); break;
        case 80: _t->band3SidechainReactivityChanged(); break;
        case 81: _t->band4SidechainReactivityChanged(); break;
        case 82: _t->band5SidechainReactivityChanged(); break;
        case 83: _t->band6SidechainReactivityChanged(); break;
        case 84: _t->band7SidechainReactivityChanged(); break;
        case 85: _t->band0SidechainPreampChanged(); break;
        case 86: _t->band1SidechainPreampChanged(); break;
        case 87: _t->band2SidechainPreampChanged(); break;
        case 88: _t->band3SidechainPreampChanged(); break;
        case 89: _t->band4SidechainPreampChanged(); break;
        case 90: _t->band5SidechainPreampChanged(); break;
        case 91: _t->band6SidechainPreampChanged(); break;
        case 92: _t->band7SidechainPreampChanged(); break;
        case 93: _t->band0SidechainCustomLowcutFilterChanged(); break;
        case 94: _t->band1SidechainCustomLowcutFilterChanged(); break;
        case 95: _t->band2SidechainCustomLowcutFilterChanged(); break;
        case 96: _t->band3SidechainCustomLowcutFilterChanged(); break;
        case 97: _t->band4SidechainCustomLowcutFilterChanged(); break;
        case 98: _t->band5SidechainCustomLowcutFilterChanged(); break;
        case 99: _t->band6SidechainCustomLowcutFilterChanged(); break;
        case 100: _t->band7SidechainCustomLowcutFilterChanged(); break;
        case 101: _t->band0SidechainCustomHighcutFilterChanged(); break;
        case 102: _t->band1SidechainCustomHighcutFilterChanged(); break;
        case 103: _t->band2SidechainCustomHighcutFilterChanged(); break;
        case 104: _t->band3SidechainCustomHighcutFilterChanged(); break;
        case 105: _t->band4SidechainCustomHighcutFilterChanged(); break;
        case 106: _t->band5SidechainCustomHighcutFilterChanged(); break;
        case 107: _t->band6SidechainCustomHighcutFilterChanged(); break;
        case 108: _t->band7SidechainCustomHighcutFilterChanged(); break;
        case 109: _t->band0SidechainLowcutFrequencyChanged(); break;
        case 110: _t->band1SidechainLowcutFrequencyChanged(); break;
        case 111: _t->band2SidechainLowcutFrequencyChanged(); break;
        case 112: _t->band3SidechainLowcutFrequencyChanged(); break;
        case 113: _t->band4SidechainLowcutFrequencyChanged(); break;
        case 114: _t->band5SidechainLowcutFrequencyChanged(); break;
        case 115: _t->band6SidechainLowcutFrequencyChanged(); break;
        case 116: _t->band7SidechainLowcutFrequencyChanged(); break;
        case 117: _t->band0SidechainHighcutFrequencyChanged(); break;
        case 118: _t->band1SidechainHighcutFrequencyChanged(); break;
        case 119: _t->band2SidechainHighcutFrequencyChanged(); break;
        case 120: _t->band3SidechainHighcutFrequencyChanged(); break;
        case 121: _t->band4SidechainHighcutFrequencyChanged(); break;
        case 122: _t->band5SidechainHighcutFrequencyChanged(); break;
        case 123: _t->band6SidechainHighcutFrequencyChanged(); break;
        case 124: _t->band7SidechainHighcutFrequencyChanged(); break;
        case 125: _t->compressionModeLabelsChanged(); break;
        case 126: _t->band0CompressionModeChanged(); break;
        case 127: _t->band1CompressionModeChanged(); break;
        case 128: _t->band2CompressionModeChanged(); break;
        case 129: _t->band3CompressionModeChanged(); break;
        case 130: _t->band4CompressionModeChanged(); break;
        case 131: _t->band5CompressionModeChanged(); break;
        case 132: _t->band6CompressionModeChanged(); break;
        case 133: _t->band7CompressionModeChanged(); break;
        case 134: _t->band0CompressorEnableChanged(); break;
        case 135: _t->band1CompressorEnableChanged(); break;
        case 136: _t->band2CompressorEnableChanged(); break;
        case 137: _t->band3CompressorEnableChanged(); break;
        case 138: _t->band4CompressorEnableChanged(); break;
        case 139: _t->band5CompressorEnableChanged(); break;
        case 140: _t->band6CompressorEnableChanged(); break;
        case 141: _t->band7CompressorEnableChanged(); break;
        case 142: _t->band0SoloChanged(); break;
        case 143: _t->band1SoloChanged(); break;
        case 144: _t->band2SoloChanged(); break;
        case 145: _t->band3SoloChanged(); break;
        case 146: _t->band4SoloChanged(); break;
        case 147: _t->band5SoloChanged(); break;
        case 148: _t->band6SoloChanged(); break;
        case 149: _t->band7SoloChanged(); break;
        case 150: _t->band0MuteChanged(); break;
        case 151: _t->band1MuteChanged(); break;
        case 152: _t->band2MuteChanged(); break;
        case 153: _t->band3MuteChanged(); break;
        case 154: _t->band4MuteChanged(); break;
        case 155: _t->band5MuteChanged(); break;
        case 156: _t->band6MuteChanged(); break;
        case 157: _t->band7MuteChanged(); break;
        case 158: _t->band0AttackThresholdChanged(); break;
        case 159: _t->band1AttackThresholdChanged(); break;
        case 160: _t->band2AttackThresholdChanged(); break;
        case 161: _t->band3AttackThresholdChanged(); break;
        case 162: _t->band4AttackThresholdChanged(); break;
        case 163: _t->band5AttackThresholdChanged(); break;
        case 164: _t->band6AttackThresholdChanged(); break;
        case 165: _t->band7AttackThresholdChanged(); break;
        case 166: _t->band0AttackTimeChanged(); break;
        case 167: _t->band1AttackTimeChanged(); break;
        case 168: _t->band2AttackTimeChanged(); break;
        case 169: _t->band3AttackTimeChanged(); break;
        case 170: _t->band4AttackTimeChanged(); break;
        case 171: _t->band5AttackTimeChanged(); break;
        case 172: _t->band6AttackTimeChanged(); break;
        case 173: _t->band7AttackTimeChanged(); break;
        case 174: _t->band0ReleaseThresholdChanged(); break;
        case 175: _t->band1ReleaseThresholdChanged(); break;
        case 176: _t->band2ReleaseThresholdChanged(); break;
        case 177: _t->band3ReleaseThresholdChanged(); break;
        case 178: _t->band4ReleaseThresholdChanged(); break;
        case 179: _t->band5ReleaseThresholdChanged(); break;
        case 180: _t->band6ReleaseThresholdChanged(); break;
        case 181: _t->band7ReleaseThresholdChanged(); break;
        case 182: _t->band0ReleaseTimeChanged(); break;
        case 183: _t->band1ReleaseTimeChanged(); break;
        case 184: _t->band2ReleaseTimeChanged(); break;
        case 185: _t->band3ReleaseTimeChanged(); break;
        case 186: _t->band4ReleaseTimeChanged(); break;
        case 187: _t->band5ReleaseTimeChanged(); break;
        case 188: _t->band6ReleaseTimeChanged(); break;
        case 189: _t->band7ReleaseTimeChanged(); break;
        case 190: _t->band0RatioChanged(); break;
        case 191: _t->band1RatioChanged(); break;
        case 192: _t->band2RatioChanged(); break;
        case 193: _t->band3RatioChanged(); break;
        case 194: _t->band4RatioChanged(); break;
        case 195: _t->band5RatioChanged(); break;
        case 196: _t->band6RatioChanged(); break;
        case 197: _t->band7RatioChanged(); break;
        case 198: _t->band0KneeChanged(); break;
        case 199: _t->band1KneeChanged(); break;
        case 200: _t->band2KneeChanged(); break;
        case 201: _t->band3KneeChanged(); break;
        case 202: _t->band4KneeChanged(); break;
        case 203: _t->band5KneeChanged(); break;
        case 204: _t->band6KneeChanged(); break;
        case 205: _t->band7KneeChanged(); break;
        case 206: _t->band0BoostThresholdChanged(); break;
        case 207: _t->band1BoostThresholdChanged(); break;
        case 208: _t->band2BoostThresholdChanged(); break;
        case 209: _t->band3BoostThresholdChanged(); break;
        case 210: _t->band4BoostThresholdChanged(); break;
        case 211: _t->band5BoostThresholdChanged(); break;
        case 212: _t->band6BoostThresholdChanged(); break;
        case 213: _t->band7BoostThresholdChanged(); break;
        case 214: _t->band0BoostAmountChanged(); break;
        case 215: _t->band1BoostAmountChanged(); break;
        case 216: _t->band2BoostAmountChanged(); break;
        case 217: _t->band3BoostAmountChanged(); break;
        case 218: _t->band4BoostAmountChanged(); break;
        case 219: _t->band5BoostAmountChanged(); break;
        case 220: _t->band6BoostAmountChanged(); break;
        case 221: _t->band7BoostAmountChanged(); break;
        case 222: _t->band0MakeupChanged(); break;
        case 223: _t->band1MakeupChanged(); break;
        case 224: _t->band2MakeupChanged(); break;
        case 225: _t->band3MakeupChanged(); break;
        case 226: _t->band4MakeupChanged(); break;
        case 227: _t->band5MakeupChanged(); break;
        case 228: _t->band6MakeupChanged(); break;
        case 229: _t->band7MakeupChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::bypassChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::inputGainChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::outputGainChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::dryChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::wetChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::viewSidechainChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::externalSidechainEnabledChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::stereoSplitChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::compressorModeLabelsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::compressorModeChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::envelopeBoostLabelsChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::envelopeBoostChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::inputToSidechainChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::inputToLinkChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::sidechainToInputChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::sidechainToLinkChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::linkToSidechainChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::linkToInputChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1EnableChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2EnableChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3EnableChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4EnableChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5EnableChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6EnableChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7EnableChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1SplitFrequencyChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2SplitFrequencyChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3SplitFrequencyChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4SplitFrequencyChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5SplitFrequencyChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6SplitFrequencyChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7SplitFrequencyChanged, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::sidechainInputDeviceChanged, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::sidechainTypeLabelsChanged, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0SidechainTypeChanged, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1SidechainTypeChanged, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2SidechainTypeChanged, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3SidechainTypeChanged, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4SidechainTypeChanged, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5SidechainTypeChanged, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6SidechainTypeChanged, 40))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7SidechainTypeChanged, 41))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::sidechainModeLabelsChanged, 42))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0SidechainModeChanged, 43))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1SidechainModeChanged, 44))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2SidechainModeChanged, 45))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3SidechainModeChanged, 46))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4SidechainModeChanged, 47))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5SidechainModeChanged, 48))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6SidechainModeChanged, 49))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7SidechainModeChanged, 50))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::sidechainSourceLabelsChanged, 51))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0SidechainSourceChanged, 52))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1SidechainSourceChanged, 53))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2SidechainSourceChanged, 54))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3SidechainSourceChanged, 55))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4SidechainSourceChanged, 56))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5SidechainSourceChanged, 57))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6SidechainSourceChanged, 58))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7SidechainSourceChanged, 59))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::stereoSplitSourceLabelsChanged, 60))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0StereoSplitSourceChanged, 61))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1StereoSplitSourceChanged, 62))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2StereoSplitSourceChanged, 63))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3StereoSplitSourceChanged, 64))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4StereoSplitSourceChanged, 65))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5StereoSplitSourceChanged, 66))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6StereoSplitSourceChanged, 67))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7StereoSplitSourceChanged, 68))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0SidechainLookaheadChanged, 69))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1SidechainLookaheadChanged, 70))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2SidechainLookaheadChanged, 71))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3SidechainLookaheadChanged, 72))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4SidechainLookaheadChanged, 73))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5SidechainLookaheadChanged, 74))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6SidechainLookaheadChanged, 75))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7SidechainLookaheadChanged, 76))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0SidechainReactivityChanged, 77))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1SidechainReactivityChanged, 78))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2SidechainReactivityChanged, 79))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3SidechainReactivityChanged, 80))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4SidechainReactivityChanged, 81))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5SidechainReactivityChanged, 82))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6SidechainReactivityChanged, 83))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7SidechainReactivityChanged, 84))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0SidechainPreampChanged, 85))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1SidechainPreampChanged, 86))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2SidechainPreampChanged, 87))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3SidechainPreampChanged, 88))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4SidechainPreampChanged, 89))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5SidechainPreampChanged, 90))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6SidechainPreampChanged, 91))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7SidechainPreampChanged, 92))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0SidechainCustomLowcutFilterChanged, 93))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1SidechainCustomLowcutFilterChanged, 94))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2SidechainCustomLowcutFilterChanged, 95))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3SidechainCustomLowcutFilterChanged, 96))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4SidechainCustomLowcutFilterChanged, 97))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5SidechainCustomLowcutFilterChanged, 98))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6SidechainCustomLowcutFilterChanged, 99))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7SidechainCustomLowcutFilterChanged, 100))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0SidechainCustomHighcutFilterChanged, 101))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1SidechainCustomHighcutFilterChanged, 102))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2SidechainCustomHighcutFilterChanged, 103))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3SidechainCustomHighcutFilterChanged, 104))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4SidechainCustomHighcutFilterChanged, 105))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5SidechainCustomHighcutFilterChanged, 106))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6SidechainCustomHighcutFilterChanged, 107))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7SidechainCustomHighcutFilterChanged, 108))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0SidechainLowcutFrequencyChanged, 109))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1SidechainLowcutFrequencyChanged, 110))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2SidechainLowcutFrequencyChanged, 111))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3SidechainLowcutFrequencyChanged, 112))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4SidechainLowcutFrequencyChanged, 113))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5SidechainLowcutFrequencyChanged, 114))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6SidechainLowcutFrequencyChanged, 115))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7SidechainLowcutFrequencyChanged, 116))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0SidechainHighcutFrequencyChanged, 117))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1SidechainHighcutFrequencyChanged, 118))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2SidechainHighcutFrequencyChanged, 119))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3SidechainHighcutFrequencyChanged, 120))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4SidechainHighcutFrequencyChanged, 121))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5SidechainHighcutFrequencyChanged, 122))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6SidechainHighcutFrequencyChanged, 123))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7SidechainHighcutFrequencyChanged, 124))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::compressionModeLabelsChanged, 125))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0CompressionModeChanged, 126))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1CompressionModeChanged, 127))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2CompressionModeChanged, 128))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3CompressionModeChanged, 129))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4CompressionModeChanged, 130))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5CompressionModeChanged, 131))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6CompressionModeChanged, 132))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7CompressionModeChanged, 133))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0CompressorEnableChanged, 134))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1CompressorEnableChanged, 135))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2CompressorEnableChanged, 136))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3CompressorEnableChanged, 137))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4CompressorEnableChanged, 138))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5CompressorEnableChanged, 139))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6CompressorEnableChanged, 140))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7CompressorEnableChanged, 141))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0SoloChanged, 142))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1SoloChanged, 143))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2SoloChanged, 144))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3SoloChanged, 145))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4SoloChanged, 146))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5SoloChanged, 147))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6SoloChanged, 148))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7SoloChanged, 149))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0MuteChanged, 150))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1MuteChanged, 151))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2MuteChanged, 152))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3MuteChanged, 153))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4MuteChanged, 154))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5MuteChanged, 155))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6MuteChanged, 156))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7MuteChanged, 157))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0AttackThresholdChanged, 158))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1AttackThresholdChanged, 159))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2AttackThresholdChanged, 160))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3AttackThresholdChanged, 161))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4AttackThresholdChanged, 162))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5AttackThresholdChanged, 163))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6AttackThresholdChanged, 164))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7AttackThresholdChanged, 165))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0AttackTimeChanged, 166))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1AttackTimeChanged, 167))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2AttackTimeChanged, 168))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3AttackTimeChanged, 169))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4AttackTimeChanged, 170))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5AttackTimeChanged, 171))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6AttackTimeChanged, 172))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7AttackTimeChanged, 173))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0ReleaseThresholdChanged, 174))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1ReleaseThresholdChanged, 175))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2ReleaseThresholdChanged, 176))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3ReleaseThresholdChanged, 177))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4ReleaseThresholdChanged, 178))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5ReleaseThresholdChanged, 179))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6ReleaseThresholdChanged, 180))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7ReleaseThresholdChanged, 181))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0ReleaseTimeChanged, 182))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1ReleaseTimeChanged, 183))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2ReleaseTimeChanged, 184))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3ReleaseTimeChanged, 185))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4ReleaseTimeChanged, 186))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5ReleaseTimeChanged, 187))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6ReleaseTimeChanged, 188))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7ReleaseTimeChanged, 189))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0RatioChanged, 190))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1RatioChanged, 191))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2RatioChanged, 192))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3RatioChanged, 193))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4RatioChanged, 194))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5RatioChanged, 195))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6RatioChanged, 196))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7RatioChanged, 197))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0KneeChanged, 198))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1KneeChanged, 199))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2KneeChanged, 200))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3KneeChanged, 201))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4KneeChanged, 202))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5KneeChanged, 203))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6KneeChanged, 204))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7KneeChanged, 205))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0BoostThresholdChanged, 206))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1BoostThresholdChanged, 207))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2BoostThresholdChanged, 208))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3BoostThresholdChanged, 209))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4BoostThresholdChanged, 210))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5BoostThresholdChanged, 211))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6BoostThresholdChanged, 212))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7BoostThresholdChanged, 213))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0BoostAmountChanged, 214))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1BoostAmountChanged, 215))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2BoostAmountChanged, 216))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3BoostAmountChanged, 217))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4BoostAmountChanged, 218))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5BoostAmountChanged, 219))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6BoostAmountChanged, 220))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7BoostAmountChanged, 221))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band0MakeupChanged, 222))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band1MakeupChanged, 223))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band2MakeupChanged, 224))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band3MakeupChanged, 225))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band4MakeupChanged, 226))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band5MakeupChanged, 227))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band6MakeupChanged, 228))
            return;
        if (QtMocHelpers::indexOfMethod<void (DbMultibandCompressor::*)()>(_a, &DbMultibandCompressor::band7MakeupChanged, 229))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bypass(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isBypassImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultBypassValue(); break;
        case 3: *reinterpret_cast<double*>(_v) = _t->inputGain(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isInputGainImmutable(); break;
        case 5: *reinterpret_cast<double*>(_v) = _t->defaultInputGainValue(); break;
        case 6: *reinterpret_cast<double*>(_v) = _t->outputGain(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isOutputGainImmutable(); break;
        case 8: *reinterpret_cast<double*>(_v) = _t->defaultOutputGainValue(); break;
        case 9: *reinterpret_cast<double*>(_v) = _t->dry(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isDryImmutable(); break;
        case 11: *reinterpret_cast<double*>(_v) = _t->defaultDryValue(); break;
        case 12: *reinterpret_cast<double*>(_v) = _t->wet(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isWetImmutable(); break;
        case 14: *reinterpret_cast<double*>(_v) = _t->defaultWetValue(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->viewSidechain(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isViewSidechainImmutable(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->defaultViewSidechainValue(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->externalSidechainEnabled(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isExternalSidechainEnabledImmutable(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->defaultExternalSidechainEnabledValue(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->stereoSplit(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isStereoSplitImmutable(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->defaultStereoSplitValue(); break;
        case 24: *reinterpret_cast<QStringList*>(_v) = _t->compressorModeLabels(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isCompressorModeLabelsImmutable(); break;
        case 26: *reinterpret_cast<QStringList*>(_v) = _t->defaultCompressorModeLabelsValue(); break;
        case 27: *reinterpret_cast<int*>(_v) = _t->compressorMode(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isCompressorModeImmutable(); break;
        case 29: *reinterpret_cast<int*>(_v) = _t->defaultCompressorModeValue(); break;
        case 30: *reinterpret_cast<QStringList*>(_v) = _t->envelopeBoostLabels(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isEnvelopeBoostLabelsImmutable(); break;
        case 32: *reinterpret_cast<QStringList*>(_v) = _t->defaultEnvelopeBoostLabelsValue(); break;
        case 33: *reinterpret_cast<int*>(_v) = _t->envelopeBoost(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isEnvelopeBoostImmutable(); break;
        case 35: *reinterpret_cast<int*>(_v) = _t->defaultEnvelopeBoostValue(); break;
        case 36: *reinterpret_cast<double*>(_v) = _t->inputToSidechain(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isInputToSidechainImmutable(); break;
        case 38: *reinterpret_cast<double*>(_v) = _t->defaultInputToSidechainValue(); break;
        case 39: *reinterpret_cast<double*>(_v) = _t->inputToLink(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->isInputToLinkImmutable(); break;
        case 41: *reinterpret_cast<double*>(_v) = _t->defaultInputToLinkValue(); break;
        case 42: *reinterpret_cast<double*>(_v) = _t->sidechainToInput(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->isSidechainToInputImmutable(); break;
        case 44: *reinterpret_cast<double*>(_v) = _t->defaultSidechainToInputValue(); break;
        case 45: *reinterpret_cast<double*>(_v) = _t->sidechainToLink(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->isSidechainToLinkImmutable(); break;
        case 47: *reinterpret_cast<double*>(_v) = _t->defaultSidechainToLinkValue(); break;
        case 48: *reinterpret_cast<double*>(_v) = _t->linkToSidechain(); break;
        case 49: *reinterpret_cast<bool*>(_v) = _t->isLinkToSidechainImmutable(); break;
        case 50: *reinterpret_cast<double*>(_v) = _t->defaultLinkToSidechainValue(); break;
        case 51: *reinterpret_cast<double*>(_v) = _t->linkToInput(); break;
        case 52: *reinterpret_cast<bool*>(_v) = _t->isLinkToInputImmutable(); break;
        case 53: *reinterpret_cast<double*>(_v) = _t->defaultLinkToInputValue(); break;
        case 54: *reinterpret_cast<bool*>(_v) = _t->band1Enable(); break;
        case 55: *reinterpret_cast<bool*>(_v) = _t->isBand1EnableImmutable(); break;
        case 56: *reinterpret_cast<bool*>(_v) = _t->defaultBand1EnableValue(); break;
        case 57: *reinterpret_cast<bool*>(_v) = _t->band2Enable(); break;
        case 58: *reinterpret_cast<bool*>(_v) = _t->isBand2EnableImmutable(); break;
        case 59: *reinterpret_cast<bool*>(_v) = _t->defaultBand2EnableValue(); break;
        case 60: *reinterpret_cast<bool*>(_v) = _t->band3Enable(); break;
        case 61: *reinterpret_cast<bool*>(_v) = _t->isBand3EnableImmutable(); break;
        case 62: *reinterpret_cast<bool*>(_v) = _t->defaultBand3EnableValue(); break;
        case 63: *reinterpret_cast<bool*>(_v) = _t->band4Enable(); break;
        case 64: *reinterpret_cast<bool*>(_v) = _t->isBand4EnableImmutable(); break;
        case 65: *reinterpret_cast<bool*>(_v) = _t->defaultBand4EnableValue(); break;
        case 66: *reinterpret_cast<bool*>(_v) = _t->band5Enable(); break;
        case 67: *reinterpret_cast<bool*>(_v) = _t->isBand5EnableImmutable(); break;
        case 68: *reinterpret_cast<bool*>(_v) = _t->defaultBand5EnableValue(); break;
        case 69: *reinterpret_cast<bool*>(_v) = _t->band6Enable(); break;
        case 70: *reinterpret_cast<bool*>(_v) = _t->isBand6EnableImmutable(); break;
        case 71: *reinterpret_cast<bool*>(_v) = _t->defaultBand6EnableValue(); break;
        case 72: *reinterpret_cast<bool*>(_v) = _t->band7Enable(); break;
        case 73: *reinterpret_cast<bool*>(_v) = _t->isBand7EnableImmutable(); break;
        case 74: *reinterpret_cast<bool*>(_v) = _t->defaultBand7EnableValue(); break;
        case 75: *reinterpret_cast<double*>(_v) = _t->band1SplitFrequency(); break;
        case 76: *reinterpret_cast<bool*>(_v) = _t->isBand1SplitFrequencyImmutable(); break;
        case 77: *reinterpret_cast<double*>(_v) = _t->defaultBand1SplitFrequencyValue(); break;
        case 78: *reinterpret_cast<double*>(_v) = _t->band2SplitFrequency(); break;
        case 79: *reinterpret_cast<bool*>(_v) = _t->isBand2SplitFrequencyImmutable(); break;
        case 80: *reinterpret_cast<double*>(_v) = _t->defaultBand2SplitFrequencyValue(); break;
        case 81: *reinterpret_cast<double*>(_v) = _t->band3SplitFrequency(); break;
        case 82: *reinterpret_cast<bool*>(_v) = _t->isBand3SplitFrequencyImmutable(); break;
        case 83: *reinterpret_cast<double*>(_v) = _t->defaultBand3SplitFrequencyValue(); break;
        case 84: *reinterpret_cast<double*>(_v) = _t->band4SplitFrequency(); break;
        case 85: *reinterpret_cast<bool*>(_v) = _t->isBand4SplitFrequencyImmutable(); break;
        case 86: *reinterpret_cast<double*>(_v) = _t->defaultBand4SplitFrequencyValue(); break;
        case 87: *reinterpret_cast<double*>(_v) = _t->band5SplitFrequency(); break;
        case 88: *reinterpret_cast<bool*>(_v) = _t->isBand5SplitFrequencyImmutable(); break;
        case 89: *reinterpret_cast<double*>(_v) = _t->defaultBand5SplitFrequencyValue(); break;
        case 90: *reinterpret_cast<double*>(_v) = _t->band6SplitFrequency(); break;
        case 91: *reinterpret_cast<bool*>(_v) = _t->isBand6SplitFrequencyImmutable(); break;
        case 92: *reinterpret_cast<double*>(_v) = _t->defaultBand6SplitFrequencyValue(); break;
        case 93: *reinterpret_cast<double*>(_v) = _t->band7SplitFrequency(); break;
        case 94: *reinterpret_cast<bool*>(_v) = _t->isBand7SplitFrequencyImmutable(); break;
        case 95: *reinterpret_cast<double*>(_v) = _t->defaultBand7SplitFrequencyValue(); break;
        case 96: *reinterpret_cast<QString*>(_v) = _t->sidechainInputDevice(); break;
        case 97: *reinterpret_cast<bool*>(_v) = _t->isSidechainInputDeviceImmutable(); break;
        case 98: *reinterpret_cast<QString*>(_v) = _t->defaultSidechainInputDeviceValue(); break;
        case 99: *reinterpret_cast<QStringList*>(_v) = _t->sidechainTypeLabels(); break;
        case 100: *reinterpret_cast<bool*>(_v) = _t->isSidechainTypeLabelsImmutable(); break;
        case 101: *reinterpret_cast<QStringList*>(_v) = _t->defaultSidechainTypeLabelsValue(); break;
        case 102: *reinterpret_cast<int*>(_v) = _t->band0SidechainType(); break;
        case 103: *reinterpret_cast<bool*>(_v) = _t->isBand0SidechainTypeImmutable(); break;
        case 104: *reinterpret_cast<int*>(_v) = _t->defaultBand0SidechainTypeValue(); break;
        case 105: *reinterpret_cast<int*>(_v) = _t->band1SidechainType(); break;
        case 106: *reinterpret_cast<bool*>(_v) = _t->isBand1SidechainTypeImmutable(); break;
        case 107: *reinterpret_cast<int*>(_v) = _t->defaultBand1SidechainTypeValue(); break;
        case 108: *reinterpret_cast<int*>(_v) = _t->band2SidechainType(); break;
        case 109: *reinterpret_cast<bool*>(_v) = _t->isBand2SidechainTypeImmutable(); break;
        case 110: *reinterpret_cast<int*>(_v) = _t->defaultBand2SidechainTypeValue(); break;
        case 111: *reinterpret_cast<int*>(_v) = _t->band3SidechainType(); break;
        case 112: *reinterpret_cast<bool*>(_v) = _t->isBand3SidechainTypeImmutable(); break;
        case 113: *reinterpret_cast<int*>(_v) = _t->defaultBand3SidechainTypeValue(); break;
        case 114: *reinterpret_cast<int*>(_v) = _t->band4SidechainType(); break;
        case 115: *reinterpret_cast<bool*>(_v) = _t->isBand4SidechainTypeImmutable(); break;
        case 116: *reinterpret_cast<int*>(_v) = _t->defaultBand4SidechainTypeValue(); break;
        case 117: *reinterpret_cast<int*>(_v) = _t->band5SidechainType(); break;
        case 118: *reinterpret_cast<bool*>(_v) = _t->isBand5SidechainTypeImmutable(); break;
        case 119: *reinterpret_cast<int*>(_v) = _t->defaultBand5SidechainTypeValue(); break;
        case 120: *reinterpret_cast<int*>(_v) = _t->band6SidechainType(); break;
        case 121: *reinterpret_cast<bool*>(_v) = _t->isBand6SidechainTypeImmutable(); break;
        case 122: *reinterpret_cast<int*>(_v) = _t->defaultBand6SidechainTypeValue(); break;
        case 123: *reinterpret_cast<int*>(_v) = _t->band7SidechainType(); break;
        case 124: *reinterpret_cast<bool*>(_v) = _t->isBand7SidechainTypeImmutable(); break;
        case 125: *reinterpret_cast<int*>(_v) = _t->defaultBand7SidechainTypeValue(); break;
        case 126: *reinterpret_cast<QStringList*>(_v) = _t->sidechainModeLabels(); break;
        case 127: *reinterpret_cast<bool*>(_v) = _t->isSidechainModeLabelsImmutable(); break;
        case 128: *reinterpret_cast<QStringList*>(_v) = _t->defaultSidechainModeLabelsValue(); break;
        case 129: *reinterpret_cast<int*>(_v) = _t->band0SidechainMode(); break;
        case 130: *reinterpret_cast<bool*>(_v) = _t->isBand0SidechainModeImmutable(); break;
        case 131: *reinterpret_cast<int*>(_v) = _t->defaultBand0SidechainModeValue(); break;
        case 132: *reinterpret_cast<int*>(_v) = _t->band1SidechainMode(); break;
        case 133: *reinterpret_cast<bool*>(_v) = _t->isBand1SidechainModeImmutable(); break;
        case 134: *reinterpret_cast<int*>(_v) = _t->defaultBand1SidechainModeValue(); break;
        case 135: *reinterpret_cast<int*>(_v) = _t->band2SidechainMode(); break;
        case 136: *reinterpret_cast<bool*>(_v) = _t->isBand2SidechainModeImmutable(); break;
        case 137: *reinterpret_cast<int*>(_v) = _t->defaultBand2SidechainModeValue(); break;
        case 138: *reinterpret_cast<int*>(_v) = _t->band3SidechainMode(); break;
        case 139: *reinterpret_cast<bool*>(_v) = _t->isBand3SidechainModeImmutable(); break;
        case 140: *reinterpret_cast<int*>(_v) = _t->defaultBand3SidechainModeValue(); break;
        case 141: *reinterpret_cast<int*>(_v) = _t->band4SidechainMode(); break;
        case 142: *reinterpret_cast<bool*>(_v) = _t->isBand4SidechainModeImmutable(); break;
        case 143: *reinterpret_cast<int*>(_v) = _t->defaultBand4SidechainModeValue(); break;
        case 144: *reinterpret_cast<int*>(_v) = _t->band5SidechainMode(); break;
        case 145: *reinterpret_cast<bool*>(_v) = _t->isBand5SidechainModeImmutable(); break;
        case 146: *reinterpret_cast<int*>(_v) = _t->defaultBand5SidechainModeValue(); break;
        case 147: *reinterpret_cast<int*>(_v) = _t->band6SidechainMode(); break;
        case 148: *reinterpret_cast<bool*>(_v) = _t->isBand6SidechainModeImmutable(); break;
        case 149: *reinterpret_cast<int*>(_v) = _t->defaultBand6SidechainModeValue(); break;
        case 150: *reinterpret_cast<int*>(_v) = _t->band7SidechainMode(); break;
        case 151: *reinterpret_cast<bool*>(_v) = _t->isBand7SidechainModeImmutable(); break;
        case 152: *reinterpret_cast<int*>(_v) = _t->defaultBand7SidechainModeValue(); break;
        case 153: *reinterpret_cast<QStringList*>(_v) = _t->sidechainSourceLabels(); break;
        case 154: *reinterpret_cast<bool*>(_v) = _t->isSidechainSourceLabelsImmutable(); break;
        case 155: *reinterpret_cast<QStringList*>(_v) = _t->defaultSidechainSourceLabelsValue(); break;
        case 156: *reinterpret_cast<int*>(_v) = _t->band0SidechainSource(); break;
        case 157: *reinterpret_cast<bool*>(_v) = _t->isBand0SidechainSourceImmutable(); break;
        case 158: *reinterpret_cast<int*>(_v) = _t->defaultBand0SidechainSourceValue(); break;
        case 159: *reinterpret_cast<int*>(_v) = _t->band1SidechainSource(); break;
        case 160: *reinterpret_cast<bool*>(_v) = _t->isBand1SidechainSourceImmutable(); break;
        case 161: *reinterpret_cast<int*>(_v) = _t->defaultBand1SidechainSourceValue(); break;
        case 162: *reinterpret_cast<int*>(_v) = _t->band2SidechainSource(); break;
        case 163: *reinterpret_cast<bool*>(_v) = _t->isBand2SidechainSourceImmutable(); break;
        case 164: *reinterpret_cast<int*>(_v) = _t->defaultBand2SidechainSourceValue(); break;
        case 165: *reinterpret_cast<int*>(_v) = _t->band3SidechainSource(); break;
        case 166: *reinterpret_cast<bool*>(_v) = _t->isBand3SidechainSourceImmutable(); break;
        case 167: *reinterpret_cast<int*>(_v) = _t->defaultBand3SidechainSourceValue(); break;
        case 168: *reinterpret_cast<int*>(_v) = _t->band4SidechainSource(); break;
        case 169: *reinterpret_cast<bool*>(_v) = _t->isBand4SidechainSourceImmutable(); break;
        case 170: *reinterpret_cast<int*>(_v) = _t->defaultBand4SidechainSourceValue(); break;
        case 171: *reinterpret_cast<int*>(_v) = _t->band5SidechainSource(); break;
        case 172: *reinterpret_cast<bool*>(_v) = _t->isBand5SidechainSourceImmutable(); break;
        case 173: *reinterpret_cast<int*>(_v) = _t->defaultBand5SidechainSourceValue(); break;
        case 174: *reinterpret_cast<int*>(_v) = _t->band6SidechainSource(); break;
        case 175: *reinterpret_cast<bool*>(_v) = _t->isBand6SidechainSourceImmutable(); break;
        case 176: *reinterpret_cast<int*>(_v) = _t->defaultBand6SidechainSourceValue(); break;
        case 177: *reinterpret_cast<int*>(_v) = _t->band7SidechainSource(); break;
        case 178: *reinterpret_cast<bool*>(_v) = _t->isBand7SidechainSourceImmutable(); break;
        case 179: *reinterpret_cast<int*>(_v) = _t->defaultBand7SidechainSourceValue(); break;
        case 180: *reinterpret_cast<QStringList*>(_v) = _t->stereoSplitSourceLabels(); break;
        case 181: *reinterpret_cast<bool*>(_v) = _t->isStereoSplitSourceLabelsImmutable(); break;
        case 182: *reinterpret_cast<QStringList*>(_v) = _t->defaultStereoSplitSourceLabelsValue(); break;
        case 183: *reinterpret_cast<int*>(_v) = _t->band0StereoSplitSource(); break;
        case 184: *reinterpret_cast<bool*>(_v) = _t->isBand0StereoSplitSourceImmutable(); break;
        case 185: *reinterpret_cast<int*>(_v) = _t->defaultBand0StereoSplitSourceValue(); break;
        case 186: *reinterpret_cast<int*>(_v) = _t->band1StereoSplitSource(); break;
        case 187: *reinterpret_cast<bool*>(_v) = _t->isBand1StereoSplitSourceImmutable(); break;
        case 188: *reinterpret_cast<int*>(_v) = _t->defaultBand1StereoSplitSourceValue(); break;
        case 189: *reinterpret_cast<int*>(_v) = _t->band2StereoSplitSource(); break;
        case 190: *reinterpret_cast<bool*>(_v) = _t->isBand2StereoSplitSourceImmutable(); break;
        case 191: *reinterpret_cast<int*>(_v) = _t->defaultBand2StereoSplitSourceValue(); break;
        case 192: *reinterpret_cast<int*>(_v) = _t->band3StereoSplitSource(); break;
        case 193: *reinterpret_cast<bool*>(_v) = _t->isBand3StereoSplitSourceImmutable(); break;
        case 194: *reinterpret_cast<int*>(_v) = _t->defaultBand3StereoSplitSourceValue(); break;
        case 195: *reinterpret_cast<int*>(_v) = _t->band4StereoSplitSource(); break;
        case 196: *reinterpret_cast<bool*>(_v) = _t->isBand4StereoSplitSourceImmutable(); break;
        case 197: *reinterpret_cast<int*>(_v) = _t->defaultBand4StereoSplitSourceValue(); break;
        case 198: *reinterpret_cast<int*>(_v) = _t->band5StereoSplitSource(); break;
        case 199: *reinterpret_cast<bool*>(_v) = _t->isBand5StereoSplitSourceImmutable(); break;
        case 200: *reinterpret_cast<int*>(_v) = _t->defaultBand5StereoSplitSourceValue(); break;
        case 201: *reinterpret_cast<int*>(_v) = _t->band6StereoSplitSource(); break;
        case 202: *reinterpret_cast<bool*>(_v) = _t->isBand6StereoSplitSourceImmutable(); break;
        case 203: *reinterpret_cast<int*>(_v) = _t->defaultBand6StereoSplitSourceValue(); break;
        case 204: *reinterpret_cast<int*>(_v) = _t->band7StereoSplitSource(); break;
        case 205: *reinterpret_cast<bool*>(_v) = _t->isBand7StereoSplitSourceImmutable(); break;
        case 206: *reinterpret_cast<int*>(_v) = _t->defaultBand7StereoSplitSourceValue(); break;
        case 207: *reinterpret_cast<double*>(_v) = _t->band0SidechainLookahead(); break;
        case 208: *reinterpret_cast<bool*>(_v) = _t->isBand0SidechainLookaheadImmutable(); break;
        case 209: *reinterpret_cast<double*>(_v) = _t->defaultBand0SidechainLookaheadValue(); break;
        case 210: *reinterpret_cast<double*>(_v) = _t->band1SidechainLookahead(); break;
        case 211: *reinterpret_cast<bool*>(_v) = _t->isBand1SidechainLookaheadImmutable(); break;
        case 212: *reinterpret_cast<double*>(_v) = _t->defaultBand1SidechainLookaheadValue(); break;
        case 213: *reinterpret_cast<double*>(_v) = _t->band2SidechainLookahead(); break;
        case 214: *reinterpret_cast<bool*>(_v) = _t->isBand2SidechainLookaheadImmutable(); break;
        case 215: *reinterpret_cast<double*>(_v) = _t->defaultBand2SidechainLookaheadValue(); break;
        case 216: *reinterpret_cast<double*>(_v) = _t->band3SidechainLookahead(); break;
        case 217: *reinterpret_cast<bool*>(_v) = _t->isBand3SidechainLookaheadImmutable(); break;
        case 218: *reinterpret_cast<double*>(_v) = _t->defaultBand3SidechainLookaheadValue(); break;
        case 219: *reinterpret_cast<double*>(_v) = _t->band4SidechainLookahead(); break;
        case 220: *reinterpret_cast<bool*>(_v) = _t->isBand4SidechainLookaheadImmutable(); break;
        case 221: *reinterpret_cast<double*>(_v) = _t->defaultBand4SidechainLookaheadValue(); break;
        case 222: *reinterpret_cast<double*>(_v) = _t->band5SidechainLookahead(); break;
        case 223: *reinterpret_cast<bool*>(_v) = _t->isBand5SidechainLookaheadImmutable(); break;
        case 224: *reinterpret_cast<double*>(_v) = _t->defaultBand5SidechainLookaheadValue(); break;
        case 225: *reinterpret_cast<double*>(_v) = _t->band6SidechainLookahead(); break;
        case 226: *reinterpret_cast<bool*>(_v) = _t->isBand6SidechainLookaheadImmutable(); break;
        case 227: *reinterpret_cast<double*>(_v) = _t->defaultBand6SidechainLookaheadValue(); break;
        case 228: *reinterpret_cast<double*>(_v) = _t->band7SidechainLookahead(); break;
        case 229: *reinterpret_cast<bool*>(_v) = _t->isBand7SidechainLookaheadImmutable(); break;
        case 230: *reinterpret_cast<double*>(_v) = _t->defaultBand7SidechainLookaheadValue(); break;
        case 231: *reinterpret_cast<double*>(_v) = _t->band0SidechainReactivity(); break;
        case 232: *reinterpret_cast<bool*>(_v) = _t->isBand0SidechainReactivityImmutable(); break;
        case 233: *reinterpret_cast<double*>(_v) = _t->defaultBand0SidechainReactivityValue(); break;
        case 234: *reinterpret_cast<double*>(_v) = _t->band1SidechainReactivity(); break;
        case 235: *reinterpret_cast<bool*>(_v) = _t->isBand1SidechainReactivityImmutable(); break;
        case 236: *reinterpret_cast<double*>(_v) = _t->defaultBand1SidechainReactivityValue(); break;
        case 237: *reinterpret_cast<double*>(_v) = _t->band2SidechainReactivity(); break;
        case 238: *reinterpret_cast<bool*>(_v) = _t->isBand2SidechainReactivityImmutable(); break;
        case 239: *reinterpret_cast<double*>(_v) = _t->defaultBand2SidechainReactivityValue(); break;
        case 240: *reinterpret_cast<double*>(_v) = _t->band3SidechainReactivity(); break;
        case 241: *reinterpret_cast<bool*>(_v) = _t->isBand3SidechainReactivityImmutable(); break;
        case 242: *reinterpret_cast<double*>(_v) = _t->defaultBand3SidechainReactivityValue(); break;
        case 243: *reinterpret_cast<double*>(_v) = _t->band4SidechainReactivity(); break;
        case 244: *reinterpret_cast<bool*>(_v) = _t->isBand4SidechainReactivityImmutable(); break;
        case 245: *reinterpret_cast<double*>(_v) = _t->defaultBand4SidechainReactivityValue(); break;
        case 246: *reinterpret_cast<double*>(_v) = _t->band5SidechainReactivity(); break;
        case 247: *reinterpret_cast<bool*>(_v) = _t->isBand5SidechainReactivityImmutable(); break;
        case 248: *reinterpret_cast<double*>(_v) = _t->defaultBand5SidechainReactivityValue(); break;
        case 249: *reinterpret_cast<double*>(_v) = _t->band6SidechainReactivity(); break;
        case 250: *reinterpret_cast<bool*>(_v) = _t->isBand6SidechainReactivityImmutable(); break;
        case 251: *reinterpret_cast<double*>(_v) = _t->defaultBand6SidechainReactivityValue(); break;
        case 252: *reinterpret_cast<double*>(_v) = _t->band7SidechainReactivity(); break;
        case 253: *reinterpret_cast<bool*>(_v) = _t->isBand7SidechainReactivityImmutable(); break;
        case 254: *reinterpret_cast<double*>(_v) = _t->defaultBand7SidechainReactivityValue(); break;
        case 255: *reinterpret_cast<double*>(_v) = _t->band0SidechainPreamp(); break;
        case 256: *reinterpret_cast<bool*>(_v) = _t->isBand0SidechainPreampImmutable(); break;
        case 257: *reinterpret_cast<double*>(_v) = _t->defaultBand0SidechainPreampValue(); break;
        case 258: *reinterpret_cast<double*>(_v) = _t->band1SidechainPreamp(); break;
        case 259: *reinterpret_cast<bool*>(_v) = _t->isBand1SidechainPreampImmutable(); break;
        case 260: *reinterpret_cast<double*>(_v) = _t->defaultBand1SidechainPreampValue(); break;
        case 261: *reinterpret_cast<double*>(_v) = _t->band2SidechainPreamp(); break;
        case 262: *reinterpret_cast<bool*>(_v) = _t->isBand2SidechainPreampImmutable(); break;
        case 263: *reinterpret_cast<double*>(_v) = _t->defaultBand2SidechainPreampValue(); break;
        case 264: *reinterpret_cast<double*>(_v) = _t->band3SidechainPreamp(); break;
        case 265: *reinterpret_cast<bool*>(_v) = _t->isBand3SidechainPreampImmutable(); break;
        case 266: *reinterpret_cast<double*>(_v) = _t->defaultBand3SidechainPreampValue(); break;
        case 267: *reinterpret_cast<double*>(_v) = _t->band4SidechainPreamp(); break;
        case 268: *reinterpret_cast<bool*>(_v) = _t->isBand4SidechainPreampImmutable(); break;
        case 269: *reinterpret_cast<double*>(_v) = _t->defaultBand4SidechainPreampValue(); break;
        case 270: *reinterpret_cast<double*>(_v) = _t->band5SidechainPreamp(); break;
        case 271: *reinterpret_cast<bool*>(_v) = _t->isBand5SidechainPreampImmutable(); break;
        case 272: *reinterpret_cast<double*>(_v) = _t->defaultBand5SidechainPreampValue(); break;
        case 273: *reinterpret_cast<double*>(_v) = _t->band6SidechainPreamp(); break;
        case 274: *reinterpret_cast<bool*>(_v) = _t->isBand6SidechainPreampImmutable(); break;
        case 275: *reinterpret_cast<double*>(_v) = _t->defaultBand6SidechainPreampValue(); break;
        case 276: *reinterpret_cast<double*>(_v) = _t->band7SidechainPreamp(); break;
        case 277: *reinterpret_cast<bool*>(_v) = _t->isBand7SidechainPreampImmutable(); break;
        case 278: *reinterpret_cast<double*>(_v) = _t->defaultBand7SidechainPreampValue(); break;
        case 279: *reinterpret_cast<bool*>(_v) = _t->band0SidechainCustomLowcutFilter(); break;
        case 280: *reinterpret_cast<bool*>(_v) = _t->isBand0SidechainCustomLowcutFilterImmutable(); break;
        case 281: *reinterpret_cast<bool*>(_v) = _t->defaultBand0SidechainCustomLowcutFilterValue(); break;
        case 282: *reinterpret_cast<bool*>(_v) = _t->band1SidechainCustomLowcutFilter(); break;
        case 283: *reinterpret_cast<bool*>(_v) = _t->isBand1SidechainCustomLowcutFilterImmutable(); break;
        case 284: *reinterpret_cast<bool*>(_v) = _t->defaultBand1SidechainCustomLowcutFilterValue(); break;
        case 285: *reinterpret_cast<bool*>(_v) = _t->band2SidechainCustomLowcutFilter(); break;
        case 286: *reinterpret_cast<bool*>(_v) = _t->isBand2SidechainCustomLowcutFilterImmutable(); break;
        case 287: *reinterpret_cast<bool*>(_v) = _t->defaultBand2SidechainCustomLowcutFilterValue(); break;
        case 288: *reinterpret_cast<bool*>(_v) = _t->band3SidechainCustomLowcutFilter(); break;
        case 289: *reinterpret_cast<bool*>(_v) = _t->isBand3SidechainCustomLowcutFilterImmutable(); break;
        case 290: *reinterpret_cast<bool*>(_v) = _t->defaultBand3SidechainCustomLowcutFilterValue(); break;
        case 291: *reinterpret_cast<bool*>(_v) = _t->band4SidechainCustomLowcutFilter(); break;
        case 292: *reinterpret_cast<bool*>(_v) = _t->isBand4SidechainCustomLowcutFilterImmutable(); break;
        case 293: *reinterpret_cast<bool*>(_v) = _t->defaultBand4SidechainCustomLowcutFilterValue(); break;
        case 294: *reinterpret_cast<bool*>(_v) = _t->band5SidechainCustomLowcutFilter(); break;
        case 295: *reinterpret_cast<bool*>(_v) = _t->isBand5SidechainCustomLowcutFilterImmutable(); break;
        case 296: *reinterpret_cast<bool*>(_v) = _t->defaultBand5SidechainCustomLowcutFilterValue(); break;
        case 297: *reinterpret_cast<bool*>(_v) = _t->band6SidechainCustomLowcutFilter(); break;
        case 298: *reinterpret_cast<bool*>(_v) = _t->isBand6SidechainCustomLowcutFilterImmutable(); break;
        case 299: *reinterpret_cast<bool*>(_v) = _t->defaultBand6SidechainCustomLowcutFilterValue(); break;
        case 300: *reinterpret_cast<bool*>(_v) = _t->band7SidechainCustomLowcutFilter(); break;
        case 301: *reinterpret_cast<bool*>(_v) = _t->isBand7SidechainCustomLowcutFilterImmutable(); break;
        case 302: *reinterpret_cast<bool*>(_v) = _t->defaultBand7SidechainCustomLowcutFilterValue(); break;
        case 303: *reinterpret_cast<bool*>(_v) = _t->band0SidechainCustomHighcutFilter(); break;
        case 304: *reinterpret_cast<bool*>(_v) = _t->isBand0SidechainCustomHighcutFilterImmutable(); break;
        case 305: *reinterpret_cast<bool*>(_v) = _t->defaultBand0SidechainCustomHighcutFilterValue(); break;
        case 306: *reinterpret_cast<bool*>(_v) = _t->band1SidechainCustomHighcutFilter(); break;
        case 307: *reinterpret_cast<bool*>(_v) = _t->isBand1SidechainCustomHighcutFilterImmutable(); break;
        case 308: *reinterpret_cast<bool*>(_v) = _t->defaultBand1SidechainCustomHighcutFilterValue(); break;
        case 309: *reinterpret_cast<bool*>(_v) = _t->band2SidechainCustomHighcutFilter(); break;
        case 310: *reinterpret_cast<bool*>(_v) = _t->isBand2SidechainCustomHighcutFilterImmutable(); break;
        case 311: *reinterpret_cast<bool*>(_v) = _t->defaultBand2SidechainCustomHighcutFilterValue(); break;
        case 312: *reinterpret_cast<bool*>(_v) = _t->band3SidechainCustomHighcutFilter(); break;
        case 313: *reinterpret_cast<bool*>(_v) = _t->isBand3SidechainCustomHighcutFilterImmutable(); break;
        case 314: *reinterpret_cast<bool*>(_v) = _t->defaultBand3SidechainCustomHighcutFilterValue(); break;
        case 315: *reinterpret_cast<bool*>(_v) = _t->band4SidechainCustomHighcutFilter(); break;
        case 316: *reinterpret_cast<bool*>(_v) = _t->isBand4SidechainCustomHighcutFilterImmutable(); break;
        case 317: *reinterpret_cast<bool*>(_v) = _t->defaultBand4SidechainCustomHighcutFilterValue(); break;
        case 318: *reinterpret_cast<bool*>(_v) = _t->band5SidechainCustomHighcutFilter(); break;
        case 319: *reinterpret_cast<bool*>(_v) = _t->isBand5SidechainCustomHighcutFilterImmutable(); break;
        case 320: *reinterpret_cast<bool*>(_v) = _t->defaultBand5SidechainCustomHighcutFilterValue(); break;
        case 321: *reinterpret_cast<bool*>(_v) = _t->band6SidechainCustomHighcutFilter(); break;
        case 322: *reinterpret_cast<bool*>(_v) = _t->isBand6SidechainCustomHighcutFilterImmutable(); break;
        case 323: *reinterpret_cast<bool*>(_v) = _t->defaultBand6SidechainCustomHighcutFilterValue(); break;
        case 324: *reinterpret_cast<bool*>(_v) = _t->band7SidechainCustomHighcutFilter(); break;
        case 325: *reinterpret_cast<bool*>(_v) = _t->isBand7SidechainCustomHighcutFilterImmutable(); break;
        case 326: *reinterpret_cast<bool*>(_v) = _t->defaultBand7SidechainCustomHighcutFilterValue(); break;
        case 327: *reinterpret_cast<double*>(_v) = _t->band0SidechainLowcutFrequency(); break;
        case 328: *reinterpret_cast<bool*>(_v) = _t->isBand0SidechainLowcutFrequencyImmutable(); break;
        case 329: *reinterpret_cast<double*>(_v) = _t->defaultBand0SidechainLowcutFrequencyValue(); break;
        case 330: *reinterpret_cast<double*>(_v) = _t->band1SidechainLowcutFrequency(); break;
        case 331: *reinterpret_cast<bool*>(_v) = _t->isBand1SidechainLowcutFrequencyImmutable(); break;
        case 332: *reinterpret_cast<double*>(_v) = _t->defaultBand1SidechainLowcutFrequencyValue(); break;
        case 333: *reinterpret_cast<double*>(_v) = _t->band2SidechainLowcutFrequency(); break;
        case 334: *reinterpret_cast<bool*>(_v) = _t->isBand2SidechainLowcutFrequencyImmutable(); break;
        case 335: *reinterpret_cast<double*>(_v) = _t->defaultBand2SidechainLowcutFrequencyValue(); break;
        case 336: *reinterpret_cast<double*>(_v) = _t->band3SidechainLowcutFrequency(); break;
        case 337: *reinterpret_cast<bool*>(_v) = _t->isBand3SidechainLowcutFrequencyImmutable(); break;
        case 338: *reinterpret_cast<double*>(_v) = _t->defaultBand3SidechainLowcutFrequencyValue(); break;
        case 339: *reinterpret_cast<double*>(_v) = _t->band4SidechainLowcutFrequency(); break;
        case 340: *reinterpret_cast<bool*>(_v) = _t->isBand4SidechainLowcutFrequencyImmutable(); break;
        case 341: *reinterpret_cast<double*>(_v) = _t->defaultBand4SidechainLowcutFrequencyValue(); break;
        case 342: *reinterpret_cast<double*>(_v) = _t->band5SidechainLowcutFrequency(); break;
        case 343: *reinterpret_cast<bool*>(_v) = _t->isBand5SidechainLowcutFrequencyImmutable(); break;
        case 344: *reinterpret_cast<double*>(_v) = _t->defaultBand5SidechainLowcutFrequencyValue(); break;
        case 345: *reinterpret_cast<double*>(_v) = _t->band6SidechainLowcutFrequency(); break;
        case 346: *reinterpret_cast<bool*>(_v) = _t->isBand6SidechainLowcutFrequencyImmutable(); break;
        case 347: *reinterpret_cast<double*>(_v) = _t->defaultBand6SidechainLowcutFrequencyValue(); break;
        case 348: *reinterpret_cast<double*>(_v) = _t->band7SidechainLowcutFrequency(); break;
        case 349: *reinterpret_cast<bool*>(_v) = _t->isBand7SidechainLowcutFrequencyImmutable(); break;
        case 350: *reinterpret_cast<double*>(_v) = _t->defaultBand7SidechainLowcutFrequencyValue(); break;
        case 351: *reinterpret_cast<double*>(_v) = _t->band0SidechainHighcutFrequency(); break;
        case 352: *reinterpret_cast<bool*>(_v) = _t->isBand0SidechainHighcutFrequencyImmutable(); break;
        case 353: *reinterpret_cast<double*>(_v) = _t->defaultBand0SidechainHighcutFrequencyValue(); break;
        case 354: *reinterpret_cast<double*>(_v) = _t->band1SidechainHighcutFrequency(); break;
        case 355: *reinterpret_cast<bool*>(_v) = _t->isBand1SidechainHighcutFrequencyImmutable(); break;
        case 356: *reinterpret_cast<double*>(_v) = _t->defaultBand1SidechainHighcutFrequencyValue(); break;
        case 357: *reinterpret_cast<double*>(_v) = _t->band2SidechainHighcutFrequency(); break;
        case 358: *reinterpret_cast<bool*>(_v) = _t->isBand2SidechainHighcutFrequencyImmutable(); break;
        case 359: *reinterpret_cast<double*>(_v) = _t->defaultBand2SidechainHighcutFrequencyValue(); break;
        case 360: *reinterpret_cast<double*>(_v) = _t->band3SidechainHighcutFrequency(); break;
        case 361: *reinterpret_cast<bool*>(_v) = _t->isBand3SidechainHighcutFrequencyImmutable(); break;
        case 362: *reinterpret_cast<double*>(_v) = _t->defaultBand3SidechainHighcutFrequencyValue(); break;
        case 363: *reinterpret_cast<double*>(_v) = _t->band4SidechainHighcutFrequency(); break;
        case 364: *reinterpret_cast<bool*>(_v) = _t->isBand4SidechainHighcutFrequencyImmutable(); break;
        case 365: *reinterpret_cast<double*>(_v) = _t->defaultBand4SidechainHighcutFrequencyValue(); break;
        case 366: *reinterpret_cast<double*>(_v) = _t->band5SidechainHighcutFrequency(); break;
        case 367: *reinterpret_cast<bool*>(_v) = _t->isBand5SidechainHighcutFrequencyImmutable(); break;
        case 368: *reinterpret_cast<double*>(_v) = _t->defaultBand5SidechainHighcutFrequencyValue(); break;
        case 369: *reinterpret_cast<double*>(_v) = _t->band6SidechainHighcutFrequency(); break;
        case 370: *reinterpret_cast<bool*>(_v) = _t->isBand6SidechainHighcutFrequencyImmutable(); break;
        case 371: *reinterpret_cast<double*>(_v) = _t->defaultBand6SidechainHighcutFrequencyValue(); break;
        case 372: *reinterpret_cast<double*>(_v) = _t->band7SidechainHighcutFrequency(); break;
        case 373: *reinterpret_cast<bool*>(_v) = _t->isBand7SidechainHighcutFrequencyImmutable(); break;
        case 374: *reinterpret_cast<double*>(_v) = _t->defaultBand7SidechainHighcutFrequencyValue(); break;
        case 375: *reinterpret_cast<QStringList*>(_v) = _t->compressionModeLabels(); break;
        case 376: *reinterpret_cast<bool*>(_v) = _t->isCompressionModeLabelsImmutable(); break;
        case 377: *reinterpret_cast<QStringList*>(_v) = _t->defaultCompressionModeLabelsValue(); break;
        case 378: *reinterpret_cast<int*>(_v) = _t->band0CompressionMode(); break;
        case 379: *reinterpret_cast<bool*>(_v) = _t->isBand0CompressionModeImmutable(); break;
        case 380: *reinterpret_cast<int*>(_v) = _t->defaultBand0CompressionModeValue(); break;
        case 381: *reinterpret_cast<int*>(_v) = _t->band1CompressionMode(); break;
        case 382: *reinterpret_cast<bool*>(_v) = _t->isBand1CompressionModeImmutable(); break;
        case 383: *reinterpret_cast<int*>(_v) = _t->defaultBand1CompressionModeValue(); break;
        case 384: *reinterpret_cast<int*>(_v) = _t->band2CompressionMode(); break;
        case 385: *reinterpret_cast<bool*>(_v) = _t->isBand2CompressionModeImmutable(); break;
        case 386: *reinterpret_cast<int*>(_v) = _t->defaultBand2CompressionModeValue(); break;
        case 387: *reinterpret_cast<int*>(_v) = _t->band3CompressionMode(); break;
        case 388: *reinterpret_cast<bool*>(_v) = _t->isBand3CompressionModeImmutable(); break;
        case 389: *reinterpret_cast<int*>(_v) = _t->defaultBand3CompressionModeValue(); break;
        case 390: *reinterpret_cast<int*>(_v) = _t->band4CompressionMode(); break;
        case 391: *reinterpret_cast<bool*>(_v) = _t->isBand4CompressionModeImmutable(); break;
        case 392: *reinterpret_cast<int*>(_v) = _t->defaultBand4CompressionModeValue(); break;
        case 393: *reinterpret_cast<int*>(_v) = _t->band5CompressionMode(); break;
        case 394: *reinterpret_cast<bool*>(_v) = _t->isBand5CompressionModeImmutable(); break;
        case 395: *reinterpret_cast<int*>(_v) = _t->defaultBand5CompressionModeValue(); break;
        case 396: *reinterpret_cast<int*>(_v) = _t->band6CompressionMode(); break;
        case 397: *reinterpret_cast<bool*>(_v) = _t->isBand6CompressionModeImmutable(); break;
        case 398: *reinterpret_cast<int*>(_v) = _t->defaultBand6CompressionModeValue(); break;
        case 399: *reinterpret_cast<int*>(_v) = _t->band7CompressionMode(); break;
        case 400: *reinterpret_cast<bool*>(_v) = _t->isBand7CompressionModeImmutable(); break;
        case 401: *reinterpret_cast<int*>(_v) = _t->defaultBand7CompressionModeValue(); break;
        case 402: *reinterpret_cast<bool*>(_v) = _t->band0CompressorEnable(); break;
        case 403: *reinterpret_cast<bool*>(_v) = _t->isBand0CompressorEnableImmutable(); break;
        case 404: *reinterpret_cast<bool*>(_v) = _t->defaultBand0CompressorEnableValue(); break;
        case 405: *reinterpret_cast<bool*>(_v) = _t->band1CompressorEnable(); break;
        case 406: *reinterpret_cast<bool*>(_v) = _t->isBand1CompressorEnableImmutable(); break;
        case 407: *reinterpret_cast<bool*>(_v) = _t->defaultBand1CompressorEnableValue(); break;
        case 408: *reinterpret_cast<bool*>(_v) = _t->band2CompressorEnable(); break;
        case 409: *reinterpret_cast<bool*>(_v) = _t->isBand2CompressorEnableImmutable(); break;
        case 410: *reinterpret_cast<bool*>(_v) = _t->defaultBand2CompressorEnableValue(); break;
        case 411: *reinterpret_cast<bool*>(_v) = _t->band3CompressorEnable(); break;
        case 412: *reinterpret_cast<bool*>(_v) = _t->isBand3CompressorEnableImmutable(); break;
        case 413: *reinterpret_cast<bool*>(_v) = _t->defaultBand3CompressorEnableValue(); break;
        case 414: *reinterpret_cast<bool*>(_v) = _t->band4CompressorEnable(); break;
        case 415: *reinterpret_cast<bool*>(_v) = _t->isBand4CompressorEnableImmutable(); break;
        case 416: *reinterpret_cast<bool*>(_v) = _t->defaultBand4CompressorEnableValue(); break;
        case 417: *reinterpret_cast<bool*>(_v) = _t->band5CompressorEnable(); break;
        case 418: *reinterpret_cast<bool*>(_v) = _t->isBand5CompressorEnableImmutable(); break;
        case 419: *reinterpret_cast<bool*>(_v) = _t->defaultBand5CompressorEnableValue(); break;
        case 420: *reinterpret_cast<bool*>(_v) = _t->band6CompressorEnable(); break;
        case 421: *reinterpret_cast<bool*>(_v) = _t->isBand6CompressorEnableImmutable(); break;
        case 422: *reinterpret_cast<bool*>(_v) = _t->defaultBand6CompressorEnableValue(); break;
        case 423: *reinterpret_cast<bool*>(_v) = _t->band7CompressorEnable(); break;
        case 424: *reinterpret_cast<bool*>(_v) = _t->isBand7CompressorEnableImmutable(); break;
        case 425: *reinterpret_cast<bool*>(_v) = _t->defaultBand7CompressorEnableValue(); break;
        case 426: *reinterpret_cast<bool*>(_v) = _t->band0Solo(); break;
        case 427: *reinterpret_cast<bool*>(_v) = _t->isBand0SoloImmutable(); break;
        case 428: *reinterpret_cast<bool*>(_v) = _t->defaultBand0SoloValue(); break;
        case 429: *reinterpret_cast<bool*>(_v) = _t->band1Solo(); break;
        case 430: *reinterpret_cast<bool*>(_v) = _t->isBand1SoloImmutable(); break;
        case 431: *reinterpret_cast<bool*>(_v) = _t->defaultBand1SoloValue(); break;
        case 432: *reinterpret_cast<bool*>(_v) = _t->band2Solo(); break;
        case 433: *reinterpret_cast<bool*>(_v) = _t->isBand2SoloImmutable(); break;
        case 434: *reinterpret_cast<bool*>(_v) = _t->defaultBand2SoloValue(); break;
        case 435: *reinterpret_cast<bool*>(_v) = _t->band3Solo(); break;
        case 436: *reinterpret_cast<bool*>(_v) = _t->isBand3SoloImmutable(); break;
        case 437: *reinterpret_cast<bool*>(_v) = _t->defaultBand3SoloValue(); break;
        case 438: *reinterpret_cast<bool*>(_v) = _t->band4Solo(); break;
        case 439: *reinterpret_cast<bool*>(_v) = _t->isBand4SoloImmutable(); break;
        case 440: *reinterpret_cast<bool*>(_v) = _t->defaultBand4SoloValue(); break;
        case 441: *reinterpret_cast<bool*>(_v) = _t->band5Solo(); break;
        case 442: *reinterpret_cast<bool*>(_v) = _t->isBand5SoloImmutable(); break;
        case 443: *reinterpret_cast<bool*>(_v) = _t->defaultBand5SoloValue(); break;
        case 444: *reinterpret_cast<bool*>(_v) = _t->band6Solo(); break;
        case 445: *reinterpret_cast<bool*>(_v) = _t->isBand6SoloImmutable(); break;
        case 446: *reinterpret_cast<bool*>(_v) = _t->defaultBand6SoloValue(); break;
        case 447: *reinterpret_cast<bool*>(_v) = _t->band7Solo(); break;
        case 448: *reinterpret_cast<bool*>(_v) = _t->isBand7SoloImmutable(); break;
        case 449: *reinterpret_cast<bool*>(_v) = _t->defaultBand7SoloValue(); break;
        case 450: *reinterpret_cast<bool*>(_v) = _t->band0Mute(); break;
        case 451: *reinterpret_cast<bool*>(_v) = _t->isBand0MuteImmutable(); break;
        case 452: *reinterpret_cast<bool*>(_v) = _t->defaultBand0MuteValue(); break;
        case 453: *reinterpret_cast<bool*>(_v) = _t->band1Mute(); break;
        case 454: *reinterpret_cast<bool*>(_v) = _t->isBand1MuteImmutable(); break;
        case 455: *reinterpret_cast<bool*>(_v) = _t->defaultBand1MuteValue(); break;
        case 456: *reinterpret_cast<bool*>(_v) = _t->band2Mute(); break;
        case 457: *reinterpret_cast<bool*>(_v) = _t->isBand2MuteImmutable(); break;
        case 458: *reinterpret_cast<bool*>(_v) = _t->defaultBand2MuteValue(); break;
        case 459: *reinterpret_cast<bool*>(_v) = _t->band3Mute(); break;
        case 460: *reinterpret_cast<bool*>(_v) = _t->isBand3MuteImmutable(); break;
        case 461: *reinterpret_cast<bool*>(_v) = _t->defaultBand3MuteValue(); break;
        case 462: *reinterpret_cast<bool*>(_v) = _t->band4Mute(); break;
        case 463: *reinterpret_cast<bool*>(_v) = _t->isBand4MuteImmutable(); break;
        case 464: *reinterpret_cast<bool*>(_v) = _t->defaultBand4MuteValue(); break;
        case 465: *reinterpret_cast<bool*>(_v) = _t->band5Mute(); break;
        case 466: *reinterpret_cast<bool*>(_v) = _t->isBand5MuteImmutable(); break;
        case 467: *reinterpret_cast<bool*>(_v) = _t->defaultBand5MuteValue(); break;
        case 468: *reinterpret_cast<bool*>(_v) = _t->band6Mute(); break;
        case 469: *reinterpret_cast<bool*>(_v) = _t->isBand6MuteImmutable(); break;
        case 470: *reinterpret_cast<bool*>(_v) = _t->defaultBand6MuteValue(); break;
        case 471: *reinterpret_cast<bool*>(_v) = _t->band7Mute(); break;
        case 472: *reinterpret_cast<bool*>(_v) = _t->isBand7MuteImmutable(); break;
        case 473: *reinterpret_cast<bool*>(_v) = _t->defaultBand7MuteValue(); break;
        case 474: *reinterpret_cast<double*>(_v) = _t->band0AttackThreshold(); break;
        case 475: *reinterpret_cast<bool*>(_v) = _t->isBand0AttackThresholdImmutable(); break;
        case 476: *reinterpret_cast<double*>(_v) = _t->defaultBand0AttackThresholdValue(); break;
        case 477: *reinterpret_cast<double*>(_v) = _t->band1AttackThreshold(); break;
        case 478: *reinterpret_cast<bool*>(_v) = _t->isBand1AttackThresholdImmutable(); break;
        case 479: *reinterpret_cast<double*>(_v) = _t->defaultBand1AttackThresholdValue(); break;
        case 480: *reinterpret_cast<double*>(_v) = _t->band2AttackThreshold(); break;
        case 481: *reinterpret_cast<bool*>(_v) = _t->isBand2AttackThresholdImmutable(); break;
        case 482: *reinterpret_cast<double*>(_v) = _t->defaultBand2AttackThresholdValue(); break;
        case 483: *reinterpret_cast<double*>(_v) = _t->band3AttackThreshold(); break;
        case 484: *reinterpret_cast<bool*>(_v) = _t->isBand3AttackThresholdImmutable(); break;
        case 485: *reinterpret_cast<double*>(_v) = _t->defaultBand3AttackThresholdValue(); break;
        case 486: *reinterpret_cast<double*>(_v) = _t->band4AttackThreshold(); break;
        case 487: *reinterpret_cast<bool*>(_v) = _t->isBand4AttackThresholdImmutable(); break;
        case 488: *reinterpret_cast<double*>(_v) = _t->defaultBand4AttackThresholdValue(); break;
        case 489: *reinterpret_cast<double*>(_v) = _t->band5AttackThreshold(); break;
        case 490: *reinterpret_cast<bool*>(_v) = _t->isBand5AttackThresholdImmutable(); break;
        case 491: *reinterpret_cast<double*>(_v) = _t->defaultBand5AttackThresholdValue(); break;
        case 492: *reinterpret_cast<double*>(_v) = _t->band6AttackThreshold(); break;
        case 493: *reinterpret_cast<bool*>(_v) = _t->isBand6AttackThresholdImmutable(); break;
        case 494: *reinterpret_cast<double*>(_v) = _t->defaultBand6AttackThresholdValue(); break;
        case 495: *reinterpret_cast<double*>(_v) = _t->band7AttackThreshold(); break;
        case 496: *reinterpret_cast<bool*>(_v) = _t->isBand7AttackThresholdImmutable(); break;
        case 497: *reinterpret_cast<double*>(_v) = _t->defaultBand7AttackThresholdValue(); break;
        case 498: *reinterpret_cast<double*>(_v) = _t->band0AttackTime(); break;
        case 499: *reinterpret_cast<bool*>(_v) = _t->isBand0AttackTimeImmutable(); break;
        case 500: *reinterpret_cast<double*>(_v) = _t->defaultBand0AttackTimeValue(); break;
        case 501: *reinterpret_cast<double*>(_v) = _t->band1AttackTime(); break;
        case 502: *reinterpret_cast<bool*>(_v) = _t->isBand1AttackTimeImmutable(); break;
        case 503: *reinterpret_cast<double*>(_v) = _t->defaultBand1AttackTimeValue(); break;
        case 504: *reinterpret_cast<double*>(_v) = _t->band2AttackTime(); break;
        case 505: *reinterpret_cast<bool*>(_v) = _t->isBand2AttackTimeImmutable(); break;
        case 506: *reinterpret_cast<double*>(_v) = _t->defaultBand2AttackTimeValue(); break;
        case 507: *reinterpret_cast<double*>(_v) = _t->band3AttackTime(); break;
        case 508: *reinterpret_cast<bool*>(_v) = _t->isBand3AttackTimeImmutable(); break;
        case 509: *reinterpret_cast<double*>(_v) = _t->defaultBand3AttackTimeValue(); break;
        case 510: *reinterpret_cast<double*>(_v) = _t->band4AttackTime(); break;
        case 511: *reinterpret_cast<bool*>(_v) = _t->isBand4AttackTimeImmutable(); break;
        case 512: *reinterpret_cast<double*>(_v) = _t->defaultBand4AttackTimeValue(); break;
        case 513: *reinterpret_cast<double*>(_v) = _t->band5AttackTime(); break;
        case 514: *reinterpret_cast<bool*>(_v) = _t->isBand5AttackTimeImmutable(); break;
        case 515: *reinterpret_cast<double*>(_v) = _t->defaultBand5AttackTimeValue(); break;
        case 516: *reinterpret_cast<double*>(_v) = _t->band6AttackTime(); break;
        case 517: *reinterpret_cast<bool*>(_v) = _t->isBand6AttackTimeImmutable(); break;
        case 518: *reinterpret_cast<double*>(_v) = _t->defaultBand6AttackTimeValue(); break;
        case 519: *reinterpret_cast<double*>(_v) = _t->band7AttackTime(); break;
        case 520: *reinterpret_cast<bool*>(_v) = _t->isBand7AttackTimeImmutable(); break;
        case 521: *reinterpret_cast<double*>(_v) = _t->defaultBand7AttackTimeValue(); break;
        case 522: *reinterpret_cast<double*>(_v) = _t->band0ReleaseThreshold(); break;
        case 523: *reinterpret_cast<bool*>(_v) = _t->isBand0ReleaseThresholdImmutable(); break;
        case 524: *reinterpret_cast<double*>(_v) = _t->defaultBand0ReleaseThresholdValue(); break;
        case 525: *reinterpret_cast<double*>(_v) = _t->band1ReleaseThreshold(); break;
        case 526: *reinterpret_cast<bool*>(_v) = _t->isBand1ReleaseThresholdImmutable(); break;
        case 527: *reinterpret_cast<double*>(_v) = _t->defaultBand1ReleaseThresholdValue(); break;
        case 528: *reinterpret_cast<double*>(_v) = _t->band2ReleaseThreshold(); break;
        case 529: *reinterpret_cast<bool*>(_v) = _t->isBand2ReleaseThresholdImmutable(); break;
        case 530: *reinterpret_cast<double*>(_v) = _t->defaultBand2ReleaseThresholdValue(); break;
        case 531: *reinterpret_cast<double*>(_v) = _t->band3ReleaseThreshold(); break;
        case 532: *reinterpret_cast<bool*>(_v) = _t->isBand3ReleaseThresholdImmutable(); break;
        case 533: *reinterpret_cast<double*>(_v) = _t->defaultBand3ReleaseThresholdValue(); break;
        case 534: *reinterpret_cast<double*>(_v) = _t->band4ReleaseThreshold(); break;
        case 535: *reinterpret_cast<bool*>(_v) = _t->isBand4ReleaseThresholdImmutable(); break;
        case 536: *reinterpret_cast<double*>(_v) = _t->defaultBand4ReleaseThresholdValue(); break;
        case 537: *reinterpret_cast<double*>(_v) = _t->band5ReleaseThreshold(); break;
        case 538: *reinterpret_cast<bool*>(_v) = _t->isBand5ReleaseThresholdImmutable(); break;
        case 539: *reinterpret_cast<double*>(_v) = _t->defaultBand5ReleaseThresholdValue(); break;
        case 540: *reinterpret_cast<double*>(_v) = _t->band6ReleaseThreshold(); break;
        case 541: *reinterpret_cast<bool*>(_v) = _t->isBand6ReleaseThresholdImmutable(); break;
        case 542: *reinterpret_cast<double*>(_v) = _t->defaultBand6ReleaseThresholdValue(); break;
        case 543: *reinterpret_cast<double*>(_v) = _t->band7ReleaseThreshold(); break;
        case 544: *reinterpret_cast<bool*>(_v) = _t->isBand7ReleaseThresholdImmutable(); break;
        case 545: *reinterpret_cast<double*>(_v) = _t->defaultBand7ReleaseThresholdValue(); break;
        case 546: *reinterpret_cast<double*>(_v) = _t->band0ReleaseTime(); break;
        case 547: *reinterpret_cast<bool*>(_v) = _t->isBand0ReleaseTimeImmutable(); break;
        case 548: *reinterpret_cast<double*>(_v) = _t->defaultBand0ReleaseTimeValue(); break;
        case 549: *reinterpret_cast<double*>(_v) = _t->band1ReleaseTime(); break;
        case 550: *reinterpret_cast<bool*>(_v) = _t->isBand1ReleaseTimeImmutable(); break;
        case 551: *reinterpret_cast<double*>(_v) = _t->defaultBand1ReleaseTimeValue(); break;
        case 552: *reinterpret_cast<double*>(_v) = _t->band2ReleaseTime(); break;
        case 553: *reinterpret_cast<bool*>(_v) = _t->isBand2ReleaseTimeImmutable(); break;
        case 554: *reinterpret_cast<double*>(_v) = _t->defaultBand2ReleaseTimeValue(); break;
        case 555: *reinterpret_cast<double*>(_v) = _t->band3ReleaseTime(); break;
        case 556: *reinterpret_cast<bool*>(_v) = _t->isBand3ReleaseTimeImmutable(); break;
        case 557: *reinterpret_cast<double*>(_v) = _t->defaultBand3ReleaseTimeValue(); break;
        case 558: *reinterpret_cast<double*>(_v) = _t->band4ReleaseTime(); break;
        case 559: *reinterpret_cast<bool*>(_v) = _t->isBand4ReleaseTimeImmutable(); break;
        case 560: *reinterpret_cast<double*>(_v) = _t->defaultBand4ReleaseTimeValue(); break;
        case 561: *reinterpret_cast<double*>(_v) = _t->band5ReleaseTime(); break;
        case 562: *reinterpret_cast<bool*>(_v) = _t->isBand5ReleaseTimeImmutable(); break;
        case 563: *reinterpret_cast<double*>(_v) = _t->defaultBand5ReleaseTimeValue(); break;
        case 564: *reinterpret_cast<double*>(_v) = _t->band6ReleaseTime(); break;
        case 565: *reinterpret_cast<bool*>(_v) = _t->isBand6ReleaseTimeImmutable(); break;
        case 566: *reinterpret_cast<double*>(_v) = _t->defaultBand6ReleaseTimeValue(); break;
        case 567: *reinterpret_cast<double*>(_v) = _t->band7ReleaseTime(); break;
        case 568: *reinterpret_cast<bool*>(_v) = _t->isBand7ReleaseTimeImmutable(); break;
        case 569: *reinterpret_cast<double*>(_v) = _t->defaultBand7ReleaseTimeValue(); break;
        case 570: *reinterpret_cast<double*>(_v) = _t->band0Ratio(); break;
        case 571: *reinterpret_cast<bool*>(_v) = _t->isBand0RatioImmutable(); break;
        case 572: *reinterpret_cast<double*>(_v) = _t->defaultBand0RatioValue(); break;
        case 573: *reinterpret_cast<double*>(_v) = _t->band1Ratio(); break;
        case 574: *reinterpret_cast<bool*>(_v) = _t->isBand1RatioImmutable(); break;
        case 575: *reinterpret_cast<double*>(_v) = _t->defaultBand1RatioValue(); break;
        case 576: *reinterpret_cast<double*>(_v) = _t->band2Ratio(); break;
        case 577: *reinterpret_cast<bool*>(_v) = _t->isBand2RatioImmutable(); break;
        case 578: *reinterpret_cast<double*>(_v) = _t->defaultBand2RatioValue(); break;
        case 579: *reinterpret_cast<double*>(_v) = _t->band3Ratio(); break;
        case 580: *reinterpret_cast<bool*>(_v) = _t->isBand3RatioImmutable(); break;
        case 581: *reinterpret_cast<double*>(_v) = _t->defaultBand3RatioValue(); break;
        case 582: *reinterpret_cast<double*>(_v) = _t->band4Ratio(); break;
        case 583: *reinterpret_cast<bool*>(_v) = _t->isBand4RatioImmutable(); break;
        case 584: *reinterpret_cast<double*>(_v) = _t->defaultBand4RatioValue(); break;
        case 585: *reinterpret_cast<double*>(_v) = _t->band5Ratio(); break;
        case 586: *reinterpret_cast<bool*>(_v) = _t->isBand5RatioImmutable(); break;
        case 587: *reinterpret_cast<double*>(_v) = _t->defaultBand5RatioValue(); break;
        case 588: *reinterpret_cast<double*>(_v) = _t->band6Ratio(); break;
        case 589: *reinterpret_cast<bool*>(_v) = _t->isBand6RatioImmutable(); break;
        case 590: *reinterpret_cast<double*>(_v) = _t->defaultBand6RatioValue(); break;
        case 591: *reinterpret_cast<double*>(_v) = _t->band7Ratio(); break;
        case 592: *reinterpret_cast<bool*>(_v) = _t->isBand7RatioImmutable(); break;
        case 593: *reinterpret_cast<double*>(_v) = _t->defaultBand7RatioValue(); break;
        case 594: *reinterpret_cast<double*>(_v) = _t->band0Knee(); break;
        case 595: *reinterpret_cast<bool*>(_v) = _t->isBand0KneeImmutable(); break;
        case 596: *reinterpret_cast<double*>(_v) = _t->defaultBand0KneeValue(); break;
        case 597: *reinterpret_cast<double*>(_v) = _t->band1Knee(); break;
        case 598: *reinterpret_cast<bool*>(_v) = _t->isBand1KneeImmutable(); break;
        case 599: *reinterpret_cast<double*>(_v) = _t->defaultBand1KneeValue(); break;
        case 600: *reinterpret_cast<double*>(_v) = _t->band2Knee(); break;
        case 601: *reinterpret_cast<bool*>(_v) = _t->isBand2KneeImmutable(); break;
        case 602: *reinterpret_cast<double*>(_v) = _t->defaultBand2KneeValue(); break;
        case 603: *reinterpret_cast<double*>(_v) = _t->band3Knee(); break;
        case 604: *reinterpret_cast<bool*>(_v) = _t->isBand3KneeImmutable(); break;
        case 605: *reinterpret_cast<double*>(_v) = _t->defaultBand3KneeValue(); break;
        case 606: *reinterpret_cast<double*>(_v) = _t->band4Knee(); break;
        case 607: *reinterpret_cast<bool*>(_v) = _t->isBand4KneeImmutable(); break;
        case 608: *reinterpret_cast<double*>(_v) = _t->defaultBand4KneeValue(); break;
        case 609: *reinterpret_cast<double*>(_v) = _t->band5Knee(); break;
        case 610: *reinterpret_cast<bool*>(_v) = _t->isBand5KneeImmutable(); break;
        case 611: *reinterpret_cast<double*>(_v) = _t->defaultBand5KneeValue(); break;
        case 612: *reinterpret_cast<double*>(_v) = _t->band6Knee(); break;
        case 613: *reinterpret_cast<bool*>(_v) = _t->isBand6KneeImmutable(); break;
        case 614: *reinterpret_cast<double*>(_v) = _t->defaultBand6KneeValue(); break;
        case 615: *reinterpret_cast<double*>(_v) = _t->band7Knee(); break;
        case 616: *reinterpret_cast<bool*>(_v) = _t->isBand7KneeImmutable(); break;
        case 617: *reinterpret_cast<double*>(_v) = _t->defaultBand7KneeValue(); break;
        case 618: *reinterpret_cast<double*>(_v) = _t->band0BoostThreshold(); break;
        case 619: *reinterpret_cast<bool*>(_v) = _t->isBand0BoostThresholdImmutable(); break;
        case 620: *reinterpret_cast<double*>(_v) = _t->defaultBand0BoostThresholdValue(); break;
        case 621: *reinterpret_cast<double*>(_v) = _t->band1BoostThreshold(); break;
        case 622: *reinterpret_cast<bool*>(_v) = _t->isBand1BoostThresholdImmutable(); break;
        case 623: *reinterpret_cast<double*>(_v) = _t->defaultBand1BoostThresholdValue(); break;
        case 624: *reinterpret_cast<double*>(_v) = _t->band2BoostThreshold(); break;
        case 625: *reinterpret_cast<bool*>(_v) = _t->isBand2BoostThresholdImmutable(); break;
        case 626: *reinterpret_cast<double*>(_v) = _t->defaultBand2BoostThresholdValue(); break;
        case 627: *reinterpret_cast<double*>(_v) = _t->band3BoostThreshold(); break;
        case 628: *reinterpret_cast<bool*>(_v) = _t->isBand3BoostThresholdImmutable(); break;
        case 629: *reinterpret_cast<double*>(_v) = _t->defaultBand3BoostThresholdValue(); break;
        case 630: *reinterpret_cast<double*>(_v) = _t->band4BoostThreshold(); break;
        case 631: *reinterpret_cast<bool*>(_v) = _t->isBand4BoostThresholdImmutable(); break;
        case 632: *reinterpret_cast<double*>(_v) = _t->defaultBand4BoostThresholdValue(); break;
        case 633: *reinterpret_cast<double*>(_v) = _t->band5BoostThreshold(); break;
        case 634: *reinterpret_cast<bool*>(_v) = _t->isBand5BoostThresholdImmutable(); break;
        case 635: *reinterpret_cast<double*>(_v) = _t->defaultBand5BoostThresholdValue(); break;
        case 636: *reinterpret_cast<double*>(_v) = _t->band6BoostThreshold(); break;
        case 637: *reinterpret_cast<bool*>(_v) = _t->isBand6BoostThresholdImmutable(); break;
        case 638: *reinterpret_cast<double*>(_v) = _t->defaultBand6BoostThresholdValue(); break;
        case 639: *reinterpret_cast<double*>(_v) = _t->band7BoostThreshold(); break;
        case 640: *reinterpret_cast<bool*>(_v) = _t->isBand7BoostThresholdImmutable(); break;
        case 641: *reinterpret_cast<double*>(_v) = _t->defaultBand7BoostThresholdValue(); break;
        case 642: *reinterpret_cast<double*>(_v) = _t->band0BoostAmount(); break;
        case 643: *reinterpret_cast<bool*>(_v) = _t->isBand0BoostAmountImmutable(); break;
        case 644: *reinterpret_cast<double*>(_v) = _t->defaultBand0BoostAmountValue(); break;
        case 645: *reinterpret_cast<double*>(_v) = _t->band1BoostAmount(); break;
        case 646: *reinterpret_cast<bool*>(_v) = _t->isBand1BoostAmountImmutable(); break;
        case 647: *reinterpret_cast<double*>(_v) = _t->defaultBand1BoostAmountValue(); break;
        case 648: *reinterpret_cast<double*>(_v) = _t->band2BoostAmount(); break;
        case 649: *reinterpret_cast<bool*>(_v) = _t->isBand2BoostAmountImmutable(); break;
        case 650: *reinterpret_cast<double*>(_v) = _t->defaultBand2BoostAmountValue(); break;
        case 651: *reinterpret_cast<double*>(_v) = _t->band3BoostAmount(); break;
        case 652: *reinterpret_cast<bool*>(_v) = _t->isBand3BoostAmountImmutable(); break;
        case 653: *reinterpret_cast<double*>(_v) = _t->defaultBand3BoostAmountValue(); break;
        case 654: *reinterpret_cast<double*>(_v) = _t->band4BoostAmount(); break;
        case 655: *reinterpret_cast<bool*>(_v) = _t->isBand4BoostAmountImmutable(); break;
        case 656: *reinterpret_cast<double*>(_v) = _t->defaultBand4BoostAmountValue(); break;
        case 657: *reinterpret_cast<double*>(_v) = _t->band5BoostAmount(); break;
        case 658: *reinterpret_cast<bool*>(_v) = _t->isBand5BoostAmountImmutable(); break;
        case 659: *reinterpret_cast<double*>(_v) = _t->defaultBand5BoostAmountValue(); break;
        case 660: *reinterpret_cast<double*>(_v) = _t->band6BoostAmount(); break;
        case 661: *reinterpret_cast<bool*>(_v) = _t->isBand6BoostAmountImmutable(); break;
        case 662: *reinterpret_cast<double*>(_v) = _t->defaultBand6BoostAmountValue(); break;
        case 663: *reinterpret_cast<double*>(_v) = _t->band7BoostAmount(); break;
        case 664: *reinterpret_cast<bool*>(_v) = _t->isBand7BoostAmountImmutable(); break;
        case 665: *reinterpret_cast<double*>(_v) = _t->defaultBand7BoostAmountValue(); break;
        case 666: *reinterpret_cast<double*>(_v) = _t->band0Makeup(); break;
        case 667: *reinterpret_cast<bool*>(_v) = _t->isBand0MakeupImmutable(); break;
        case 668: *reinterpret_cast<double*>(_v) = _t->defaultBand0MakeupValue(); break;
        case 669: *reinterpret_cast<double*>(_v) = _t->band1Makeup(); break;
        case 670: *reinterpret_cast<bool*>(_v) = _t->isBand1MakeupImmutable(); break;
        case 671: *reinterpret_cast<double*>(_v) = _t->defaultBand1MakeupValue(); break;
        case 672: *reinterpret_cast<double*>(_v) = _t->band2Makeup(); break;
        case 673: *reinterpret_cast<bool*>(_v) = _t->isBand2MakeupImmutable(); break;
        case 674: *reinterpret_cast<double*>(_v) = _t->defaultBand2MakeupValue(); break;
        case 675: *reinterpret_cast<double*>(_v) = _t->band3Makeup(); break;
        case 676: *reinterpret_cast<bool*>(_v) = _t->isBand3MakeupImmutable(); break;
        case 677: *reinterpret_cast<double*>(_v) = _t->defaultBand3MakeupValue(); break;
        case 678: *reinterpret_cast<double*>(_v) = _t->band4Makeup(); break;
        case 679: *reinterpret_cast<bool*>(_v) = _t->isBand4MakeupImmutable(); break;
        case 680: *reinterpret_cast<double*>(_v) = _t->defaultBand4MakeupValue(); break;
        case 681: *reinterpret_cast<double*>(_v) = _t->band5Makeup(); break;
        case 682: *reinterpret_cast<bool*>(_v) = _t->isBand5MakeupImmutable(); break;
        case 683: *reinterpret_cast<double*>(_v) = _t->defaultBand5MakeupValue(); break;
        case 684: *reinterpret_cast<double*>(_v) = _t->band6Makeup(); break;
        case 685: *reinterpret_cast<bool*>(_v) = _t->isBand6MakeupImmutable(); break;
        case 686: *reinterpret_cast<double*>(_v) = _t->defaultBand6MakeupValue(); break;
        case 687: *reinterpret_cast<double*>(_v) = _t->band7Makeup(); break;
        case 688: *reinterpret_cast<bool*>(_v) = _t->isBand7MakeupImmutable(); break;
        case 689: *reinterpret_cast<double*>(_v) = _t->defaultBand7MakeupValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBypass(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setInputGain(*reinterpret_cast<double*>(_v)); break;
        case 6: _t->setOutputGain(*reinterpret_cast<double*>(_v)); break;
        case 9: _t->setDry(*reinterpret_cast<double*>(_v)); break;
        case 12: _t->setWet(*reinterpret_cast<double*>(_v)); break;
        case 15: _t->setViewSidechain(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setExternalSidechainEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 21: _t->setStereoSplit(*reinterpret_cast<bool*>(_v)); break;
        case 24: _t->setCompressorModeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 27: _t->setCompressorMode(*reinterpret_cast<int*>(_v)); break;
        case 30: _t->setEnvelopeBoostLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 33: _t->setEnvelopeBoost(*reinterpret_cast<int*>(_v)); break;
        case 36: _t->setInputToSidechain(*reinterpret_cast<double*>(_v)); break;
        case 39: _t->setInputToLink(*reinterpret_cast<double*>(_v)); break;
        case 42: _t->setSidechainToInput(*reinterpret_cast<double*>(_v)); break;
        case 45: _t->setSidechainToLink(*reinterpret_cast<double*>(_v)); break;
        case 48: _t->setLinkToSidechain(*reinterpret_cast<double*>(_v)); break;
        case 51: _t->setLinkToInput(*reinterpret_cast<double*>(_v)); break;
        case 54: _t->setBand1Enable(*reinterpret_cast<bool*>(_v)); break;
        case 57: _t->setBand2Enable(*reinterpret_cast<bool*>(_v)); break;
        case 60: _t->setBand3Enable(*reinterpret_cast<bool*>(_v)); break;
        case 63: _t->setBand4Enable(*reinterpret_cast<bool*>(_v)); break;
        case 66: _t->setBand5Enable(*reinterpret_cast<bool*>(_v)); break;
        case 69: _t->setBand6Enable(*reinterpret_cast<bool*>(_v)); break;
        case 72: _t->setBand7Enable(*reinterpret_cast<bool*>(_v)); break;
        case 75: _t->setBand1SplitFrequency(*reinterpret_cast<double*>(_v)); break;
        case 78: _t->setBand2SplitFrequency(*reinterpret_cast<double*>(_v)); break;
        case 81: _t->setBand3SplitFrequency(*reinterpret_cast<double*>(_v)); break;
        case 84: _t->setBand4SplitFrequency(*reinterpret_cast<double*>(_v)); break;
        case 87: _t->setBand5SplitFrequency(*reinterpret_cast<double*>(_v)); break;
        case 90: _t->setBand6SplitFrequency(*reinterpret_cast<double*>(_v)); break;
        case 93: _t->setBand7SplitFrequency(*reinterpret_cast<double*>(_v)); break;
        case 96: _t->setSidechainInputDevice(*reinterpret_cast<QString*>(_v)); break;
        case 99: _t->setSidechainTypeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 102: _t->setBand0SidechainType(*reinterpret_cast<int*>(_v)); break;
        case 105: _t->setBand1SidechainType(*reinterpret_cast<int*>(_v)); break;
        case 108: _t->setBand2SidechainType(*reinterpret_cast<int*>(_v)); break;
        case 111: _t->setBand3SidechainType(*reinterpret_cast<int*>(_v)); break;
        case 114: _t->setBand4SidechainType(*reinterpret_cast<int*>(_v)); break;
        case 117: _t->setBand5SidechainType(*reinterpret_cast<int*>(_v)); break;
        case 120: _t->setBand6SidechainType(*reinterpret_cast<int*>(_v)); break;
        case 123: _t->setBand7SidechainType(*reinterpret_cast<int*>(_v)); break;
        case 126: _t->setSidechainModeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 129: _t->setBand0SidechainMode(*reinterpret_cast<int*>(_v)); break;
        case 132: _t->setBand1SidechainMode(*reinterpret_cast<int*>(_v)); break;
        case 135: _t->setBand2SidechainMode(*reinterpret_cast<int*>(_v)); break;
        case 138: _t->setBand3SidechainMode(*reinterpret_cast<int*>(_v)); break;
        case 141: _t->setBand4SidechainMode(*reinterpret_cast<int*>(_v)); break;
        case 144: _t->setBand5SidechainMode(*reinterpret_cast<int*>(_v)); break;
        case 147: _t->setBand6SidechainMode(*reinterpret_cast<int*>(_v)); break;
        case 150: _t->setBand7SidechainMode(*reinterpret_cast<int*>(_v)); break;
        case 153: _t->setSidechainSourceLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 156: _t->setBand0SidechainSource(*reinterpret_cast<int*>(_v)); break;
        case 159: _t->setBand1SidechainSource(*reinterpret_cast<int*>(_v)); break;
        case 162: _t->setBand2SidechainSource(*reinterpret_cast<int*>(_v)); break;
        case 165: _t->setBand3SidechainSource(*reinterpret_cast<int*>(_v)); break;
        case 168: _t->setBand4SidechainSource(*reinterpret_cast<int*>(_v)); break;
        case 171: _t->setBand5SidechainSource(*reinterpret_cast<int*>(_v)); break;
        case 174: _t->setBand6SidechainSource(*reinterpret_cast<int*>(_v)); break;
        case 177: _t->setBand7SidechainSource(*reinterpret_cast<int*>(_v)); break;
        case 180: _t->setStereoSplitSourceLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 183: _t->setBand0StereoSplitSource(*reinterpret_cast<int*>(_v)); break;
        case 186: _t->setBand1StereoSplitSource(*reinterpret_cast<int*>(_v)); break;
        case 189: _t->setBand2StereoSplitSource(*reinterpret_cast<int*>(_v)); break;
        case 192: _t->setBand3StereoSplitSource(*reinterpret_cast<int*>(_v)); break;
        case 195: _t->setBand4StereoSplitSource(*reinterpret_cast<int*>(_v)); break;
        case 198: _t->setBand5StereoSplitSource(*reinterpret_cast<int*>(_v)); break;
        case 201: _t->setBand6StereoSplitSource(*reinterpret_cast<int*>(_v)); break;
        case 204: _t->setBand7StereoSplitSource(*reinterpret_cast<int*>(_v)); break;
        case 207: _t->setBand0SidechainLookahead(*reinterpret_cast<double*>(_v)); break;
        case 210: _t->setBand1SidechainLookahead(*reinterpret_cast<double*>(_v)); break;
        case 213: _t->setBand2SidechainLookahead(*reinterpret_cast<double*>(_v)); break;
        case 216: _t->setBand3SidechainLookahead(*reinterpret_cast<double*>(_v)); break;
        case 219: _t->setBand4SidechainLookahead(*reinterpret_cast<double*>(_v)); break;
        case 222: _t->setBand5SidechainLookahead(*reinterpret_cast<double*>(_v)); break;
        case 225: _t->setBand6SidechainLookahead(*reinterpret_cast<double*>(_v)); break;
        case 228: _t->setBand7SidechainLookahead(*reinterpret_cast<double*>(_v)); break;
        case 231: _t->setBand0SidechainReactivity(*reinterpret_cast<double*>(_v)); break;
        case 234: _t->setBand1SidechainReactivity(*reinterpret_cast<double*>(_v)); break;
        case 237: _t->setBand2SidechainReactivity(*reinterpret_cast<double*>(_v)); break;
        case 240: _t->setBand3SidechainReactivity(*reinterpret_cast<double*>(_v)); break;
        case 243: _t->setBand4SidechainReactivity(*reinterpret_cast<double*>(_v)); break;
        case 246: _t->setBand5SidechainReactivity(*reinterpret_cast<double*>(_v)); break;
        case 249: _t->setBand6SidechainReactivity(*reinterpret_cast<double*>(_v)); break;
        case 252: _t->setBand7SidechainReactivity(*reinterpret_cast<double*>(_v)); break;
        case 255: _t->setBand0SidechainPreamp(*reinterpret_cast<double*>(_v)); break;
        case 258: _t->setBand1SidechainPreamp(*reinterpret_cast<double*>(_v)); break;
        case 261: _t->setBand2SidechainPreamp(*reinterpret_cast<double*>(_v)); break;
        case 264: _t->setBand3SidechainPreamp(*reinterpret_cast<double*>(_v)); break;
        case 267: _t->setBand4SidechainPreamp(*reinterpret_cast<double*>(_v)); break;
        case 270: _t->setBand5SidechainPreamp(*reinterpret_cast<double*>(_v)); break;
        case 273: _t->setBand6SidechainPreamp(*reinterpret_cast<double*>(_v)); break;
        case 276: _t->setBand7SidechainPreamp(*reinterpret_cast<double*>(_v)); break;
        case 279: _t->setBand0SidechainCustomLowcutFilter(*reinterpret_cast<bool*>(_v)); break;
        case 282: _t->setBand1SidechainCustomLowcutFilter(*reinterpret_cast<bool*>(_v)); break;
        case 285: _t->setBand2SidechainCustomLowcutFilter(*reinterpret_cast<bool*>(_v)); break;
        case 288: _t->setBand3SidechainCustomLowcutFilter(*reinterpret_cast<bool*>(_v)); break;
        case 291: _t->setBand4SidechainCustomLowcutFilter(*reinterpret_cast<bool*>(_v)); break;
        case 294: _t->setBand5SidechainCustomLowcutFilter(*reinterpret_cast<bool*>(_v)); break;
        case 297: _t->setBand6SidechainCustomLowcutFilter(*reinterpret_cast<bool*>(_v)); break;
        case 300: _t->setBand7SidechainCustomLowcutFilter(*reinterpret_cast<bool*>(_v)); break;
        case 303: _t->setBand0SidechainCustomHighcutFilter(*reinterpret_cast<bool*>(_v)); break;
        case 306: _t->setBand1SidechainCustomHighcutFilter(*reinterpret_cast<bool*>(_v)); break;
        case 309: _t->setBand2SidechainCustomHighcutFilter(*reinterpret_cast<bool*>(_v)); break;
        case 312: _t->setBand3SidechainCustomHighcutFilter(*reinterpret_cast<bool*>(_v)); break;
        case 315: _t->setBand4SidechainCustomHighcutFilter(*reinterpret_cast<bool*>(_v)); break;
        case 318: _t->setBand5SidechainCustomHighcutFilter(*reinterpret_cast<bool*>(_v)); break;
        case 321: _t->setBand6SidechainCustomHighcutFilter(*reinterpret_cast<bool*>(_v)); break;
        case 324: _t->setBand7SidechainCustomHighcutFilter(*reinterpret_cast<bool*>(_v)); break;
        case 327: _t->setBand0SidechainLowcutFrequency(*reinterpret_cast<double*>(_v)); break;
        case 330: _t->setBand1SidechainLowcutFrequency(*reinterpret_cast<double*>(_v)); break;
        case 333: _t->setBand2SidechainLowcutFrequency(*reinterpret_cast<double*>(_v)); break;
        case 336: _t->setBand3SidechainLowcutFrequency(*reinterpret_cast<double*>(_v)); break;
        case 339: _t->setBand4SidechainLowcutFrequency(*reinterpret_cast<double*>(_v)); break;
        case 342: _t->setBand5SidechainLowcutFrequency(*reinterpret_cast<double*>(_v)); break;
        case 345: _t->setBand6SidechainLowcutFrequency(*reinterpret_cast<double*>(_v)); break;
        case 348: _t->setBand7SidechainLowcutFrequency(*reinterpret_cast<double*>(_v)); break;
        case 351: _t->setBand0SidechainHighcutFrequency(*reinterpret_cast<double*>(_v)); break;
        case 354: _t->setBand1SidechainHighcutFrequency(*reinterpret_cast<double*>(_v)); break;
        case 357: _t->setBand2SidechainHighcutFrequency(*reinterpret_cast<double*>(_v)); break;
        case 360: _t->setBand3SidechainHighcutFrequency(*reinterpret_cast<double*>(_v)); break;
        case 363: _t->setBand4SidechainHighcutFrequency(*reinterpret_cast<double*>(_v)); break;
        case 366: _t->setBand5SidechainHighcutFrequency(*reinterpret_cast<double*>(_v)); break;
        case 369: _t->setBand6SidechainHighcutFrequency(*reinterpret_cast<double*>(_v)); break;
        case 372: _t->setBand7SidechainHighcutFrequency(*reinterpret_cast<double*>(_v)); break;
        case 375: _t->setCompressionModeLabels(*reinterpret_cast<QStringList*>(_v)); break;
        case 378: _t->setBand0CompressionMode(*reinterpret_cast<int*>(_v)); break;
        case 381: _t->setBand1CompressionMode(*reinterpret_cast<int*>(_v)); break;
        case 384: _t->setBand2CompressionMode(*reinterpret_cast<int*>(_v)); break;
        case 387: _t->setBand3CompressionMode(*reinterpret_cast<int*>(_v)); break;
        case 390: _t->setBand4CompressionMode(*reinterpret_cast<int*>(_v)); break;
        case 393: _t->setBand5CompressionMode(*reinterpret_cast<int*>(_v)); break;
        case 396: _t->setBand6CompressionMode(*reinterpret_cast<int*>(_v)); break;
        case 399: _t->setBand7CompressionMode(*reinterpret_cast<int*>(_v)); break;
        case 402: _t->setBand0CompressorEnable(*reinterpret_cast<bool*>(_v)); break;
        case 405: _t->setBand1CompressorEnable(*reinterpret_cast<bool*>(_v)); break;
        case 408: _t->setBand2CompressorEnable(*reinterpret_cast<bool*>(_v)); break;
        case 411: _t->setBand3CompressorEnable(*reinterpret_cast<bool*>(_v)); break;
        case 414: _t->setBand4CompressorEnable(*reinterpret_cast<bool*>(_v)); break;
        case 417: _t->setBand5CompressorEnable(*reinterpret_cast<bool*>(_v)); break;
        case 420: _t->setBand6CompressorEnable(*reinterpret_cast<bool*>(_v)); break;
        case 423: _t->setBand7CompressorEnable(*reinterpret_cast<bool*>(_v)); break;
        case 426: _t->setBand0Solo(*reinterpret_cast<bool*>(_v)); break;
        case 429: _t->setBand1Solo(*reinterpret_cast<bool*>(_v)); break;
        case 432: _t->setBand2Solo(*reinterpret_cast<bool*>(_v)); break;
        case 435: _t->setBand3Solo(*reinterpret_cast<bool*>(_v)); break;
        case 438: _t->setBand4Solo(*reinterpret_cast<bool*>(_v)); break;
        case 441: _t->setBand5Solo(*reinterpret_cast<bool*>(_v)); break;
        case 444: _t->setBand6Solo(*reinterpret_cast<bool*>(_v)); break;
        case 447: _t->setBand7Solo(*reinterpret_cast<bool*>(_v)); break;
        case 450: _t->setBand0Mute(*reinterpret_cast<bool*>(_v)); break;
        case 453: _t->setBand1Mute(*reinterpret_cast<bool*>(_v)); break;
        case 456: _t->setBand2Mute(*reinterpret_cast<bool*>(_v)); break;
        case 459: _t->setBand3Mute(*reinterpret_cast<bool*>(_v)); break;
        case 462: _t->setBand4Mute(*reinterpret_cast<bool*>(_v)); break;
        case 465: _t->setBand5Mute(*reinterpret_cast<bool*>(_v)); break;
        case 468: _t->setBand6Mute(*reinterpret_cast<bool*>(_v)); break;
        case 471: _t->setBand7Mute(*reinterpret_cast<bool*>(_v)); break;
        case 474: _t->setBand0AttackThreshold(*reinterpret_cast<double*>(_v)); break;
        case 477: _t->setBand1AttackThreshold(*reinterpret_cast<double*>(_v)); break;
        case 480: _t->setBand2AttackThreshold(*reinterpret_cast<double*>(_v)); break;
        case 483: _t->setBand3AttackThreshold(*reinterpret_cast<double*>(_v)); break;
        case 486: _t->setBand4AttackThreshold(*reinterpret_cast<double*>(_v)); break;
        case 489: _t->setBand5AttackThreshold(*reinterpret_cast<double*>(_v)); break;
        case 492: _t->setBand6AttackThreshold(*reinterpret_cast<double*>(_v)); break;
        case 495: _t->setBand7AttackThreshold(*reinterpret_cast<double*>(_v)); break;
        case 498: _t->setBand0AttackTime(*reinterpret_cast<double*>(_v)); break;
        case 501: _t->setBand1AttackTime(*reinterpret_cast<double*>(_v)); break;
        case 504: _t->setBand2AttackTime(*reinterpret_cast<double*>(_v)); break;
        case 507: _t->setBand3AttackTime(*reinterpret_cast<double*>(_v)); break;
        case 510: _t->setBand4AttackTime(*reinterpret_cast<double*>(_v)); break;
        case 513: _t->setBand5AttackTime(*reinterpret_cast<double*>(_v)); break;
        case 516: _t->setBand6AttackTime(*reinterpret_cast<double*>(_v)); break;
        case 519: _t->setBand7AttackTime(*reinterpret_cast<double*>(_v)); break;
        case 522: _t->setBand0ReleaseThreshold(*reinterpret_cast<double*>(_v)); break;
        case 525: _t->setBand1ReleaseThreshold(*reinterpret_cast<double*>(_v)); break;
        case 528: _t->setBand2ReleaseThreshold(*reinterpret_cast<double*>(_v)); break;
        case 531: _t->setBand3ReleaseThreshold(*reinterpret_cast<double*>(_v)); break;
        case 534: _t->setBand4ReleaseThreshold(*reinterpret_cast<double*>(_v)); break;
        case 537: _t->setBand5ReleaseThreshold(*reinterpret_cast<double*>(_v)); break;
        case 540: _t->setBand6ReleaseThreshold(*reinterpret_cast<double*>(_v)); break;
        case 543: _t->setBand7ReleaseThreshold(*reinterpret_cast<double*>(_v)); break;
        case 546: _t->setBand0ReleaseTime(*reinterpret_cast<double*>(_v)); break;
        case 549: _t->setBand1ReleaseTime(*reinterpret_cast<double*>(_v)); break;
        case 552: _t->setBand2ReleaseTime(*reinterpret_cast<double*>(_v)); break;
        case 555: _t->setBand3ReleaseTime(*reinterpret_cast<double*>(_v)); break;
        case 558: _t->setBand4ReleaseTime(*reinterpret_cast<double*>(_v)); break;
        case 561: _t->setBand5ReleaseTime(*reinterpret_cast<double*>(_v)); break;
        case 564: _t->setBand6ReleaseTime(*reinterpret_cast<double*>(_v)); break;
        case 567: _t->setBand7ReleaseTime(*reinterpret_cast<double*>(_v)); break;
        case 570: _t->setBand0Ratio(*reinterpret_cast<double*>(_v)); break;
        case 573: _t->setBand1Ratio(*reinterpret_cast<double*>(_v)); break;
        case 576: _t->setBand2Ratio(*reinterpret_cast<double*>(_v)); break;
        case 579: _t->setBand3Ratio(*reinterpret_cast<double*>(_v)); break;
        case 582: _t->setBand4Ratio(*reinterpret_cast<double*>(_v)); break;
        case 585: _t->setBand5Ratio(*reinterpret_cast<double*>(_v)); break;
        case 588: _t->setBand6Ratio(*reinterpret_cast<double*>(_v)); break;
        case 591: _t->setBand7Ratio(*reinterpret_cast<double*>(_v)); break;
        case 594: _t->setBand0Knee(*reinterpret_cast<double*>(_v)); break;
        case 597: _t->setBand1Knee(*reinterpret_cast<double*>(_v)); break;
        case 600: _t->setBand2Knee(*reinterpret_cast<double*>(_v)); break;
        case 603: _t->setBand3Knee(*reinterpret_cast<double*>(_v)); break;
        case 606: _t->setBand4Knee(*reinterpret_cast<double*>(_v)); break;
        case 609: _t->setBand5Knee(*reinterpret_cast<double*>(_v)); break;
        case 612: _t->setBand6Knee(*reinterpret_cast<double*>(_v)); break;
        case 615: _t->setBand7Knee(*reinterpret_cast<double*>(_v)); break;
        case 618: _t->setBand0BoostThreshold(*reinterpret_cast<double*>(_v)); break;
        case 621: _t->setBand1BoostThreshold(*reinterpret_cast<double*>(_v)); break;
        case 624: _t->setBand2BoostThreshold(*reinterpret_cast<double*>(_v)); break;
        case 627: _t->setBand3BoostThreshold(*reinterpret_cast<double*>(_v)); break;
        case 630: _t->setBand4BoostThreshold(*reinterpret_cast<double*>(_v)); break;
        case 633: _t->setBand5BoostThreshold(*reinterpret_cast<double*>(_v)); break;
        case 636: _t->setBand6BoostThreshold(*reinterpret_cast<double*>(_v)); break;
        case 639: _t->setBand7BoostThreshold(*reinterpret_cast<double*>(_v)); break;
        case 642: _t->setBand0BoostAmount(*reinterpret_cast<double*>(_v)); break;
        case 645: _t->setBand1BoostAmount(*reinterpret_cast<double*>(_v)); break;
        case 648: _t->setBand2BoostAmount(*reinterpret_cast<double*>(_v)); break;
        case 651: _t->setBand3BoostAmount(*reinterpret_cast<double*>(_v)); break;
        case 654: _t->setBand4BoostAmount(*reinterpret_cast<double*>(_v)); break;
        case 657: _t->setBand5BoostAmount(*reinterpret_cast<double*>(_v)); break;
        case 660: _t->setBand6BoostAmount(*reinterpret_cast<double*>(_v)); break;
        case 663: _t->setBand7BoostAmount(*reinterpret_cast<double*>(_v)); break;
        case 666: _t->setBand0Makeup(*reinterpret_cast<double*>(_v)); break;
        case 669: _t->setBand1Makeup(*reinterpret_cast<double*>(_v)); break;
        case 672: _t->setBand2Makeup(*reinterpret_cast<double*>(_v)); break;
        case 675: _t->setBand3Makeup(*reinterpret_cast<double*>(_v)); break;
        case 678: _t->setBand4Makeup(*reinterpret_cast<double*>(_v)); break;
        case 681: _t->setBand5Makeup(*reinterpret_cast<double*>(_v)); break;
        case 684: _t->setBand6Makeup(*reinterpret_cast<double*>(_v)); break;
        case 687: _t->setBand7Makeup(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DbMultibandCompressor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DbMultibandCompressor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21DbMultibandCompressorE_t>.strings))
        return static_cast<void*>(this);
    return KConfigBaseEE::qt_metacast(_clname);
}

int DbMultibandCompressor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigBaseEE::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 230)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 230;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 230)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 230;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 690;
    }
    return _id;
}

// SIGNAL 0
void DbMultibandCompressor::bypassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DbMultibandCompressor::inputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DbMultibandCompressor::outputGainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DbMultibandCompressor::dryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DbMultibandCompressor::wetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DbMultibandCompressor::viewSidechainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DbMultibandCompressor::externalSidechainEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void DbMultibandCompressor::stereoSplitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void DbMultibandCompressor::compressorModeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void DbMultibandCompressor::compressorModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DbMultibandCompressor::envelopeBoostLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DbMultibandCompressor::envelopeBoostChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void DbMultibandCompressor::inputToSidechainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void DbMultibandCompressor::inputToLinkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void DbMultibandCompressor::sidechainToInputChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void DbMultibandCompressor::sidechainToLinkChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void DbMultibandCompressor::linkToSidechainChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void DbMultibandCompressor::linkToInputChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void DbMultibandCompressor::band1EnableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void DbMultibandCompressor::band2EnableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void DbMultibandCompressor::band3EnableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void DbMultibandCompressor::band4EnableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void DbMultibandCompressor::band5EnableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void DbMultibandCompressor::band6EnableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void DbMultibandCompressor::band7EnableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void DbMultibandCompressor::band1SplitFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void DbMultibandCompressor::band2SplitFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void DbMultibandCompressor::band3SplitFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void DbMultibandCompressor::band4SplitFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void DbMultibandCompressor::band5SplitFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void DbMultibandCompressor::band6SplitFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void DbMultibandCompressor::band7SplitFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void DbMultibandCompressor::sidechainInputDeviceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}

// SIGNAL 33
void DbMultibandCompressor::sidechainTypeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 33, nullptr);
}

// SIGNAL 34
void DbMultibandCompressor::band0SidechainTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 34, nullptr);
}

// SIGNAL 35
void DbMultibandCompressor::band1SidechainTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 35, nullptr);
}

// SIGNAL 36
void DbMultibandCompressor::band2SidechainTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 36, nullptr);
}

// SIGNAL 37
void DbMultibandCompressor::band3SidechainTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 37, nullptr);
}

// SIGNAL 38
void DbMultibandCompressor::band4SidechainTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 38, nullptr);
}

// SIGNAL 39
void DbMultibandCompressor::band5SidechainTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 39, nullptr);
}

// SIGNAL 40
void DbMultibandCompressor::band6SidechainTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 40, nullptr);
}

// SIGNAL 41
void DbMultibandCompressor::band7SidechainTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 41, nullptr);
}

// SIGNAL 42
void DbMultibandCompressor::sidechainModeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 42, nullptr);
}

// SIGNAL 43
void DbMultibandCompressor::band0SidechainModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 43, nullptr);
}

// SIGNAL 44
void DbMultibandCompressor::band1SidechainModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 44, nullptr);
}

// SIGNAL 45
void DbMultibandCompressor::band2SidechainModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 45, nullptr);
}

// SIGNAL 46
void DbMultibandCompressor::band3SidechainModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 46, nullptr);
}

// SIGNAL 47
void DbMultibandCompressor::band4SidechainModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 47, nullptr);
}

// SIGNAL 48
void DbMultibandCompressor::band5SidechainModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 48, nullptr);
}

// SIGNAL 49
void DbMultibandCompressor::band6SidechainModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 49, nullptr);
}

// SIGNAL 50
void DbMultibandCompressor::band7SidechainModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 50, nullptr);
}

// SIGNAL 51
void DbMultibandCompressor::sidechainSourceLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 51, nullptr);
}

// SIGNAL 52
void DbMultibandCompressor::band0SidechainSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 52, nullptr);
}

// SIGNAL 53
void DbMultibandCompressor::band1SidechainSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 53, nullptr);
}

// SIGNAL 54
void DbMultibandCompressor::band2SidechainSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 54, nullptr);
}

// SIGNAL 55
void DbMultibandCompressor::band3SidechainSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 55, nullptr);
}

// SIGNAL 56
void DbMultibandCompressor::band4SidechainSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 56, nullptr);
}

// SIGNAL 57
void DbMultibandCompressor::band5SidechainSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 57, nullptr);
}

// SIGNAL 58
void DbMultibandCompressor::band6SidechainSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 58, nullptr);
}

// SIGNAL 59
void DbMultibandCompressor::band7SidechainSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 59, nullptr);
}

// SIGNAL 60
void DbMultibandCompressor::stereoSplitSourceLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 60, nullptr);
}

// SIGNAL 61
void DbMultibandCompressor::band0StereoSplitSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 61, nullptr);
}

// SIGNAL 62
void DbMultibandCompressor::band1StereoSplitSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 62, nullptr);
}

// SIGNAL 63
void DbMultibandCompressor::band2StereoSplitSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 63, nullptr);
}

// SIGNAL 64
void DbMultibandCompressor::band3StereoSplitSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 64, nullptr);
}

// SIGNAL 65
void DbMultibandCompressor::band4StereoSplitSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 65, nullptr);
}

// SIGNAL 66
void DbMultibandCompressor::band5StereoSplitSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 66, nullptr);
}

// SIGNAL 67
void DbMultibandCompressor::band6StereoSplitSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 67, nullptr);
}

// SIGNAL 68
void DbMultibandCompressor::band7StereoSplitSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 68, nullptr);
}

// SIGNAL 69
void DbMultibandCompressor::band0SidechainLookaheadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 69, nullptr);
}

// SIGNAL 70
void DbMultibandCompressor::band1SidechainLookaheadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 70, nullptr);
}

// SIGNAL 71
void DbMultibandCompressor::band2SidechainLookaheadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 71, nullptr);
}

// SIGNAL 72
void DbMultibandCompressor::band3SidechainLookaheadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 72, nullptr);
}

// SIGNAL 73
void DbMultibandCompressor::band4SidechainLookaheadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 73, nullptr);
}

// SIGNAL 74
void DbMultibandCompressor::band5SidechainLookaheadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 74, nullptr);
}

// SIGNAL 75
void DbMultibandCompressor::band6SidechainLookaheadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 75, nullptr);
}

// SIGNAL 76
void DbMultibandCompressor::band7SidechainLookaheadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 76, nullptr);
}

// SIGNAL 77
void DbMultibandCompressor::band0SidechainReactivityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 77, nullptr);
}

// SIGNAL 78
void DbMultibandCompressor::band1SidechainReactivityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 78, nullptr);
}

// SIGNAL 79
void DbMultibandCompressor::band2SidechainReactivityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 79, nullptr);
}

// SIGNAL 80
void DbMultibandCompressor::band3SidechainReactivityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 80, nullptr);
}

// SIGNAL 81
void DbMultibandCompressor::band4SidechainReactivityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 81, nullptr);
}

// SIGNAL 82
void DbMultibandCompressor::band5SidechainReactivityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 82, nullptr);
}

// SIGNAL 83
void DbMultibandCompressor::band6SidechainReactivityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 83, nullptr);
}

// SIGNAL 84
void DbMultibandCompressor::band7SidechainReactivityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 84, nullptr);
}

// SIGNAL 85
void DbMultibandCompressor::band0SidechainPreampChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 85, nullptr);
}

// SIGNAL 86
void DbMultibandCompressor::band1SidechainPreampChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 86, nullptr);
}

// SIGNAL 87
void DbMultibandCompressor::band2SidechainPreampChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 87, nullptr);
}

// SIGNAL 88
void DbMultibandCompressor::band3SidechainPreampChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 88, nullptr);
}

// SIGNAL 89
void DbMultibandCompressor::band4SidechainPreampChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 89, nullptr);
}

// SIGNAL 90
void DbMultibandCompressor::band5SidechainPreampChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 90, nullptr);
}

// SIGNAL 91
void DbMultibandCompressor::band6SidechainPreampChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 91, nullptr);
}

// SIGNAL 92
void DbMultibandCompressor::band7SidechainPreampChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 92, nullptr);
}

// SIGNAL 93
void DbMultibandCompressor::band0SidechainCustomLowcutFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 93, nullptr);
}

// SIGNAL 94
void DbMultibandCompressor::band1SidechainCustomLowcutFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 94, nullptr);
}

// SIGNAL 95
void DbMultibandCompressor::band2SidechainCustomLowcutFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 95, nullptr);
}

// SIGNAL 96
void DbMultibandCompressor::band3SidechainCustomLowcutFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 96, nullptr);
}

// SIGNAL 97
void DbMultibandCompressor::band4SidechainCustomLowcutFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 97, nullptr);
}

// SIGNAL 98
void DbMultibandCompressor::band5SidechainCustomLowcutFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 98, nullptr);
}

// SIGNAL 99
void DbMultibandCompressor::band6SidechainCustomLowcutFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 99, nullptr);
}

// SIGNAL 100
void DbMultibandCompressor::band7SidechainCustomLowcutFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 100, nullptr);
}

// SIGNAL 101
void DbMultibandCompressor::band0SidechainCustomHighcutFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 101, nullptr);
}

// SIGNAL 102
void DbMultibandCompressor::band1SidechainCustomHighcutFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 102, nullptr);
}

// SIGNAL 103
void DbMultibandCompressor::band2SidechainCustomHighcutFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 103, nullptr);
}

// SIGNAL 104
void DbMultibandCompressor::band3SidechainCustomHighcutFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 104, nullptr);
}

// SIGNAL 105
void DbMultibandCompressor::band4SidechainCustomHighcutFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 105, nullptr);
}

// SIGNAL 106
void DbMultibandCompressor::band5SidechainCustomHighcutFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 106, nullptr);
}

// SIGNAL 107
void DbMultibandCompressor::band6SidechainCustomHighcutFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 107, nullptr);
}

// SIGNAL 108
void DbMultibandCompressor::band7SidechainCustomHighcutFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 108, nullptr);
}

// SIGNAL 109
void DbMultibandCompressor::band0SidechainLowcutFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 109, nullptr);
}

// SIGNAL 110
void DbMultibandCompressor::band1SidechainLowcutFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 110, nullptr);
}

// SIGNAL 111
void DbMultibandCompressor::band2SidechainLowcutFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 111, nullptr);
}

// SIGNAL 112
void DbMultibandCompressor::band3SidechainLowcutFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 112, nullptr);
}

// SIGNAL 113
void DbMultibandCompressor::band4SidechainLowcutFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 113, nullptr);
}

// SIGNAL 114
void DbMultibandCompressor::band5SidechainLowcutFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 114, nullptr);
}

// SIGNAL 115
void DbMultibandCompressor::band6SidechainLowcutFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 115, nullptr);
}

// SIGNAL 116
void DbMultibandCompressor::band7SidechainLowcutFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 116, nullptr);
}

// SIGNAL 117
void DbMultibandCompressor::band0SidechainHighcutFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 117, nullptr);
}

// SIGNAL 118
void DbMultibandCompressor::band1SidechainHighcutFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 118, nullptr);
}

// SIGNAL 119
void DbMultibandCompressor::band2SidechainHighcutFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 119, nullptr);
}

// SIGNAL 120
void DbMultibandCompressor::band3SidechainHighcutFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 120, nullptr);
}

// SIGNAL 121
void DbMultibandCompressor::band4SidechainHighcutFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 121, nullptr);
}

// SIGNAL 122
void DbMultibandCompressor::band5SidechainHighcutFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 122, nullptr);
}

// SIGNAL 123
void DbMultibandCompressor::band6SidechainHighcutFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 123, nullptr);
}

// SIGNAL 124
void DbMultibandCompressor::band7SidechainHighcutFrequencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 124, nullptr);
}

// SIGNAL 125
void DbMultibandCompressor::compressionModeLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 125, nullptr);
}

// SIGNAL 126
void DbMultibandCompressor::band0CompressionModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 126, nullptr);
}

// SIGNAL 127
void DbMultibandCompressor::band1CompressionModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 127, nullptr);
}

// SIGNAL 128
void DbMultibandCompressor::band2CompressionModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 128, nullptr);
}

// SIGNAL 129
void DbMultibandCompressor::band3CompressionModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 129, nullptr);
}

// SIGNAL 130
void DbMultibandCompressor::band4CompressionModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 130, nullptr);
}

// SIGNAL 131
void DbMultibandCompressor::band5CompressionModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 131, nullptr);
}

// SIGNAL 132
void DbMultibandCompressor::band6CompressionModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 132, nullptr);
}

// SIGNAL 133
void DbMultibandCompressor::band7CompressionModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 133, nullptr);
}

// SIGNAL 134
void DbMultibandCompressor::band0CompressorEnableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 134, nullptr);
}

// SIGNAL 135
void DbMultibandCompressor::band1CompressorEnableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 135, nullptr);
}

// SIGNAL 136
void DbMultibandCompressor::band2CompressorEnableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 136, nullptr);
}

// SIGNAL 137
void DbMultibandCompressor::band3CompressorEnableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 137, nullptr);
}

// SIGNAL 138
void DbMultibandCompressor::band4CompressorEnableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 138, nullptr);
}

// SIGNAL 139
void DbMultibandCompressor::band5CompressorEnableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 139, nullptr);
}

// SIGNAL 140
void DbMultibandCompressor::band6CompressorEnableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 140, nullptr);
}

// SIGNAL 141
void DbMultibandCompressor::band7CompressorEnableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 141, nullptr);
}

// SIGNAL 142
void DbMultibandCompressor::band0SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 142, nullptr);
}

// SIGNAL 143
void DbMultibandCompressor::band1SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 143, nullptr);
}

// SIGNAL 144
void DbMultibandCompressor::band2SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 144, nullptr);
}

// SIGNAL 145
void DbMultibandCompressor::band3SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 145, nullptr);
}

// SIGNAL 146
void DbMultibandCompressor::band4SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 146, nullptr);
}

// SIGNAL 147
void DbMultibandCompressor::band5SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 147, nullptr);
}

// SIGNAL 148
void DbMultibandCompressor::band6SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 148, nullptr);
}

// SIGNAL 149
void DbMultibandCompressor::band7SoloChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 149, nullptr);
}

// SIGNAL 150
void DbMultibandCompressor::band0MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 150, nullptr);
}

// SIGNAL 151
void DbMultibandCompressor::band1MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 151, nullptr);
}

// SIGNAL 152
void DbMultibandCompressor::band2MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 152, nullptr);
}

// SIGNAL 153
void DbMultibandCompressor::band3MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 153, nullptr);
}

// SIGNAL 154
void DbMultibandCompressor::band4MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 154, nullptr);
}

// SIGNAL 155
void DbMultibandCompressor::band5MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 155, nullptr);
}

// SIGNAL 156
void DbMultibandCompressor::band6MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 156, nullptr);
}

// SIGNAL 157
void DbMultibandCompressor::band7MuteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 157, nullptr);
}

// SIGNAL 158
void DbMultibandCompressor::band0AttackThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 158, nullptr);
}

// SIGNAL 159
void DbMultibandCompressor::band1AttackThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 159, nullptr);
}

// SIGNAL 160
void DbMultibandCompressor::band2AttackThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 160, nullptr);
}

// SIGNAL 161
void DbMultibandCompressor::band3AttackThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 161, nullptr);
}

// SIGNAL 162
void DbMultibandCompressor::band4AttackThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 162, nullptr);
}

// SIGNAL 163
void DbMultibandCompressor::band5AttackThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 163, nullptr);
}

// SIGNAL 164
void DbMultibandCompressor::band6AttackThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 164, nullptr);
}

// SIGNAL 165
void DbMultibandCompressor::band7AttackThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 165, nullptr);
}

// SIGNAL 166
void DbMultibandCompressor::band0AttackTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 166, nullptr);
}

// SIGNAL 167
void DbMultibandCompressor::band1AttackTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 167, nullptr);
}

// SIGNAL 168
void DbMultibandCompressor::band2AttackTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 168, nullptr);
}

// SIGNAL 169
void DbMultibandCompressor::band3AttackTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 169, nullptr);
}

// SIGNAL 170
void DbMultibandCompressor::band4AttackTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 170, nullptr);
}

// SIGNAL 171
void DbMultibandCompressor::band5AttackTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 171, nullptr);
}

// SIGNAL 172
void DbMultibandCompressor::band6AttackTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 172, nullptr);
}

// SIGNAL 173
void DbMultibandCompressor::band7AttackTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 173, nullptr);
}

// SIGNAL 174
void DbMultibandCompressor::band0ReleaseThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 174, nullptr);
}

// SIGNAL 175
void DbMultibandCompressor::band1ReleaseThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 175, nullptr);
}

// SIGNAL 176
void DbMultibandCompressor::band2ReleaseThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 176, nullptr);
}

// SIGNAL 177
void DbMultibandCompressor::band3ReleaseThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 177, nullptr);
}

// SIGNAL 178
void DbMultibandCompressor::band4ReleaseThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 178, nullptr);
}

// SIGNAL 179
void DbMultibandCompressor::band5ReleaseThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 179, nullptr);
}

// SIGNAL 180
void DbMultibandCompressor::band6ReleaseThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 180, nullptr);
}

// SIGNAL 181
void DbMultibandCompressor::band7ReleaseThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 181, nullptr);
}

// SIGNAL 182
void DbMultibandCompressor::band0ReleaseTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 182, nullptr);
}

// SIGNAL 183
void DbMultibandCompressor::band1ReleaseTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 183, nullptr);
}

// SIGNAL 184
void DbMultibandCompressor::band2ReleaseTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 184, nullptr);
}

// SIGNAL 185
void DbMultibandCompressor::band3ReleaseTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 185, nullptr);
}

// SIGNAL 186
void DbMultibandCompressor::band4ReleaseTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 186, nullptr);
}

// SIGNAL 187
void DbMultibandCompressor::band5ReleaseTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 187, nullptr);
}

// SIGNAL 188
void DbMultibandCompressor::band6ReleaseTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 188, nullptr);
}

// SIGNAL 189
void DbMultibandCompressor::band7ReleaseTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 189, nullptr);
}

// SIGNAL 190
void DbMultibandCompressor::band0RatioChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 190, nullptr);
}

// SIGNAL 191
void DbMultibandCompressor::band1RatioChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 191, nullptr);
}

// SIGNAL 192
void DbMultibandCompressor::band2RatioChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 192, nullptr);
}

// SIGNAL 193
void DbMultibandCompressor::band3RatioChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 193, nullptr);
}

// SIGNAL 194
void DbMultibandCompressor::band4RatioChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 194, nullptr);
}

// SIGNAL 195
void DbMultibandCompressor::band5RatioChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 195, nullptr);
}

// SIGNAL 196
void DbMultibandCompressor::band6RatioChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 196, nullptr);
}

// SIGNAL 197
void DbMultibandCompressor::band7RatioChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 197, nullptr);
}

// SIGNAL 198
void DbMultibandCompressor::band0KneeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 198, nullptr);
}

// SIGNAL 199
void DbMultibandCompressor::band1KneeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 199, nullptr);
}

// SIGNAL 200
void DbMultibandCompressor::band2KneeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 200, nullptr);
}

// SIGNAL 201
void DbMultibandCompressor::band3KneeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 201, nullptr);
}

// SIGNAL 202
void DbMultibandCompressor::band4KneeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 202, nullptr);
}

// SIGNAL 203
void DbMultibandCompressor::band5KneeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 203, nullptr);
}

// SIGNAL 204
void DbMultibandCompressor::band6KneeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 204, nullptr);
}

// SIGNAL 205
void DbMultibandCompressor::band7KneeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 205, nullptr);
}

// SIGNAL 206
void DbMultibandCompressor::band0BoostThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 206, nullptr);
}

// SIGNAL 207
void DbMultibandCompressor::band1BoostThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 207, nullptr);
}

// SIGNAL 208
void DbMultibandCompressor::band2BoostThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 208, nullptr);
}

// SIGNAL 209
void DbMultibandCompressor::band3BoostThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 209, nullptr);
}

// SIGNAL 210
void DbMultibandCompressor::band4BoostThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 210, nullptr);
}

// SIGNAL 211
void DbMultibandCompressor::band5BoostThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 211, nullptr);
}

// SIGNAL 212
void DbMultibandCompressor::band6BoostThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 212, nullptr);
}

// SIGNAL 213
void DbMultibandCompressor::band7BoostThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 213, nullptr);
}

// SIGNAL 214
void DbMultibandCompressor::band0BoostAmountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 214, nullptr);
}

// SIGNAL 215
void DbMultibandCompressor::band1BoostAmountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 215, nullptr);
}

// SIGNAL 216
void DbMultibandCompressor::band2BoostAmountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 216, nullptr);
}

// SIGNAL 217
void DbMultibandCompressor::band3BoostAmountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 217, nullptr);
}

// SIGNAL 218
void DbMultibandCompressor::band4BoostAmountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 218, nullptr);
}

// SIGNAL 219
void DbMultibandCompressor::band5BoostAmountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 219, nullptr);
}

// SIGNAL 220
void DbMultibandCompressor::band6BoostAmountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 220, nullptr);
}

// SIGNAL 221
void DbMultibandCompressor::band7BoostAmountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 221, nullptr);
}

// SIGNAL 222
void DbMultibandCompressor::band0MakeupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 222, nullptr);
}

// SIGNAL 223
void DbMultibandCompressor::band1MakeupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 223, nullptr);
}

// SIGNAL 224
void DbMultibandCompressor::band2MakeupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 224, nullptr);
}

// SIGNAL 225
void DbMultibandCompressor::band3MakeupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 225, nullptr);
}

// SIGNAL 226
void DbMultibandCompressor::band4MakeupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 226, nullptr);
}

// SIGNAL 227
void DbMultibandCompressor::band5MakeupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 227, nullptr);
}

// SIGNAL 228
void DbMultibandCompressor::band6MakeupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 228, nullptr);
}

// SIGNAL 229
void DbMultibandCompressor::band7MakeupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 229, nullptr);
}
QT_WARNING_POP
